@@ -48,9 +48,9 @@
 #include <abinit.h>
 
 #include <support.h>
-#include <visu_object.h>
 #include <visu_gtk.h>
 #include <gtk_main.h>
+#include <gtk_interactive.h>
 #include <gtk_renderingWindowWidget.h>
 #include <extensions/marks.h>
 #include <openGLFunctions/interactive.h>
@@ -81,52 +81,48 @@ enum
   };
 
 static gulong onSpin_id;
-#ifdef HAVE_ABINIT_SYMMETRY
 static AbSymmetry *sym;
-#endif
 static GtkWidget *lblSymName, *lblSymId, *lblSymWarning, *spinTol;
 static GtkWidget *spinNode, *vbox, *vboxSym;
 static guint timeout = 0;
 static VisuInteractive *inter;
 static GtkListStore *symList;
 
-static void onSelection(VisuInteractive *inter,
-                        VisuInteractivePick pick, VisuNode *node0,
+static void onSelection(VisuInteractive *inter, VisuInteractivePick pick,
+                        VisuNodeArray *array, VisuNode *node0,
                         VisuNode *node1, VisuNode *node2, gpointer data);
 static void onSymmetryToggled(GtkToggleButton *toggle, gpointer data);
 static void onSymmetryClicked(GtkButton *button, gpointer data);
 static void onTolChanged(GtkSpinButton *spin, gpointer data);
-static void onVisuDataChanged(VisuObject *visu, VisuData *dataObj, gpointer data);
+static void onVisuDataChanged(VisuUiMain *visu, VisuData *dataObj, gpointer data);
 static void onSpinNode(GtkSpinButton *button, gpointer data);
-static void onPickClickStop(VisuInteractive *inter, gpointer data);
 
-#ifdef HAVE_ABINIT_SYMMETRY
 static gchar* symAnalyse(AbSymmetry *sym, int iSym);
 static void getEquivalents(VisuData *dataObj, VisuNode *node);
 static void updateSymmetries(VisuData *dataObj, gdouble tol);
-#endif
 static void formatSymOperators(GtkTreeViewColumn *column, GtkCellRenderer *cell,
                                GtkTreeModel *model, GtkTreeIter *iter, gpointer data);
 
-GtkWidget* buildTab(VisuUiMain *main _U_, gchar **label,
+GtkWidget* buildTab(VisuUiMain *main, gchar **label,
 		    gchar **help, GtkWidget **radio)
 {
   GtkWidget *wd, *hbox, *bt, *scroll;
   VisuData *data;
   VisuUiRenderingWindow *window;
+  VisuGlNodeScene *scene;
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
 
   window = visu_ui_main_class_getDefaultRendering();
-  data = visu_ui_rendering_window_getData(window);
+  scene = visu_ui_rendering_window_getGlScene(window);
+  data = visu_gl_node_scene_getData(scene);
   g_return_val_if_fail(data, (GtkWidget*)0);
 
   inter = visu_interactive_new(interactive_pick);
-  g_object_ref(G_OBJECT(inter));
-  g_signal_connect(G_OBJECT(inter), "stop",
-		   G_CALLBACK(onPickClickStop), (gpointer)window);
+  g_signal_connect_swapped(G_OBJECT(inter), "stop",
+                           G_CALLBACK(visu_ui_interactive_toggle), (gpointer)0);
   g_signal_connect(G_OBJECT(inter), "node-selection",
-		   G_CALLBACK(onSelection), (gpointer)window);
+		   G_CALLBACK(onSelection), (gpointer)0);
 
   *label = _("Symmetries");
   *help  = g_strdup(ABINIT_SYMMETRIES_INFO);
@@ -139,10 +135,9 @@ GtkWidget* buildTab(VisuUiMain *main _U_, gchar **label,
                                G_TYPE_STRING);
 
   vbox = gtk_vbox_new(FALSE, 0);
+  g_signal_connect_swapped(vbox, "destroy", G_CALLBACK(g_object_unref), inter);
 
-#ifdef HAVE_ABINIT_SYMMETRY
   sym = (AbSymmetry*)0;
-#endif
 
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
@@ -179,7 +174,7 @@ GtkWidget* buildTab(VisuUiMain *main _U_, gchar **label,
 		       " are provided by ABINIT ("
 		       "<span font_desc=\"courier\" color=\"blue\">"
 		       "http://www.abinit.org</span>).</span>"));
-  gtk_misc_set_alignment(GTK_MISC(wd), 1.0, 0.5);
+  gtk_widget_set_halign(wd, 1.0);
   gtk_label_set_use_markup(GTK_LABEL(wd), TRUE);
   gtk_box_pack_end(GTK_BOX(vbox), wd, FALSE, FALSE, 5);
 
@@ -188,27 +183,27 @@ GtkWidget* buildTab(VisuUiMain *main _U_, gchar **label,
   gtk_box_pack_start(GTK_BOX(vboxSym), hbox, FALSE, FALSE, 10);
   wd = gtk_label_new(_("<b>Space group:</b>"));
   gtk_label_set_use_markup(GTK_LABEL(wd), TRUE);
-  gtk_misc_set_padding(GTK_MISC(wd), 10, 0);
+  gtk_widget_set_margin_start(wd, 10);
   gtk_box_pack_start(GTK_BOX(hbox), wd, FALSE, FALSE, 0);
   wd = gtk_label_new(_("<span font_desc=\"courier\" color=\"blue\">"
 		       "http://en.wikipedia.org/wiki/Space_group</span>"));
   gtk_label_set_selectable(GTK_LABEL(wd), TRUE);
   gtk_label_set_use_markup(GTK_LABEL(wd), TRUE);
   gtk_box_pack_end(GTK_BOX(hbox), wd, FALSE, FALSE, 10);
-  wd = gtk_image_new_from_stock(GTK_STOCK_HELP, GTK_ICON_SIZE_MENU);
+  wd = gtk_image_new_from_icon_name("help-browser", GTK_ICON_SIZE_MENU);
   gtk_box_pack_end(GTK_BOX(hbox), wd, FALSE, FALSE, 0);
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vboxSym), hbox, FALSE, FALSE, 0);
   wd = gtk_label_new(_("Crystal system:"));
   gtk_box_pack_start(GTK_BOX(hbox), wd, FALSE, FALSE, 0);
   lblSymName = gtk_label_new("");
-  gtk_misc_set_alignment(GTK_MISC(lblSymName), 0., 0.5);
+  gtk_widget_set_halign(lblSymName, 0.);
   gtk_box_pack_start(GTK_BOX(hbox), lblSymName, TRUE, TRUE, 5);
   wd = gtk_label_new(_("space group:"));
   gtk_box_pack_start(GTK_BOX(hbox), wd, FALSE, FALSE, 0);
   lblSymId = gtk_label_new("");
   gtk_label_set_use_markup(GTK_LABEL(lblSymId), TRUE);
-  gtk_misc_set_alignment(GTK_MISC(lblSymId), 0., 0.5);
+  gtk_widget_set_halign(lblSymId, 0.);
   gtk_box_pack_start(GTK_BOX(hbox), lblSymId, TRUE, TRUE, 5);
   lblSymWarning = gtk_label_new(_("<span color=\"red\">Warning:</span> the Bravais lattice determined from the primitive vectors is more symmetric than the real one obtained from coordinates (printed)."));
   gtk_label_set_use_markup(GTK_LABEL(lblSymWarning), TRUE);
@@ -216,7 +211,7 @@ GtkWidget* buildTab(VisuUiMain *main _U_, gchar **label,
   gtk_label_set_line_wrap_mode(GTK_LABEL(lblSymWarning), PANGO_WRAP_WORD);
   gtk_box_pack_start(GTK_BOX(vboxSym), lblSymWarning, FALSE, FALSE, 0);
   wd = gtk_label_new(_("List of symmetry operations:"));
-  gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
+  gtk_widget_set_halign(wd, 0.);
   gtk_box_pack_start(GTK_BOX(vboxSym), wd, FALSE, FALSE, 3);
   scroll = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
@@ -224,7 +219,6 @@ GtkWidget* buildTab(VisuUiMain *main _U_, gchar **label,
   gtk_box_pack_start(GTK_BOX(vboxSym), scroll, TRUE, TRUE, 0);
   wd = gtk_tree_view_new_with_model(GTK_TREE_MODEL(symList));
   gtk_container_add(GTK_CONTAINER(scroll), wd);
-  gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(wd), TRUE);
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes(_("Id"), renderer,
 						    "text", SYM_ID, NULL);
@@ -253,8 +247,8 @@ GtkWidget* buildTab(VisuUiMain *main _U_, gchar **label,
   /* The interface to choose one atom to select. */
   wd = gtk_label_new(_("<b>Equivalent atoms:</b>"));
   gtk_label_set_use_markup(GTK_LABEL(wd), TRUE);
-  gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
-  gtk_misc_set_padding(GTK_MISC(wd), 10, 0);
+  gtk_widget_set_halign(wd, 0.);
+  gtk_widget_set_margin_start(wd, 10);
   gtk_box_pack_start(GTK_BOX(vboxSym), wd, FALSE, FALSE, 10);
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vboxSym), hbox, FALSE, FALSE, 0);
@@ -270,10 +264,8 @@ GtkWidget* buildTab(VisuUiMain *main _U_, gchar **label,
   gtk_widget_show_all(vbox);
   gtk_widget_hide(lblSymWarning);
     
-  g_signal_connect(VISU_OBJECT_INSTANCE, "dataRendered",
-		   G_CALLBACK(onVisuDataChanged), (gpointer)0);
-
-  onVisuDataChanged((VisuObject*)0, data, (gpointer)0);
+  g_signal_connect(main, "DataFocused", G_CALLBACK(onVisuDataChanged), (gpointer)0);
+  onVisuDataChanged((VisuUiMain*)0, data, (gpointer)0);
 
   return vbox;
 }
@@ -328,17 +320,11 @@ void stopSelect(VisuUiRenderingWindow *window)
   visu_ui_rendering_window_popInteractive(window, inter);
 }
 
-static void onPickClickStop(VisuInteractive *inter _U_, gpointer data _U_)
+static void onSelection(VisuInteractive *inter _U_, VisuInteractivePick pick _U_,
+                        VisuNodeArray *array, VisuNode *node0,
+                        VisuNode *node1 _U_, VisuNode *node2 _U_, gpointer data _U_)
 {
-}
-
-static void onSelection(VisuInteractive *inter _U_,
-                        VisuInteractivePick pick _U_, VisuNode *node0,
-                        VisuNode *node1 _U_, VisuNode *node2 _U_, gpointer data)
-{
-#ifdef HAVE_ABINIT_SYMMETRY
-  getEquivalents(visu_ui_rendering_window_getData(VISU_UI_RENDERING_WINDOW(data)), node0);
-#endif
+  getEquivalents(VISU_DATA(array), node0);
   g_signal_handler_block(G_OBJECT(spinNode), onSpin_id);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinNode), node0->number + 1);
   g_signal_handler_unblock(G_OBJECT(spinNode), onSpin_id);
@@ -352,43 +338,36 @@ static void onSymmetryClicked(GtkButton *button _U_, gpointer spin)
   VisuData *dataObj;
 
   /* Get the current VisuData object. */
-  dataObj = visu_ui_rendering_window_getData(visu_ui_main_class_getDefaultRendering());
+  dataObj = visu_gl_node_scene_getData(visu_ui_rendering_window_getGlScene(visu_ui_main_class_getDefaultRendering()));
 
-#ifdef HAVE_ABINIT_SYMMETRY
   updateSymmetries(dataObj, gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin)));
-#endif
 }
 static void onTolChanged(GtkSpinButton *spin, gpointer data _U_)
 {
   VisuData *dataObj;
 
   /* Get the current VisuData object. */
-  dataObj = visu_ui_rendering_window_getData(visu_ui_main_class_getDefaultRendering());
+  dataObj = visu_gl_node_scene_getData(visu_ui_rendering_window_getGlScene(visu_ui_main_class_getDefaultRendering()));
 
-#ifdef HAVE_ABINIT_SYMMETRY
   updateSymmetries(dataObj, gtk_spin_button_get_value(spin));
-#endif
 }
-static void onVisuDataChanged(VisuObject *visu _U_, VisuData *dataObj,
+static void onVisuDataChanged(VisuUiMain *visu _U_, VisuData *dataObj,
 			      gpointer data _U_)
 {
   VisuNodeArrayIter iter;
 
   gtk_widget_set_sensitive(vbox, (dataObj !=(VisuData*)0));
 
-#ifdef HAVE_ABINIT_SYMMETRY
   updateSymmetries((VisuData*)0, 0);
-#endif
   
   if (dataObj)
     {
-      visu_node_array_iterNew(VISU_NODE_ARRAY(dataObj), &iter);
+      visu_node_array_iter_new(VISU_NODE_ARRAY(dataObj), &iter);
       gtk_spin_button_set_range(GTK_SPIN_BUTTON(spinNode), 0, iter.idMax + 1);
     }
 }
 static void onSpinNode(GtkSpinButton *button, gpointer data _U_)
 {
-  VisuUiRenderingWindow *window;
   VisuData *dataObj;
   VisuNode *node;
 
@@ -396,42 +375,38 @@ static void onSpinNode(GtkSpinButton *button, gpointer data _U_)
     return;
 
   /* Get the current VisuData object. */
-  window = visu_ui_main_class_getDefaultRendering();
-  dataObj = visu_ui_rendering_window_getData(window);
+  dataObj = visu_gl_node_scene_getData(visu_ui_rendering_window_getGlScene(visu_ui_main_class_getDefaultRendering()));
   node = visu_node_array_getFromId(VISU_NODE_ARRAY(dataObj),
                                    (int)gtk_spin_button_get_value(button) - 1);
 
-#ifdef HAVE_ABINIT_SYMMETRY
   getEquivalents(dataObj, node);
-#endif
 }
 static gboolean onRemoveEquivalents(gpointer data _U_)
 {
+  timeout = 0;
   return FALSE;
 }
 
 static void removeEquivalents(gpointer data)
 {
   VisuGlExtMarks *marks;
-  GList *lst;
+  GArray *ids;
 
-  lst = (GList*)data;
+  ids = (GArray*)data;
 
   /* Get the current VisuData object. */
-  marks = visu_ui_rendering_window_getMarks(visu_ui_main_class_getDefaultRendering());
+  marks = visu_gl_node_scene_getMarks(visu_ui_rendering_window_getGlScene(visu_ui_main_class_getDefaultRendering()));
 
-  visu_gl_ext_marks_setHighlightedList(marks, lst, MARKS_STATUS_TOGGLE);
-  g_list_free(lst);
-
-  VISU_REDRAW_FORCE;
+  visu_gl_ext_marks_setHighlight(marks, ids, MARKS_STATUS_TOGGLE);
+  g_array_unref(ids);
 }
-#ifdef HAVE_ABINIT_SYMMETRY
 static void getEquivalents(VisuData *dataObj, VisuNode *node)
 {
+  guint j;
   int i, nSym;
   int *nodes;
+  GArray *ids;
   gboolean found;
-  GList *lst, *tmpLst;
 #if GLIB_MINOR_VERSION > 13
 #define fact 1
 #define G_TIMEOUT_ADD_FULL g_timeout_add_seconds_full
@@ -447,14 +422,17 @@ static void getEquivalents(VisuData *dataObj, VisuNode *node)
   if (ab_symmetry_get_equivalent_atom(sym, &nodes, &nSym, node->number + 1) ==
       AB_NO_ERROR)
     {
-      lst = (GList*)0;
+      ids = g_array_new(FALSE, FALSE, sizeof(guint));
       for (i = 0; i < nSym; i++)
 	{
 	  found = FALSE;
-	  for ( tmpLst = lst; tmpLst && !found; tmpLst = g_list_next(tmpLst))
-	    found = (nodes[i * 4 + 3] == (GPOINTER_TO_INT(tmpLst->data) + 1));
+	  for ( j = 0; j < ids->len && !found; j++)
+	    found = (nodes[i * 4 + 3] == g_array_index(ids, int, j) + 1);
 	  if (!found)
-	    lst = g_list_prepend(lst, GINT_TO_POINTER(nodes[i * 4 + 3] - 1));
+            {
+              j = nodes[i * 4 + 3] - 1;
+              g_array_append_val(ids, j);
+            }
 	}
       g_free(nodes);
 
@@ -463,19 +441,16 @@ static void getEquivalents(VisuData *dataObj, VisuNode *node)
 	g_source_remove(timeout);
 
       /* Set the new highlights. */
-      visu_gl_ext_marks_setHighlightedList
-	(visu_ui_rendering_window_getMarks(visu_ui_main_class_getDefaultRendering()),
-	 lst, MARKS_STATUS_SET);
+      visu_gl_ext_marks_setHighlight
+	(visu_gl_node_scene_getMarks(visu_ui_rendering_window_getGlScene(visu_ui_main_class_getDefaultRendering())),
+	 ids, MARKS_STATUS_SET);
 
       /* Add the new timeout. */
       timeout = G_TIMEOUT_ADD_FULL(G_PRIORITY_DEFAULT, 3 * fact,
-				   onRemoveEquivalents, lst, removeEquivalents);
-      /* lst will be freed in the timeout. */
-				 
-      VISU_REDRAW_FORCE;
+				   onRemoveEquivalents, ids, removeEquivalents);
+      /* ids will be freed in the timeout. */
     }
 }
-#endif
 
 gpointer startThreadSymmetry(gpointer data _U_)
 {
@@ -492,11 +467,10 @@ gpointer startThreadSymmetry(gpointer data _U_)
               (gpointer)g_thread_self());
   dt = abinit_getDt();
 
-#ifdef HAVE_ABINIT_SYMMETRY
   visu_box_getCellMatrix(visu_boxed_getBox(VISU_BOXED(dt->data)), box);
   ab_symmetry_set_lattice(dt->sym, box);
       
-  visu_node_array_iterNew(VISU_NODE_ARRAY(dt->data), &iter);
+  visu_node_array_iter_new(VISU_NODE_ARRAY(dt->data), &iter);
   i = 0;
   typat = g_malloc(sizeof(int) * iter.nAllStoredNodes);
   xred = g_malloc(sizeof(double) * 3 * iter.nAllStoredNodes);
@@ -525,15 +499,13 @@ gpointer startThreadSymmetry(gpointer data _U_)
   if (errno == AB_NO_ERROR || errno == AB_ERROR_SYM_BRAVAIS_XRED)
     g_free(spGrp);
   else if (errno != AB_ERROR_SYM_NOT_PRIMITIVE)
-    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+    dt->error = g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_METHOD,
                             "An error occured in ABINIT plug-in.");
-#endif
   abinit_mutexUnlock();
 
   return (gpointer)0;
 }
 
-#ifdef HAVE_ABINIT_SYMMETRY
 static void updateSymmetries(VisuData *dataObj, gdouble tol)
 {
   double genAfm[3];
@@ -575,8 +547,12 @@ static void updateSymmetries(VisuData *dataObj, gdouble tol)
 #ifdef G_THREADS_ENABLED
       abinit_mutexInit();
       dt->error = (GError*)0;
+#if GLIB_MINOR_VERSION < 32
       ld_thread = g_thread_create(startThreadSymmetry, (gpointer)0,
 				  TRUE, &(dt->error));
+#else
+      ld_thread = g_thread_new(NULL, startThreadSymmetry, (gpointer)0);
+#endif
       DBG_fprintf(stderr, "AB symmetry: run ABINIT symmetry into a thread (%p).\n",
                   (gpointer)ld_thread);
       if (ld_thread)
@@ -677,12 +653,9 @@ static void updateSymmetries(VisuData *dataObj, gdouble tol)
       gtk_label_set_text(GTK_LABEL(lblSymId), "");
     }
 }
-#endif
 
-#ifdef HAVE_ABINIT_SYMMETRY
 static gchar* symAnalyse(AbSymmetry *sym, int iSym)
 {
-#ifdef HAVE_SYM_GET_TYPE
   AbError error;
   int type;
   gchar *label;
@@ -692,7 +665,5 @@ static gchar* symAnalyse(AbSymmetry *sym, int iSym)
   if (error == AB_NO_ERROR)
     return label;
   else
-#endif
     return g_strdup(_("Unknown symmetry"));
 }
-#endif
