@@ -50,7 +50,7 @@
 GtkWidget* buildTab(VisuUiMain *main, gchar **label,
 		    gchar **help, GtkWidget **radio);
 
-void startSelect(VisuRenderingWindow *window);
-void stopSelect(VisuRenderingWindow *window);
+void startSelect(VisuUiRenderingWindow *window);
+void stopSelect(VisuUiRenderingWindow *window);
 
 #endif
