@@ -55,12 +55,8 @@
 #include <openGLFunctions/interactive.h>
 #include <coreTools/toolMatrix.h>
 #include <coreTools/toolPhysic.h>
-#include <renderingMethods/renderingAtomic.h>
-#include <renderingMethods/renderingSpin.h>
 
-#ifdef HAVE_ABINIT_SYMMETRY
 #include "ab_symmetry.h"
-#endif
 
 /* For compatibility with older version. */
 #ifndef AB6_INVARS_STR
@@ -80,6 +76,7 @@
 #define ABINIT_AUTHORS     "Caliste Damien"
 
 /* Local methods */
+#ifdef HAVE_ABINIT_PARSER
 static void abStructuralInit(VisuRendering *method);
 static void abSpinInit(VisuRendering *method);
 static gboolean loadAbinitIn(VisuData *data, const gchar* filename,
@@ -93,6 +90,7 @@ static GError* loadAbinit(VisuData *data, AbInvars *dt, int nSet);
 static gboolean waitDt(gpointer data);
 static void freeDt(gpointer dt);
 static gchar** readPseudoFiles(AbinitData *dt);
+#endif
 
 /* Local variables */
 static gchar *iconPath;
@@ -101,16 +99,17 @@ static gchar *iconPath;
 gboolean abinitInit()
 {
   DBG_fprintf(stderr, "Abinit: loading plug-in 'abinit'...\n");
+  iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "abinit.png", NULL);
 
+#ifdef HAVE_ABINIT_PARSER
   DBG_fprintf(stderr, "Abinit: declare a new rendering load method.\n");
   abStructuralInit(visu_rendering_getByName(VISU_RENDERING_ATOMIC_NAME));
 
   DBG_fprintf(stderr, "Abinit: declare a new spin load method.\n");
   abSpinInit(visu_rendering_getByName(VISU_RENDERING_SPIN_NAME));
 
-  iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "abinit.png", NULL);
-
   ab_mpi_init();
+#endif
 
   return TRUE;
 }
@@ -118,9 +117,7 @@ gboolean abinitInit()
 gboolean abinitInitGtk()
 {
   DBG_fprintf(stderr, "Abinit: declare a new interactive tab.\n");
-#ifdef HAVE_ABINIT_SYMMETRY
   visu_ui_interactive_addAction(buildTab, startSelect, stopSelect);
-#endif
 
   return TRUE;
 }
@@ -140,6 +137,7 @@ const char* abinitGet_icon()
   return iconPath;
 }
 
+#ifdef HAVE_ABINIT_PARSER
 static void abStructuralInit(VisuRendering *method)
 {
 #ifdef HAVE_NEW_WITH_PSEUDO
@@ -153,18 +151,30 @@ static void abStructuralInit(VisuRendering *method)
                                                     type),
                                95, loadAbinitIn);
 }
+#endif
 
 static GMutex *dt_mutex = (GMutex*)0;
 void abinit_mutexInit()
 {
   if (!dt_mutex)
-    dt_mutex = g_mutex_new();
+    {
+#if GLIB_MINOR_VERSION < 32
+      dt_mutex = g_mutex_new();
+#else
+      dt_mutex = g_malloc(sizeof(GMutex));
+      g_mutex_init(dt_mutex);
+#endif
+    }
 }
 void abinit_mutexRelease()
 {
   if (dt_mutex)
     {
+#if GLIB_MINOR_VERSION < 32
       g_mutex_free(dt_mutex);
+#else
+      g_mutex_clear(dt_mutex);
+#endif
       dt_mutex = (GMutex*)0;
     }
 }
@@ -186,6 +196,7 @@ AbinitData* abinit_getDirectDt()
   return &ABINIT_DATA;
 }
 
+#ifdef HAVE_ABINIT_PARSER
 static gboolean loadAbinitIn(VisuData *data, const gchar* filename,
 			     ToolFileFormat *format _U_, int nSet,
                              GCancellable *cancel, GError **error)
@@ -335,7 +346,7 @@ static gboolean waitDt(gpointer data _U_)
 
   DBG_fprintf(stderr, "AB structure: stop waiting, analyse.\n");
   dt->isABFormat = TRUE;
-  if (dt->error && dt->error->code == RENDERING_ERROR_FILE)
+  if (dt->error && dt->error->code == TOOL_FILE_FORMAT_ERROR_FILE)
     {
       dt->isABFormat = FALSE;
       g_error_free(dt->error);
@@ -427,7 +438,7 @@ static gchar** readPseudoFiles(AbinitData *dt)
                   (gpointer)g_thread_self(), (gchar*)lst->data);
       if (!g_file_test((const gchar*)lst->data, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
         {
-          dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+          dt->error = g_error_new(VISU_ERROR_RENDERING, TOOL_FILE_FORMAT_ERROR_FILE,
                                   "Invalid psedo-potential file '%s'.",
                                   (const gchar*)lst->data);
           g_io_channel_shutdown(ioFile, FALSE, NULL);
@@ -453,6 +464,7 @@ static gchar** readPseudoFiles(AbinitData *dt)
 
   return out;
 }
+#endif
 
 void FC_FUNC(wrtout, WRTOUT)(int *unit,char message[500], char mode_paral[4])
 {
@@ -465,7 +477,7 @@ void FC_FUNC(wrtout, WRTOUT)(int *unit,char message[500], char mode_paral[4])
 #ifdef G_THREADS_ENABLED
   if (dt->useSignals && g_async_queue_try_pop(dt->signals))
     {
-      dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_CANCEL,
+      dt->error = g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_CANCEL,
                               "Loading process cancelled.");
       abinit_mutexUnlock();
       g_thread_exit((gpointer)0);
@@ -490,22 +502,22 @@ void FC_FUNC(wrtout, WRTOUT)(int *unit,char message[500], char mode_paral[4])
   ptLen     = strstr(buf, "The number of lines already read from input file=");
   ptMinus   = strstr(buf, "the occurence of a minus sign followed");
   if (ptError && ptInvars0)
-    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+    dt->error = g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_FILE,
                             "Not an ABINIT file (no 'natom' keyword found).");
   else if (ptError && ptInstrng)
-    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+    dt->error = g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_FILE,
                             "Not an ABINIT file (tab characters found in the file).");
   else if (ptError && ptSize)
-    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+    dt->error = g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_FILE,
                             "Not an ABINIT file (input file too long).");
   else if (ptError && ptLen)
-    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+    dt->error = g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_FILE,
                             "Not an ABINIT file (too many lines).");
   else if (ptError && ptMinus)
-    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+    dt->error = g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_FILE,
                             "Not an ABINIT file (minus space error).");
   else if (ptError)
-    dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT, "%s", buf);
+    dt->error = g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_FORMAT, "%s", buf);
   else
     dt->error = (GError*)0;
 
@@ -535,7 +547,7 @@ void FC_FUNC(leave_new, LEAVE_NEW)(char mode_paral[4])
 
   DBG_fprintf(stderr, "AB(%p) main: leave_new(%c%c%c%c)\n", (gpointer)g_thread_self(),
 	      mode_paral[0], mode_paral[1], mode_paral[2], mode_paral[3]);
-  dt->error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FILE,
+  dt->error = g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_FILE,
                           "Not an ABINIT file");
   DBG_fprintf(stderr, "AB(%p) main: return error (%p).\n",
               (gpointer)g_thread_self(), (gpointer)dt->error);
@@ -553,6 +565,7 @@ void FC_FUNC(psp_from_data, PSP_FROM_DATA)()
 {
 }
 
+#ifdef HAVE_ABINIT_PARSER
 static GError* loadAbinit(VisuData *data, AbInvars *dt, int nSet)
 {
   int ndtset, i;
@@ -574,7 +587,7 @@ static GError* loadAbinit(VisuData *data, AbInvars *dt, int nSet)
   /* Ok, try to find the required keywords. */
   error = ab_invars_get_ndtset(dt, &ndtset);
   if (error != AB_NO_ERROR)
-    return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
+    return g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_METHOD,
 		       "Abinit loader report error %d while getting n datasets.",
 		       (int)error);
   DBG_fprintf(stderr, "AB structure: found %d dtsets.\n", ndtset);
@@ -582,18 +595,18 @@ static GError* loadAbinit(VisuData *data, AbInvars *dt, int nSet)
   visu_data_setNSubset(data, ndtset);
 
   g_return_val_if_fail(nSet >= 0 && nSet < ndtset,
-		       g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
+		       g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_METHOD,
 				   "Can't load dataset %d.", nSet));
 
   error = ab_invars_get_integer(dt, AB_INVARS_NTYPAT, nSet + 1, &ntypat);
   if (error != AB_NO_ERROR)
-    return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
+    return g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_METHOD,
 		       "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 		       ab6_error_string_from_id(error),
 		       AB_INVARS_STR(AB_INVARS_NTYPAT));
   error = ab_invars_get_integer(dt, AB_INVARS_NATOM,  nSet + 1, &natom);
   if (error != AB_NO_ERROR)
-    return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
+    return g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_METHOD,
 		       "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 		       ab6_error_string_from_id(error),
 		       AB_INVARS_STR(AB_INVARS_NATOM));
@@ -606,7 +619,7 @@ static GError* loadAbinit(VisuData *data, AbInvars *dt, int nSet)
   if (error != AB_NO_ERROR)
     {
       g_free(typat);
-      return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
+      return g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_METHOD,
 			 "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 			 ab6_error_string_from_id(error),
 			 AB_INVARS_STR(AB_INVARS_TYPAT));
@@ -618,7 +631,7 @@ static GError* loadAbinit(VisuData *data, AbInvars *dt, int nSet)
   if (error != AB_NO_ERROR)
     {
       g_free(typat); g_free(znucl);
-      return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
+      return g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_METHOD,
 			 "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 			 ab6_error_string_from_id(error),
 			 AB_INVARS_STR(AB_INVARS_ZNUCL));
@@ -691,7 +704,7 @@ static GError* loadAbinit(VisuData *data, AbInvars *dt, int nSet)
   if (error != AB_NO_ERROR)
     {
       g_free(ntypes);
-      return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
+      return g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_METHOD,
 			 "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 			 ab_error_string_from_id(error),
 			 AB_INVARS_STR(AB_INVARS_RPRIMD_ORIG));
@@ -703,7 +716,14 @@ static GError* loadAbinit(VisuData *data, AbInvars *dt, int nSet)
   DBG_fprintf(stderr, " |                  ( %f %f %f )\n",
 	      rprimd[2][0], rprimd[2][1], rprimd[2][2]);
   boxObj = visu_box_new_full(rprimd, VISU_BOX_PERIODIC);
-  visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(boxObj), FALSE);
+  if (visu_box_getGeometry(boxObj, VISU_BOX_DXX) == G_MAXFLOAT)
+    {
+      g_free(ntypes);
+      return g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_FORMAT,
+                         _("Abinit loader report error:\n basis-set is degenerated.\n"));
+    }
+
+  visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(boxObj));
   g_object_unref(boxObj);
   
   coord = g_malloc(sizeof(double) * 3 * natom);
@@ -713,7 +733,7 @@ static GError* loadAbinit(VisuData *data, AbInvars *dt, int nSet)
     {
       g_free(ntypes);
       g_free(coord);
-      return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
+      return g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_METHOD,
 			 "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 			 ab6_error_string_from_id(error),
 			 AB_INVARS_STR(AB_INVARS_XRED_ORIG));
@@ -746,7 +766,7 @@ static GError* loadAbinit(VisuData *data, AbInvars *dt, int nSet)
   if (error != AB_NO_ERROR)
     {
       g_free(spinat);
-      return g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_METHOD,
+      return g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_METHOD,
 			 "Abinit loader report error:\n %s\nwhile getting attribute '%s'.",
 			 ab6_error_string_from_id(error),
 			 AB_INVARS_STR(AB_INVARS_SPINAT));
@@ -829,7 +849,7 @@ static gboolean loadAbinitSpin(VisuData *data, const gchar* filename,
                                        freeSpin, newOrCopySpin, (gpointer)0);
 
   g_value_init(&spinValue, G_TYPE_POINTER);
-  visu_node_array_iterNew(VISU_NODE_ARRAY(data), &iter);
+  visu_node_array_iter_new(VISU_NODE_ARRAY(data), &iter);
   for(visu_node_array_iterStartNumber(VISU_NODE_ARRAY(data), &iter); iter.node;
       visu_node_array_iterNextNodeNumber(VISU_NODE_ARRAY(data), &iter))
     {
@@ -855,3 +875,4 @@ static gboolean loadAbinitSpin(VisuData *data, const gchar* filename,
   *error = (GError*)0;
   return TRUE;
 }
+#endif
