@@ -40,15 +40,14 @@
 */
 
 #include <visu_basic.h>
-#include <visu_rendering.h>
-#include <visu_data.h>
+#include <visu_object.h>
 #include <visu_configFile.h>
-#include <renderingMethods/renderingAtomic_ascii.h>
+#include <visu_dataloader.h>
+#include <visu_dataatomic.h>
 #include <coreTools/toolMatrix.h>
 #include <coreTools/toolPhysic.h>
-#include <coreTools/toolConfigFile.h>
+
 #include <extraFunctions/scalarFields.h>
-#include <extraFunctions/extraNode.h>
 #include <extraGtkFunctions/gtk_numericalEntryWidget.h>
 #include <extraGtkFunctions/gtk_elementComboBox.h>
 #include <panelModules/panelSurfaces.h>
@@ -85,6 +84,7 @@ extern void FC_FUNC_(memocc_report, MEMOCC_REPORT)();
 /* Local variables */
 static gchar *iconPath;
 static VisuScalarFieldMethod *fmtBigDFT;
+static VisuDataLoader *wvlLoader = NULL;
 static gboolean isPanelInitialised;
 static gboolean useCGrid, useFGrid, useLoadWithGrid;
 static GtkWidget *lblCGrid, *lblFGrid;
@@ -103,15 +103,13 @@ static gboolean disableCallbacks;
 /* Local methods. */
 static void updateGridLabels(VisuData *dataObj);
 static void initialisePanel(VisuUiPanel *panel);
-static gboolean loadBigDFTIn(VisuData *data, const gchar* filename,
-                             ToolFileFormat *format, int nSet,
+static gboolean loadBigDFTIn(VisuDataLoader *self, const gchar* filename,
+                             VisuData *data, guint nSet,
                              GCancellable *cancel, GError **error);
 static void update_memory_estimation(VisuData *data);
 static int redirect_init(int out_pipe[2]);
 static void redirect_dump(int out_pipe[2], int stdout_fileno_old);
-static void exportParameters(GString *data, VisuData *dataObj, VisuGlView *view);
-static gboolean readUseBigDFT(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
-                              VisuData *dataObj, VisuGlView *view, GError **error);
+static void exportParameters(GString *data, VisuData *dataObj);
 
 /* Callbacks. */
 static gboolean onFieldChooserHook(GSignalInvocationHint *ihint, guint nvalues,
@@ -149,9 +147,9 @@ gboolean bigdftplugInit()
                                            bigdftDensityLoad, G_PRIORITY_HIGH - 4);
   tool_file_format_setValidator(TOOL_FILE_FORMAT(fmtBigDFT), bigdftTestWaveFile);
 
-  fmtWvl = tool_file_format_new(_("BigDFT wavelet boxes"), typeWvl);
-  visu_rendering_addFileFormat(visu_rendering_getByName(VISU_RENDERING_ATOMIC_NAME), 0,
-                               fmtWvl, 22, loadBigDFTIn);
+  wvlLoader = visu_data_loader_new(_("BigDFT wavelet boxes"), typeWvl,
+                                    FALSE, loadBigDFTIn, 22);
+  visu_data_atomic_class_addLoader(wvlLoader);
   tool_file_format_addPropertyDouble(fmtWvl, "hx", _("Hgrid along x"), 0.45);
   tool_file_format_addPropertyDouble(fmtWvl, "hy", _("Hgrid along y"), 0.45);
   tool_file_format_addPropertyDouble(fmtWvl, "hz", _("Hgrid along z"), 0.45);
@@ -192,13 +190,13 @@ gboolean bigdftplugInit()
   bdft_system_init();
 
   visu_config_file_addKnownTag("bigdft");
-  resourceEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
-					  FLAG_PARAMETER_BIGDFT,
-					  DESC_PARAMETER_BIGDFT,
-					  1, readUseBigDFT);
+  resourceEntry = visu_config_file_addBooleanEntry(VISU_CONFIG_FILE_PARAMETER,
+                                                   FLAG_PARAMETER_BIGDFT,
+                                                   DESC_PARAMETER_BIGDFT,
+                                                   &useLoadWithGrid, FALSE);
   visu_config_file_entry_setVersion(resourceEntry, 3.7f);
   visu_config_file_addExportFunction(VISU_CONFIG_FILE_PARAMETER,
-                                    exportParameters);
+                                     exportParameters);
 
   return TRUE;
 }
@@ -213,7 +211,7 @@ gboolean bigdftplugInitGtk()
   g_signal_connect(G_OBJECT(panelBigDFT), "page-entered",
 		   G_CALLBACK(onPanelEnter), (gpointer)0);
 
-  g_signal_add_emission_hook(g_signal_lookup("validate", VISU_UI_TYPE_FIELD_CHOOSER),
+  g_signal_add_emission_hook(g_signal_lookup("validate", VISU_TYPE_UI_FIELD_CHOOSER),
                              0, onFieldChooserHook, (gpointer)0, (GDestroyNotify)0);
 
   return TRUE;
@@ -587,7 +585,7 @@ static gboolean bigdftDensityLoad(VisuScalarFieldMethod *meth, const gchar *file
       box[1][1] = h[1] * n[1];
       box[2][2] = h[2] * n[2];
       boxObj = visu_box_new_full(box, VISU_BOX_PERIODIC);
-      visu_boxed_setBox(VISU_BOXED(field), VISU_BOXED(boxObj), FALSE);
+      visu_boxed_setBox(VISU_BOXED(field), VISU_BOXED(boxObj));
       g_object_unref(boxObj);
       visu_scalar_field_setGridSize(field, n);
       DBG_fprintf(stderr, "BigDFT: transfer density into field object.\n");
@@ -916,8 +914,8 @@ void bigdft_show_grid(VisuData *dataObj, GArray *grid, const gchar *gG, guint id
 }
 
 /* Structural loading. */
-static gboolean loadBigDFTIn(VisuData *data, const gchar* filename,
-                             ToolFileFormat *format, int nSet _U_,
+static gboolean loadBigDFTIn(VisuDataLoader *self, const gchar* filename,
+                             VisuData *data, guint nSet _U_,
                              GCancellable *cancel _U_, GError **error)
 {
   BigDFT_Locreg *glr;
@@ -936,6 +934,7 @@ static gboolean loadBigDFTIn(VisuData *data, const gchar* filename,
   gchar *dirname, *cwd;
   gboolean newAt;
   VisuBox *boxObj;
+  VisuNodeValuesString *labels;
 
   /* gboolean valid; */
   /* BigDFT_LocregIter iter; */
@@ -1001,12 +1000,12 @@ static gboolean loadBigDFTIn(VisuData *data, const gchar* filename,
     }
   
   /* We get some input parameters. */
-  ixc = GET_OPT_INT(format, "ixc");
-  h[0] = GET_OPT_DBL(format, "hx");
-  h[1] = GET_OPT_DBL(format, "hy");
-  h[2] = GET_OPT_DBL(format, "hz");
-  crmult = GET_OPT_DBL(format, "crmult");
-  frmult = GET_OPT_DBL(format, "frmult");
+  ixc = GET_OPT_INT(self, "ixc");
+  h[0] = GET_OPT_DBL(self, "hx");
+  h[1] = GET_OPT_DBL(self, "hy");
+  h[2] = GET_OPT_DBL(self, "hz");
+  crmult = GET_OPT_DBL(self, "crmult");
+  frmult = GET_OPT_DBL(self, "frmult");
 
   /* We set up the population. */
   eles = g_array_sized_new(FALSE, FALSE, sizeof(VisuElement*), atoms->ntypes);
@@ -1102,7 +1101,7 @@ static gboolean loadBigDFTIn(VisuData *data, const gchar* filename,
       grid[1] = glr->n[1] + 1;
       grid[2] = glr->n[2] + 1;
     }
-  visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(boxObj), FALSE);
+  visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(boxObj));
   g_object_unref(boxObj);
   visu_box_setMargin(boxObj, visu_node_array_getMaxElementSize(VISU_NODE_ARRAY(data)) +
                      visu_data_getAllNodeExtens(data, boxObj), TRUE);
@@ -1180,10 +1179,11 @@ static gboolean loadBigDFTIn(VisuData *data, const gchar* filename,
   g_free(fgrid);
 
   /* Possible label. */
-  visu_extra_node_addLabel(data);
+  labels = visu_data_getNodeLabels(data);
   for (i = 0; i < atoms->nat; i++)
-    visu_extra_node_setLabel(data, i,
-                       bigdft_atoms_get_extra_as_label(BIGDFT_ATOMS(wf->lzd), i));
+    visu_node_values_string_setAt
+      (labels, visu_node_array_getFromId(VISU_NODE_ARRAY(data), i),
+       bigdft_atoms_get_extra_as_label(BIGDFT_ATOMS(wf->lzd), i));
 
   return TRUE;
 }
@@ -1464,18 +1464,7 @@ static void redirect_dump(int out_pipe[2], int stdout_fileno_old)
 #endif
 }
 
-static gboolean readUseBigDFT(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
-                              VisuData *dataObj _U_, VisuGlView *view _U_,
-                              GError **error)
-{
-  g_return_val_if_fail(nbLines == 1, FALSE);
-
-  if (!tool_config_file_readBoolean(lines[0], position, &useLoadWithGrid, 1, error))
-    return FALSE;
-
-  return TRUE;
-}
-static void exportParameters(GString *data, VisuData *dataObj _U_, VisuGlView *view _U_)
+static void exportParameters(GString *data, VisuData *dataObj _U_)
 {
   g_string_append_printf(data, "# %s\n", DESC_PARAMETER_BIGDFT);
   g_string_append_printf(data, "%s[bigdft]: %d\n\n", FLAG_PARAMETER_BIGDFT,
