@@ -80,7 +80,7 @@ static GtkListStore *orbsd_kpt, *orbsd_spu, *orbsd_spd;
 typedef struct _StoredWfData
 {
   gulong signal;
-  const VisuSurfaces *surf;
+  const VisuSurface *surf;
 } StoredWfData;
 enum
   {
@@ -507,12 +507,12 @@ static void onGetSCF(GtkButton *bt _U_, gpointer user_data)
   gchar *lbl, *str;
   double box[3][3];
   float shift[3];
-  guint kind, istep, ikpt, iorb, ispin, nspinor, psiSize, i, nsurf;
-  const VisuSurfaces *surf;
+  guint kind, istep, ikpt, iorb, ispin, nspinor, psiSize, i;
+  const VisuSurface *surf;
   float *isoValues;
   VisuData *dataObj;
   StoredWfData *dt;
-  const gchar **names;
+  const gchar *names;
   VisuBox *boxObj;
 
   if (!gtk_tree_selection_get_selected
@@ -526,7 +526,7 @@ static void onGetSCF(GtkButton *bt _U_, gpointer user_data)
   gtk_tree_model_get(model, &iter, SCF_TYPE, &kind, -1);
 
   dt = (StoredWfData*)0;
-  surf = (const VisuSurfaces*)0;
+  surf = (const VisuSurface*)0;
   switch (kind)
     {
     case SCF_TYPE_WF:
@@ -568,7 +568,7 @@ static void onGetSCF(GtkButton *bt _U_, gpointer user_data)
       dt = (StoredWfData*)g_object_get_data(G_OBJECT(dataObj), "BigDFT_storedWf");
       surf = (dt)?dt[ikpt * BIGDFT_ORBS(wf)->norb + iorb +
                      ((ispin == BIGDFT_SPIN_DOWN)?BIGDFT_ORBS(wf)->norbu:0)].surf:
-        (const VisuSurfaces*)0;
+        (const VisuSurface*)0;
       break;
     case SCF_TYPE_V_EXT:
       gtk_tree_model_get(model, &iter, SCF_OBJECT, &denspot, SCF_GLR, &glr, -1);
@@ -601,7 +601,7 @@ static void onGetSCF(GtkButton *bt _U_, gpointer user_data)
       box[1][1] = glr->h[1] * glr->ni[1] * 0.5;
       box[2][2] = glr->h[2] * glr->ni[2] * 0.5;
       boxObj = visu_box_new_full(box, (BIGDFT_ATOMS(glr)->geocode != 'F')?VISU_BOX_PERIODIC:VISU_BOX_FREE);
-      visu_boxed_setBox(VISU_BOXED(field), VISU_BOXED(boxObj), FALSE);
+      visu_boxed_setBox(VISU_BOXED(field), VISU_BOXED(boxObj));
       g_object_unref(boxObj);
       visu_scalar_field_setGridSize(field, glr->ni);
       shift[0] = glr->h[0] * (glr->ni[0] - 2 * glr->n[0] - 2) * 0.25 -
@@ -619,21 +619,17 @@ static void onGetSCF(GtkButton *bt _U_, gpointer user_data)
       wrap->len = glr->ni[0] * glr->ni[1] * glr->ni[2];
       visu_scalar_field_setData(field, wrap, TRUE);
       g_array_free(wrap, FALSE);
+      visu_scalarfield_set_add(visu_scalarfield_set_getDefault(), lbl, field);
       visu_ui_panel_surfaces_setUsed(TRUE);
-      visu_ui_panel_surfaces_addField(field, &iter);
       if (surf)
         {
-          isoValues = visu_surfaces_getPropertyFloat((VisuSurfaces*)surf,
-                                                   VISU_SURFACES_PROPERTY_POTENTIAL);
-          nsurf = (guint)visu_surfaces_getN((VisuSurfaces*)surf);
-          names = g_malloc(sizeof(char*) * nsurf);
-          for (i = 0; i < nsurf; i++)
-            names[i] = visu_surfaces_getName((VisuSurfaces*)surf, (int)i);
-          visu_ui_panel_surfaces_compute(&iter, isoValues, names, nsurf);
-          g_free(names);
+          isoValues = visu_surface_getPropertyFloat((VisuSurface*)surf,
+                                                   VISU_SURFACE_PROPERTY_POTENTIAL);
+          names = visu_surface_resource_getLabel(visu_surface_getResource((VisuSurface*)surf));
+          visu_ui_panel_surfaces_compute(field, isoValues, &names, 1);
         }
       else
-        surf = visu_ui_panel_surfaces_computeAuto(&iter);
+        visu_ui_panel_surfaces_computeAuto(field);
     }
 
   g_object_unref(G_OBJECT(glr));
