@@ -45,6 +45,7 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 
 #include <Python.h>
 
@@ -87,9 +88,9 @@ static void initialisePython();
 static void initialisePanel(VisuUiPanel *panel);
 static gboolean loadScript(gpointer file);
 static void addInitScript(const gchar *file, gboolean immediate, GtkWindow *parent);
-static void exportParameters(GString *data, VisuData *dataObj, VisuGlView *view);
-static gboolean readInitScripts(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
-                                VisuData *dataObj, VisuGlView *view, GError **error);
+static void exportParameters(GString *data, VisuData *dataObj);
+static gboolean readInitScripts(VisuConfigFileEntry *entry, gchar **lines,
+                                int nbLines, int position, GError **error);
 static void _bufSetText(const gchar *text, GtkTextTag *tag, gboolean error);
 
 /* Callbacks. */
@@ -103,7 +104,9 @@ static gboolean onPyIO(GIOChannel *source, GIOCondition condition, gpointer data
 static void onOutputCleared(GtkToolButton *bt, gpointer data);
 static void onOutputCancel(GtkToolButton *bt, gpointer data);
 static void onOutputGetData(GtkToolButton *bt, gpointer data);
+#if GTK_MAJOR_VERSION >= 3
 static void onVScroll(GtkAdjustment *adj, gpointer data);
+#endif
 static void onInteractiveEntry(GtkEntry *entry, gpointer data);
 static gboolean onKeyPressed(GtkWidget *widget, GdkEventKey *event, gpointer data);
 
@@ -114,6 +117,8 @@ gboolean pythongiInit(void)
   const gchar *file;
   VisuConfigFileEntry *entry;
 
+  DBG_fprintf(stderr, "Plugin PythonGI: initialisation.\n");
+
   iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "pythongi.png", NULL);
 
   initScripts = gtk_list_store_new(N_SCRIPTS, G_TYPE_STRING, G_TYPE_STRING);
@@ -130,12 +135,14 @@ gboolean pythongiInit(void)
   options = commandLineGet_options();
   if (options && (opt = (ToolOption*)g_hash_table_lookup(options, "pyScriptInit")))
     {
+      DBG_fprintf(stderr, "Plugin PythonGI: will run init script.\n");
       initialisePython();
       file = g_value_get_string(tool_option_getValue(opt));
       addInitScript(file, TRUE, (GtkWindow*)0);
     }
   if (options && (opt = (ToolOption*)g_hash_table_lookup(options, "pyScript")))
     {
+      DBG_fprintf(stderr, "Plugin PythonGI: will run py script.\n");
       initialisePython();
       file = g_value_get_string(tool_option_getValue(opt));
       g_idle_add_full(G_PRIORITY_LOW, loadScript, (gpointer)file, NULL);
@@ -145,7 +152,7 @@ gboolean pythongiInit(void)
   entry = visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
                                    FLAG_PARAMETER_INIT_SCRIPTS,
                                    DESC_PARAMETER_INIT_SCRIPTS,
-                                   1, readInitScripts);
+                                    1, readInitScripts);
   visu_config_file_entry_setVersion(entry, 3.7f);
   visu_config_file_addExportFunction(VISU_CONFIG_FILE_PARAMETER,
                                     exportParameters);
@@ -295,11 +302,12 @@ static void initialisePanel(VisuUiPanel *panel)
     }
 
   vbox = gtk_vbox_new(FALSE, 0);
+  gtk_container_set_border_width(GTK_CONTAINER(panel), 5);
   gtk_container_add(GTK_CONTAINER(panel), vbox);
 
   wd = gtk_label_new(_("<b>Scripts loaded on startup</b>"));
   gtk_label_set_use_markup(GTK_LABEL(wd), TRUE);
-  gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
+  gtk_label_set_xalign(GTK_LABEL(wd), 0.);
   gtk_widget_set_name(wd, "label_head");
   gtk_box_pack_start(GTK_BOX(vbox), wd, FALSE, FALSE, 0);
 
@@ -339,35 +347,39 @@ static void initialisePanel(VisuUiPanel *panel)
   gtk_toolbar_set_icon_size(GTK_TOOLBAR(wd), GTK_ICON_SIZE_SMALL_TOOLBAR);
   gtk_box_pack_start(GTK_BOX(hbox), wd, FALSE, FALSE, 0);
 
-  item = gtk_tool_button_new_from_stock(GTK_STOCK_ADD);
+  item = gtk_tool_button_new(NULL, NULL);
+  gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(item), "list-add");
   g_signal_connect(G_OBJECT(item), "clicked",
                    G_CALLBACK(onInitScriptAdded), (gpointer)0);
   gtk_toolbar_insert(GTK_TOOLBAR(wd), item, -1);
-  item = gtk_tool_button_new_from_stock(GTK_STOCK_REMOVE);
+  item = gtk_tool_button_new(NULL, NULL);
+  gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(item), "list-remove");
   g_signal_connect(G_OBJECT(item), "clicked",
                    G_CALLBACK(onInitScriptRemoved), (gpointer)selection);
   gtk_toolbar_insert(GTK_TOOLBAR(wd), item, -1);
-  item = gtk_tool_button_new_from_stock(GTK_STOCK_REFRESH);
+  item = gtk_tool_button_new(NULL, NULL);
+  gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(item), "view-refresh");
   g_signal_connect(G_OBJECT(item), "clicked",
                    G_CALLBACK(onInitScriptReload), (gpointer)selection);
   gtk_toolbar_insert(GTK_TOOLBAR(wd), item, -1);
 
   wd = gtk_label_new(_("<b>Interactive scripting</b>"));
   gtk_label_set_use_markup(GTK_LABEL(wd), TRUE);
-  gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
+  gtk_label_set_xalign(GTK_LABEL(wd), 0.);
   gtk_widget_set_name(wd, "label_head");
   gtk_box_pack_start(GTK_BOX(vbox), wd, FALSE, FALSE, 0);
 
   hbox = gtk_hbox_new(FALSE, 3);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
   wd = gtk_label_new(_("Load:"));
-  gtk_misc_set_padding(GTK_MISC(wd), 5, 0);
+  gtk_widget_set_margin_start(wd, 5);
   gtk_box_pack_start(GTK_BOX(hbox), wd, FALSE, FALSE, 0);
   pyFileChooser = gtk_file_chooser_button_new(_("Choose a Python script"),
 					      GTK_FILE_CHOOSER_ACTION_OPEN);
   addFilters(pyFileChooser);
   gtk_box_pack_start(GTK_BOX(hbox), pyFileChooser, TRUE, TRUE, 0);
-  pyExecute = gtk_button_new_from_stock(GTK_STOCK_EXECUTE);
+  pyExecute = gtk_button_new_from_icon_name("system-run", GTK_ICON_SIZE_SMALL_TOOLBAR);
+  gtk_widget_set_margin_end(pyExecute, 5);
   gtk_widget_set_sensitive(pyExecute, FALSE);
   gtk_box_pack_start(GTK_BOX(hbox), pyExecute, FALSE, FALSE, 0);
 
@@ -391,8 +403,10 @@ static void initialisePanel(VisuUiPanel *panel)
   gtk_text_view_set_editable(GTK_TEXT_VIEW(pyTextView), FALSE);
   gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(pyTextView), FALSE);
   gtk_container_add(GTK_CONTAINER(scrolled), pyTextView);
+#if GTK_MAJOR_VERSION >= 3
   g_signal_connect(G_OBJECT(gtk_scrollable_get_vadjustment(GTK_SCROLLABLE(pyTextView))),
                    "changed", G_CALLBACK(onVScroll), (gpointer)0);
+#endif
 
   wd = gtk_toolbar_new();
   gtk_orientable_set_orientation(GTK_ORIENTABLE(wd), GTK_ORIENTATION_VERTICAL);
@@ -400,24 +414,29 @@ static void initialisePanel(VisuUiPanel *panel)
   gtk_toolbar_set_icon_size(GTK_TOOLBAR(wd), GTK_ICON_SIZE_SMALL_TOOLBAR);
   gtk_box_pack_start(GTK_BOX(hbox), wd, FALSE, FALSE, 0);
 
-  item = gtk_tool_button_new_from_stock(GTK_STOCK_CLEAR);
+  item = gtk_tool_button_new(NULL, NULL);
+  gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(item), "edit-clear");
   g_signal_connect(G_OBJECT(item), "clicked",
                    G_CALLBACK(onOutputCleared), (gpointer)0);
   gtk_toolbar_insert(GTK_TOOLBAR(wd), item, -1);
   gtk_widget_set_tooltip_text(GTK_WIDGET(item), _("Clear Python output."));
-  item = gtk_tool_button_new_from_stock(GTK_STOCK_CANCEL);
+  item = gtk_tool_button_new(NULL, NULL);
+  gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(item), "process-stop");
   gtk_widget_set_sensitive(GTK_WIDGET(item), FALSE);
   g_signal_connect(G_OBJECT(item), "clicked",
                    G_CALLBACK(onOutputCancel), (gpointer)0);
   gtk_toolbar_insert(GTK_TOOLBAR(wd), item, -1);
-  item = gtk_tool_button_new_from_stock(GTK_STOCK_FIND);
+  item = gtk_tool_button_new(NULL, NULL);
+  gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(item), "edit-find");
   gtk_toolbar_insert(GTK_TOOLBAR(wd), item, -1);
   gtk_widget_set_tooltip_text(GTK_WIDGET(item),
                               _("Get the current VisuData object as 'data'"
                                 " variable and the current VisuGlView as 'view'."));
 
   wd = gtk_entry_new();
+#if GTK_MAJOR_VERSION > 3 || (GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION > 1)
   gtk_entry_set_placeholder_text(GTK_ENTRY(wd), _("Python interactive command line"));
+#endif
   g_signal_connect(G_OBJECT(wd), "activate",
                    G_CALLBACK(onInteractiveEntry), (gpointer)0);
   g_signal_connect(G_OBJECT(wd), "key-press-event",
@@ -521,8 +540,8 @@ static void onInitScriptAdded(GtkToolButton *bt _U_, gpointer data _U_)
   parent = visu_ui_panel_getContainerWindow(VISU_UI_PANEL(panelPython));
   dialog = gtk_file_chooser_dialog_new(_("Choose a Python script"), parent,
                                        GTK_FILE_CHOOSER_ACTION_OPEN,
-                                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                                       TOOL_ICON_CANCEL, GTK_RESPONSE_CANCEL,
+                                       TOOL_ICON_OPEN, GTK_RESPONSE_ACCEPT,
                                        NULL);
   addFilters(dialog);
 
@@ -613,11 +632,16 @@ static void onOutputCancel(GtkToolButton *bt _U_, gpointer data _U_)
 static void onOutputGetData(GtkToolButton *bt _U_, gpointer data)
 {
   DBG_fprintf(stderr, "Panel PythonGI: get current data.\n");
-  gtk_entry_set_text(GTK_ENTRY(data), "data = v_sim.UiMainClass.getDefaultRendering().getData()");
+  gtk_entry_set_text(GTK_ENTRY(data), "scene = v_sim.UiMainClass.getDefaultRendering().getGlScene()");
   g_signal_emit_by_name(G_OBJECT(data), "activate");
-  gtk_entry_set_text(GTK_ENTRY(data), "view = v_sim.UiMainClass.getDefaultRendering().getGlView()");
+  gtk_entry_set_text(GTK_ENTRY(data), "data = scene.getData()");
+  g_signal_emit_by_name(G_OBJECT(data), "activate");
+  gtk_entry_set_text(GTK_ENTRY(data), "view = scene.getGlView()");
+  g_signal_emit_by_name(G_OBJECT(data), "activate");
+  gtk_entry_set_text(GTK_ENTRY(data), "selection = v_sim.ui_interactive_pick_getSelection()");
   g_signal_emit_by_name(G_OBJECT(data), "activate");
 }
+#if GTK_MAJOR_VERSION >= 3
 static void onVScroll(GtkAdjustment *adj, gpointer data _U_)
 {
   guint oldUpper;
@@ -630,6 +654,7 @@ static void onVScroll(GtkAdjustment *adj, gpointer data _U_)
   g_object_set_data(G_OBJECT(adj), "old-upper",
                     GINT_TO_POINTER(gtk_adjustment_get_upper(adj)));
 }
+#endif
 static void onInteractiveEntry(GtkEntry *entry, gpointer data _U_)
 {
   _bufSetText("> ", NULL, FALSE);
@@ -660,15 +685,16 @@ static gboolean onKeyPressed(GtkWidget *widget, GdkEventKey *event, gpointer dat
 /**************/
 /* Parameters */
 /**************/
-static gboolean readInitScripts(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position _U_,
-                                VisuData *dataObj _U_, VisuGlView *view _U_,
-                                GError **error _U_)
+static gboolean readInitScripts(VisuConfigFileEntry *entry _U_, gchar **lines,
+                                int nbLines, int position _U_, GError **error _U_)
 {
   gchar **paths;
   guint i;
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
+  DBG_fprintf(stderr, "Plugin PythonGI: initialisation scripts.\n");
+  
   initialisePython();
 
   paths = g_strsplit_set(lines[0], ":\n", 100);
@@ -682,7 +708,7 @@ static gboolean readInitScripts(VisuConfigFileEntry *entry _U_, gchar **lines, i
 
   return TRUE;
 }
-static void exportParameters(GString *data, VisuData *dataObj _U_, VisuGlView *view _U_)
+static void exportParameters(GString *data, VisuData *dataObj _U_)
 {
   gboolean valid;
   GtkTreeIter iter;
