@@ -49,9 +49,8 @@
 
 #include <visu_tools.h>
 #include <visu_basic.h>
-#include <renderingMethods/renderingAtomic.h>
-#include <renderingMethods/renderingAtomic_ascii.h>
-#include <renderingMethods/renderingSpin.h>
+#include <visu_dataloadable.h>
+#include <visu_dataspin.h>
 #include <coreTools/toolMatrix.h>
 #include <coreTools/toolPhysic.h>
 
@@ -62,17 +61,20 @@
 #define XSF_AUTHORS     "Caliste Damien"
 
 /* Local methods */
-static gboolean loadXsfIn(VisuData *data, const gchar* filename,
-			  ToolFileFormat *format, int nSet,
+static gboolean loadXsfIn(VisuDataLoader *self, VisuDataLoadable *data,
+                          guint type, guint nSet,
                           GCancellable *cancel, GError **error);
-static gboolean loadXsfSpin(VisuData *data, const gchar* filename,
-			    ToolFileFormat *format, int nSet,
+static gboolean loadXsfSpin(VisuDataLoader *self, VisuDataLoadable *data,
+                            guint type, guint nSet,
                             GCancellable *cancel, GError **error);
-static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **error);
-static void xsfStructuralInit(VisuRendering *method);
-static void xsfSpinInit(VisuRendering *method);
+static int read_xsf_file(VisuDataLoadable *data, guint type,
+                         int nSet, GError **error);
+static void xsfStructuralInit();
+static void xsfSpinInit();
 /* Local variables */
 static gchar *iconPath;
+static VisuDataLoader *xsfLoader = NULL;
+static VisuDataLoader *spinLoader = NULL;
 
 /* Required methods for a loadable module. */
 gboolean xsfInit()
@@ -80,10 +82,10 @@ gboolean xsfInit()
   DBG_fprintf(stderr, "XSF: loading plug-in 'xsf'...\n");
 
   DBG_fprintf(stderr, "XSF: declare a new rendering load method.\n");
-  xsfStructuralInit(visu_rendering_getByName(VISU_RENDERING_ATOMIC_NAME));
+  xsfStructuralInit();
 
   DBG_fprintf(stderr, "XSF: declare a new spin load method.\n");
-  xsfSpinInit(visu_rendering_getByName(VISU_RENDERING_SPIN_NAME));
+  xsfSpinInit();
 
   iconPath = g_build_filename(V_SIM_PIXMAPS_DIR, "xsf.png", NULL);
 
@@ -108,31 +110,24 @@ const char* xsfGet_icon()
   return iconPath;
 }
 
-static void xsfStructuralInit(VisuRendering *method)
+static void xsfStructuralInit()
 {
   const gchar *type[] = {"*.xsf", "*.axsf", (char*)0};
   
-  visu_rendering_addFileFormat(method, 0,
-                               tool_file_format_new(_("XCrysDen Structure File format"),
-                                                    type),
-                               90, loadXsfIn);
+  xsfLoader = visu_data_loader_new(_("XCrysDen Structure File format"), type,
+                                   FALSE, loadXsfIn, 70);
+  visu_data_atomic_class_addLoader(xsfLoader);
 }
 
-static gboolean loadXsfIn(VisuData *data, const gchar* filename,
-			  ToolFileFormat *format _U_, int nSet,
+static gboolean loadXsfIn(VisuDataLoader *self _U_, VisuDataLoadable *data,
+                          guint type, guint nSet,
                           GCancellable *cancel _U_, GError **error)
 {
   int res;
-  GIOChannel *readFrom;
 
   g_return_val_if_fail(error && *error == (GError*)0, FALSE);
-  g_return_val_if_fail(data && filename, FALSE);
 
-  readFrom = g_io_channel_new_file(filename, "r", error);
-  if (!readFrom)
-    return FALSE;
-
-  res = read_xsf_file(data, readFrom, nSet, error);
+  res = read_xsf_file(data, type, nSet, error);
 
   if (res < 0)
     /* The file is not a XSF file. */
@@ -148,16 +143,16 @@ static gboolean loadXsfIn(VisuData *data, const gchar* filename,
 void xsf_reader_new(struct xsf_reader *rd)
 {
   /* The storage for read line. */
+  rd->flux      = tool_files_new();
   rd->line      = g_string_new("");
 
   /* Storage of number of elements per types. */
-  rd->ntype     = 0;
-  rd->elements  = g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL, g_free);
+  rd->iter      = visu_data_loader_iter_new();
   rd->nodeTypes = (VisuElement**)0;
   rd->bc        = VISU_BOX_FREE;
 
   rd->coords    = (float*)0;
-  rd->forces    = (float*)0;
+  rd->forces    = (GArray*)0;
   /* rd->lst       = (GList*)0; */
 }
 
@@ -165,13 +160,13 @@ void xsf_reader_free(struct xsf_reader *rd)
 {
   /* GList *tmpLst; */
 
-  g_hash_table_destroy(rd->elements);
+  visu_data_loader_iter_unref(rd->iter);
   if (rd->nodeTypes)
     g_free(rd->nodeTypes);
   if (rd->coords)
     g_free(rd->coords);
   if (rd->forces)
-    g_free(rd->forces);
+    g_array_free(rd->forces, TRUE);
   
   /* if (rd->lst) */
   /*   { */
@@ -185,19 +180,16 @@ void xsf_reader_free(struct xsf_reader *rd)
   /*   }   */
 
   g_string_free(rd->line, TRUE);
-  if (g_io_channel_shutdown(rd->flux, FALSE, (GError**)0) != G_IO_STATUS_NORMAL)
-    g_warning("XSF: can't close file.");
-  g_io_channel_unref(rd->flux);
+  if (rd->flux)
+    g_object_unref(rd->flux);
 }
 
 gboolean xsf_reader_skip_comment(struct xsf_reader *rd, GError **error)
 {
-  gsize term;
-
   /* Eat blank or commentary lines. */
   do
     {
-      rd->status = g_io_channel_read_line_string(rd->flux, rd->line, &term, error);
+      rd->status = tool_files_read_line_string(rd->flux, rd->line, NULL, error);
       if (rd->status != G_IO_STATUS_NORMAL && rd->status != G_IO_STATUS_EOF)
 	return FALSE;
       g_strstrip(rd->line->str);
@@ -221,7 +213,7 @@ gboolean xsf_reader_get_flag(struct xsf_reader *rd, gboolean *found, const gchar
     {
       if (mandatory && sscanf(rd->line->str + len, "%d", value) != 1 && *value <= 0)
 	{
-	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+	  *error = g_error_new(VISU_DATA_LOADABLE_ERROR, DATA_LOADABLE_ERROR_FORMAT,
 			       _("Wrong XSF format, '%s' flag has a"
 				 " wrong value.\n"), flag);
 	  return FALSE;
@@ -230,7 +222,7 @@ gboolean xsf_reader_get_flag(struct xsf_reader *rd, gboolean *found, const gchar
 	{
 	  if (*value <= 0)
 	    {
-	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+	      *error = g_error_new(VISU_DATA_LOADABLE_ERROR, DATA_LOADABLE_ERROR_FORMAT,
 				   _("Wrong XSF format, '%s' flag has a"
 				     " wrong value.\n"), flag);
 	      return FALSE;
@@ -275,7 +267,7 @@ gboolean xsf_reader_get_box(struct xsf_reader *rd, double cart[3][3], GError **e
       if (sscanf(rd->line->str, "%lf %lf %lf\n",
 		 cart[i], cart[i] + 1, cart[i] + 2) != 3)
 	{
-	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+	  *error = g_error_new(VISU_DATA_LOADABLE_ERROR, DATA_LOADABLE_ERROR_FORMAT,
 			       _("Wrong XSF format, missing float values"
 				 " after tag '%s'.\n"), "PRIMVEC");
 	  return FALSE;
@@ -298,18 +290,16 @@ static gboolean read_coords(struct xsf_reader *rd, GError **error)
   float rcov, f[3];
   gchar *name, *ptChar;
   VisuElement *type;
-  struct VisuMethAscii *infos;
 
   if (sscanf(rd->line->str, "%d", &rd->nNodes) != 1 && rd->nNodes <= 0)
     {
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+      *error = g_error_new(VISU_DATA_LOADABLE_ERROR, DATA_LOADABLE_ERROR_FORMAT,
 			   _("Wrong XSF format, missing or wrong integer values"
 			     " after tag '%s'.\n"), "PRIMCOORD");
       return FALSE;
     }
   if (!xsf_reader_skip_comment(rd, error))
     return FALSE;
-  rd->ntype     = 0;
   rd->nodeTypes = g_malloc(sizeof(VisuElement*) * rd->nNodes);
   rd->coords    = g_malloc(sizeof(float) * 3 * rd->nNodes);
   DBG_fprintf(stderr, "XSF: read coordinates.\n");
@@ -320,7 +310,7 @@ static gboolean read_coords(struct xsf_reader *rd, GError **error)
       ptChar = strchr(name, ' ');
       if (!ptChar)
 	{
-	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+	  *error = g_error_new(VISU_DATA_LOADABLE_ERROR, DATA_LOADABLE_ERROR_FORMAT,
 			       _("Wrong XSF format, can't read coordinates at line '%s'.\n"),
                                name);
 	  return FALSE;
@@ -332,7 +322,7 @@ static gboolean read_coords(struct xsf_reader *rd, GError **error)
 		  rd->coords + 3 * i + 1, rd->coords + 3 * i + 2, f + 0, f + 1, f + 2);
       if (nb != 3 && nb != 6)
 	{
-	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+	  *error = g_error_new(VISU_DATA_LOADABLE_ERROR, DATA_LOADABLE_ERROR_FORMAT,
 			       _("Wrong XSF format, can't read coordinates from '%s' (only %d read).\n"),
                                ptChar + 1, nb);
 	  return FALSE;
@@ -341,15 +331,13 @@ static gboolean read_coords(struct xsf_reader *rd, GError **error)
 	{
 	  /* If forces where not used, we allocate then now. */
 	  if (!rd->forces)
-	    rd->forces = g_malloc(sizeof(float) * 3 * rd->nNodes);
-          rd->forces[3 * i + 0] = f[0];
-          rd->forces[3 * i + 1] = f[1];
-          rd->forces[3 * i + 2] = f[2];
+            rd->forces = g_array_sized_new(FALSE, FALSE, sizeof(float), rd->nNodes * 3);
+          g_array_insert_vals(rd->forces, 3 * i, f, 3);
 	}
       /* Try to find a z number instead of a name. */
       rcov = -1.f;
       if (sscanf(name, "%d", &zele) == 1 &&
-	  tool_physic_getSymbolFromZ(&ptChar, &rcov, zele))
+	  tool_physic_getSymbolFromZ(&ptChar, &rcov, (float*)0, zele))
 	{
 	  g_free(name);
 	  name = g_strdup(ptChar);
@@ -357,19 +345,7 @@ static gboolean read_coords(struct xsf_reader *rd, GError **error)
       /* adding nomloc to the hashtable */
       type = visu_element_retrieveFromName(name, (gboolean*)0);
       rd->nodeTypes[i] = type;
-      infos = (struct VisuMethAscii*)g_hash_table_lookup(rd->elements,
-						     (gconstpointer)type);
-      if (!infos)
-	{
-	  infos = g_malloc(sizeof(struct VisuMethAscii));
-	  infos->ele = type;
-	  infos->pos = rd->ntype;
-	  infos->nbNodes = 1;
-	  g_hash_table_insert(rd->elements, (gpointer)type, (gpointer)infos);
-	  rd->ntype += 1;
-	}
-      else
-	infos->nbNodes += 1;
+      visu_data_loader_iter_addNode(rd->iter, type);
       if (!xsf_reader_skip_comment(rd, error))
 	return FALSE;
     }
@@ -378,25 +354,27 @@ static gboolean read_coords(struct xsf_reader *rd, GError **error)
 }
 
 
-static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **error)
+static int read_xsf_file(VisuDataLoadable *data, guint type, int nSet, GError **error)
 {
   struct xsf_reader rd;
   gboolean found;
   int valInt;
   double box[3][3];
-  int i;
   int nSets, iNodes;
-  GArray *nattyp, *types;
   VisuBox *boxObj;
   float xyz[3];
 
   /* We read every line that corresponds to this schema : "%s %f %f %f" */
   DBG_fprintf(stderr, "XSF: reading file as an xsf file.\n");
 
-  rd.flux = flux;
-
   xsf_reader_new(&rd);
 
+  if (!tool_files_open(rd.flux, visu_data_loadable_getFilename(data, type), error))
+    {
+      xsf_reader_free(&rd);
+      return -1;
+    }
+  
   /* We read the file completely to find the number of sets of points
      and we store only the one corresponding to @nSet. */
   nSets     = -1;
@@ -425,7 +403,7 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	  DBG_fprintf(stderr, "XSF: found the 'ANIMSTEPS' flag (%d).\n", valInt);
 	  if (nSets > 0)
 	    {
-	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+	      *error = g_error_new(VISU_DATA_LOADABLE_ERROR, DATA_LOADABLE_ERROR_FORMAT,
 				   _("Wrong XSF format, '%s' tag already"
 				     " defined.\n"), "ANIMSTEPS");
 	      xsf_reader_free(&rd);
@@ -447,7 +425,7 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	{
 	  if (rd.bc == VISU_BOX_FREE)
 	    {
-	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+	      *error = g_error_new(VISU_DATA_LOADABLE_ERROR, DATA_LOADABLE_ERROR_FORMAT,
 				   _("Wrong XSF format, primitive vectors found"
 				     " with free boundary conditions.\n"));
 	      xsf_reader_free(&rd);
@@ -477,7 +455,7 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	{
 	  if (rd.bc == VISU_BOX_FREE)
 	    {
-	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+	      *error = g_error_new(VISU_DATA_LOADABLE_ERROR, DATA_LOADABLE_ERROR_FORMAT,
 				   _("Wrong XSF format, primitive coordinates found"
 				     " with free boundary conditions.\n"));
 	      xsf_reader_free(&rd);
@@ -506,7 +484,7 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
 	{
 	  if (rd.bc != VISU_BOX_FREE)
 	    {
-	      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+	      *error = g_error_new(VISU_DATA_LOADABLE_ERROR, DATA_LOADABLE_ERROR_FORMAT,
 				   _("Wrong XSF format, atom coordinates found"
 				     " with free boundary conditions.\n"));
 	      xsf_reader_free(&rd);
@@ -534,58 +512,40 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
     }
   while(rd.status != G_IO_STATUS_EOF && rd.coords == (float*)0);
   
-  DBG_fprintf(stderr, " | found %d types.\n", rd.ntype);
-  if (rd.ntype == 0)
+  /* Begin the storage into VisuData. */
+  if (!visu_data_loader_iter_allocate(rd.iter, VISU_NODE_ARRAY(data)))
     {
       xsf_reader_free(&rd);
       return -1;
     }
 
   /* Allocate the space for the nodes. */
-  types  = g_array_sized_new(FALSE, FALSE, sizeof(VisuElement*), rd.ntype);
-  nattyp = g_array_sized_new(FALSE, FALSE, sizeof(guint), rd.ntype);
-  g_array_set_size(types, rd.ntype);
-  g_array_set_size(nattyp, rd.ntype);
-  g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToType, (gpointer)types);
-  g_hash_table_foreach(rd.elements, (GHFunc)visu_meth_asciiValToNb, (gpointer)nattyp);
+  visu_data_loadable_setNSets(data, nSets);
 
-  DBG_fprintf(stderr, " | begin to transfer data to VisuData.\n");
-  /* Begin the storage into VisuData. */
-  visu_data_setNSubset(data, nSets);
-
-  visu_node_array_allocate(VISU_NODE_ARRAY(data), types, nattyp);
-  DBG_fprintf(stderr, "XSF: there are %d types in this file.\n", rd.ntype);
-  if (DEBUG)
-    for (i = 0; i < rd.ntype; i++)
-      fprintf(stderr, " | %d atom(s) for type %d.\n",
-              g_array_index(nattyp, guint, i), i);
-  g_array_free(nattyp, TRUE);
-  g_array_free(types, TRUE);
-         
-  /* Store the coordinates */
   boxObj = visu_box_new_full(box, rd.bc);
-  visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(boxObj), FALSE);
+  if (visu_box_getGeometry(boxObj, VISU_BOX_DXX) == G_MAXFLOAT)
+    {
+      *error = g_error_new(VISU_DATA_LOADABLE_ERROR, DATA_LOADABLE_ERROR_FORMAT,
+                           _("Wrong XSF format, basis-set is degenerated.\n"));
+      g_object_unref(boxObj);
+      xsf_reader_free(&rd);
+      return 1;
+    }
+  visu_box_setUnit(boxObj, TOOL_UNITS_ANGSTROEM);
+  visu_boxed_setBox(VISU_BOXED(data), VISU_BOXED(boxObj));
   g_object_unref(boxObj);
   for(iNodes = 0; iNodes < rd.nNodes; iNodes++)
     {
       visu_box_convertFullToCell(boxObj, xyz, rd.coords + 3 * iNodes);
-      visu_data_addNodeFromElement(data, rd.nodeTypes[iNodes],
-                                   xyz, FALSE, FALSE);
+      visu_data_addNodeFromElement(VISU_DATA(data), rd.nodeTypes[iNodes],
+                                   xyz, FALSE);
     }
-  visu_box_setMargin(boxObj, visu_node_array_getMaxElementSize(VISU_NODE_ARRAY(data)) +
-                     visu_data_getAllNodeExtens(data, boxObj), TRUE);
-  visu_box_setUnit(boxObj, TOOL_UNITS_ANGSTROEM);
 
   /* We store the forces as a property to be used later by the spin
      loading method. */
   if (rd.forces)
-    {
-      visu_rendering_atomic_setForces(data, rd.forces);
-      g_object_set_data_full(G_OBJECT(data), "XSF_forces",
-			     (gpointer)rd.forces, g_free);
-      /* We nullify the rd.forces pointer to avoid its deletion. */
-      rd.forces = (float*)0;
-    }
+    visu_node_values_vector_set
+      (visu_data_atomic_getForces(VISU_DATA_ATOMIC(data), TRUE), rd.forces);
 
   /* Free the local data. */
   xsf_reader_free(&rd);
@@ -593,96 +553,41 @@ static int read_xsf_file(VisuData *data, GIOChannel *flux, int nSet, GError **er
   return 0;
 }
 
-static void freeSpin(gpointer obj, gpointer data _U_)
-{
-#if GLIB_MINOR_VERSION > 9
-  g_slice_free1(sizeof(float) * 3, obj);
-#else
-  g_free(obj);
-#endif
-}
-static gpointer newOrCopySpin(gconstpointer obj, gpointer data _U_)
-{
-  float *spinData;
-
-#if GLIB_MINOR_VERSION > 9
-  spinData = g_slice_alloc(sizeof(float) * 3);
-#else
-  spinData = g_malloc(sizeof(float) * 3);
-#endif
-  if (obj)
-    memcpy(spinData, obj, sizeof(float) * 3);
-  else
-    memset(spinData, 0, sizeof(float) * 3);
-    
-  return (gpointer)spinData;
-}
-
-static void xsfSpinInit(VisuRendering *method)
+static void xsfSpinInit()
 {
   const gchar *type[] = {"*.xsf", "*.axsf", (char*)0};
 
-  visu_rendering_addFileFormat(method, FILE_KIND_SPIN,
-                               tool_file_format_new(_("XCrysDen Structure File format"),
-                                                    type),
-                               40, loadXsfSpin);
+  spinLoader = visu_data_loader_new(_("XCrysDen Structure File format"), type,
+                                    FALSE, loadXsfSpin, 40);
+  visu_data_spin_class_addLoader(spinLoader);
 }
 
-static void initMaxModulus(VisuElement *ele _U_, GValue *val)
-{
-  DBG_fprintf(stderr, " | init max modulus of val %p.\n", (gpointer)val);
-  g_value_init(val, G_TYPE_FLOAT);
-  g_value_set_float(val, -G_MAXFLOAT);
-}
-
-static gboolean loadXsfSpin(VisuData *data, const gchar* filename,
-			    ToolFileFormat *format _U_, int nSet _U_,
+static gboolean loadXsfSpin(VisuDataLoader *self _U_, VisuDataLoadable *data,
+                            guint type _U_, guint nSet _U_,
                             GCancellable *cancel _U_, GError **error)
 {
-  float *forces, *svgSpinValues;
-  GValueArray *svgMaxSpinModulus;
-  float sph[3], vals[3];
-  VisuNodeProperty *spin;
-  VisuNodeArrayIter iter;
-  GValue spinValue = {0, {{0}, {0}}};
-  GValue *val;
+  VisuNodeValuesVector *forces;
+  VisuNodeValuesIter iter;
+  gboolean valid;
+  float vals[3], *fxyz;
 
   g_return_val_if_fail(error && *error == (GError*)0, FALSE);
-  g_return_val_if_fail(data && filename, FALSE);
 
-  forces = (float*)g_object_get_data(G_OBJECT(data), "XSF_forces");
+  forces = visu_data_atomic_getForces(VISU_DATA_ATOMIC(data), FALSE);
   if (!forces)
     return FALSE;
 
   /* We check that spin and position are the same. */
   /* TODO... */
 
-  /* Create a storage for max values of spin modulus for each element. */
-  svgMaxSpinModulus = visu_node_array_setElementProperty(VISU_NODE_ARRAY(data),
-                                                         VISU_RENDERING_SPIN_MAX_MODULUS_ID,
-                                                         initMaxModulus);
-  spin = visu_node_array_property_newPointer(VISU_NODE_ARRAY(data), VISU_RENDERING_SPIN_VALUES_ID,
-                                       freeSpin, newOrCopySpin, (gpointer)0);
-
-  g_value_init(&spinValue, G_TYPE_POINTER);
-  visu_node_array_iterNew(VISU_NODE_ARRAY(data), &iter);
-  for(visu_node_array_iterStartNumber(VISU_NODE_ARRAY(data), &iter); iter.node;
-      visu_node_array_iterNextNodeNumber(VISU_NODE_ARRAY(data), &iter))
+  for (valid = visu_node_values_iter_new(&iter, ITER_NODES_BY_TYPE, VISU_NODE_VALUES(forces));
+       valid; valid = visu_node_values_iter_next(&iter))
     {
-      visu_box_convertFullToCell(visu_boxed_getBox(VISU_BOXED(data)), vals,
-                                 forces + iter.node->number * 3);
-      tool_matrix_cartesianToSpherical(sph, vals);
-      svgSpinValues = newOrCopySpin(sph, (gpointer)0);
-      g_value_set_pointer(&spinValue, svgSpinValues);
-      visu_node_property_setValue(spin, iter.node, &spinValue);
-      val = g_value_array_get_nth(svgMaxSpinModulus, iter.iElement);
-      g_value_set_float(val, MAX(vals[TOOL_MATRIX_SPHERICAL_MODULUS],
-                                 g_value_get_float(val)));
+      fxyz = (float*)g_value_get_pointer(&iter.value);
+      visu_box_convertFullToCell(visu_boxed_getBox(VISU_BOXED(data)), vals, fxyz);
+      visu_data_spin_setAt(VISU_DATA_SPIN(data), iter.iter.node, vals);
     }
 
-  /* We kill the temporary forces property. */
-  g_free(g_object_steal_data(G_OBJECT(data), "XSF_forces"));
-
   /* Everything is OK. */
   *error = (GError*)0;
   return TRUE;
