@@ -47,19 +47,19 @@
 
 #include <glib.h>
 
-#include <visu_rendering.h>
-#include <extraFunctions/scalarFields.h>
+#include <extraFunctions/sfielddata.h>
 
 /* Local methods. */
-static gboolean xsfDensityLoad(VisuScalarFieldMethod *meth, const gchar *filename,
-                               GList **fieldList, GError **error);
+static gboolean xsfDensityLoad(VisuScalarFieldMethod *meth,
+                               VisuScalarFieldMethodData *data,
+                               GCancellable *cancel, GError **error);
 
 void xsfDensityInit()
 {
   const gchar *type[] = {"*.xsf", "*.axsf", (char*)0};
   
   visu_scalar_field_method_new(_("XCrysDen density file format"),
-                               type, xsfDensityLoad, G_PRIORITY_HIGH - 10);
+                               type, xsfDensityLoad, G_PRIORITY_HIGH - 5);
 }
 
 static gboolean read_values(struct xsf_reader *rd, guint mesh[3],
@@ -93,8 +93,8 @@ static gboolean read_values(struct xsf_reader *rd, guint mesh[3],
           {
             if (sscanf(tokens[j], "%lf", &g_array_index(density, double, i)) != 1)
               {
-                *error = g_error_new(VISU_ERROR_RENDERING,
-                                     RENDERING_ERROR_FORMAT,
+                *error = g_error_new(TOOL_FILE_FORMAT_ERROR,
+                                     TOOL_FILE_FORMAT_ERROR_FORMAT,
                                      _("Wrong XSF format, unreadable float value"
                                        " %d for density.\n"), i);
                 g_strfreev(tokens);
@@ -106,7 +106,7 @@ static gboolean read_values(struct xsf_reader *rd, guint mesh[3],
       g_strfreev(tokens);
       if (!xsf_reader_skip_comment(rd, error))
 	{
-	  *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+	  *error = g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_FORMAT,
 	        	       _("Wrong XSF format, missing density lines.\n"));
           g_array_unref(density);
 	  return FALSE;
@@ -120,7 +120,7 @@ static gboolean read_values(struct xsf_reader *rd, guint mesh[3],
 #endif
   if (rd->status != G_IO_STATUS_NORMAL)
     {
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
+      *error = g_error_new(TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_FORMAT,
 			   _("Wrong XSF format, missing float values"
 			     " for density (%d read, %d awaited).\n"),
 			   i, mesh[0] * mesh[1] * mesh[2]);
@@ -131,9 +131,8 @@ static gboolean read_values(struct xsf_reader *rd, guint mesh[3],
   return TRUE;
 }
 
-static gboolean read_one_density(struct xsf_reader *rd, VisuScalarField **field, GError **error)
+static gboolean read_one_density(struct xsf_reader *rd, VisuScalarFieldData *field, GError **error)
 {
-  VisuScalarField *density;
   VisuBox *boxObj;
   gchar *comment;
   gboolean found;
@@ -143,109 +142,78 @@ static gboolean read_one_density(struct xsf_reader *rd, VisuScalarField **field,
   double box[3][3];
   GArray *values;
 
-  density = visu_scalar_field_new(rd->filename);
-
   /* Read the comment and the flag. */
   comment = g_strdup(rd->line->str);
   g_strstrip(comment);
-  visu_scalar_field_setCommentary(density, comment);
+  visu_scalar_field_setCommentary(VISU_SCALAR_FIELD(field), comment);
   g_free(comment);
   if (!xsf_reader_skip_comment(rd, error))
-    {
-      g_object_unref(density);
-      return FALSE;
-    }
+    return FALSE;
   if (!xsf_reader_get_flag(rd, &found, "BEGIN_DATAGRID_3D", &valInt, FALSE, error))
-    {
-      g_object_unref(density);
-      return FALSE;
-    }
+    return FALSE;
 
   /* Read the mesh size. */
   if (sscanf(rd->line->str, "%u %u %u", mesh, mesh + 1, mesh + 2) != 3)
     {
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-			   _("Wrong XSF format, missing or wrong mesh size"
-			     " after tag '%s'.\n"), "BEGIN_DATAGRID_3D");
-      g_object_unref(density);
+      g_set_error(error, TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_FORMAT,
+                  _("Wrong XSF format, missing or wrong mesh size"
+                    " after tag '%s'.\n"), "BEGIN_DATAGRID_3D");
       return FALSE;
     }
   if (!xsf_reader_skip_comment(rd, error))
-    {
-      g_object_unref(density);
-      return FALSE;
-    }
-  visu_scalar_field_setGridSize(density, mesh);
+    return FALSE;
+  visu_scalar_field_setGridSize(VISU_SCALAR_FIELD(field), mesh);
 
   /* Read the translation. */
   if (sscanf(rd->line->str, "%f %f %f", trans, trans + 1, trans + 2) != 3)
     {
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-			   _("Wrong XSF format, missing or wrong translation definition."));
-      g_object_unref(density);
+      g_set_error(error, TOOL_FILE_FORMAT_ERROR, TOOL_FILE_FORMAT_ERROR_FORMAT,
+                  _("Wrong XSF format, missing or wrong translation definition."));
       return FALSE;
     }
   if (!xsf_reader_skip_comment(rd, error))
-    {
-      g_object_unref(density);
-      return FALSE;
-    }
-  if (ABS(trans[0]) + ABS(trans[1]) + ABS(trans[2]) > 1e-6)
-    {
-      *error = g_error_new(VISU_ERROR_RENDERING, RENDERING_ERROR_FORMAT,
-			   _("Translation in data grid is an unsupported feature of XSF files."));
-      g_object_unref(density);
-      return FALSE;
-    }
+    return FALSE;
+  /* visu_pointset_setTranslation(VISU_POINTSET(field), trans, TRUE); */
 
   /* Read the box. */
   if (!xsf_reader_get_box(rd, box, error))
-    {
-      g_object_unref(density);
-      return FALSE;
-    }
+    return FALSE;
   boxObj = visu_box_new_full(box, VISU_BOX_PERIODIC);
   visu_box_setMargin(boxObj, 0.f, FALSE);
-  visu_boxed_setBox(VISU_BOXED(density), VISU_BOXED(boxObj), FALSE);
+  visu_boxed_setBox(VISU_BOXED(field), VISU_BOXED(boxObj));
   g_object_unref(boxObj);
 
   /* Read the values. */
   if (!read_values(rd, mesh, &values, error))
-    {
-      g_object_unref(density);
-      return FALSE;
-    }
-  DBG_fprintf(stderr, "Cube: transfer density into field object.\n");
-  visu_scalar_field_setData(density, values, FALSE);
+    return FALSE;
+  DBG_fprintf(stderr, "XSF: transfer density into field object.\n");
+  visu_scalar_field_data_set(field, values, VISU_SCALAR_FIELD_DATA_XYZ);
   g_array_unref(values);
 
-  *field = density;
   return TRUE;
 }
 
-static gboolean xsfDensityLoad(VisuScalarFieldMethod *meth _U_, const gchar *filename,
-                               GList **fieldList, GError **error)
+static gboolean xsfDensityLoad(VisuScalarFieldMethod *meth _U_,
+                               VisuScalarFieldMethodData *data,
+                               GCancellable *cancel _U_, GError **error)
 {
   struct xsf_reader rd;
-  gboolean found;
+  gboolean flag;
   int valInt;
-  VisuScalarField *field;
+  VisuScalarFieldData *field;
 
-  g_return_val_if_fail(error && *error == (GError*)0, FALSE);
-  g_return_val_if_fail(filename, FALSE);
-  g_return_val_if_fail(*fieldList == (GList*)0, FALSE);
+  g_return_val_if_fail(data, FALSE);
+  g_return_val_if_fail(!error || *error == (GError*)0, FALSE);
 
   xsf_reader_new(&rd);
 
-  rd.filename = filename;
-  rd.flux = g_io_channel_new_file(filename, "r", error);
-  if (!rd.flux)
+  if (!tool_files_open(rd.flux, visu_scalar_field_method_data_getFilename(data), error))
     {
       xsf_reader_free(&rd);
       return FALSE;
     }
 
-  found = FALSE;
+  field = (VisuScalarFieldData*)0;
   /* We read all the file. */
   if (!xsf_reader_skip_comment(&rd, error))
     {
@@ -255,31 +223,36 @@ static gboolean xsfDensityLoad(VisuScalarFieldMethod *meth _U_, const gchar *fil
   do
     {
       /* If BLOCK_DATAGRID_3D is found, we store the densities. */
-      if (!xsf_reader_get_flag(&rd, &found, "BEGIN_BLOCK_DATAGRID_3D", &valInt, FALSE, error))
+      if (!xsf_reader_get_flag(&rd, &flag, "BEGIN_BLOCK_DATAGRID_3D", &valInt, FALSE, error))
 	{
 	  xsf_reader_free(&rd);
 	  return FALSE;
 	}
-      if (found)
+      if (flag)
         {
 	  DBG_fprintf(stderr, "XSF: found the 'BEGIN_BLOCK_DATAGRID_3D' flag.\n");
-          if (!read_one_density(&rd, &field, error))
+          field = g_object_new(VISU_TYPE_SCALAR_FIELD_DATA, "label", visu_scalar_field_method_data_getFilename(data), NULL);
+          g_object_ref(field);
+          visu_scalar_field_method_data_addField(data, VISU_SCALAR_FIELD(field));
+          visu_scalar_field_method_data_ready(data);
+          if (!read_one_density(&rd, field, error))
             {
+              g_object_unref(field);
               xsf_reader_free(&rd);
               return TRUE;
             }
-          *fieldList = g_list_append(*fieldList, (gpointer)field);
+          g_object_unref(field);
         }
       
       /* We go on. */
       if (!xsf_reader_skip_comment(&rd, error))
 	{
 	  xsf_reader_free(&rd);
-          return found;
+          return field != (VisuScalarFieldData*)0;
 	}
     }
   while(rd.status != G_IO_STATUS_EOF);
 
   xsf_reader_free(&rd);
-  return found;
+  return field != (VisuScalarFieldData*)0;
 }
