@@ -43,16 +43,16 @@
 
 #include <pygobject.h>
 
-static int       planePy_init   (PlanePy *self, PyObject *args, PyObject *kwds);
+static int       planePy_init   (VisuPlanePy *self, PyObject *args, PyObject *kwds);
 static PyObject* planePy_new    (PyTypeObject *type, PyObject *args, PyObject *kwds);
-static void      planePy_free   (PlanePy* self);
+static void      planePy_free   (VisuPlanePy* self);
 static PyObject* planePy_set    (PyObject *obj, PyObject *args, PyObject *kwds);
 static PyObject* planePy_getRGBA(PyObject *obj, PyObject *args);
 
-static PyMethodDef PlanePyMethods[] =
+static PyMethodDef VisuPlanePyMethods[] =
   {
     {"set", (PyCFunction)planePy_set, METH_VARARGS | METH_KEYWORDS,
-     "Change the characteristics of a Plane.\n\n"
+     "Change the characteristics of a VisuPlane.\n\n"
      "Keyword arguments:\n"
      "rgba     (optional) -- a tuple of four floats values between 0 and 1\n"
      "                       describing the RGBA colour of the plane.\n"
@@ -72,11 +72,11 @@ static PyMethodDef PlanePyMethods[] =
      "         describing the RGBA colour of the plane."},
     {NULL, NULL, 0, NULL}
   };
-static PyTypeObject PlanePyType = {
+static PyTypeObject VisuPlanePyType = {
   PyObject_HEAD_INIT(NULL)
   0,                         /*ob_size*/
-  "v_sim.PlanePy",           /*tp_name*/
-  sizeof(PlanePy),           /*tp_basicsize*/
+  "v_sim.VisuPlanePy",           /*tp_name*/
+  sizeof(VisuPlanePy),           /*tp_basicsize*/
   0,                         /*tp_itemsize*/
   (destructor)planePy_free,  /*tp_dealloc*/
   0,                         /*tp_print*/
@@ -101,7 +101,7 @@ static PyTypeObject PlanePyType = {
   0,                         /* tp_weaklistoffset */
   0,                         /* tp_iter */
   0,                         /* tp_iternext */
-  PlanePyMethods,            /* tp_methods */
+  VisuPlanePyMethods,            /* tp_methods */
   0,                         /* tp_members */
   0,                         /* tp_getset */
   0,                         /* tp_base */
@@ -124,19 +124,19 @@ static PyTypeObject PlanePyType = {
 
 
 
-static int planePy_init(PlanePy *self _U_, PyObject *args _U_, PyObject *kwds _U_)
+static int planePy_init(VisuPlanePy *self _U_, PyObject *args _U_, PyObject *kwds _U_)
 {
   return 0;
 }
 static PyObject* planePy_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
-  PlanePy *self;
+  VisuPlanePy *self;
 
-  self = (PlanePy*)type->tp_alloc(type, 0);
+  self = (VisuPlanePy*)type->tp_alloc(type, 0);
   if (self != NULL)
     {
-      DBG_fprintf(stderr, "Visu Python: new Plane object %p.\n", self);
-      self->obj = planeNew_undefined();
+      DBG_fprintf(stderr, "Visu Python: new VisuPlane object %p.\n", self);
+      self->obj = visu_plane_newUndefined();
       if (!self->obj)
 	{
 	  Py_DECREF(self);
@@ -156,9 +156,9 @@ static PyObject* planePy_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 /*   Py_INCREF(self); */
   return (PyObject *)self;
 }
-static void planePy_free(PlanePy* self)
+static void planePy_free(VisuPlanePy* self)
 {
-  DBG_fprintf(stderr, "Visu Python: deallocate a Plane object %p.\n", self);
+  DBG_fprintf(stderr, "Visu Python: deallocate a VisuPlane object %p.\n", self);
 
   if (self->obj)
     g_object_unref(G_OBJECT(self->obj));
@@ -167,7 +167,7 @@ static void planePy_free(PlanePy* self)
 }
 static PyObject* planePy_set(PyObject *obj, PyObject *args, PyObject *kwds)
 {
-  PlanePy *self;
+  VisuPlanePy *self;
   static char *kwlist[] = {"rgba", "normal", "distance",
 			   "rendered", "hide", NULL};
   PyObject *rgbPy = NULL, *vectPy = NULL, *rendered = Py_True;
@@ -177,9 +177,9 @@ static PyObject* planePy_set(PyObject *obj, PyObject *args, PyObject *kwds)
   float dist = -12345.f;
   int res, hide = -2;
 
-  self = (PlanePy*)obj;
+  self = (VisuPlanePy*)obj;
 
-  DBG_fprintf(stderr, "Visu Python: set values for Plane %p object %p.\n",
+  DBG_fprintf(stderr, "Visu Python: set values for VisuPlane %p object %p.\n",
 	      self->obj, obj);
 
   if (! PyArg_ParseTupleAndKeywords(args, kwds, "|O!O!fO!i", kwlist,
@@ -204,15 +204,15 @@ static PyObject* planePy_set(PyObject *obj, PyObject *args, PyObject *kwds)
   if (rgb[0] >= 0.f)
     {
       color = tool_color_addFloatRGBA(rgb, NULL);
-      res = planeSet_color(self->obj, color) || res;
+      res = visu_plane_setColor(self->obj, color) || res;
     }
   if (vect[0] != -123456.f)
-    res = planeSet_normalVector(self->obj, vect) || res;
+    res = visu_plane_setNormalVector(self->obj, vect) || res;
   if (dist != -12345.f)
-    res = planeSet_distanceFromOrigin(self->obj, dist) || res;
-  res = planeSet_rendered(self->obj, (rendered == Py_True)) || res;
+    res = visu_plane_setDistanceFromOrigin(self->obj, dist) || res;
+  res = visu_plane_setRendered(self->obj, (rendered == Py_True)) || res;
   if (hide != -2)
-    res = planeSet_hiddenState(self->obj, hide) || res;
+    res = visu_plane_setHiddenState(self->obj, hide) || res;
 
   if (res)
     {
@@ -228,16 +228,16 @@ static PyObject* planePy_set(PyObject *obj, PyObject *args, PyObject *kwds)
 
 static PyObject* planePy_getRGBA(PyObject *obj, PyObject *args)
 {
-  PlanePy *self;
+  VisuPlanePy *self;
   PyObject *ret;
   ToolColor *color;
 
-  self = (PlanePy*)obj;
+  self = (VisuPlanePy*)obj;
 
-  DBG_fprintf(stderr, "Visu Python: get RGBA for Plane %p object %p.\n",
+  DBG_fprintf(stderr, "Visu Python: get RGBA for VisuPlane %p object %p.\n",
 	      self->obj, obj);
 
-  planeGet_color(self->obj, &color);
+  visu_plane_getColor(self->obj, &color);
   ret = Py_BuildValue("(ffff)", color->rgba[0], color->rgba[1],
 		      color->rgba[2], color->rgba[3]);
   
@@ -247,5 +247,5 @@ static PyObject* planePy_getRGBA(PyObject *obj, PyObject *args)
 
 PyTypeObject* planePyGet_type()
 {
-  return &PlanePyType;
+  return &VisuPlanePyType;
 }
