@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -347,58 +347,25 @@ gboolean tool_config_file_readString(gchar *line, int position, gchar ***values,
   return TRUE;
 }
 /**
- * tool_config_file_readFloatWithElement:
- * @line: string where values are read from ;
- * @position: the number of the line of the config
- *            file which the @line argument is taken from ;
- * @values: allocated area to store read values ;
- * @size: the number of floating point values to be read ;
- * @ele: a pointer to a #VisuElement location ;
- * @error: a location to store a possible reading error.
- *
- * Same as tool_config_file_readFloat() but begins by reading an element
- * at the begining of the line.
- *
- * Returns: TRUE if no error occured.
- */
-gboolean tool_config_file_readFloatWithElement(gchar *line, int position, float *values,
-					 guint size, VisuElement **ele, GError **error)
-{
-  int id;
-  gboolean res;
-  gchar **tokens;
-
-  /* Read @size boolean values from @line. */
-  tokens = g_strsplit_set(line, " \n", TOOL_MAX_LINE_LENGTH);
-  id = 0;
-  res = tool_config_file_readElementFromTokens(tokens, &id, ele, 1, position, error);
-  if (!res)
-    {
-      g_strfreev(tokens);
-      return FALSE;
-    }
-  res = tool_config_file_readFloatFromTokens(tokens, &id, values, size, position, error);
-  g_strfreev(tokens);
-
-  return res;
-}
-/**
- * tool_config_file_readBooleanWithElement:
+ * tool_config_file_readBooleanWithLabel:
  * @line: string where values are read from ;
  * @position: the number of the line of the config
  *            file which the @line argument is taken from ;
  * @values: allocated area to store read values ;
  * @size: the number of boolean values to be read ;
- * @ele: a pointer to a #VisuElement location ;
+ * @label: (allow-none): a location to store a string ;
  * @error: a location to store a possible reading error.
  *
- * Same as tool_config_file_readBoolean() but begins by reading an element
- * at the begining of the line.
+ * Same as tool_config_file_readBoolean() but begins by reading a
+ * string label at the begining of the line and store it in @label. If
+ * @label is %NULL, only booleans are parsed.
+ *
+ * Since: 3.8
  *
  * Returns: TRUE if no error occured.
  */
-gboolean tool_config_file_readBooleanWithElement(gchar *line, int position, gboolean *values,
-					   guint size, VisuElement **ele, GError **error)
+gboolean tool_config_file_readBooleanWithLabel(gchar *line, int position, gboolean *values,
+                                               guint size, gchar **label, GError **error)
 {
   int id;
   gboolean res;
@@ -407,11 +374,21 @@ gboolean tool_config_file_readBooleanWithElement(gchar *line, int position, gboo
   /* Read @size boolean values from @line. */
   tokens = g_strsplit_set(line, " \n", TOOL_MAX_LINE_LENGTH);
   id = 0;
-  res = tool_config_file_readElementFromTokens(tokens, &id, ele, 1, position, error);
-  if (!res)
+  if (label)
     {
-      g_strfreev(tokens);
-      return FALSE;
+      while (tokens[id] && !tokens[id][0]) id++;
+      if (!tokens[id])
+        {
+          *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_MISSING,
+                               _("Parse error at line %d, a label"
+                                 " should appear here but none has been found.\n"),
+                               position);
+          g_strfreev(tokens);
+          return FALSE;
+        }
+      *label = g_strdup(tokens[id]);
+      DBG_fprintf(stderr, "Tool ConfigFile: found a label '%s'.\n", *label);
+      id += 1;
     }
   res = tool_config_file_readBooleanFromTokens(tokens, &id, values, size, position, error);
   g_strfreev(tokens);
@@ -419,98 +396,75 @@ gboolean tool_config_file_readBooleanWithElement(gchar *line, int position, gboo
   return res;
 }
 /**
- * tool_config_file_readStringWithElement:
+ * tool_config_file_readFloatWithLabel:
  * @line: string where values are read from ;
  * @position: the number of the line of the config
  *            file which the @line argument is taken from ;
- * @values: a location to point on a gchar** ;
- * @size: the number of strings to be read ;
- * @ele: a pointer to a #VisuElement location ;
+ * @values: allocated area to store read values ;
+ * @size: the number of float values to be read ;
+ * @label: (allow-none): a location to store a string ;
  * @error: a location to store a possible reading error.
  *
- * Same as tool_config_file_readString() but begins by reading an element
- * at the begining of the line.
+ * Same as tool_config_file_readFloat() but begins by reading a
+ * string label at the begining of the line and store it in @label. If
+ * @label is %NULL, only floats are parsed.
  *
- * Returns: TRUE if no error occured, then @values point on an allocated
- *          memory area that is NULL terminated and that must be freed
- *          with g_strfreev().
+ * Since: 3.8
+ *
+ * Returns: TRUE if no error occured.
  */
-gboolean tool_config_file_readStringWithElement(gchar *line, int position, gchar ***values,
-					  guint size, VisuElement **ele, GError **error)
+gboolean tool_config_file_readFloatWithLabel(gchar *line, int position, gfloat *values,
+                                             guint size, gchar **label, GError **error)
 {
   int id;
   gboolean res;
   gchar **tokens;
 
-  /* Read @size boolean values from @line. */
+  /* Read @size float values from @line. */
   tokens = g_strsplit_set(line, " \n", TOOL_MAX_LINE_LENGTH);
   id = 0;
-  res = tool_config_file_readElementFromTokens(tokens, &id, ele, 1, position, error);
-  if (!res)
+  if (label)
     {
-      g_strfreev(tokens);
-      return FALSE;
+      while (tokens[id] && !tokens[id][0]) id++;
+      if (!tokens[id])
+        {
+          *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_MISSING,
+                               _("Parse error at line %d, a label"
+                                 " should appear here but none has been found.\n"),
+                               position);
+          g_strfreev(tokens);
+          return FALSE;
+        }
+      *label = g_strdup(tokens[id]);
+      DBG_fprintf(stderr, "Tool ConfigFile: found a label '%s'.\n", *label);
+      id += 1;
     }
-  res = tool_config_file_readStringFromTokens(tokens, &id, values, size, position, error);
+  res = tool_config_file_readFloatFromTokens(tokens, &id, values, size, position, error);
   g_strfreev(tokens);
 
   return res;
 }
-/**
- * tool_config_file_readElementFromTokens:
- * @tokens: array of tokens resulting from a call to g_strsplit() with " " as separator ;
- * @position: IN, the position of the beginning in @tokens ; OUT, one token
- *            after the last read ;
- * @values: allocated area to store read values ;
- * @size: the number of #VisuElement to be read ;
- * @lineId: the number of the line of the config
- *          file which the @line argument is taken from ;
- * @error: a location to store a possible reading error.
- *
- * Read @size #VisuElement from @tokens, store them in @values and returns
- * the new head in @tokens.
- *
- * Returns: TRUE if no error occured.
- */
-gboolean tool_config_file_readElementFromTokens(gchar **tokens, int *position, VisuElement **values,
-					  guint size, int lineId, GError **error)
-{
-  guint i, nb;
+/* gboolean tool_config_file_readStringWithElement(gchar *line, int position, gchar ***values, */
+/* 					  guint size, VisuElement **ele, GError **error) */
+/* { */
+/*   int id; */
+/*   gboolean res; */
+/*   gchar **tokens; */
 
-  g_return_val_if_fail(error && (*error == (GError*)0), FALSE);
-  g_return_val_if_fail(values, FALSE);
-  g_return_val_if_fail(tokens && position, FALSE);
-  
-  /* Read @size VisuElement from @tokens. */
-  nb = 0;
-  for (i = *position; tokens[i] && nb < size; i++)
-    {
-      if (tokens[i][0] != '\0')
-	{
-	  values[nb] = visu_element_retrieveFromName(tokens[i], (gboolean*)0);
-	  if (!values[nb])
-	    {
-              *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_BAD_ELEMENT_NAME,
-                                   _("Parse error at line %d, '%s' wrong"
-                                     " element name.\n"), lineId, tokens[i]);
-              *position = i;
-              return FALSE;
-	    }
-	  nb += 1;
-	}
-    }
-  *position = i;
+/*   /\* Read @size boolean values from @line. *\/ */
+/*   tokens = g_strsplit_set(line, " \n", TOOL_MAX_LINE_LENGTH); */
+/*   id = 0; */
+/*   res = tool_config_file_readElementFromTokens(tokens, &id, ele, 1, position, error); */
+/*   if (!res) */
+/*     { */
+/*       g_strfreev(tokens); */
+/*       return FALSE; */
+/*     } */
+/*   res = tool_config_file_readStringFromTokens(tokens, &id, values, size, position, error); */
+/*   g_strfreev(tokens); */
 
-  if (nb != size)
-    {
-      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_MISSING,
-			   _("Parse error at line %d, %d elements"
-			     " should appear here but %d has been found.\n"),
-			   lineId, size, nb);
-      return FALSE;
-    }
-  return TRUE;
-}
+/*   return res; */
+/* } */
 /**
  * tool_config_file_readIntegerFromTokens:
  * @tokens: array of tokens resulting from a call to g_strsplit() with " " as separator ;
@@ -630,3 +584,34 @@ gboolean tool_config_file_clampFloat(float *variable, float value, float min, fl
   return FALSE;
 }
 
+/**
+ * tool_config_file_clampInt:
+ * @variable: a pointer to a storage for the value ;
+ * @value: the value to put in the storage ;
+ * @min: a lower bound ;
+ * @max: a upper bound.
+ *
+ * Integer version o tool_config_file_clampFloat().
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if the value is out of bounds.
+ */
+gboolean tool_config_file_clampInt(int *variable, int value, int min, int max)
+{
+  g_return_val_if_fail(variable, FALSE);
+
+  if (max > min && value > max)
+    {
+      *variable = max;
+      return TRUE;
+    }
+  if (min < max && value < min)
+    {
+      *variable = min;
+      return TRUE;
+    }
+  
+  *variable = value;
+  return FALSE;
+}
