@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -45,6 +45,7 @@
 #include "toolFileFormat.h"
 
 #include <visu_tools.h>
+#include <visu_commandLine.h>
 #include <string.h>
 #include <stdlib.h>
 
@@ -99,6 +100,7 @@ struct _ToolFileFormatPrivate
 {
   /* This is the list of file patterns, for example (*.jpg; *.jpeg; *.jpe). */
   GList *fileType;
+  GList *fileMatchers;
   gboolean ignoreFileType;
   
   /* This is a short text to describe this file format.
@@ -108,15 +110,13 @@ struct _ToolFileFormatPrivate
      of "name ({patterns},)". */
   gchar *labelString;
 
-  /* A vlidating routine for this file format. */
+  /* A validating routine for this file format. */
   ToolFileFormatValidate validate;
 
   /* This is a private field. It enables to add some properties
      to a file format. See fileFormatAdd_property*() and tool_file_format_property_get*()
      to control them. */
   GList *properties;
-
-  gboolean dispose_has_run;
 };
 
 enum {
@@ -126,20 +126,21 @@ enum {
     IGNORE_PROP
 };
 
-static void tool_file_format_dispose (GObject *obj);
 static void tool_file_format_finalize(GObject *obj);
 static void tool_file_format_get_property(GObject* obj, guint property_id,
                                           GValue *value, GParamSpec *pspec);
 static void tool_file_format_set_property(GObject* obj, guint property_id,
                                           const GValue *value, GParamSpec *pspec);
 
-G_DEFINE_TYPE(ToolFileFormat, tool_file_format, G_TYPE_OBJECT)
+static ToolOption* _getProperty(const ToolFileFormat *format, const gchar *name);
+
+G_DEFINE_TYPE_WITH_CODE(ToolFileFormat, tool_file_format, VISU_TYPE_OBJECT,
+                        G_ADD_PRIVATE(ToolFileFormat))
 
 static void tool_file_format_class_init(ToolFileFormatClass *klass)
 {
   DBG_fprintf(stderr, "Tool FileFormat: creating the class of the object.\n");
 
-  G_OBJECT_CLASS(klass)->dispose      = tool_file_format_dispose;
   G_OBJECT_CLASS(klass)->finalize     = tool_file_format_finalize;
   G_OBJECT_CLASS(klass)->set_property = tool_file_format_set_property;
   G_OBJECT_CLASS(klass)->get_property = tool_file_format_get_property;
@@ -154,7 +155,7 @@ static void tool_file_format_class_init(ToolFileFormatClass *klass)
   g_object_class_install_property
     (G_OBJECT_CLASS(klass), NAME_PROP,
      g_param_spec_string("name", _("Name"), _("File format description."), "",
-                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_READABLE));
+                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
   /**
    * ToolFileFormat::label:
    *
@@ -178,9 +179,7 @@ static void tool_file_format_class_init(ToolFileFormatClass *klass)
     (G_OBJECT_CLASS(klass), IGNORE_PROP,
      g_param_spec_boolean("ignore-type", _("Ignore file patterns"),
                           _("Don't restrict file matching to the given patterns."),
-                          FALSE, G_PARAM_WRITABLE | G_PARAM_READABLE));
-
-  g_type_class_add_private(klass, sizeof(ToolFileFormatPrivate));
+                          FALSE, G_PARAM_READWRITE));
 }
 
 static void tool_file_format_init(ToolFileFormat *fmt)
@@ -188,48 +187,30 @@ static void tool_file_format_init(ToolFileFormat *fmt)
   DBG_fprintf(stderr, "Tool FileFormat: initializing new object (%p).\n",
 	      (gpointer)fmt);
 
-  fmt->priv = G_TYPE_INSTANCE_GET_PRIVATE(fmt, TOOL_TYPE_FILE_FORMAT, ToolFileFormatPrivate);
+  fmt->priv = tool_file_format_get_instance_private(fmt);
   fmt->priv->name           = (gchar*)0;
   fmt->priv->fileType       = (GList*)0;
+  fmt->priv->fileMatchers   = (GList*)0;
   fmt->priv->labelString    = (gchar*)0;
   fmt->priv->validate       = (ToolFileFormatValidate)0;
   fmt->priv->properties     = (GList*)0;
   fmt->priv->ignoreFileType = FALSE;
 }
 
-static void tool_file_format_dispose(GObject *obj)
-{
-  DBG_fprintf(stderr, "Tool FileFormat: dispose object %p.\n", (gpointer)obj);
-
-  if (TOOL_FILE_FORMAT(obj)->priv->dispose_has_run)
-    return;
-
-  TOOL_FILE_FORMAT(obj)->priv->dispose_has_run = TRUE;
-  /* Chain up to the parent class */
-  G_OBJECT_CLASS(tool_file_format_parent_class)->dispose(obj);
-}
 static void tool_file_format_finalize(GObject *obj)
 {
   ToolFileFormatPrivate *format;
-  GList *tmpLst;
 
   DBG_fprintf(stderr, "Tool FileFormat: finalize object %p.\n", (gpointer)obj);
 
   format = TOOL_FILE_FORMAT(obj)->priv;
 
-  if (format->name)
-    g_free(format->name);
+  g_free(format->name);
+  g_free(format->labelString);
 
-  if (format->labelString)
-    g_free(format->labelString);
-
-  for (tmpLst = format->fileType; tmpLst; tmpLst = g_list_next(tmpLst))
-    g_free(tmpLst->data);
-  g_list_free(format->fileType);
-
-  for (tmpLst = format->properties; tmpLst; tmpLst = g_list_next(tmpLst))
-    tool_option_free(tmpLst->data);
-  g_list_free(format->properties);
+  g_list_free_full(format->fileType, g_free);
+  g_list_free_full(format->fileMatchers, (GDestroyNotify)g_pattern_spec_free);
+  g_list_free_full(format->properties, (GDestroyNotify)tool_option_free);
 
   /* Chain up to the parent class */
   G_OBJECT_CLASS(tool_file_format_parent_class)->finalize(obj);
@@ -376,10 +357,12 @@ void tool_file_format_addPatterns(ToolFileFormat *fmt, const gchar **patterns)
 {
   gint n;
 
-  g_return_if_fail(IS_TOOL_FILE_FORMAT(fmt));
+  g_return_if_fail(TOOL_IS_FILE_FORMAT(fmt));
 
   for (n = 0; patterns[n]; n++)
     fmt->priv->fileType = g_list_append(fmt->priv->fileType, g_strdup(patterns[n]));
+  g_list_free_full(fmt->priv->fileMatchers, (GDestroyNotify)g_pattern_spec_free);
+  fmt->priv->fileMatchers = (GList*)0;
   _buildLabel(fmt);
 }
 /**
@@ -508,6 +491,21 @@ const gchar* tool_file_format_match(ToolFileFormat *format, const gchar *filenam
   DBG_fprintf(stderr, "%d.\n", (tmpLst != (GList*)0));
   return (tmpLst)?(const gchar*)tmpLst->data:(const gchar*)0;
 }
+static gboolean _validate(ToolFileFormat *format, const gchar *filename)
+{
+  gboolean passed;
+  GList *lst;
+
+  if (!format->priv->fileMatchers)
+    for (lst = format->priv->fileType; lst; lst = g_list_next(lst))
+      format->priv->fileMatchers = g_list_prepend(format->priv->fileMatchers,
+                                                  g_pattern_spec_new((char*)lst->data));
+
+  passed = FALSE;
+  for (lst = format->priv->fileMatchers; lst && !passed; lst = g_list_next(lst))
+    passed = g_pattern_match_string((GPatternSpec*)lst->data, filename);
+  return passed;
+}
 /**
  * tool_file_format_validate:
  * @format: a #ToolFileFormat ;
@@ -520,7 +518,9 @@ const gchar* tool_file_format_match(ToolFileFormat *format, const gchar *filenam
  * Since: 3.7
  *
  * Returns: TRUE, if the file (after minimal parsing) is of this file
- * format. If there is no validator routine, it returns FALSE anyway.
+ * format. If there is no validator routine, it is using a built-in
+ * one, based on pattern matching with file types, see
+ * tool_file_format_addPatterns().
  */
 gboolean tool_file_format_validate(ToolFileFormat *format, const gchar *filename)
 {
@@ -533,14 +533,14 @@ gboolean tool_file_format_validate(ToolFileFormat *format, const gchar *filename
   if (format->priv->validate)
     res = format->priv->validate(filename);
   else
-    res = FALSE;
+    res = _validate(format, filename);
   DBG_fprintf(stderr, "%d.\n", res);
   return res;
 }
 /**
  * tool_file_format_setValidator:
  * @format: a #ToolFileFormat ;
- * @validate: (scope call): a pointer to a validator routine.
+ * @validate: (scope call) (allow-none): a pointer to a validator routine.
  *
  * Set up a validating routine that do a minimal parsing to check that
  * a provided file corresponds to this file format.
@@ -566,7 +566,7 @@ void tool_file_format_setValidator(ToolFileFormat *format,
  **/
 void tool_file_format_addOption(ToolFileFormat *format, ToolOption *opt)
 {
-  g_return_if_fail(IS_TOOL_FILE_FORMAT(format));
+  g_return_if_fail(TOOL_IS_FILE_FORMAT(format));
 
   format->priv->properties = g_list_append(format->priv->properties, (gpointer)opt);
 }
@@ -589,7 +589,7 @@ ToolOption* tool_file_format_addPropertyBoolean(ToolFileFormat *format,
   ToolOption *opt;
   GValue *val;
 
-  opt = tool_file_format_getPropertyByName(format, name);
+  opt = _getProperty(format, name);
   if (!opt)
     {
       opt = tool_option_new(name, label, G_TYPE_BOOLEAN);
@@ -617,7 +617,7 @@ ToolOption* tool_file_format_addPropertyInt(ToolFileFormat *format,
   ToolOption *opt;
   GValue *val;
 
-  opt = tool_file_format_getPropertyByName(format, name);
+  opt = _getProperty(format, name);
   if (!opt)
     {
       opt = tool_option_new(name, label, G_TYPE_INT);
@@ -647,7 +647,7 @@ ToolOption* tool_file_format_addPropertyDouble(ToolFileFormat *format,
   ToolOption *opt;
   GValue *val;
 
-  opt = tool_file_format_getPropertyByName(format, name);
+  opt = _getProperty(format, name);
   if (!opt)
     {
       opt = tool_option_new(name, label, G_TYPE_DOUBLE);
@@ -689,20 +689,7 @@ gboolean tool_file_format_iterNextProperty(ToolFileFormat *format,
   return TRUE;
 }
 
-/**
- * tool_file_format_getPropertyByName:
- * @format: a #ToolFileFormat.
- * @name: the name of a property.
- *
- * Retrieve the corresponding property to @name from the biven
- * @format.
- *
- * Since: 3.5
- *
- * Returns: (transfer none): the found #ToolOption or NULL.
- */
-ToolOption* tool_file_format_getPropertyByName(ToolFileFormat *format,
-                                               const gchar *name)
+static ToolOption* _getProperty(const ToolFileFormat *format, const gchar *name)
 {
   GList *lst;
 
@@ -715,3 +702,82 @@ ToolOption* tool_file_format_getPropertyByName(ToolFileFormat *format,
       return (ToolOption*)lst->data;
   return (ToolOption*)0;
 }
+
+/**
+ * tool_file_format_setPropertiesFromCLI:
+ * @format: A #ToolFileFormat object.
+ *
+ * Scan all options from command line and affects values.
+ *
+ * Since: 3.8
+ **/
+void tool_file_format_setPropertiesFromCLI(ToolFileFormat *format)
+{
+  GHashTable *opts;
+  GHashTableIter iter;
+  gpointer key, value;
+  ToolOption *prop;
+
+  opts = commandLineGet_options();
+  if (!opts)
+    return;
+
+  g_hash_table_iter_init(&iter, opts);
+  while(g_hash_table_iter_next(&iter, &key, &value))
+    {
+      prop = _getProperty(format, (const gchar*)key);
+      if (prop)
+        g_value_copy(tool_option_getValue((ToolOption*)value),
+                     tool_option_getValue(prop));
+    }
+}
+
+/**
+ * tool_file_format_getPropertyBoolean:
+ * @format: a #ToolFileFormat object.
+ * @name: a property name.
+ *
+ * Retrieves the value of property @prop.
+ *
+ * Since: 3.8
+ *
+ * Returns: the property value if exists, FALSE otherwise.
+ **/
+gboolean tool_file_format_getPropertyBoolean(const ToolFileFormat *format,
+                                             const gchar *name)
+{
+  ToolOption *prop;
+
+  g_return_val_if_fail(TOOL_IS_FILE_FORMAT(format), FALSE);
+
+  prop = _getProperty(format, name);
+  if (!prop)
+    return FALSE;
+
+  return g_value_get_boolean(tool_option_getValue(prop));  
+}
+
+/**
+ * tool_file_format_getPropertyInt:
+ * @format: a #ToolFileFormat object.
+ * @name: a property name.
+ *
+ * Retrieves the value of property @prop.
+ *
+ * Since: 3.8
+ *
+ * Returns: the property value if exists, -1 otherwise.
+ **/
+gint tool_file_format_getPropertyInt(const ToolFileFormat *format,
+                                     const gchar *name)
+{
+  ToolOption *prop;
+
+  g_return_val_if_fail(TOOL_IS_FILE_FORMAT(format), -1);
+
+  prop = _getProperty(format, name);
+  if (!prop)
+    return -1;
+
+  return g_value_get_int(tool_option_getValue(prop));  
+}
