@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -78,11 +78,10 @@
 
 /**
  * ToolVector:
- * @vect: (array fixed-size=3) (element-type gfloat):
  *
- * Structure used for bindings.
+ * An opaque object, to exchange three floats as #GObject properties.
  *
- * Since: 3.7
+ * Since: 3.8
  */
 
 /**
@@ -169,10 +168,7 @@ gboolean tool_matrix_reducePrimitiveVectors(double reduced[6], double full[3][3]
 			  " = (%d, %d, %d)\n", i, j, k);
 	    }
 	  else
-	    {
-	      g_warning("The input axes are not in 3D.");
-	      return FALSE;
-	    }
+            return FALSE;
 	}
     }
   Y[k] = -1.;
@@ -284,6 +280,55 @@ void tool_matrix_setIdentity(float mat[3][3])
   mat[2][1] = 0.f;
   mat[2][2] = 1.f;
 }
+/**
+ * tool_matrix_set:
+ * @mat: a matrix.
+ * @orig: a matrix.
+ *
+ * Copy @orig into @mat.
+ *
+ * Since: 3.8
+ **/
+void tool_matrix_set(float mat[3][3], float orig[3][3])
+{
+  mat[0][0] = orig[0][0];
+  mat[0][1] = orig[0][1];
+  mat[0][2] = orig[0][2];
+  mat[1][0] = orig[1][0];
+  mat[1][1] = orig[1][1];
+  mat[1][2] = orig[1][2];
+  mat[2][0] = orig[2][0];
+  mat[2][1] = orig[2][1];
+  mat[2][2] = orig[2][2];
+}
+/**
+ * tool_matrix_rotate:
+ * @mat: a matrix.
+ * @angle: an angle in degrees.
+ * @dir: a direction.
+ *
+ * Create a rotation matrix along axis @dir of the given @angle.
+ *
+ * Since: 3.8
+ **/
+void tool_matrix_rotate(float mat[3][3], float angle, ToolXyzDir dir)
+{
+  float rot[3][3], work[3][3];
+  int perm[3][3] = {{1, 2, 0}, {2, 0, 1}, {0, 1, 2}};
+
+  rot[perm[dir][0]][perm[dir][0]] = cos(angle * TOOL_PI180);
+  rot[perm[dir][0]][perm[dir][1]] = -sin(angle * TOOL_PI180);
+  rot[perm[dir][0]][perm[dir][2]] = 0.f;
+  rot[perm[dir][1]][perm[dir][0]] = sin(angle * TOOL_PI180);
+  rot[perm[dir][1]][perm[dir][1]] = cos(angle * TOOL_PI180);
+  rot[perm[dir][1]][perm[dir][2]] = 0.f;
+  rot[perm[dir][2]][perm[dir][0]] = 0.f;
+  rot[perm[dir][2]][perm[dir][1]] = 0.f;
+  rot[perm[dir][2]][perm[dir][2]] = 1.f;
+
+  tool_matrix_set(work, mat);
+  tool_matrix_productMatrix(mat, work, rot);
+}
 
 /**
  * tool_matrix_productMatrix:
@@ -460,49 +505,48 @@ gboolean tool_matrix_getRotationFromFull(float rot[3][3],
  *
  * Since: 3.3
  */
-void tool_matrix_cartesianToSpherical(float *spherical, float *cartesian)
+void tool_matrix_cartesianToSpherical(float spherical[3], const float cartesian[3])
 {
 /* s[0] = rho, s[1] = theta, s[2] = phi
    c[0] = x, c[1] = y, c[2] = z */
-  const float *c = cartesian;
-  float *s = spherical;
-
   double rho;
   double theta; 
   double phi;
 
-  if(c[0] == 0 && c[1] == 0 && c[2] == 0)
+  if (cartesian[0] == 0 && cartesian[1] == 0 && cartesian[2] == 0)
     {
-      s[0] = 0;
-      s[1] = 0;
-      s[2] = 0;
+      spherical[TOOL_MATRIX_SPHERICAL_MODULUS] = 0;
+      spherical[TOOL_MATRIX_SPHERICAL_THETA] = 0;
+      spherical[TOOL_MATRIX_SPHERICAL_PHI] = 0;
       return;
     }
 
-  rho = sqrt(c[0]*c[0] + c[1]*c[1] + c[2]*c[2]);
+  rho = sqrt(cartesian[0] * cartesian[0] +
+             cartesian[1] * cartesian[1] +
+             cartesian[2] * cartesian[2]);
 
-  if(c[0] == 0 && c[1] == 0)
-    theta = (c[2] > 0) ? 0 : G_PI;
+  if (cartesian[0] == 0 && cartesian[1] == 0)
+    theta = (cartesian[2] > 0) ? 0 : G_PI;
   else 
-    theta = acos(CLAMP(c[2]/rho, -1., 1.));
+    theta = acos(CLAMP(cartesian[2] / rho, -1., 1.));
 
-  if(c[0] != 0)
+  if (cartesian[0] != 0)
     {
-      phi = atan(c[1]/c[0]) + G_PI*((c[0] < 0) ? 1 : 0);
+      phi = atan(cartesian[1] / cartesian[0]) + G_PI*((cartesian[0] < 0) ? 1 : 0);
     }
   else
     {
-      if(c[1] == 0) /* facultatif*/
+      if (cartesian[1] == 0) /* facultatif*/
 	phi = 0;    /* facultatif*/
-      else if(c[1] > 0)
+      else if(cartesian[1] > 0)
 	phi = G_PI_2;
       else
 	phi = -G_PI_2;
     }
 
-  s[0] = rho;
-  s[1] = /*tool_modulo_float(RAD2DEG(theta), 180);*/ RAD2DEG(theta);
-  s[2] = tool_modulo_float(RAD2DEG(phi), 360);
+  spherical[TOOL_MATRIX_SPHERICAL_MODULUS] = rho;
+  spherical[TOOL_MATRIX_SPHERICAL_THETA] = RAD2DEG(theta);
+  spherical[TOOL_MATRIX_SPHERICAL_PHI] = tool_modulo_float(RAD2DEG(phi), 360);
 }
 
 /**
@@ -515,11 +559,16 @@ void tool_matrix_cartesianToSpherical(float *spherical, float *cartesian)
  *
  * Since: 3.3
  */
-void tool_matrix_sphericalToCartesian(float *cartesian, float *spherical)
+void tool_matrix_sphericalToCartesian(float cartesian[3], const float spherical[3])
 {
-  cartesian[0] = spherical[0] * sin(DEG2RAD(spherical[1]))*cos(DEG2RAD(spherical[2]));
-  cartesian[1] = spherical[0] * sin(DEG2RAD(spherical[1]))*sin(DEG2RAD(spherical[2]));
-  cartesian[2] = spherical[0] * cos(DEG2RAD(spherical[1]));
+  cartesian[0] = spherical[TOOL_MATRIX_SPHERICAL_MODULUS] *
+    sin(DEG2RAD(spherical[TOOL_MATRIX_SPHERICAL_THETA])) *
+    cos(DEG2RAD(spherical[TOOL_MATRIX_SPHERICAL_PHI]));
+  cartesian[1] = spherical[TOOL_MATRIX_SPHERICAL_MODULUS] *
+    sin(DEG2RAD(spherical[TOOL_MATRIX_SPHERICAL_THETA])) *
+    sin(DEG2RAD(spherical[TOOL_MATRIX_SPHERICAL_PHI]));
+  cartesian[2] = spherical[TOOL_MATRIX_SPHERICAL_MODULUS] *
+    cos(DEG2RAD(spherical[TOOL_MATRIX_SPHERICAL_THETA]));
 }
 
 /**
@@ -589,7 +638,7 @@ gboolean tool_matrix_getInter2DFromList(float i[2], float *lambda,
 #define FLAG_PARAMETER_THRESHOLD "scale_log_threshold"
 #define DESC_PARAMETER_THRESHOLD "Value of the threshold used in the zero centred TOOL_MATRIX_SCALING_LOG scaling function ; a positive float (1e-3)"
 static float threshold = 1e-3;
-static void exportParameters(GString *data, VisuData *dataObj, VisuGlView *view);
+static void exportParameters(GString *data, VisuData *dataObj);
 
 /**
  * tool_matrix_getScaledLinear:
@@ -602,7 +651,7 @@ static void exportParameters(GString *data, VisuData *dataObj, VisuGlView *view)
  *
  * Since: 3.5
  */
-double tool_matrix_getScaledLinear(double x, double minmax[2])
+float tool_matrix_getScaledLinear(float x, float minmax[2])
 {
   return ((CLAMP(x, minmax[0], minmax[1]) - minmax[0]) /
 	  (minmax[1] - minmax[0]));
@@ -618,10 +667,10 @@ double tool_matrix_getScaledLinear(double x, double minmax[2])
  *
  * Since: 3.5
  */
-double tool_matrix_getScaledLog(double x, double minmax[2])
+float tool_matrix_getScaledLog(float x, float minmax[2])
 {
-  /* double v; */
-  double lMinMax[2];
+  /* float v; */
+  float lMinMax[2];
 
   lMinMax[0] = log10(MAX(1e-12, minmax[0]));
   lMinMax[1] = log10(MAX(1e-12, minmax[1]));
@@ -639,9 +688,9 @@ double tool_matrix_getScaledLog(double x, double minmax[2])
  *
  * Since: 3.5
  */
-double tool_matrix_getScaledZeroCentredLog(double x, double minmax[2])
+float tool_matrix_getScaledZeroCentredLog(float x, float minmax[2])
 {
-  double v, m;
+  float v, m;
 
   m = MAX(minmax[1], -minmax[0]);
   v = CLAMP(x, -m, m);
@@ -660,7 +709,7 @@ double tool_matrix_getScaledZeroCentredLog(double x, double minmax[2])
  *
  * Since: 3.5
  */
-double tool_matrix_getScaledLinearInv(double x, double minmax[2])
+float tool_matrix_getScaledLinearInv(float x, float minmax[2])
 {
   return (minmax[0] + CLAMP(x, 0., 1.) * (minmax[1] - minmax[0]));
 }
@@ -675,7 +724,7 @@ double tool_matrix_getScaledLinearInv(double x, double minmax[2])
  *
  * Since: 3.5
  */
-double tool_matrix_getScaledLogInv(double x, double minmax[2])
+float tool_matrix_getScaledLogInv(float x, float minmax[2])
 {
   return MAX(1e-12, minmax[0]) * pow(MAX(1e-12, minmax[1]) / MAX(1e-12, minmax[0]), CLAMP(x, 0., 1.));
   /* return (minmax[0] + (minmax[1] - minmax[0]) * exp((1. - CLAMP(x, 0., 1.)) * param)); */
@@ -691,9 +740,9 @@ double tool_matrix_getScaledLogInv(double x, double minmax[2])
  *
  * Since: 3.5
  */
-double tool_matrix_getScaledZeroCentredLogInv(double x, double minmax[2])
+float tool_matrix_getScaledZeroCentredLogInv(float x, float minmax[2])
 {
-  double s, m, out;
+  float s, m, out;
 
   DBG_fprintf(stderr, "Matrix: get inv ZCL %g (%g-%g).\n", x, minmax[0], minmax[1]);
   s = (x < 0.5)?-1.:1.;
@@ -703,7 +752,7 @@ double tool_matrix_getScaledZeroCentredLogInv(double x, double minmax[2])
   return out;
 }
 
-static void exportParameters(GString *data, VisuData *dataObj _U_, VisuGlView *view _U_)
+static void exportParameters(GString *data, VisuData *dataObj _U_)
 {
   g_string_append_printf(data, "# %s\n", DESC_PARAMETER_THRESHOLD);
   g_string_append_printf(data, "%s: %f\n\n", FLAG_PARAMETER_THRESHOLD,
@@ -725,8 +774,158 @@ void tool_matrix_init(void)
   entry = visu_config_file_addFloatArrayEntry(VISU_CONFIG_FILE_PARAMETER,
                                               FLAG_PARAMETER_THRESHOLD,
                                               DESC_PARAMETER_THRESHOLD,
-                                              1, &threshold, rg);
+                                              1, &threshold, rg, FALSE);
   visu_config_file_entry_setVersion(entry, 3.5f);
   visu_config_file_addExportFunction(VISU_CONFIG_FILE_PARAMETER,
-				   exportParameters);
+                                     exportParameters);
+}
+
+static gpointer vector_copy(gconstpointer boxed)
+{
+  gfloat *vector, *orig = (gfloat*)boxed;
+
+  if (!boxed)
+    return (gpointer)0;
+
+  vector = g_malloc(sizeof(gfloat) * 3);
+  vector[0] = orig[0];
+  vector[1] = orig[1];
+  vector[2] = orig[2];
+  return (gpointer)vector;
+}
+/**
+ * tool_vector_get_type:
+ *
+ * Create and retrieve a #GType for a #ToolVector object.
+ *
+ * Since: 3.8
+ *
+ * Returns: a new type for #ToolVector structures.
+ */
+GType tool_vector_get_type(void)
+{
+  static GType g_define_type_id = 0;
+
+  if (g_define_type_id == 0)
+    g_define_type_id = g_boxed_type_register_static("ToolVector",
+                                                    (GBoxedCopyFunc)vector_copy, g_free);
+  return g_define_type_id;
+}
+
+/**
+ * tool_vector_new:
+ * @orig: (array fixed-size=3): a vector.
+ *
+ * Creates a new #ToolVector by copying @orig.
+ *
+ * Since: 3.8
+ *
+ * Returns: (transfer full) (type ToolVector):
+ **/
+float* tool_vector_new(const float orig[3])
+{
+  return vector_copy(orig);
+}
+
+/**
+ * tool_vector_set:
+ * @dest: a vector.
+ * @orig: a vector.
+ *
+ * Copy @orig into @dest and also test if @dest was already equals to @orig.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if @dest is different from @orig.
+ **/
+gboolean tool_vector_set(float dest[3], const float orig[3])
+{
+  if (dest[0] == orig[0] && dest[1] == orig[1] && dest[2] == orig[2])
+    return FALSE;
+
+  dest[0] = orig[0];
+  dest[1] = orig[1];
+  dest[2] = orig[2];
+  return TRUE;
+}
+
+/**
+ * tool_vector_spherical:
+ * @cart: (array fixed-size=3): a vector in cartesian coordinates.
+ * @at: a spherical direction.
+ *
+ * Convert @cart in spherical coordinates. It is equivalent to
+ * tool_matrix_cartesianToSpherical() but returns the value in a given
+ * direction only. This is intended for bindings.
+ *
+ * Since: 3.8
+ *
+ * Returns: the coodinate in spherical.
+ **/
+float tool_vector_spherical(const float cart[3], ToolMatrixSphericalCoord at)
+{
+  float sph[3];
+
+  tool_matrix_cartesianToSpherical(sph, cart);
+  return sph[at];
+}
+
+static gpointer minmax_copy(gpointer boxed)
+{
+  gfloat *mm, *orig = (gfloat*)boxed;
+
+  if (!boxed)
+    return (gpointer)0;
+
+  mm = g_malloc(sizeof(gfloat) * 2);
+  mm[0] = orig[0];
+  mm[1] = orig[1];
+  return (gpointer)mm;
+}
+/**
+ * tool_minmax_get_type:
+ *
+ * Create and retrieve a #GType for a #ToolMinmax object.
+ *
+ * Since: 3.8
+ *
+ * Returns: a new type for #ToolMinmax structures.
+ */
+GType tool_minmax_get_type(void)
+{
+  static GType g_define_type_id = 0;
+
+  if (g_define_type_id == 0)
+    g_define_type_id = g_boxed_type_register_static("ToolMinmax", minmax_copy, g_free);
+  return g_define_type_id;
+}
+
+/**
+ * tool_minmax:
+ * @global: (array fixed-size=2): the global min and max values.
+ * @minmax: (array fixed-size=2): some min and max values.
+ *
+ * Take the minimum and maximum of @global and @minmax and put them
+ * into @global. @global should be initialised.
+ *
+ * Since: 3.8
+ **/
+void tool_minmax(float global[2], const float minmax[2])
+{
+  global[0] = MIN(minmax[0], global[0]);
+  global[1] = MAX(minmax[1], global[1]);
+}
+/**
+ * tool_minmax_fromDbl:
+ * @global: (array fixed-size=2): the global min and max values.
+ * @minmax: (array fixed-size=2): some min and max values.
+ *
+ * Same as tool_minmax() for double inputs.
+ *
+ * Since: 3.8
+ **/
+void tool_minmax_fromDbl(float global[2], const double minmax[2])
+{
+  global[0] = MIN(minmax[0], global[0]);
+  global[1] = MAX(minmax[1], global[1]);
 }
