@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -46,6 +46,7 @@
 #define TOOLMATRIX_H
 
 #include <glib.h>
+#include <glib-object.h>
 
 G_BEGIN_DECLS
 
@@ -106,12 +107,21 @@ typedef enum {
   TOOL_XYZ_Z
 } ToolXyzDir;
 
+/**
+ * TOOL_PI180:
+ *
+ * Value of pi / 180.
+ */
+#define TOOL_PI180 0.017453292522
+
 void tool_matrix_setIdentity(float mat[3][3]);
+void tool_matrix_set(float mat[3][3], float orig[3][3]);
 void tool_matrix_dtof(float mf[3][3], double md[3][3]);
 void tool_matrix_productMatrix(float matRes[3][3], float matA[3][3], float matB[3][3]);
 void tool_matrix_productVector(float vectRes[3], float mat[3][3], float vect[3]);
 gboolean tool_matrix_invert(float inv[3][3], float mat[3][3]);
 float tool_matrix_determinant(float mat[3][3]);
+void tool_matrix_rotate(float mat[3][3], float angle, ToolXyzDir dir);
 
 gboolean tool_matrix_reducePrimitiveVectors(double reduced[6], double full[3][3]);
 gboolean tool_matrix_getRotationFromFull(float rot[3][3],
@@ -135,8 +145,9 @@ typedef enum
     TOOL_MATRIX_SPHERICAL_THETA,
     TOOL_MATRIX_SPHERICAL_PHI
   } ToolMatrixSphericalCoord;
-void tool_matrix_cartesianToSpherical(float *spherical, float *cartesian);
-void tool_matrix_sphericalToCartesian(float *cartesian, float *spherical);
+void tool_matrix_cartesianToSpherical(float spherical[3], const float cartesian[3]);
+void tool_matrix_sphericalToCartesian(float cartesian[3], const float spherical[3]);
+float tool_vector_spherical(const float cart[3], ToolMatrixSphericalCoord at);
 
 /**
  * ToolMatrixScalingFlag:
@@ -151,7 +162,7 @@ void tool_matrix_sphericalToCartesian(float *cartesian, float *spherical);
  * (1e-5).
  * @TOOL_MATRIX_SCALING_N_VALUES: number of available scale functions.
  *
- * Flag used to specify the transformation for scalarFieldDraw_map()
+ * Flag used to specify the transformation for maps, see scalarFieldDraw_map()
  * routine.
  *
  * Since: 3.4
@@ -174,14 +185,14 @@ typedef enum
  *
  * Since: 3.4
  */
-typedef double (*tool_matrix_getScaledValue)(double x, double minmax[2]);
-double tool_matrix_getScaledLinear(double x, double minmax[2]);
-double tool_matrix_getScaledLog(double x, double minmax[2]);
-double tool_matrix_getScaledZeroCentredLog(double x, double minmax[2]);
+typedef float (*tool_matrix_getScaledValue)(float x, float minmax[2]);
+float tool_matrix_getScaledLinear(float x, float minmax[2]);
+float tool_matrix_getScaledLog(float x, float minmax[2]);
+float tool_matrix_getScaledZeroCentredLog(float x, float minmax[2]);
 
-double tool_matrix_getScaledLinearInv(double x, double minmax[2]);
-double tool_matrix_getScaledLogInv(double x, double minmax[2]);
-double tool_matrix_getScaledZeroCentredLogInv(double x, double minmax[2]);
+float tool_matrix_getScaledLinearInv(float x, float minmax[2]);
+float tool_matrix_getScaledLogInv(float x, float minmax[2]);
+float tool_matrix_getScaledZeroCentredLogInv(float x, float minmax[2]);
 
 gboolean tool_matrix_getInter2D(float *lambda,
 			   float a[2], float b[2], float A[2], float B[2]);
@@ -189,11 +200,20 @@ gboolean tool_matrix_getInter2DFromList(float i[2], float *lambda,
 				   float a[2], float b[2], GList *set);
 
 /* These structures are used for bindings. */
-typedef struct _ToolVector ToolVector;
-struct _ToolVector
-{
-  float vect[3];
-};
+#define    TOOL_TYPE_VECTOR (tool_vector_get_type())
+GType      tool_vector_get_type(void);
+
+gboolean tool_vector_set(float dest[3], const float orig[3]);
+
+float* tool_vector_new(const float orig[3]);
+
+/* typedef gfloat[3] ToolVector; */
+
+/* typedef struct _ToolVector ToolVector; */
+/* struct _ToolVector */
+/* { */
+/*   float vect[3]; */
+/* }; */
 typedef struct _ToolGridSize ToolGridSize;
 struct _ToolGridSize
 {
@@ -202,6 +222,26 @@ struct _ToolGridSize
 
 void tool_matrix_init(void);
 
+/* These structures are used for bindings. */
+#define    TOOL_TYPE_MINMAX (tool_minmax_get_type())
+GType      tool_minmax_get_type(void);
+
+void tool_minmax(float global[2], const float minmax[2]);
+void tool_minmax_fromDbl(float global[2], const double minmax[2]);
+
+/**
+ * ToolScalingId:
+ * @TOOL_SCALING_NORMALIZE: input data are converted into [0;1] using input min/max values.
+ * @TOOL_SCALING_MINMAX: input data are converted into [0;1] using user defined min/max values.
+ *
+ * Control how input data are converted into [0;1], after conversion,
+ * values are clamped if needed.
+ */
+typedef enum
+  {
+    TOOL_SCALING_NORMALIZE,
+    TOOL_SCALING_MINMAX
+  } ToolScalingId;
 
 G_END_DECLS
 
