@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -49,7 +49,6 @@
 
 #include <pango/pango.h>
 
-#include <visu_object.h>
 #include <visu_configFile.h>
 #include "toolConfigFile.h"
 #include "toolColor.h"
@@ -66,18 +65,11 @@
  * gradient (ranging from 0 to 1). Resulting color vector are clamped
  * to [0;1] if needed.</para>
  * <para>Use tool_shade_new() to create a new shade, giving the arguments as
- * defined above. A shade can be linked to an image to represent it,
- * use shadeSet_pathToImage() to do it.</para>
- * <!--<para>In near future, the code that can discretize the
- * resulting color gradient will be imported here from dataFile.c and
- * could then be shared between other modules. At present time, each
- * module needs to write it own transformation code after having
- * retrieved the transformation coefficients with
- * shadeGet_colorTransformation().</para>-->
+ * defined above.</para>
  * <para>To share color gradients between modules in V_Sim, you can
- * add new shade to the global list of stored shades using
- * tool_shade_appendList() and get this list with a call to
- * tool_shade_getList().</para>
+ * find a global list of stored shades with tool_shade_getStorage().
+ * This is a #ToolPool object. Use tool_pool_add() to add a new shade
+ * to it.</para>
  */
 
 
@@ -87,11 +79,11 @@
 
 #define FLAG_SHADE "shade_palette"
 #define DESC_SHADE "Define a new shade by giving colours to points ; label (val [name|#rgb|#rrggbb|...], ...)"
-static void exportParameters(GString *data, VisuData *dataObj, VisuGlView *view);
+static void exportParameters(GString *data, VisuData *dataObj);
 static gboolean readShade(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines,int position,
-                          VisuData *dataObj, VisuGlView *view, GError **error);
+                          GError **error);
 static gboolean parseValue(gchar *line, float *index, float rgb[3], GError **error);
-static GList* _buildPresetList(void);
+static void _buildPresetList(void);
 
 struct _ToolShade
 {
@@ -111,7 +103,7 @@ struct _ToolShade
   gchar *steps;
 };
 
-static GList *toolShadeList = (GList*)0;
+static ToolPool *shadePool = NULL;
 
 /**
  * tool_shade_get_type:
@@ -145,6 +137,22 @@ GType tool_shade_get_type(void)
   return g_define_type_id;
 }
 
+/**
+ * tool_shade_getById:
+ * @id: an id.
+ *
+ * Convenience function calling tool_pool_getById() on the default
+ * #ToolShade storage.
+ *
+ * Since: 3.8
+ *
+ * Returns: a #ToolShade from the pool.
+ **/
+const ToolShade* tool_shade_getById(guint id)
+{
+  return tool_pool_getById(tool_shade_getStorage(), id);
+}
+
 /**
  * tool_shade_new:
  * @labelUTF8: a UTF8 string that shortly named this new shade ;
@@ -360,6 +368,7 @@ void tool_shade_free(ToolShade *shade)
 {
   if (shade)
     {
+      DBG_fprintf(stderr, "Tool Shade: freeing %p.\n", (gpointer)shade);
       g_free(shade->labelUTF8);
       g_free(shade->index);
       g_free(shade->vectCh[0]);
@@ -377,7 +386,7 @@ void tool_shade_free(ToolShade *shade)
  *
  * Returns: a newly created shade.
  */
-ToolShade* tool_shade_copy(ToolShade *shade)
+ToolShade* tool_shade_copy(const ToolShade *shade)
 {
   ToolShade *out;
 
@@ -404,6 +413,43 @@ ToolShade* tool_shade_copy(ToolShade *shade)
 
   return out;
 }
+static gint _compare(const ToolShade* sh1, const ToolShade *sh2)
+{
+  guint i;
+  gboolean equal;
+
+  if (!sh1 && !sh2)
+    return 0;
+  if (!sh1)
+    return -1;
+  if (!sh2)
+    return +1;
+
+  if (sh1->mode != sh2->mode)
+    return (sh2 - sh1);
+  if (sh1->colorMode != sh2->colorMode)
+    return (sh2 - sh1);
+
+  if (sh1->mode == TOOL_SHADE_MODE_LINEAR)
+    return (sh1->vectA[0] == sh2->vectA[0] &&
+	    sh1->vectA[1] == sh2->vectA[1] &&
+	    sh1->vectA[2] == sh2->vectA[2] &&
+	    sh1->vectB[0] == sh2->vectB[0] &&
+	    sh1->vectB[1] == sh2->vectB[1] &&
+	    sh1->vectB[2] == sh2->vectB[2]) ? 0 : (sh2 - sh1);
+  else
+    {
+      if (sh1->nVals != sh2->nVals)
+	return (sh2 - sh1);
+      equal = TRUE;
+      for (i = 0; i < sh1->nVals && equal; i++)
+	equal = equal && (sh1->index[i] == sh2->index[i]) &&
+          (sh1->vectCh[0][i] == sh2->vectCh[0][i]) &&
+	  (sh1->vectCh[1][i] == sh2->vectCh[1][i]) &&
+	  (sh1->vectCh[2][i] == sh2->vectCh[2][i]);
+      return equal ? 0 : (sh2 - sh1);
+    }
+}
 /**
  * tool_shade_compare:
  * @sh1: a #ToolShade ;
@@ -414,37 +460,9 @@ ToolShade* tool_shade_copy(ToolShade *shade)
  *
  * Returns: TRUE if @shade1 is equivalent to @shade2.
  */
-gboolean tool_shade_compare(ToolShade* sh1, ToolShade *sh2)
+gboolean tool_shade_compare(const ToolShade* sh1, const ToolShade *sh2)
 {
-  guint i;
-  gboolean equal;
-
-  g_return_val_if_fail(sh1 && sh2, FALSE);
-
-  if (sh1->mode != sh2->mode)
-    return FALSE;
-  if (sh1->colorMode != sh2->colorMode)
-    return FALSE;
-
-  if (sh1->mode == TOOL_SHADE_MODE_LINEAR)
-    return (sh1->vectA[0] == sh2->vectA[0] &&
-	    sh1->vectA[1] == sh2->vectA[1] &&
-	    sh1->vectA[2] == sh2->vectA[2] &&
-	    sh1->vectB[0] == sh2->vectB[0] &&
-	    sh1->vectB[1] == sh2->vectB[1] &&
-	    sh1->vectB[2] == sh2->vectB[2]);
-  else
-    {
-      if (sh1->nVals != sh2->nVals)
-	return FALSE;
-      equal = TRUE;
-      for (i = 0; i < sh1->nVals && equal; i++)
-	equal = equal && (sh1->index[i] == sh2->index[i]) &&
-          (sh1->vectCh[0][i] == sh2->vectCh[0][i]) &&
-	  (sh1->vectCh[1][i] == sh2->vectCh[1][i]) &&
-	  (sh1->vectCh[2][i] == sh2->vectCh[2][i]);
-      return equal;
-    }
+  return (_compare(sh1, sh2) == 0);
 }
 /**
  * tool_shade_getLabel:
@@ -480,7 +498,7 @@ ToolShadeColorMode tool_shade_getColorMode(ToolShade *shade)
  *
  * Returns: the mode.
  */
-ToolShadeMode tool_shade_getMode(ToolShade *shade)
+ToolShadeMode tool_shade_getMode(const ToolShade *shade)
 {
   g_return_val_if_fail(shade, (int)0);
   return shade->mode;
@@ -516,7 +534,8 @@ gboolean tool_shade_setColorMode(ToolShade *shade, ToolShadeColorMode mode)
  *
  * Returns: TRUE if @vectA, @vectB and @vectX have been set correctly.
  */
-gboolean tool_shade_getLinearCoeff(ToolShade *shade, float **vectA, float **vectB)
+gboolean tool_shade_getLinearCoeff(const ToolShade *shade,
+                                   const float **vectA, const float **vectB)
 {
   g_return_val_if_fail(shade, FALSE);
   g_return_val_if_fail(shade->mode == TOOL_SHADE_MODE_LINEAR, FALSE);
@@ -635,59 +654,23 @@ void tool_shade_valueToRGB(const ToolShade *shade, float rgba[4], float value)
 /* Methods to deal with internal shade list. */
 /*********************************************/
 /**
- * tool_shade_getList:
+ * tool_shade_getStorage:
  *
  * It returns a read-only pointer to the internal shade list. Use tool_shade_appendList()
  * to add new shades to this list.
  *
- * Returns: (transfer none) (element-type ToolShade*): a pointer to the internal shade list.
- */
-GList* tool_shade_getList(void)
-{
-  if (!toolShadeList)
-    toolShadeList = _buildPresetList();
-
-  return toolShadeList;
-}
-/**
- * tool_shade_appendList:
- * @shade: a #ToolShade object.
- * @unique: a boolean.
+ * Since: 3.8
  *
- * Add a shape to the internal list. Use the return value or tool_shade_getList() method
- * to look into this list. If @unique is TRUE, the internal list is
- * read and @shade is added only if it is not already existing in the list.
- *
- * Returns: (transfer none) (element-type ToolShade*): a read-only
- * pointer to the internal shade list.
+ * Returns: (transfer none): a pointer to the internal shade list.
  */
-GList* tool_shade_appendList(ToolShade *shade, gboolean unique)
+ToolPool* tool_shade_getStorage(void)
 {
-  GList *lst;
-  gboolean add;
+  if (!shadePool)
+    _buildPresetList();
 
-  g_return_val_if_fail(shade, (GList*)0);
-
-  DBG_fprintf(stderr, "Tool Shade: appending shade %p to %p.\n",
-          (gpointer)shade, (gpointer)toolShadeList);
-  if (!toolShadeList)
-    toolShadeList = _buildPresetList();
-
-  add = TRUE;
-  if (unique)
-      for (lst = toolShadeList; lst && add; lst = g_list_next(lst))
-        if (tool_shade_compare(shade, (ToolShade*)lst->data))
-          add = FALSE;
-
-  if (add)
-    {
-      toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
-      g_signal_emit_by_name(VISU_OBJECT_INSTANCE, "shadeNewAvailable", (gpointer)shade, NULL);
-    }
-
-  return toolShadeList;
+  return shadePool;
 }
-static GList* _buildPresetList(void)
+static void _buildPresetList(void)
 {
   ToolShade *shade;
   float vectA[3], vectB[3];
@@ -710,6 +693,8 @@ static GList* _buildPresetList(void)
   float jetG[jetn] = {0.f, 0.f, 0.5f, 1.f, 1.f, 1.f, 0.5f, 0.f, 0.f};
   float jetB[jetn] = {0.5f, 1.f, 1.f, 1.f, 0.5f, 0.f, 0.f, 0.f, 0.f};
 
+  shadePool = tool_pool_new(TOOL_TYPE_SHADE, (GCompareFunc)_compare);
+
   /* Create a blue to red color range. */
   vectA[0] = -0.66667;
   vectA[1] = 0.;
@@ -719,7 +704,7 @@ static GList* _buildPresetList(void)
   vectB[2] = 1.;
   shade = tool_shade_new(_("blue to red"), vectA, vectB, TOOL_SHADE_COLOR_MODE_HSV);
   shade->userDefined = FALSE;
-  toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
+  tool_pool_take(shadePool, shade);
 
   /* Create a black to white (through yellow and red) color range. */
   vectA[0] = 2.66667;
@@ -730,7 +715,7 @@ static GList* _buildPresetList(void)
   vectB[2] = -3.;
   shade = tool_shade_new(_("hot color"), vectA, vectB, TOOL_SHADE_COLOR_MODE_RGB);
   shade->userDefined = FALSE;
-  toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
+  tool_pool_take(shadePool, shade);
 
   /* Create a blue to yellow (through dark purple) color range. */
   vectA[0] = 1.33333;
@@ -741,7 +726,7 @@ static GList* _buildPresetList(void)
   vectB[2] = 1.;
   shade = tool_shade_new(_("blue to yellow"), vectA, vectB, TOOL_SHADE_COLOR_MODE_RGB);
   shade->userDefined = FALSE;
-  toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
+  tool_pool_take(shadePool, shade);
 
   /* Create a blue and red shade with black zero centred. */
   vectA[0] = -2.;
@@ -752,18 +737,18 @@ static GList* _buildPresetList(void)
   vectB[2] = -1.;
   shade = tool_shade_new(_("zero centred dark"), vectA, vectB, TOOL_SHADE_COLOR_MODE_RGB);
   shade->userDefined = FALSE;
-  toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
+  tool_pool_take(shadePool, shade);
 
   /* Create a blue and red shade with withe zero centred. */
   shade = tool_shade_newFromData(_("zero centred light"), zclLn,
                                  zclR, zclG, zclB, TOOL_SHADE_COLOR_MODE_RGB);
   shade->userDefined = FALSE;
-  toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
+  tool_pool_take(shadePool, shade);
 
   shade = tool_shade_newFromData(_("zero centred coloured"), zccLn,
 			    zccH, zccS, zccV, TOOL_SHADE_COLOR_MODE_HSV);
   shade->userDefined = FALSE;
-  toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
+  tool_pool_take(shadePool, shade);
 
   /* Create a green to red color range. */
   vectA[0] = -.3333;
@@ -774,7 +759,7 @@ static GList* _buildPresetList(void)
   vectB[2] = 1.;
   shade = tool_shade_new(_("green to red"), vectA, vectB, TOOL_SHADE_COLOR_MODE_HSV);
   shade->userDefined = FALSE;
-  toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
+  tool_pool_take(shadePool, shade);
 
   /* Create a white to red color range. */
   vectA[0] = -.3333;
@@ -785,7 +770,7 @@ static GList* _buildPresetList(void)
   vectB[2] = 1.;
   shade = tool_shade_new(_("light green to red"), vectA, vectB, TOOL_SHADE_COLOR_MODE_HSV);
   shade->userDefined = FALSE;
-  toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
+  tool_pool_take(shadePool, shade);
 
   /* Create a black to white color range. */
   vectA[0] = 0.;
@@ -796,7 +781,7 @@ static GList* _buildPresetList(void)
   vectB[2] = 0.;
   shade = tool_shade_new(_("black to white"), vectA, vectB, TOOL_SHADE_COLOR_MODE_HSV);
   shade->userDefined = FALSE;
-  toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
+  tool_pool_take(shadePool, shade);
 
   /* Create a black to white color range. */
   vectA[0] = 0.;
@@ -807,7 +792,7 @@ static GList* _buildPresetList(void)
   vectB[2] = 1.;
   shade = tool_shade_new(_("white to black"), vectA, vectB, TOOL_SHADE_COLOR_MODE_HSV);
   shade->userDefined = FALSE;
-  toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
+  tool_pool_take(shadePool, shade);
   
   /* Create a black to red (through purple) color range. */
   vectA[0] = 1.;
@@ -818,15 +803,13 @@ static GList* _buildPresetList(void)
   vectB[2] = 0.;
   shade = tool_shade_new(_("purple color"), vectA, vectB, TOOL_SHADE_COLOR_MODE_HSV);
   shade->userDefined = FALSE;
-  toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
+  tool_pool_take(shadePool, shade);
 
   /* Create the so-called Jet colour map. */
   shade = tool_shade_newFromData(_("Jet map"), jetn,
                                  jetR, jetG, jetB, TOOL_SHADE_COLOR_MODE_RGB);
   shade->userDefined = FALSE;
-  toolShadeList = g_list_append(toolShadeList, (gpointer)shade);
-
-  return toolShadeList;
+  tool_pool_take(shadePool, shade);
 }
 
 static gboolean parseValue(gchar *line, float *index, float rgb[3], GError **error)
@@ -863,7 +846,7 @@ static gboolean parseValue(gchar *line, float *index, float rgb[3], GError **err
 
   return TRUE;
 }
-static void exportParameters(GString *data, VisuData *dataObj _U_, VisuGlView *view _U_)
+static void exportParameters(GString *data, VisuData *dataObj _U_)
 {
   GList *lst;
   ToolShade *shade;
@@ -873,11 +856,11 @@ static void exportParameters(GString *data, VisuData *dataObj _U_, VisuGlView *v
   GString *buf;
 
   visu_config_file_exportComment(data, DESC_SHADE);
-  for (lst = toolShadeList; lst; lst = g_list_next(lst))
+  for (lst = tool_pool_asList(shadePool); lst; lst = g_list_next(lst))
     if (((ToolShade*)lst->data)->userDefined)
       {
         shade = (ToolShade*)lst->data;
-        buf = g_string_new("(");
+        buf = g_string_new("");
         if (shade->userDefined)
           g_string_append(buf, shade->steps);
         else
@@ -892,32 +875,33 @@ static void exportParameters(GString *data, VisuData *dataObj _U_, VisuGlView *v
               g_string_append_printf(buf, "%g %s", shade->index[i], color);
               g_free(color);
             }
-        g_string_append_printf(buf, ")");
         visu_config_file_exportEntry(data, FLAG_SHADE, shade->labelUTF8,
                                      "%s", buf->str);
         g_string_free(buf, TRUE);
       }
   visu_config_file_exportComment(data, "");
 }
-static gboolean readShade(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines _U_, int position,
-                          VisuData *dataObj _U_, VisuGlView *view _U_, GError **error)
+static gboolean readShade(VisuConfigFileEntry *entry, gchar **lines, int nbLines _U_, int position _U_,
+                          GError **error)
 {
   gchar *name, *descr;
   char *startDef, *endDef;
   ToolShade *shade;
+  ToolPool *pool;
   
+  name = g_strdup(visu_config_file_entry_getLabel(entry));
+
   startDef = strchr(lines[0], '(');
-  endDef = strchr(lines[0], ')');
-  if (!startDef || !endDef)
-    {
-      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_MISSING,
-                           _("Parse error at line %d, cannot find parenthesis"
-                             " containing the description of a shade.\n"), position);
-      return FALSE;
-    }
-  name = g_strndup(lines[0], startDef - lines[0] - 1);  
-  descr = g_strndup(startDef + 1, endDef - startDef - 1);
-  
+  if (!startDef)
+    startDef = lines[0];
+  else
+    startDef += 1;
+  endDef = strchr(startDef, ')');
+  if (endDef)
+    descr = g_strndup(startDef, endDef - startDef);
+  else
+    descr = g_strdup(startDef);
+
   shade = tool_shade_newFromString(g_strstrip(name), descr,
                                    TOOL_SHADE_COLOR_MODE_RGB, error);
   g_free(name);
@@ -925,7 +909,8 @@ static gboolean readShade(VisuConfigFileEntry *entry _U_, gchar **lines, int nbL
 
   if (!shade)
     return FALSE;
-  tool_shade_appendList(shade, TRUE);
+  pool = tool_shade_getStorage();
+  tool_pool_take(pool, shade);
 
   return TRUE;
 }
