@@ -1,20 +1,20 @@
 /*   EXTRAITS DE LA LICENCE
 	Copyright CEA, contributeurs : Damien CALISTE, laboratoire L_Sim, (2011)
   
-	Adresse ml :
+	Adresse mèl :
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -46,7 +46,7 @@
 #include <math.h>
 
 #include <visu_tools.h>
-#include <extraFunctions/extraNode.h>
+#include <visu_dataloadable.h>
 #include <extraFunctions/geometry.h>
 #include <coreTools/toolPhysic.h>
 
@@ -60,16 +60,12 @@
  * or replicated nodes.
  */
 
-static gboolean writeDataInABINIT(ToolFileFormat *format, const char* filename,
-				 int width, int height, VisuData *dataObj,
-				 guchar* imageData, GError **error,
-				 ToolVoidDataFunc functionWait, gpointer data);
-static gpointer waitData;
-static ToolVoidDataFunc waitFunc;
+static gboolean writeDataInABINIT(VisuDumpData *format, const char* filename,
+                                  VisuData *dataObj, GError **error);
 
-static VisuDump *ab;
+static VisuDumpData *ab;
 
-const VisuDump* visu_dump_abinit_getStatic()
+const VisuDumpData* visu_dump_abinit_getStatic()
 {
   const gchar *typeABINIT[] = {"*.in", (char*)0};
 #define descrABINIT _("ABINIT file (crystal only)")
@@ -77,23 +73,18 @@ const VisuDump* visu_dump_abinit_getStatic()
   if (ab)
     return ab;
 
-  ab = visu_dump_new(descrABINIT, typeABINIT, writeDataInABINIT, FALSE);
+  ab = visu_dump_data_new(descrABINIT, typeABINIT, writeDataInABINIT);
   
   tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(ab), "reduced_coordinates",
 				_("Export positions in reduced coordinates"), FALSE);
   tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(ab), "angdeg_box",
 				_("Export box as lengths and angles"), FALSE);
 
-  waitData = (gpointer)0;
-  waitFunc = (ToolVoidDataFunc)0;
-
   return ab;
 }
 
-static gboolean writeDataInABINIT(ToolFileFormat *format, const char* filename,
-				 int width _U_, int height _U_, VisuData *dataObj,
-				 guchar* imageData _U_, GError **error,
-				 ToolVoidDataFunc functionWait, gpointer data)
+static gboolean writeDataInABINIT(VisuDumpData *format, const char* filename,
+                                  VisuData *dataObj, GError **error)
 {
   const gchar *nom;
   gchar *prevFile;
@@ -111,8 +102,8 @@ static gboolean writeDataInABINIT(ToolFileFormat *format, const char* filename,
   reduced = FALSE;
   angdeg  = FALSE;
   it.lst = (GList*)0;
-  for (tool_file_format_iterNextProperty(format, &it); it.lst;
-       tool_file_format_iterNextProperty(format, &it))
+  for (tool_file_format_iterNextProperty(TOOL_FILE_FORMAT(format), &it); it.lst;
+       tool_file_format_iterNextProperty(TOOL_FILE_FORMAT(format), &it))
     {
       DBG_fprintf(stderr, "Dump ABINIT: test property '%s'.\n", it.name);
       if (strcmp(it.name, "reduced_coordinates") == 0)
@@ -121,18 +112,15 @@ static gboolean writeDataInABINIT(ToolFileFormat *format, const char* filename,
 	angdeg  = g_value_get_boolean(it.val);
     }
 
-  waitData = data;
-  waitFunc = functionWait;
-
   DBG_fprintf(stderr, "Dump ABINIT: begin export of current positions...\n");
   DBG_fprintf(stderr, " | reduced %d ;\n", reduced);
   DBG_fprintf(stderr, " | angdeg  %d ;\n", angdeg);
 
   output = g_string_new("");
 
-  nom = visu_data_getFile(dataObj, 0, (ToolFileFormat**)0);
-  if (nom)
+  if (VISU_IS_DATA_LOADABLE(dataObj))
     {
+      nom = visu_data_loadable_getFilename(VISU_DATA_LOADABLE(dataObj), 0);
       prevFile = g_path_get_basename(nom);
       g_string_append_printf(output, "# V_Sim export to ABINIT from '%s'\n", prevFile);
       g_free(prevFile);
@@ -151,7 +139,8 @@ static gboolean writeDataInABINIT(ToolFileFormat *format, const char* filename,
       strcpy(tag, "xangst");
       break;
     default:
-      g_warning("Unsupported unit for ABINIT.");
+      g_warning("Unsupported unit for ABINIT, defaulting to Bohr.");
+      /* Falls through. */
     case TOOL_UNITS_UNDEFINED:
     case TOOL_UNITS_BOHR:
       unit[0] = '\0';
@@ -224,21 +213,21 @@ static gboolean writeDataInABINIT(ToolFileFormat *format, const char* filename,
                              (vertices[4][2] - vertices[0][2]) / box[2]);
     }
 
-  visu_node_array_iterNew(VISU_NODE_ARRAY(dataObj), &iter);
+  visu_node_array_iter_new(VISU_NODE_ARRAY(dataObj), &iter);
   g_string_append_printf(output, "ntypat %d\n", iter.nElements);
   g_string_append_printf(output, "natom %d\n", iter.nAllStoredNodes);
   g_string_append(output, "znucl");
   for(visu_node_array_iterStart(VISU_NODE_ARRAY(dataObj), &iter); iter.element;
-      visu_node_array_iterNextElement(VISU_NODE_ARRAY(dataObj), &iter))
+      visu_node_array_iterNextElement(VISU_NODE_ARRAY(dataObj), &iter, FALSE))
     {
-      tool_physic_getZFromSymbol(&znucl, (float*)0, iter.element->name);
+      tool_physic_getZFromSymbol(&znucl, (float*)0, (float*)0, iter.element->name);
       g_string_append_printf(output, " %d", znucl);
     }
   g_string_append(output, "\n");
   g_string_append(output, "typat");
   for(visu_node_array_iterStart(VISU_NODE_ARRAY(dataObj), &iter); iter.node;
       visu_node_array_iterNext(VISU_NODE_ARRAY(dataObj), &iter))
-    if (iter.element->rendered && iter.node->rendered)
+    if (visu_element_getRendered(iter.element) && iter.node->rendered)
       {
         g_string_append_printf(output, " %d", iter.node->posElement + 1);
         if (iter.node->number % 10 == 9)
@@ -258,7 +247,7 @@ static gboolean writeDataInABINIT(ToolFileFormat *format, const char* filename,
           uvw[1] = xyz[1];
           uvw[2] = xyz[2];
         }
-      if (iter.element->rendered && iter.node->rendered)
+      if (visu_element_getRendered(iter.element) && iter.node->rendered)
         g_string_append_printf(output, " %17.8g %17.8g %17.8g\n", uvw[0], uvw[1], uvw[2]);
     }
   g_string_append_printf(output, "\n");
