@@ -1,20 +1,20 @@
 /*   EXTRAITS DE LA LICENCE
 	Copyright CEA, contributeurs : Damien CALISTE, laboratoire L_Sim, (2011)
   
-	Adresse ml :
+	Adresse mèl :
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -41,7 +41,7 @@
 #ifndef DUMPTOABINIT_H
 #define DUMPTOABINIT_H
 
-#include <visu_dump.h>
+#include "fileDump.h"
 
 /**
  * visu_dump_abinit_getStatic:
@@ -50,6 +50,6 @@
  *
  * Returns: (transfer none): a newly created dump object to create ABINIT files.
  */
-const VisuDump* visu_dump_abinit_getStatic();
+const VisuDumpData* visu_dump_abinit_getStatic();
 
 #endif
