@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -49,10 +49,10 @@
 #include <math.h>
 
 #include <visu_tools.h>
-#include <extraFunctions/extraNode.h>
-#include <extraFunctions/geometry.h>
+#include <visu_dataloadable.h>
+#include <extraFunctions/gdiff.h>
 
-static VisuDump *ascii = NULL;
+static VisuDumpData *ascii = NULL;
 
 /**
  * SECTION:dumpToAscii
@@ -63,14 +63,10 @@ static VisuDump *ascii = NULL;
  * or replicated nodes.
  */
 
-static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
-				 int width, int height, VisuData *dataObj,
-				 guchar* imageData, GError **error,
-				 ToolVoidDataFunc functionWait, gpointer data);
-static gpointer waitData;
-static ToolVoidDataFunc waitFunc;
+static gboolean writeDataInAscii(VisuDumpData *format, const char* filename,
+				 VisuData *dataObj, GError **error);
 
-const VisuDump* visu_dump_ascii_getStatic()
+const VisuDumpData* visu_dump_ascii_getStatic()
 {
   const gchar *typeASCII[] = {"*.ascii", (char*)0};
 #define descrASCII _("ASCII file (current positions)")
@@ -78,7 +74,7 @@ const VisuDump* visu_dump_ascii_getStatic()
   if (ascii)
     return ascii;
 
-  ascii = visu_dump_new(descrASCII, typeASCII, writeDataInAscii, FALSE);
+  ascii = visu_dump_data_new(descrASCII, typeASCII, writeDataInAscii);
   
   tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(ascii), "delete_hidden_nodes",
 				_("Don't output hidden nodes"), FALSE);
@@ -93,16 +89,11 @@ const VisuDump* visu_dump_ascii_getStatic()
   tool_file_format_addPropertyBoolean(TOOL_FILE_FORMAT(ascii), "type_alignment",
 				_("Export nodes sorted by elements"), FALSE);
 
-  waitData = (gpointer)0;
-  waitFunc = (ToolVoidDataFunc)0;
-
   return ascii;
 }
 
-static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
-				 int width _U_, int height _U_, VisuData *dataObj,
-				 guchar* imageData _U_, GError **error,
-				 ToolVoidDataFunc functionWait, gpointer data)
+static gboolean writeDataInAscii(VisuDumpData *format, const char* filename,
+				 VisuData *dataObj, GError **error)
 {
   const gchar *nom;
   gchar *prevFile;
@@ -116,6 +107,8 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
   const gchar *nodeComment;
   ToolFileFormatIter it;
   VisuBox *boxObj;
+  VisuDataDiff *geodiff;
+  VisuBoxBoundaries bc;
 
   g_return_val_if_fail(error && !*error, FALSE);
 
@@ -126,8 +119,8 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
   angdeg  = FALSE;
   eleSort = FALSE;
   it.lst = (GList*)0;
-  for (tool_file_format_iterNextProperty(format, &it); it.lst;
-       tool_file_format_iterNextProperty(format, &it))
+  for (tool_file_format_iterNextProperty(TOOL_FILE_FORMAT(format), &it); it.lst;
+       tool_file_format_iterNextProperty(TOOL_FILE_FORMAT(format), &it))
     {
       DBG_fprintf(stderr, "Dump ASCII: test property '%s'.\n", it.name);
       if (strcmp(it.name, "comment_hidden_nodes") == 0)
@@ -144,9 +137,6 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
 	eleSort = g_value_get_boolean(it.val);
     }
 
-  waitData = data;
-  waitFunc = functionWait;
-
   DBG_fprintf(stderr, "Dump ASCII: begin export of current positions...\n");
   DBG_fprintf(stderr, " | comment %d ;\n", comment);
   DBG_fprintf(stderr, " | expand  %d ;\n", expand);
@@ -157,16 +147,15 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
 
   output = g_string_new("");
 
-  nom = visu_data_getFile(dataObj, 0, (ToolFileFormat**)0);
-  if (nom)
+  if (VISU_IS_DATA_LOADABLE(dataObj))
     {
+      nom = visu_data_loadable_getFilename(VISU_DATA_LOADABLE(dataObj), 0);
       prevFile = g_path_get_basename(nom);
       g_string_append_printf(output, "# V_Sim export to ascii from '%s'\n", prevFile);
       g_free(prevFile);
     }
   else
     {
-      g_warning("Can't get the name of the file to export.");
       g_string_append(output, "# V_Sim export to ascii\n");
     }
 
@@ -241,7 +230,8 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
     default:
       break;
     }
-  switch (visu_box_getBoundary(boxObj))
+  bc = visu_box_getBoundary(boxObj);
+  switch (bc)
     {
     case VISU_BOX_SURFACE_XY:
       g_string_append(output, "#keyword: surfaceXY\n");
@@ -290,18 +280,19 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
       g_string_append(output, "# Statistics are valid for all nodes (hidden or not).\n");
       g_string_append(output, "# Hidden nodes are printed, but commented.\n");
     }
-  visu_node_array_iterNew(VISU_NODE_ARRAY(dataObj), &iter);
+  visu_node_array_iter_new(VISU_NODE_ARRAY(dataObj), &iter);
   g_string_append_printf(output, "# Box contains %d element(s).\n", iter.nElements);
   g_string_append_printf(output, "# Box contains %d nodes.\n", iter.nAllStoredNodes);
   for (visu_node_array_iterStart(VISU_NODE_ARRAY(dataObj), &iter); iter.element;
-       visu_node_array_iterNextElement(VISU_NODE_ARRAY(dataObj), &iter))
+       visu_node_array_iterNextElement(VISU_NODE_ARRAY(dataObj), &iter, FALSE))
     g_string_append_printf(output, "#  | %d nodes for element '%s'.\n",
 	    iter.nStoredNodes, iter.element->name);
   if (suppr)
     g_string_append(output, "# Hidden nodes have been suppressed.\n");
-  if (visu_geodiff_hasData(dataObj))
+  geodiff = VISU_DATA_DIFF(visu_data_getNodeProperties(dataObj, VISU_DATA_DIFF_DEFAULT_ID));
+  if (geodiff)
     {
-      diff = visu_geodiff_export(dataObj);
+      diff = visu_data_diff_export(geodiff);
       g_string_append(output, diff);
       g_free(diff);
     }
@@ -312,14 +303,14 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
        (eleSort)?visu_node_array_iterNext(VISU_NODE_ARRAY(dataObj), &iter):
 	 visu_node_array_iterNextNodeNumber(VISU_NODE_ARRAY(dataObj), &iter))
     {
-      if ((iter.element->rendered && iter.node->rendered) || !comment)
+      if ((visu_element_getRendered(iter.element) && iter.node->rendered) || !comment)
 	tmpChr = ' ';
       else
 	tmpChr = '#';
 
       visu_data_getNodePosition(dataObj, iter.node, xyz);
 
-      if ((iter.element->rendered && iter.node->rendered) || !suppr)
+      if ((visu_element_getRendered(iter.element) && iter.node->rendered) || !suppr)
 	{
 /*g_message("ext : %f,  vertices : %f, ext : %f, vertices : %f, ext : %f, vertice : %f\n",ext[0],vertices[1][0],ext[1],vertices[3][0],
 	    ext[2],vertices[4][0]);*/
@@ -331,9 +322,18 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
 	  if (reduced)
 	    {
 	      visu_box_convertXYZtoBoxCoordinates(boxObj, uvw, xyz);
-	      uvw[0] /= (1.f + 2.f * ext[0]);
-	      uvw[1] /= (1.f + 2.f * ext[1]);
-	      uvw[2] /= (1.f + 2.f * ext[2]);
+              if (bc & 1)
+                uvw[0] /= (1.f + 2.f * ext[0]);
+              else
+                uvw[0] = xyz[0];
+              if (bc & 2)
+                uvw[1] /= (1.f + 2.f * ext[1]);
+              else
+                uvw[1] = xyz[1];
+              if (bc & 4)
+                uvw[2] /= (1.f + 2.f * ext[2]);
+              else
+                uvw[2] = xyz[2];
 	    }
 	  else
 	    {
@@ -345,7 +345,7 @@ static gboolean writeDataInAscii(ToolFileFormat *format, const char* filename,
                                  uvw[0], uvw[1], uvw[2],
                                  (visu_element_getPhysical(iter.element))?' ':'%',
                                  iter.element->name);
-	  nodeComment = visu_extra_node_getLabel(dataObj, iter.node);
+	  nodeComment = visu_data_getNodeLabelAt(dataObj, iter.node);
 	  if (nodeComment)
 	    g_string_append_printf(output, " %s", nodeComment);
 	  g_string_append(output, "\n");
