@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -162,9 +162,9 @@ static guint LZWEncodeImage(guint data_size);
 static void LSBFirstWriteShort(guint value);
 
 static gboolean writeViewInGifFormat(ToolFileFormat *format, const char* filename,
-				     int width, int height, VisuData *dataObj,
-				     guchar* imageData, GError **error,
-				     ToolVoidDataFunc functionWait, gpointer data);
+				      VisuGlNodeScene *scene, guint width, guint height,
+				      GError **error, ToolVoidDataFunc functionWait,
+                                      gpointer data);
 
 
 /******************************************************************************/
@@ -221,7 +221,7 @@ guint Classification(GError **error) {
             node->mid_blue+(id & 4 ? bisect : -bisect));
           if (node->child[id] == (Node *) NULL)
 	    {
-	      *error = g_error_new(VISU_ERROR_DUMP, DUMP_ERROR_ENCODE,
+	      *error = g_error_new(VISU_DUMP_ERROR, DUMP_ERROR_ENCODE,
 				   _("Unable to quantize image, "
 				     "initialisation failed for node child %d."), id);
               return 1;
@@ -448,7 +448,7 @@ guint InitializeCube(guint number_pixels, GError **error) {
      (MaxRGB+1) >> 1,(MaxRGB+1) >> 1, (MaxRGB+1) >> 1);
   if (cube.root == (Node *) NULL)
     {
-      *error = g_error_new(VISU_ERROR_DUMP, DUMP_ERROR_ENCODE,
+      *error = g_error_new(VISU_DUMP_ERROR, DUMP_ERROR_ENCODE,
 			   _("Unable to quantize image, initialisation failed."));
       return 1;
     }
@@ -811,8 +811,7 @@ VisuDump* dumpToGif_init()
   const gchar *typeGIF[] = {"*.gif", (char*)0};
   #define descrGIF _("Gif (256 colors) file")
 
-  gif = visu_dump_new(descrGIF, typeGIF, writeViewInGifFormat, TRUE);
-  visu_dump_setHasAlpha(gif, FALSE);
+  gif = VISU_DUMP(visu_dump_scene_new(descrGIF, typeGIF, writeViewInGifFormat, FALSE));
 
   waitData = (gpointer)0;
   waitFunc = (ToolVoidDataFunc)0;
@@ -822,29 +821,38 @@ VisuDump* dumpToGif_init()
 
 
 static gboolean writeViewInGifFormat(ToolFileFormat *format _U_, const char* filename,
-				     int width, int height, VisuData *dataObj _U_,
-				     guchar* imageData, GError **error,
-				     ToolVoidDataFunc functionWait, gpointer data)
+				      VisuGlNodeScene *scene, guint width, guint height,
+				      GError **error, ToolVoidDataFunc functionWait,
+                                      gpointer data)
 {
   register guint i;
   register ColorPacket *q;
   register unsigned char *p;
   unsigned char bits_per_pixel, c;
   guint status;
+  GArray *imageData;
 
   g_return_val_if_fail(error && !*error, FALSE);
-  g_return_val_if_fail(imageData, FALSE);
 
-  waitData = data;
-  waitFunc = functionWait;
-  image    = imageData;
+  imageData = visu_gl_ext_set_getPixmapData(VISU_GL_EXT_SET(scene),
+                                            width, height, FALSE);
+  if (!imageData)
+    {
+      *error = g_error_new(VISU_DUMP_ERROR, DUMP_ERROR_OPENGL,
+                           _("Can't dump OpenGL area to data.\n"));
+      return FALSE;
+    }
+
+  waitData   = data;
+  waitFunc   = functionWait;
+  image      = (unsigned char*)imageData->data;
 
   DBG_fprintf(stderr, "Dump Gif : begin export in %dx%d...\n", width, height);
 
   file = fopen(filename, "wb");
   if(!file)
     {
-      *error = g_error_new(VISU_ERROR_DUMP, DUMP_ERROR_FILE,
+      *error = g_error_new(VISU_DUMP_ERROR, DUMP_ERROR_FILE,
 			   _("Cannot open file (to write in)."));
       return FALSE;
     }
@@ -901,8 +909,8 @@ static gboolean writeViewInGifFormat(ToolFileFormat *format _U_, const char* fil
     (void) fputc(0x0,file);
     (void) fputc(0x0,file);
   }
-  /* criture du commentaire */
-  write_comment_comm((unsigned char *)"Image cre par le programme V_Sim\n"
+  /* écriture du commentaire */
+  write_comment_comm((unsigned char *)"Image créée par le programme V_Sim\n"
 		     "Auteur : L. BILLARD");
       
   (void) fputc(',',file);  /* image separator */
@@ -918,7 +926,7 @@ static gboolean writeViewInGifFormat(ToolFileFormat *format _U_, const char* fil
   status=LZWEncodeImage(Max(bits_per_pixel,2)+1);
   if (status == False)
     {
-      *error = g_error_new(VISU_ERROR_DUMP, DUMP_ERROR_ENCODE,
+      *error = g_error_new(VISU_DUMP_ERROR, DUMP_ERROR_ENCODE,
 			   _("Fail to compress the GIF file."));
       g_free(img->pixels);
       g_free(img->colormap);
@@ -933,6 +941,8 @@ static gboolean writeViewInGifFormat(ToolFileFormat *format _U_, const char* fil
   g_free(img->pixels);
   g_free(img->colormap);
   g_free(img);
+
+  g_array_free(imageData, TRUE);
   
   return TRUE;
 }
