@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -84,21 +84,21 @@ static ToolVoidDataFunc waitFunc;
 
 
 static gboolean writeViewInPsFormat(ToolFileFormat *format, const char* filename,
-				    int width, int height, VisuData *dataObj,
-				    guchar* imageData, GError **error,
-				    ToolVoidDataFunc functionWait, gpointer data);
+                                    VisuGlNodeScene *scene, guint width, guint height,
+                                    GError **error, ToolVoidDataFunc functionWait,
+                                    gpointer data);
 static gboolean writeViewInPs256Format(const char* filename,
-				       int width, int height, VisuData *dataObj,
+				       int width, int height,
 				       guchar* imageData, GError **error,
 				       ToolVoidDataFunc functionWait, gpointer data);
 static gboolean writePsTrueColor(const char* filename,
-				 int width, int height, VisuData *dataObj,
+				 int width, int height,
 				 guchar* imageData, GError **error,
 				 ToolVoidDataFunc functionWait, gpointer data);
 static gboolean writeViewInPdfFormat(ToolFileFormat *format, const char* filename,
-				     int width, int height, VisuData *dataObj,
-				     guchar* imageData, GError **error,
-				     ToolVoidDataFunc functionWait, gpointer data);
+                                     VisuGlNodeScene *scene, guint width, guint height,
+                                     GError **error, ToolVoidDataFunc functionWait,
+                                     gpointer data);
 
 static VisuDump *ps;
 const VisuDump* visu_dump_bitmap_ps_getStatic()
@@ -109,8 +109,7 @@ const VisuDump* visu_dump_bitmap_ps_getStatic()
   if (ps)
     return ps;
 
-  ps = visu_dump_new(descrPS, typePS, writeViewInPsFormat, TRUE);
-  visu_dump_setHasAlpha(ps, FALSE);
+  ps = VISU_DUMP(visu_dump_scene_new(descrPS, typePS, writeViewInPsFormat, FALSE));
 
   waitFunc = (ToolVoidDataFunc)0;
   waitData = (gpointer)0;
@@ -129,8 +128,7 @@ const VisuDump* visu_dump_bitmap_pdf_getStatic()
   if (pdf)
     return pdf;
 
-  pdf = visu_dump_new(descrPDF, typePDF, writeViewInPdfFormat, TRUE);
-  visu_dump_setHasAlpha(pdf, FALSE);
+  pdf = VISU_DUMP(visu_dump_scene_new(descrPDF, typePDF, writeViewInPdfFormat, FALSE));
 
   waitFunc = (ToolVoidDataFunc)0;
   waitData = (gpointer)0;
@@ -334,29 +332,35 @@ static void OutputDataPS256() {
 /******************************************************************************/
 
 static gboolean writeViewInPsFormat(ToolFileFormat *format, const char* filename,
-				    int width, int height, VisuData *dataObj,
-				    guchar* imageData, GError **error,
-				    ToolVoidDataFunc functionWait, gpointer data)
+                                    VisuGlNodeScene *scene, guint width, guint height,
+                                    GError **error, ToolVoidDataFunc functionWait _U_,
+                                    gpointer data _U_)
 {
-  ToolOption *prop;
-  GValue *val;
+  GArray *imageData;
 
-  prop = tool_file_format_getPropertyByName(format, "reduced_colormap");
-  g_return_val_if_fail(prop, FALSE);
+  imageData = visu_gl_ext_set_getPixmapData(VISU_GL_EXT_SET(scene),
+                                            width, height, FALSE);
+  if (!imageData)
+    {
+      *error = g_error_new(VISU_DUMP_ERROR, DUMP_ERROR_OPENGL,
+                           _("Can't dump OpenGL area to data.\n"));
+      return FALSE;
+    }
 
-  val = tool_option_getValue(prop);
-  if (g_value_get_boolean(val))
-    return writeViewInPs256Format(filename, width, height, dataObj,
-                                  imageData, error, functionWait, data);
+  if (tool_file_format_getPropertyBoolean(format, "reduced_colormap"))
+    return writeViewInPs256Format(filename, width, height,
+                                  (unsigned char*)imageData->data, error, functionWait, data);
   else
-    return writePsTrueColor(filename, width, height, dataObj,
-                            imageData, error, functionWait, data);
+    return writePsTrueColor(filename, width, height,
+                            (unsigned char*)imageData->data, error, functionWait, data);
+
+  g_array_free(imageData, TRUE);
 }
 
 /******************************************************************************/
 
 static gboolean writePsTrueColor(const char* filename,
-				 int width, int height, VisuData *dataObj _U_,
+				 int width, int height,
 				 guchar* imageData, GError **error,
 				 ToolVoidDataFunc functionWait _U_, gpointer data _U_)
 {
@@ -378,7 +382,7 @@ static gboolean writePsTrueColor(const char* filename,
   out = fopen(filename, "w");
   if(!out)
     {
-      *error = g_error_new(VISU_ERROR_DUMP, DUMP_ERROR_FILE,
+      *error = g_error_new(VISU_DUMP_ERROR, DUMP_ERROR_FILE,
 			   _("Cannot open file (to write in)."));
       return FALSE;
     }                  
@@ -455,10 +459,11 @@ static gboolean writePsTrueColor(const char* filename,
 /******************************************************************************/
 
 static gboolean writeViewInPdfFormat(ToolFileFormat *format _U_, const char* filename,
-				     int width, int height, VisuData *dataObj _U_,
-				     guchar* imageData, GError **error,
-				     ToolVoidDataFunc functionWait _U_, gpointer data _U_)
+				      VisuGlNodeScene *scene, guint width, guint height,
+				      GError **error, ToolVoidDataFunc functionWait _U_,
+                                      gpointer data _U_)
 {
+  GArray *imageData;
   time_t timer;
    
   struct tm *ltm;
@@ -467,9 +472,17 @@ static gboolean writeViewInPdfFormat(ToolFileFormat *format _U_, const char* fil
   int i;    
          
   g_return_val_if_fail(error && !*error, FALSE);
-  g_return_val_if_fail(imageData, FALSE);
 
-  image    = imageData;
+  imageData = visu_gl_ext_set_getPixmapData(VISU_GL_EXT_SET(scene),
+                                            width, height, FALSE);
+  if (!imageData)
+    {
+      *error = g_error_new(VISU_DUMP_ERROR, DUMP_ERROR_OPENGL,
+                           _("Can't dump OpenGL area to data.\n"));
+      return FALSE;
+    }
+
+  image      = (unsigned char*)imageData->data;
   PSwidth  = width;
   PSheight = height;
 
@@ -479,7 +492,7 @@ static gboolean writeViewInPdfFormat(ToolFileFormat *format _U_, const char* fil
   out = fopen(filename, "w");
   if(!out)
     {
-      *error = g_error_new(VISU_ERROR_DUMP, DUMP_ERROR_FILE,
+      *error = g_error_new(VISU_DUMP_ERROR, DUMP_ERROR_FILE,
 			   _("Cannot open file (to write in)."));
       return FALSE;
     }
@@ -576,13 +589,16 @@ static gboolean writeViewInPdfFormat(ToolFileFormat *format _U_, const char* fil
   (void)fprintf(out, "%%%%EOF\n");
     
   (void)fclose(out);
+
+  g_array_free(imageData, TRUE);
+
   return TRUE;
 }
 
 /******************************************************************************/
 
 static gboolean writeViewInPs256Format(const char* filename,
-				       int width, int height, VisuData *dataObj _U_,
+				       int width, int height,
 				       guchar* imageData, GError **error,
 				       ToolVoidDataFunc functionWait, gpointer data)
 {
@@ -635,7 +651,7 @@ static gboolean writeViewInPs256Format(const char* filename,
   out = fopen(filename, "w");
   if(!out)
     {
-      *error = g_error_new(VISU_ERROR_DUMP, DUMP_ERROR_FILE,
+      *error = g_error_new(VISU_DUMP_ERROR, DUMP_ERROR_FILE,
 			   _("Cannot open file (to write in)."));
       g_free(img->pixels);
       g_free(img->colormap);
