@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -47,6 +47,7 @@
 #include <visu_extension.h>
 #include <visu_box.h>
 #include <openGLFunctions/view.h>
+#include "iface_lined.h"
 
 /**
  * VISU_TYPE_GL_EXT_AXES:
@@ -106,6 +107,13 @@ typedef struct _VisuGlExtAxes        VisuGlExtAxes;
 typedef struct _VisuGlExtAxesPrivate VisuGlExtAxesPrivate;
 typedef struct _VisuGlExtAxesClass   VisuGlExtAxesClass;
 
+/**
+ * VisuGlExtAxes:
+ *
+ * An opaque structure.
+ *
+ * Since: 3.7
+ */
 struct _VisuGlExtAxes
 {
   VisuGlExt parent;
@@ -113,6 +121,14 @@ struct _VisuGlExtAxes
   VisuGlExtAxesPrivate *priv;
 };
 
+/**
+ * VisuGlExtAxesClass:
+ * @parent: the parent class;
+ *
+ * A short way to identify #_VisuGlExtAxesClass structure.
+ *
+ * Since: 3.7
+ */
 struct _VisuGlExtAxesClass
 {
   VisuGlExtClass parent;
@@ -140,20 +156,17 @@ GType visu_gl_ext_axes_get_type(void);
 
 VisuGlExtAxes* visu_gl_ext_axes_new(const gchar *name);
 
-gboolean visu_gl_ext_axes_setRGB(VisuGlExtAxes *axes, float rgb[3], int mask);
-gboolean visu_gl_ext_axes_setLineWidth(VisuGlExtAxes *axes, float width);
-gboolean visu_gl_ext_axes_setLineStipple(VisuGlExtAxes *axes, guint16 stipple);
 gboolean visu_gl_ext_axes_setBasisFromBox(VisuGlExtAxes *axes, VisuBox *box);
 gboolean visu_gl_ext_axes_setBasis(VisuGlExtAxes *axes, double matrix[3][3]);
 gboolean visu_gl_ext_axes_setPosition(VisuGlExtAxes *axes, float xpos, float ypos);
 
-float*  visu_gl_ext_axes_getRGB(VisuGlExtAxes *axes);
-float   visu_gl_ext_axes_getLineWidth(VisuGlExtAxes *axes);
-guint16 visu_gl_ext_axes_getLineStipple(VisuGlExtAxes *axes);
-void visu_gl_ext_axes_getPosition(VisuGlExtAxes *axes, float *xpos, float *ypos);
-VisuGlExtAxes* visu_gl_ext_axes_getDefault();
+gboolean visu_gl_ext_axes_setLabel(VisuGlExtAxes *axes, const gchar *lbl, ToolXyzDir dir);
+gboolean visu_gl_ext_axes_setLengthFactor(VisuGlExtAxes *axes, float factor);
+gboolean visu_gl_ext_axes_useOrientation(VisuGlExtAxes *axes, gboolean use);
+gboolean visu_gl_ext_axes_setOrientationTop(VisuGlExtAxes *axes,
+                                            const gfloat top[3], int dir);
 
-gboolean visu_gl_ext_axes_setGlView(VisuGlExtAxes *axes, VisuGlView *view);
-void visu_gl_ext_axes_draw(VisuGlExtAxes *axes);
+void visu_gl_ext_axes_getPosition(VisuGlExtAxes *axes, float *xpos, float *ypos);
+float visu_gl_ext_axes_getLengthFactor(VisuGlExtAxes *axes);
 
 #endif
