@@ -97,6 +97,18 @@ struct _VisuGlExtFramePrivate
   VisuGlView *view;
   gulong widthHeight_signal;
 };
+
+enum
+  {
+    PROP_0,
+    XPOS_PROP,
+    YPOS_PROP,
+    XPAD_PROP,
+    YPAD_PROP,
+    N_PROP
+  };
+static GParamSpec *properties[N_PROP];
+
 static int refMask[4] = {TOOL_COLOR_MASK_R, TOOL_COLOR_MASK_G,
                          TOOL_COLOR_MASK_B, TOOL_COLOR_MASK_A};
 static float bgRGBADefault[4] = {1.f, 1.f, 1.f, 0.4f};
@@ -106,10 +118,17 @@ static float xpadDefault = 5.f, ypadDefault = 5.f;
 
 static void visu_gl_ext_frame_finalize(GObject* obj);
 static void visu_gl_ext_frame_dispose(GObject* obj);
+static void visu_gl_ext_frame_get_property(GObject* obj, guint property_id,
+                                           GValue *value, GParamSpec *pspec);
+static void visu_gl_ext_frame_set_property(GObject* obj, guint property_id,
+                                           const GValue *value, GParamSpec *pspec);
+static void visu_gl_ext_frame_draw(VisuGlExt *ext);
+static gboolean visu_gl_ext_frame_setGlView(VisuGlExt *frame, VisuGlView *view);
 
 static void onViewChanged(VisuGlView *view, gpointer data);
 
-G_DEFINE_TYPE(VisuGlExtFrame, visu_gl_ext_frame, VISU_TYPE_GL_EXT)
+G_DEFINE_TYPE_WITH_CODE(VisuGlExtFrame, visu_gl_ext_frame, VISU_TYPE_GL_EXT,
+                        G_ADD_PRIVATE(VisuGlExtFrame))
 
 static void visu_gl_ext_frame_class_init(VisuGlExtFrameClass *klass)
 {
@@ -122,6 +141,63 @@ static void visu_gl_ext_frame_class_init(VisuGlExtFrameClass *klass)
   /* Connect the overloading methods. */
   G_OBJECT_CLASS(klass)->dispose  = visu_gl_ext_frame_dispose;
   G_OBJECT_CLASS(klass)->finalize = visu_gl_ext_frame_finalize;
+  G_OBJECT_CLASS(klass)->set_property = visu_gl_ext_frame_set_property;
+  G_OBJECT_CLASS(klass)->get_property = visu_gl_ext_frame_get_property;
+  VISU_GL_EXT_CLASS(klass)->draw = visu_gl_ext_frame_draw;
+  VISU_GL_EXT_CLASS(klass)->setGlView = visu_gl_ext_frame_setGlView;
+
+  /**
+   * VisuGlExtFrame::x-pos:
+   *
+   * Store the position along x of the frame.
+   *
+   * Since: 3.8
+   */
+  properties[XPOS_PROP] = g_param_spec_float("x-pos", "x position",
+                                             "position along x axis",
+                                             0., 1., 0.,
+                                             G_PARAM_READWRITE);
+  g_object_class_install_property(G_OBJECT_CLASS(klass), XPOS_PROP,
+				  properties[XPOS_PROP]);
+  /**
+   * VisuGlExtFrame::y-pos:
+   *
+   * Store the position along y of the frame.
+   *
+   * Since: 3.8
+   */
+  properties[YPOS_PROP] = g_param_spec_float("y-pos", "y position",
+                                             "position along y axis",
+                                             0., 1., 1.,
+                                             G_PARAM_READWRITE);
+  g_object_class_install_property(G_OBJECT_CLASS(klass), YPOS_PROP,
+				  properties[YPOS_PROP]);
+  /**
+   * VisuGlExtFrame::x-padding:
+   *
+   * Store the padding along x of the frame.
+   *
+   * Since: 3.8
+   */
+  properties[XPAD_PROP] = g_param_spec_float("x-padding", "x padding",
+                                             "padding along x axis",
+                                             0., 30., xpadDefault,
+                                             G_PARAM_READWRITE);
+  g_object_class_install_property(G_OBJECT_CLASS(klass), XPAD_PROP,
+				  properties[XPAD_PROP]);
+  /**
+   * VisuGlExtFrame::y-padding:
+   *
+   * Store the padding along y of the frame.
+   *
+   * Since: 3.8
+   */
+  properties[YPAD_PROP] = g_param_spec_float("y-padding", "y padding",
+                                             "padding along y axis",
+                                             0., 30., ypadDefault,
+                                             G_PARAM_READWRITE);
+  g_object_class_install_property(G_OBJECT_CLASS(klass), YPAD_PROP,
+				  properties[YPAD_PROP]);
 }
 
 static void visu_gl_ext_frame_init(VisuGlExtFrame *obj)
@@ -129,14 +205,13 @@ static void visu_gl_ext_frame_init(VisuGlExtFrame *obj)
   DBG_fprintf(stderr, "Extension Frame: initializing a new object (%p).\n",
 	      (gpointer)obj);
 
-  obj->isBuilt    = FALSE;
   obj->width      = 0;
   obj->height     = 0;
   obj->fontRGB[0] = fontRGBDefault[0];
   obj->fontRGB[1] = fontRGBDefault[1];
   obj->fontRGB[2] = fontRGBDefault[2];
   
-  obj->priv = g_malloc(sizeof(VisuGlExtFramePrivate));
+  obj->priv = visu_gl_ext_frame_get_instance_private(obj);
   obj->priv->dispose_has_run = FALSE;
 
   /* Private data. */
@@ -173,7 +248,7 @@ static void visu_gl_ext_frame_dispose(GObject* obj)
   frame->priv->dispose_has_run = TRUE;
 
   /* Disconnect signals. */
-  visu_gl_ext_frame_setGlView(frame, (VisuGlView*)0);
+  visu_gl_ext_frame_setGlView(VISU_GL_EXT(obj), (VisuGlView*)0);
 
   /* Chain up to the parent class */
   G_OBJECT_CLASS(visu_gl_ext_frame_parent_class)->dispose(obj);
@@ -193,7 +268,6 @@ static void visu_gl_ext_frame_finalize(GObject* obj)
     {
       DBG_fprintf(stderr, "Extension Frame: free private frame.\n");
       g_free(frame->priv->title);
-      g_free(frame->priv);
     }
 
   /* Chain up to the parent class */
@@ -202,41 +276,96 @@ static void visu_gl_ext_frame_finalize(GObject* obj)
   DBG_fprintf(stderr, "Extension Frame: freeing ... OK.\n");
 }
 
-/**
- * visu_gl_ext_frame_setGlView:
- * @frame: The #VisuGlExtFrame to attached to.
- * @view: the nodes to get the population of.
- *
- * Attach an #VisuGlView to render to and setup the frame.
- *
- * Since: 3.7
- *
- * Returns: TRUE if visu_gl_ext_frame_draw() should be called and
- * then 'OpenGLAskForReDraw' signal be emitted.
- **/
-gboolean visu_gl_ext_frame_setGlView(VisuGlExtFrame *frame, VisuGlView *view)
+static void visu_gl_ext_frame_get_property(GObject* obj, guint property_id,
+                                          GValue *value, GParamSpec *pspec)
 {
-  g_return_val_if_fail(VISU_IS_GL_EXT_FRAME(frame), FALSE);
+  VisuGlExtFrame *self = VISU_GL_EXT_FRAME(obj);
 
-  if (frame->priv->view)
+  DBG_fprintf(stderr, "Extension Frame: get property '%s' -> ",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
     {
-      g_signal_handler_disconnect(G_OBJECT(frame->priv->view), frame->priv->widthHeight_signal);
-      g_object_unref(frame->priv->view);
+    case XPOS_PROP:
+      g_value_set_float(value, self->priv->xpos);
+      DBG_fprintf(stderr, "%g.\n", self->priv->xpos);
+      break;
+    case YPOS_PROP:
+      g_value_set_float(value, self->priv->ypos);
+      DBG_fprintf(stderr, "%g.\n", self->priv->ypos);
+      break;
+    case XPAD_PROP:
+      g_value_set_float(value, self->priv->xpad);
+      DBG_fprintf(stderr, "%g.\n", self->priv->xpad);
+      break;
+    case YPAD_PROP:
+      g_value_set_float(value, self->priv->ypad);
+      DBG_fprintf(stderr, "%g.\n", self->priv->ypad);
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
+static void visu_gl_ext_frame_set_property(GObject* obj, guint property_id,
+                                          const GValue *value, GParamSpec *pspec)
+{
+  VisuGlExtFrame *self = VISU_GL_EXT_FRAME(obj);
+
+  DBG_fprintf(stderr, "Extension Frame: set property '%s' -> ",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case XPOS_PROP:
+      visu_gl_ext_frame_setPosition(self, g_value_get_float(value), self->priv->ypos);
+      DBG_fprintf(stderr, "%g.\n", self->priv->xpos);
+      break;
+    case YPOS_PROP:
+      visu_gl_ext_frame_setPosition(self, self->priv->xpos, g_value_get_float(value));
+      DBG_fprintf(stderr, "%g.\n", self->priv->ypos);
+      break;
+    case XPAD_PROP:
+      DBG_fprintf(stderr, "%g.\n", g_value_get_float(value));
+      visu_gl_ext_frame_setPadding(self, g_value_get_float(value), self->priv->ypad);
+      break;
+    case YPAD_PROP:
+      DBG_fprintf(stderr, "%g.\n", g_value_get_float(value));
+      visu_gl_ext_frame_setPadding(self, self->priv->xpad, g_value_get_float(value));
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
+
+static gboolean visu_gl_ext_frame_setGlView(VisuGlExt *frame, VisuGlView *view)
+{
+  VisuGlExtFramePrivate *priv = VISU_GL_EXT_FRAME(frame)->priv;
+
+  if (priv->view == view)
+    return FALSE;
+
+  if (priv->view)
+    {
+      g_signal_handler_disconnect(G_OBJECT(priv->view), priv->widthHeight_signal);
+      g_object_unref(priv->view);
     }
   if (view)
     {
       g_object_ref(view);
-      frame->priv->widthHeight_signal =
+      priv->widthHeight_signal =
         g_signal_connect(G_OBJECT(view), "WidthHeightChanged",
                          G_CALLBACK(onViewChanged), (gpointer)frame);
     }
   else
-    frame->priv->widthHeight_signal = 0;
-  frame->priv->view = view;
+    priv->widthHeight_signal = 0;
+  priv->view = view;
 
-  frame->isBuilt = FALSE;
-  return visu_gl_ext_getActive(VISU_GL_EXT(frame));
+  visu_gl_ext_setDirty(frame, TRUE);
+  return TRUE;
 }
+
 /**
  * visu_gl_ext_frame_setPosition:
  * @frame: the #VisuGlExtFrame object to modify.
@@ -247,20 +376,77 @@ gboolean visu_gl_ext_frame_setGlView(VisuGlExtFrame *frame, VisuGlView *view)
  *
  * Since: 3.7
  *
- * Returns: TRUE if visu_gl_ext_frame_draw() should be called and
- * then 'OpenGLAskForReDraw' signal be emitted.
+ * Returns: TRUE if any position is actually changed.
  **/
 gboolean visu_gl_ext_frame_setPosition(VisuGlExtFrame *frame, float xpos, float ypos)
 {
+  gboolean changed;
+
   g_return_val_if_fail(VISU_IS_GL_EXT_FRAME(frame), FALSE);
 
-  if (xpos == frame->priv->xpos && ypos == frame->priv->ypos)
-    return FALSE;
-  frame->priv->xpos = CLAMP(xpos, 0.f, 1.f);
-  frame->priv->ypos = CLAMP(ypos, 0.f, 1.f);
+  xpos = CLAMP(xpos, 0.f, 1.f);
+  ypos = CLAMP(ypos, 0.f, 1.f);
+  changed = FALSE;
 
-  frame->isBuilt = FALSE;
-  return visu_gl_ext_getActive(VISU_GL_EXT(frame));
+  g_object_freeze_notify(G_OBJECT(frame));
+  if (xpos != frame->priv->xpos)
+    {
+      frame->priv->xpos = xpos;
+      g_object_notify_by_pspec(G_OBJECT(frame), properties[XPOS_PROP]);
+      changed = TRUE;
+    }
+  if (ypos != frame->priv->ypos)
+    {
+      frame->priv->ypos = ypos;
+      g_object_notify_by_pspec(G_OBJECT(frame), properties[YPOS_PROP]);
+      changed = TRUE;
+    }
+  if (changed)
+    visu_gl_ext_setDirty(VISU_GL_EXT(frame), TRUE);
+  g_object_thaw_notify(G_OBJECT(frame));
+
+  return changed;
+}
+/**
+ * visu_gl_ext_frame_setPadding:
+ * @frame: the #VisuGlExtFrame object to modify.
+ * @xpad: the padding along x.
+ * @ypad: the padding along y.
+ *
+ * Change the padding of the frame representation.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if any position is actually changed.
+ **/
+gboolean visu_gl_ext_frame_setPadding(VisuGlExtFrame *frame, float xpad, float ypad)
+{
+  gboolean changed;
+
+  g_return_val_if_fail(VISU_IS_GL_EXT_FRAME(frame), FALSE);
+
+  xpad = CLAMP(xpad, 0.f, 30.f);
+  ypad = CLAMP(ypad, 0.f, 30.f);
+  changed = FALSE;
+
+  g_object_freeze_notify(G_OBJECT(frame));
+  if (xpad != frame->priv->xpad)
+    {
+      frame->priv->xpad = xpad;
+      g_object_notify_by_pspec(G_OBJECT(frame), properties[XPAD_PROP]);
+      changed = TRUE;
+    }
+  if (ypad != frame->priv->ypad)
+    {
+      frame->priv->ypad = ypad;
+      g_object_notify_by_pspec(G_OBJECT(frame), properties[YPAD_PROP]);
+      changed = TRUE;
+    }
+  if (changed)
+    visu_gl_ext_setDirty(VISU_GL_EXT(frame), TRUE);
+  g_object_thaw_notify(G_OBJECT(frame));
+
+  return changed;
 }
 #define SET_RGBA_I(S, I, V, M) {if (M & refMask[I] && S[I] != V[I]) \
       {S[I] = V[I]; diff = TRUE;}}
@@ -282,7 +468,7 @@ gboolean visu_gl_ext_frame_setPosition(VisuGlExtFrame *frame, float xpos, float
  *
  * Since: 3.7
  *
- * Returns: TRUE if visu_gl_ext_frame_draw() should be called.
+ * Returns: TRUE if value is actually changed.
  */
 gboolean visu_gl_ext_frame_setBgRGBA(VisuGlExtFrame *frame, float rgba[4], int mask)
 {
@@ -294,8 +480,8 @@ gboolean visu_gl_ext_frame_setBgRGBA(VisuGlExtFrame *frame, float rgba[4], int m
   if (!diff)
     return FALSE;
 
-  frame->isBuilt = FALSE;
-  return visu_gl_ext_getActive(VISU_GL_EXT(frame));
+  visu_gl_ext_setDirty(VISU_GL_EXT(frame), TRUE);
+  return TRUE;
 }
 /**
  * visu_gl_ext_frame_setFontRGB:
@@ -311,7 +497,7 @@ gboolean visu_gl_ext_frame_setBgRGBA(VisuGlExtFrame *frame, float rgba[4], int m
  *
  * Since: 3.7
  *
- * Returns: TRUE if visu_gl_ext_frame_draw() should be called.
+ * Returns: TRUE if value is actually changed.
  */
 gboolean visu_gl_ext_frame_setFontRGB(VisuGlExtFrame *frame, float rgb[3], int mask)
 {
@@ -323,8 +509,8 @@ gboolean visu_gl_ext_frame_setFontRGB(VisuGlExtFrame *frame, float rgb[3], int m
   if (!diff)
     return FALSE;
 
-  frame->isBuilt = FALSE;
-  return visu_gl_ext_getActive(VISU_GL_EXT(frame));
+  visu_gl_ext_setDirty(VISU_GL_EXT(frame), TRUE);
+  return TRUE;
 }
 /**
  * visu_gl_ext_frame_setScale:
@@ -335,7 +521,7 @@ gboolean visu_gl_ext_frame_setFontRGB(VisuGlExtFrame *frame, float rgb[3], int m
  *
  * Since: 3.7
  *
- * Returns: TRUE if visu_gl_ext_frame_draw() should be called.
+ * Returns: TRUE if value is actually changed.
  **/
 gboolean visu_gl_ext_frame_setScale(VisuGlExtFrame *frame, float scale)
 {
@@ -346,8 +532,8 @@ gboolean visu_gl_ext_frame_setScale(VisuGlExtFrame *frame, float scale)
 
   frame->priv->scale = CLAMP(scale, 0.01f, 10.f);
 
-  frame->isBuilt = FALSE;
-  return visu_gl_ext_getActive(VISU_GL_EXT(frame));
+  visu_gl_ext_setDirty(VISU_GL_EXT(frame), TRUE);
+  return TRUE;
 }
 /**
  * visu_gl_ext_frame_setTitle:
@@ -358,8 +544,7 @@ gboolean visu_gl_ext_frame_setScale(VisuGlExtFrame *frame, float scale)
  *
  * Since: 3.7
  *
- * Returns: TRUE if visu_gl_ext_frame_draw() should be called and
- * then 'OpenGLAskForReDraw' signal be emitted.
+ * Returns: TRUE if title is actually changed.
  **/
 gboolean visu_gl_ext_frame_setTitle(VisuGlExtFrame *frame, const gchar *title)
 {
@@ -370,8 +555,8 @@ gboolean visu_gl_ext_frame_setTitle(VisuGlExtFrame *frame, const gchar *title)
   g_free(frame->priv->title);
   frame->priv->title = g_strdup(title);
 
-  frame->isBuilt = FALSE;
-  return visu_gl_ext_getActive(VISU_GL_EXT(frame));
+  visu_gl_ext_setDirty(VISU_GL_EXT(frame), TRUE);
+  return TRUE;
 }
 /**
  * visu_gl_ext_frame_setRequisition:
@@ -384,8 +569,7 @@ gboolean visu_gl_ext_frame_setTitle(VisuGlExtFrame *frame, const gchar *title)
  *
  * Since: 3.7
  *
- * Returns: TRUE if visu_gl_ext_frame_draw() should be called and
- * then 'OpenGLAskForReDraw' signal be emitted.
+ * Returns: TRUE if requested size is changed.
  **/
 gboolean visu_gl_ext_frame_setRequisition(VisuGlExtFrame *frame, guint width, guint height)
 {
@@ -398,8 +582,8 @@ gboolean visu_gl_ext_frame_setRequisition(VisuGlExtFrame *frame, guint width, gu
   frame->priv->requisition[0] = width;
   frame->priv->requisition[1] = height;
 
-  frame->isBuilt = FALSE;
-  return visu_gl_ext_getActive(VISU_GL_EXT(frame));
+  visu_gl_ext_setDirty(VISU_GL_EXT(frame), TRUE);
+  return TRUE;
 }
 
 /**
@@ -412,7 +596,7 @@ gboolean visu_gl_ext_frame_setRequisition(VisuGlExtFrame *frame, guint width, gu
  *
  * Returns: the scaling factor used to represent frames.
  **/
-float visu_gl_ext_frame_getScale(VisuGlExtFrame *frame)
+float visu_gl_ext_frame_getScale(const VisuGlExtFrame *frame)
 {
   g_return_val_if_fail(VISU_IS_GL_EXT_FRAME(frame), 1.f);
 
@@ -428,7 +612,8 @@ float visu_gl_ext_frame_getScale(VisuGlExtFrame *frame)
  *
  * Since: 3.7
  **/
-void visu_gl_ext_frame_getPosition(VisuGlExtFrame *frame, float *xpos, float *ypos)
+void visu_gl_ext_frame_getPosition(const VisuGlExtFrame *frame,
+                                   float *xpos, float *ypos)
 {
   g_return_if_fail(VISU_IS_GL_EXT_FRAME(frame));
 
@@ -440,8 +625,7 @@ void visu_gl_ext_frame_getPosition(VisuGlExtFrame *frame, float *xpos, float *yp
 
 static void onViewChanged(VisuGlView *view _U_, gpointer data)
 {
-  VISU_GL_EXT_FRAME(data)->isBuilt = FALSE;
-  visu_gl_ext_frame_draw(VISU_GL_EXT_FRAME(data));
+  visu_gl_ext_setDirty(VISU_GL_EXT(data), TRUE);
 }
 
 /**
@@ -452,24 +636,27 @@ static void onViewChanged(VisuGlView *view _U_, gpointer data)
  *
  * Since: 3.7
  */
-void visu_gl_ext_frame_draw(VisuGlExtFrame *frame)
+static void visu_gl_ext_frame_draw(VisuGlExt *ext)
 {
   int viewport[4];
   float requisition[2];
+  VisuGlExtFrame *frame;
   VisuGlExtFrameClass *klass;
-  int xpos, ypos;
+  int xpos, ypos, dx, dy;
 
-  g_return_if_fail(VISU_IS_GL_EXT_FRAME(frame));
-
-  /* Nothing to draw; */
-  if(!visu_gl_ext_getActive(VISU_GL_EXT(frame)) || frame->isBuilt)
-    return;
+  g_return_if_fail(VISU_IS_GL_EXT_FRAME(ext));
+  frame = VISU_GL_EXT_FRAME(ext);
 
   DBG_fprintf(stderr, "Visu GlExt Frame: drawing the extension '%p'.\n", (gpointer)frame);
 
+  klass = VISU_GL_EXT_FRAME_GET_CLASS(frame);
+  if (!klass->draw ||
+      (klass->isValid && !klass->isValid(frame)))
+    return;
+
   visu_gl_text_initFontList();
 
-  glNewList(visu_gl_ext_getGlList(VISU_GL_EXT(frame)), GL_COMPILE);
+  visu_gl_ext_startDrawing(ext);
 
   /* We get the size of the current viewport. */
   glGetIntegerv(GL_VIEWPORT, viewport);
@@ -527,30 +714,32 @@ void visu_gl_ext_frame_draw(VisuGlExtFrame *frame)
     }
 
   /* We change again the viewport to adjust to padding. */
-  xpos += frame->priv->xpad * frame->priv->scale;
-  ypos += frame->priv->ypad * frame->priv->scale;
-  frame->width -= 2.f * frame->priv->xpad * frame->priv->scale;
-  frame->height -= 2.f * frame->priv->ypad * frame->priv->scale;
+  dx = frame->priv->xpad * frame->priv->scale;
+  dy = frame->priv->ypad * frame->priv->scale;
+  xpos += dx;
+  ypos += dy;
+  frame->width -= 2.f * dx * frame->priv->scale;
+  frame->height -= 2.f * dy * frame->priv->scale;
   if (frame->priv->title[0])
     frame->height -= (frame->priv->ypad + 12.) * frame->priv->scale;
+  if (frame->width > (guint)viewport[2])
+    frame->width = 0;
+  if (frame->height > (guint)viewport[3])
+    frame->height = 0;
   DBG_fprintf(stderr, "Visu GlExt Frame: frame actual size is %dx%d.\n",
               frame->width, frame->height);
-  glViewport(xpos, ypos, frame->width + frame->priv->scale,
-             frame->height + frame->priv->scale);
+  glViewport(xpos, ypos, frame->width, frame->height);
   glPopMatrix();
   glMatrixMode(GL_PROJECTION);
   glPopMatrix();
   glPushMatrix();
   glLoadIdentity();
-  glOrtho(0., (float)(frame->width + frame->priv->scale),
-          0., (float)(frame->height + frame->priv->scale), -50., +50.);  
+  glOrtho(0., (float)frame->width, 0., (float)frame->height, -50., +50.);  
   glMatrixMode(GL_MODELVIEW);
   glPushMatrix();
   glLoadIdentity();
   
-  klass = VISU_GL_EXT_FRAME_GET_CLASS(frame);
-  if (klass->draw)
-    klass->draw(frame);
+  klass->draw(frame);
 
   /* We change the projection back. */
   glPopMatrix();
@@ -563,7 +752,5 @@ void visu_gl_ext_frame_draw(VisuGlExtFrame *frame)
               viewport[2], viewport[3]);
   glViewport(0, 0, viewport[2], viewport[3]);
 
-  glEndList();
-
-  frame->isBuilt = TRUE;
+  visu_gl_ext_completeDrawing(ext);
 }
