@@ -2,20 +2,20 @@
 	Copyright CEA, contributeurs : Damien
 	CALISTE, laboratoire L_Sim, (2001-2009)
   
-	Adresse ml :
+	Adresse mèl :
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -41,12 +41,9 @@
 */
 #include "legend.h"
 
-#include <visu_object.h>
 #include <visu_configFile.h>
 #include <openGLFunctions/objectList.h>
 #include <openGLFunctions/text.h>
-#include <coreTools/toolConfigFile.h>
-#include <coreTools/toolColor.h>
 
 /**
  * SECTION:legend
@@ -95,26 +92,25 @@ struct _VisuGlExtLegendPrivate
   gboolean dispose_has_run;
 
   /* Legend definition. */
-  VisuNodeArray *nodes;
-  gulong popInc_signal, popDec_signal, eleSize_hook;
+  VisuNodeArrayRenderer *nodes;
+  gulong col_sig, mat_sig, pop_sig, siz_sig, ren_sig;
 };
 static VisuGlExtLegend* defaultLegend;
 
-static void visu_gl_ext_legend_finalize(GObject* obj);
 static void visu_gl_ext_legend_dispose(GObject* obj);
-static void visu_gl_ext_legend_draw(VisuGlExtFrame *legend);
+static void visu_gl_ext_legend_draw(const VisuGlExtFrame *legend);
+static gboolean visu_gl_ext_legend_isValid(const VisuGlExtFrame *legend);
 static void visu_gl_ext_legend_rebuild(VisuGlExt *ext);
 
 /* Local callbacks. */
-static void onNodePopulationChanged(VisuNodeArray *array, int *nodes, gpointer data);
-static gboolean onElementSize(GSignalInvocationHint *ihint, guint nvalues,
-                              const GValue *param_values, gpointer data);
-static void onEntryUsed(VisuGlExtLegend *lg, gchar *key, VisuObject *obj);
+static void setDirty(VisuGlExt *ext);
+static void onEntryUsed(VisuGlExtLegend *lg, VisuConfigFileEntry *entry, VisuConfigFile *obj);
 
 /* Local routines. */
-static void exportResources(GString *data, VisuData *dataObj, VisuGlView *view);
+static void exportResources(GString *data, VisuData *dataObj);
 
-G_DEFINE_TYPE(VisuGlExtLegend, visu_gl_ext_legend, VISU_TYPE_GL_EXT_FRAME)
+G_DEFINE_TYPE_WITH_CODE(VisuGlExtLegend, visu_gl_ext_legend, VISU_TYPE_GL_EXT_FRAME,
+                        G_ADD_PRIVATE(VisuGlExtLegend))
 
 static void visu_gl_ext_legend_class_init(VisuGlExtLegendClass *klass)
 {
@@ -127,7 +123,7 @@ static void visu_gl_ext_legend_class_init(VisuGlExtLegendClass *klass)
   resourceEntry = visu_config_file_addBooleanEntry(VISU_CONFIG_FILE_RESOURCE,
                                                    FLAG_RESOURCE_LEGEND_USED,
                                                    DESC_RESOURCE_LEGEND_USED,
-                                                   &DEFAULT_LEGEND_USED);
+                                                   &DEFAULT_LEGEND_USED, FALSE);
   visu_config_file_entry_setVersion(resourceEntry, 3.5f);
   visu_config_file_addExportFunction(VISU_CONFIG_FILE_RESOURCE,
 				   exportResources);
@@ -136,9 +132,9 @@ static void visu_gl_ext_legend_class_init(VisuGlExtLegendClass *klass)
 
   /* Connect the overloading methods. */
   G_OBJECT_CLASS(klass)->dispose  = visu_gl_ext_legend_dispose;
-  G_OBJECT_CLASS(klass)->finalize = visu_gl_ext_legend_finalize;
   VISU_GL_EXT_CLASS(klass)->rebuild = visu_gl_ext_legend_rebuild;
   VISU_GL_EXT_FRAME_CLASS(klass)->draw = visu_gl_ext_legend_draw;
+  VISU_GL_EXT_FRAME_CLASS(klass)->isValid = visu_gl_ext_legend_isValid;
 }
 
 static void visu_gl_ext_legend_init(VisuGlExtLegend *obj)
@@ -146,22 +142,17 @@ static void visu_gl_ext_legend_init(VisuGlExtLegend *obj)
   DBG_fprintf(stderr, "Extension Legend: initializing a new object (%p).\n",
 	      (gpointer)obj);
   
-  obj->priv = g_malloc(sizeof(VisuGlExtLegendPrivate));
+  obj->priv = visu_gl_ext_legend_get_instance_private(obj);
   obj->priv->dispose_has_run = FALSE;
 
   /* Private data. */
-  obj->priv->nodes         = (VisuNodeArray*)0;
-  obj->priv->popInc_signal = 0;
-  obj->priv->popDec_signal = 0;
+  obj->priv->nodes = (VisuNodeArrayRenderer*)0;
 
-  g_signal_connect_object(VISU_OBJECT_INSTANCE,
-                          "entryParsed::" FLAG_RESOURCE_LEGEND_USED,
+  g_signal_connect_object(VISU_CONFIG_FILE_RESOURCE, "parsed::" FLAG_RESOURCE_LEGEND_USED,
                           G_CALLBACK(onEntryUsed), (gpointer)obj, G_CONNECT_SWAPPED);
 
-  obj->priv->eleSize_hook =
-    g_signal_add_emission_hook(g_signal_lookup("elementSizeChanged",
-                                               VISU_TYPE_RENDERING),
-                               0, onElementSize, (gpointer)obj, (GDestroyNotify)0);
+  if (!defaultLegend)
+    defaultLegend = obj;
 }
 
 /* This method can be called several times.
@@ -179,36 +170,11 @@ static void visu_gl_ext_legend_dispose(GObject* obj)
   legend->priv->dispose_has_run = TRUE;
 
   /* Disconnect signals. */
-  visu_gl_ext_legend_setNodes(legend, (VisuNodeArray*)0);
-  g_signal_remove_emission_hook(g_signal_lookup("elementSizeChanged", VISU_TYPE_RENDERING),
-                                legend->priv->eleSize_hook);
+  visu_gl_ext_legend_setNodes(legend, (VisuNodeArrayRenderer*)0);
 
   /* Chain up to the parent class */
   G_OBJECT_CLASS(visu_gl_ext_legend_parent_class)->dispose(obj);
 }
-/* This method is called once only. */
-static void visu_gl_ext_legend_finalize(GObject* obj)
-{
-  VisuGlExtLegend *legend;
-
-  g_return_if_fail(obj);
-
-  DBG_fprintf(stderr, "Extension Legend: finalize object %p.\n", (gpointer)obj);
-
-  legend = VISU_GL_EXT_LEGEND(obj);
-
-  /* Free privs elements. */
-  if (legend->priv)
-    {
-      DBG_fprintf(stderr, "Extension Legend: free private legend.\n");
-      g_free(legend->priv);
-    }
-
-  /* Chain up to the parent class */
-  DBG_fprintf(stderr, "Extension Legend: chain to parent.\n");
-  G_OBJECT_CLASS(visu_gl_ext_legend_parent_class)->finalize(obj);
-  DBG_fprintf(stderr, "Extension Legend: freeing ... OK.\n");
-}
 
 /**
  * visu_gl_ext_legend_new:
@@ -231,12 +197,13 @@ VisuGlExtLegend* visu_gl_ext_legend_new(const gchar *name)
   DBG_fprintf(stderr,"Extension Legend: new object.\n");
   
   legend = VISU_GL_EXT(g_object_new(VISU_TYPE_GL_EXT_LEGEND,
-                                       "name", (name)?name:name_, "label", _(name),
-                                       "description", description,
-                                       "nGlObj", 1, NULL));
-  visu_gl_ext_setSaveState(legend, TRUE);
-  visu_gl_ext_setPriority(legend, VISU_GL_EXT_PRIORITY_LAST);
-  visu_gl_ext_frame_setPosition(VISU_GL_EXT_FRAME(legend), 0.f, 1.f);
+                                    "active", DEFAULT_LEGEND_USED,
+                                    "name", (name)?name:name_, "label", _(name),
+                                    "description", description, "nGlObj", 1,
+                                    "priority", VISU_GL_EXT_PRIORITY_LAST,
+                                    "saveState", TRUE,
+                                    "x-pos", 0.f, "y-pos", 1.f,
+                                    "x-padding", 5.f, "y-padding", 3.f, NULL));
   visu_gl_ext_frame_setRequisition(VISU_GL_EXT_FRAME(legend), G_MAXUINT / 2, LEGEND_HEIGHT);
 
   return VISU_GL_EXT_LEGEND(legend);
@@ -251,135 +218,136 @@ VisuGlExtLegend* visu_gl_ext_legend_new(const gchar *name)
  *
  * Since: 3.7
  *
- * Returns: TRUE if visu_gl_ext_frame_draw() should be called and
- * then 'OpenGLAskForReDraw' signal be emitted.
+ * Returns: TRUE if model has been changed.
  **/
-gboolean visu_gl_ext_legend_setNodes(VisuGlExtLegend *legend, VisuNodeArray *nodes)
+gboolean visu_gl_ext_legend_setNodes(VisuGlExtLegend *legend, VisuNodeArrayRenderer *nodes)
 {
   g_return_val_if_fail(VISU_IS_GL_EXT_LEGEND(legend), FALSE);
 
+  if (legend->priv->nodes == nodes)
+    return FALSE;
+
   if (legend->priv->nodes)
     {
-      g_signal_handler_disconnect(G_OBJECT(legend->priv->nodes), legend->priv->popInc_signal);
-      g_signal_handler_disconnect(G_OBJECT(legend->priv->nodes), legend->priv->popDec_signal);
+      g_signal_handler_disconnect(G_OBJECT(legend->priv->nodes), legend->priv->ren_sig);
+      g_signal_handler_disconnect(G_OBJECT(legend->priv->nodes), legend->priv->col_sig);
+      g_signal_handler_disconnect(G_OBJECT(legend->priv->nodes), legend->priv->mat_sig);
+      g_signal_handler_disconnect(G_OBJECT(legend->priv->nodes), legend->priv->pop_sig);
+      g_signal_handler_disconnect(G_OBJECT(legend->priv->nodes), legend->priv->siz_sig);
       g_object_unref(legend->priv->nodes);
     }
+  legend->priv->nodes = nodes;
   if (nodes)
     {
       g_object_ref(nodes);
-      legend->priv->popInc_signal =
-        g_signal_connect(G_OBJECT(nodes), "PopulationIncrease",
-                         G_CALLBACK(onNodePopulationChanged), (gpointer)legend);
-      legend->priv->popDec_signal =
-        g_signal_connect(G_OBJECT(nodes), "PopulationDecrease",
-                         G_CALLBACK(onNodePopulationChanged), (gpointer)legend);
+      legend->priv->ren_sig =
+        g_signal_connect_swapped(G_OBJECT(nodes), "element-notify::rendered",
+                                 G_CALLBACK(setDirty), (gpointer)legend);
+      legend->priv->col_sig =
+        g_signal_connect_swapped(G_OBJECT(nodes), "element-notify::color",
+                                 G_CALLBACK(setDirty), (gpointer)legend);
+      legend->priv->mat_sig =
+        g_signal_connect_swapped(G_OBJECT(nodes), "element-notify::material",
+                                 G_CALLBACK(setDirty), (gpointer)legend);
+      legend->priv->pop_sig =
+        g_signal_connect_swapped(G_OBJECT(nodes), "nodes::population",
+                                 G_CALLBACK(setDirty), (gpointer)legend);
+      legend->priv->siz_sig =
+        g_signal_connect_swapped(G_OBJECT(nodes), "element-size-changed",
+                                 G_CALLBACK(setDirty), (gpointer)legend);
     }
-  else
-    {
-      legend->priv->popInc_signal = 0;
-      legend->priv->popDec_signal = 0;
-    }
-  legend->priv->nodes = nodes;
 
-  VISU_GL_EXT_FRAME(legend)->isBuilt = FALSE;
-  return visu_gl_ext_getActive(VISU_GL_EXT(legend));
+  visu_gl_ext_setDirty(VISU_GL_EXT(legend), TRUE);
+  return TRUE;
 }
 /**
- * visu_gl_ext_legend_getDefault:
+ * visu_gl_ext_legend_getNodes:
+ * @legend: a #VisuGlExtLegend object.
  *
- * V_Sim is using a default legend object.
+ * @legend is displaying a label showing the element of a
+ * #VisuNodeArray using the rendering properties of a #VisuNodeArrayRenderer.
  *
- * Since: 3.7
+ * Since: 3.8
  *
- * Returns: (transfer none): a #VisuGlExtLegend object used by default.
+ * Returns: (transfer none): the #VisuNodeArrayRenderer this legend is
+ * based on.
  **/
-VisuGlExtLegend* visu_gl_ext_legend_getDefault()
+VisuNodeArrayRenderer* visu_gl_ext_legend_getNodes(VisuGlExtLegend *legend)
 {
-  if (!defaultLegend)
-    defaultLegend = visu_gl_ext_legend_new((gchar*)0);
-  return defaultLegend;
+  g_return_val_if_fail(VISU_IS_GL_EXT_LEGEND(legend), (VisuNodeArrayRenderer*)0);
+  return legend->priv->nodes;
 }
-static void onEntryUsed(VisuGlExtLegend *lg, gchar *key _U_, VisuObject *obj _U_)
+static void onEntryUsed(VisuGlExtLegend *lg, VisuConfigFileEntry *entry _U_, VisuConfigFile *obj _U_)
 {
   visu_gl_ext_setActive(VISU_GL_EXT(lg), DEFAULT_LEGEND_USED);
 }
-static void onNodePopulationChanged(VisuNodeArray *array _U_, int *nodes _U_,
-				    gpointer data)
+static void setDirty(VisuGlExt *ext)
 {
-  VISU_GL_EXT_FRAME(data)->isBuilt = FALSE;
-  visu_gl_ext_frame_draw(VISU_GL_EXT_FRAME(data));
+  visu_gl_ext_setDirty(ext, TRUE);
 }
-static gboolean onElementSize(GSignalInvocationHint *ihint _U_, guint nvalues _U_,
-                              const GValue *param_values _U_, gpointer data)
-{
-  VISU_GL_EXT_FRAME(data)->isBuilt = FALSE;
-  visu_gl_ext_frame_draw(VISU_GL_EXT_FRAME(data));
 
-  return TRUE;
-}
 static void visu_gl_ext_legend_rebuild(VisuGlExt *ext)
 {
   visu_gl_text_rebuildFontList();
-  VISU_GL_EXT_FRAME(ext)->isBuilt = FALSE;
-  visu_gl_ext_frame_draw(VISU_GL_EXT_FRAME(ext));
+  if (VISU_GL_EXT_GET_CLASS(ext)->draw)
+    VISU_GL_EXT_GET_CLASS(ext)->draw(ext);
 }
 
-static void visu_gl_ext_legend_draw(VisuGlExtFrame *frame)
+static gboolean visu_gl_ext_legend_isValid(const VisuGlExtFrame *frame)
+{
+  g_return_val_if_fail(VISU_IS_GL_EXT_LEGEND(frame), FALSE);
+  
+  return (VISU_GL_EXT_LEGEND(frame)->priv->nodes != (VisuNodeArrayRenderer*)0);
+}
+
+static void visu_gl_ext_legend_draw(const VisuGlExtFrame *frame)
 {
   guint dw;
   guint i;
-  float scale;
+  float scale, mSize;
   GString *str;
-  VisuNodeArrayIter iter;
-  VisuRendering *method;
+  VisuNodeArrayRendererIter iter;
   VisuGlExtLegend *legend;
+  gboolean valid;
 
   g_return_if_fail(VISU_IS_GL_EXT_LEGEND(frame));
   legend = VISU_GL_EXT_LEGEND(frame);
-  if (!legend->priv->nodes)
-    return;
 
-  method = visu_object_getRendering(VISU_OBJECT_INSTANCE);
-  g_return_if_fail(method);
+  mSize = visu_node_array_renderer_getMaxElementSize(legend->priv->nodes, &i);
+  DBG_fprintf(stderr, "Extension Legend: max size is %g (%d).\n", mSize, i);
 
   /* We draw the legend. */
   str = g_string_new("");
-  scale = 0.5f * frame->height / visu_node_array_getMaxElementSize(legend->priv->nodes);
-  visu_node_array_iterNew(legend->priv->nodes, &iter);
-  dw = MAX(frame->width / visu_node_array_getNElements(legend->priv->nodes, TRUE),
-           frame->height + 10 + 60);
-  for (visu_node_array_iterStart(legend->priv->nodes, &iter), i = 0; iter.element;
-       visu_node_array_iterNextElement(legend->priv->nodes, &iter), i+= 1)
+  scale = 0.5f * frame->height / mSize;
+  dw = MAX(frame->width / i, frame->height + 10 + 60);
+  for (valid = visu_node_array_renderer_iter_new(legend->priv->nodes, &iter, TRUE), i = 0;
+       valid; valid = visu_node_array_renderer_iter_next(&iter), i += 1)
     {
-      if (!visu_element_getPhysical(iter.element))
-        {
-          i -= 1;
-          continue;
-        }
-
       /* The element. */
       glEnable(GL_LIGHTING);
-      glCallList(visu_element_getMaterialId(iter.element));
+      if (visu_element_getRendered(iter.element))
+        visu_element_renderer_colorize(iter.renderer, VISU_ELEMENT_RENDERER_NO_EFFECT);
+      else
+        visu_element_renderer_colorize(iter.renderer, VISU_ELEMENT_RENDERER_FLATTEN_DARK);
       glPushMatrix();
-      glTranslated(i * dw + 5 + frame->height / 2,
-		   frame->height / 2, 0.f);
+      glTranslated(0.5f * frame->height + i * dw, 0.5f * frame->height, 0.f);
       glRotated(45., 0, 0, 1);  
       glRotated(60., 0, 1, 0); 
       glScalef(scale, scale, scale);
-      glCallList(visu_rendering_getElementGlId(method, iter.element));
+      visu_element_renderer_call(iter.renderer);
       glPopMatrix();
       glDisable(GL_LIGHTING);
 
       /* The label. */
       glColor3fv(VISU_GL_EXT_FRAME(legend)->fontRGB);
-      g_string_printf(str, "%s (%d)", iter.element->name, iter.nStoredNodes);
-      glRasterPos2i(i * dw + 5 + frame->height + 5, (frame->height - 20) / 2 + 5);
+      g_string_printf(str, "%s (%d)", visu_element_getName(iter.element), iter.nStoredNodes);
+      glRasterPos2f(5.f + i * dw + frame->height, 5.f + 0.5f * (frame->height - 20));
       visu_gl_text_drawChars(str->str, VISU_GL_TEXT_SMALL);
     }
   g_string_free(str, TRUE);
 }
 
-static void exportResources(GString *data, VisuData *dataObj _U_, VisuGlView *view _U_)
+static void exportResources(GString *data, VisuData *dataObj _U_)
 {
   if (!defaultLegend)
     return;
