@@ -58,6 +58,10 @@
 /**
  * VisuGlExtMapsClass:
  * @parent: the parent class;
+ * @added: a method that is called when a #VisuMap is added to a
+ * #VisuGlExtMaps object.
+ * @removed: a method that is called when a #VisuMap is removed from a
+ * #VisuGlExtMaps object.
  *
  * A short way to identify #_VisuGlExtMapsClass structure.
  *
@@ -80,7 +84,6 @@
 struct _VisuGlExtMapsPrivate
 {
   gboolean dispose_has_run;
-  gboolean isBuilt;
 
   GList *maps;
 
@@ -91,7 +94,9 @@ struct _VisuGlExtMapsPrivate
 
 typedef struct _MapHandleStruct
 {
+  VisuGlExtMaps *maps;
   VisuMap *map;
+  gulong chg_signal;
   gboolean isBuilt;
   float prec;
   ToolShade *shade;
@@ -101,21 +106,40 @@ typedef struct _MapHandleStruct
   int glListId;
 } _MapHandle;
 
+enum
+  {
+    ADDED_SIGNAL,
+    REMOVED_SIGNAL,
+    N_SIGNALS
+  };
+static guint _signals[N_SIGNALS] = { 0 };
+
 static void visu_gl_ext_maps_finalize(GObject* obj);
 static void visu_gl_ext_maps_dispose(GObject* obj);
 static void visu_gl_ext_maps_rebuild(VisuGlExt *ext);
+static void visu_gl_ext_maps_draw(VisuGlExt *maps);
+static gboolean visu_gl_ext_maps_setGlView(VisuGlExt *maps, VisuGlView *view);
+static gboolean _add(VisuGlExtMaps *maps, VisuMap *map,
+                     float prec, ToolShade *shade,
+                     const ToolColor *color, gboolean alpha);
 
 /* Local callbacks */
 static void onViewChange(VisuGlView *view, gpointer data);
+static void onMapChange(VisuMap *map, gpointer data);
 
 /* Local routines. */
-static void _setZoomLevel(_MapHandle *mhd, VisuGlView *view);
 static void _freeMapHandle(gpointer obj)
 {
   _MapHandle *mhd;
 
   mhd = (_MapHandle*)obj;
-  visu_map_unref(mhd->map);
+  if (VISU_GL_EXT_MAPS_GET_CLASS(mhd->maps)->removed)
+    VISU_GL_EXT_MAPS_GET_CLASS(mhd->maps)->removed(mhd->maps, mhd->map);
+  DBG_fprintf(stderr, "Extension Maps: emiting %p map removed.\n", (gpointer)mhd->map);
+  g_signal_emit(G_OBJECT(mhd->maps), _signals[REMOVED_SIGNAL], 0, mhd->map);
+  DBG_fprintf(stderr, "Extension Maps: emission done.\n");
+  g_signal_handler_disconnect(G_OBJECT(mhd->map), mhd->chg_signal);
+  g_object_unref(G_OBJECT(mhd->map));
   tool_shade_free(mhd->shade);
   g_free(mhd->color);
   glDeleteLists(mhd->glListId, 1);
@@ -126,26 +150,34 @@ static void _freeMapHandle(gpointer obj)
 #endif
 }
 static gpointer _newMapHandle(VisuGlExtMaps *maps, VisuMap *map,
-                              float prec, ToolShade *shade, ToolColor *color, gboolean alpha)
+                              float prec, ToolShade *shade, const ToolColor *color, gboolean alpha)
 {
   _MapHandle *mhd;
 
-  visu_map_ref(map);
+  g_object_ref(G_OBJECT(map));
 #if GLIB_MINOR_VERSION > 9
   mhd = g_slice_alloc(sizeof(_MapHandle));
 #else
   mhd = g_malloc(sizeof(_MapHandle));
 #endif
   DBG_fprintf(stderr, "Extension Maps: add listeners on map %p.\n", (gpointer)map);
+  mhd->maps = maps;
   mhd->map = map;
+  mhd->chg_signal = g_signal_connect(G_OBJECT(map), "changed",
+                                     G_CALLBACK(onMapChange), maps);
   mhd->isBuilt = FALSE;
   mhd->prec = prec;
   mhd->shade = tool_shade_copy(shade);
-  mhd->color = g_boxed_copy(TOOL_TYPE_COLOR, color);
+  mhd->color = (color) ? g_boxed_copy(TOOL_TYPE_COLOR, color) : (ToolColor*)0;
   mhd->alpha = alpha;
   mhd->glListId  = visu_gl_objectlist_new(1);
   if (maps->priv->view)
-    _setZoomLevel(mhd, maps->priv->view);
+    visu_map_setLevel(mhd->map,
+                      visu_gl_view_getPrecision(maps->priv->view),
+                      maps->priv->view->camera.gross,
+                      visu_gl_camera_getRefLength(&maps->priv->view->camera, (ToolUnits*)0));
+  if (VISU_GL_EXT_MAPS_GET_CLASS(maps)->added)
+    VISU_GL_EXT_MAPS_GET_CLASS(maps)->added(maps, map);
   return (gpointer)mhd;
 }
 static gint _cmpMapHandle(gconstpointer a, gconstpointer b)
@@ -158,7 +190,8 @@ static gint _cmpMapHandle(gconstpointer a, gconstpointer b)
 }
 #define _getMap(H) ((_MapHandle*)H)->map
 
-G_DEFINE_TYPE(VisuGlExtMaps, visu_gl_ext_maps, VISU_TYPE_GL_EXT)
+G_DEFINE_TYPE_WITH_CODE(VisuGlExtMaps, visu_gl_ext_maps, VISU_TYPE_GL_EXT,
+                        G_ADD_PRIVATE(VisuGlExtMaps))
 
 static void visu_gl_ext_maps_class_init(VisuGlExtMapsClass *klass)
 {
@@ -169,6 +202,38 @@ static void visu_gl_ext_maps_class_init(VisuGlExtMapsClass *klass)
   G_OBJECT_CLASS(klass)->dispose  = visu_gl_ext_maps_dispose;
   G_OBJECT_CLASS(klass)->finalize = visu_gl_ext_maps_finalize;
   VISU_GL_EXT_CLASS(klass)->rebuild = visu_gl_ext_maps_rebuild;
+  VISU_GL_EXT_CLASS(klass)->draw = visu_gl_ext_maps_draw;
+  VISU_GL_EXT_CLASS(klass)->setGlView = visu_gl_ext_maps_setGlView;
+  VISU_GL_EXT_MAPS_CLASS(klass)->add = _add;
+
+  /**
+   * VisuGlExtMaps::added:
+   * @maps: the object emitting the signal.
+   * @map: the added #VisuMap.
+   *
+   * This signal is emitted when @map is added to @maps.
+   *
+   * Since: 3.8
+   */
+  _signals[ADDED_SIGNAL] =
+    g_signal_new("added", G_TYPE_FROM_CLASS(klass),
+                 G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
+                 G_STRUCT_OFFSET(VisuGlExtMapsClass, added), NULL, NULL,
+                 g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, VISU_TYPE_MAP);
+  /**
+   * VisuGlExtMaps::removed:
+   * @maps: the object emitting the signal.
+   * @map: the removed #VisuMap.
+   *
+   * This signal is emitted when @map is removed to @maps.
+   *
+   * Since: 3.8
+   */
+  _signals[REMOVED_SIGNAL] =
+    g_signal_new("removed", G_TYPE_FROM_CLASS(klass),
+                 G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
+                 G_STRUCT_OFFSET(VisuGlExtMapsClass, removed), NULL, NULL,
+                 g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, VISU_TYPE_MAP);
 }
 
 static void visu_gl_ext_maps_init(VisuGlExtMaps *obj)
@@ -176,15 +241,14 @@ static void visu_gl_ext_maps_init(VisuGlExtMaps *obj)
   DBG_fprintf(stderr, "Extension Maps: initializing a new object (%p).\n",
 	      (gpointer)obj);
   
-  obj->priv = g_malloc(sizeof(VisuGlExtMapsPrivate));
+  obj->priv = visu_gl_ext_maps_get_instance_private(obj);
   obj->priv->dispose_has_run = FALSE;
 
   /* Private data. */
-  obj->priv->isBuilt  = FALSE;
-  obj->priv->maps     = (GList*)0;
-  obj->priv->view          = (VisuGlView*)0;
-  obj->priv->gross_signal  = 0;
-  obj->priv->detail_signal = 0;
+  obj->priv->maps            = (GList*)0;
+  obj->priv->view            = (VisuGlView*)0;
+  obj->priv->gross_signal    = 0;
+  obj->priv->detail_signal   = 0;
 }
 static void visu_gl_ext_maps_dispose(GObject* obj)
 {
@@ -199,7 +263,9 @@ static void visu_gl_ext_maps_dispose(GObject* obj)
   maps->priv->dispose_has_run = TRUE;
 
   /* Disconnect signals. */
-  visu_gl_ext_maps_setGlView(maps, (VisuGlView*)0);
+  visu_gl_ext_maps_setGlView(VISU_GL_EXT(obj), (VisuGlView*)0);
+  DBG_fprintf(stderr, "Extension MapSet: clearing a list of %d maps.\n",
+              g_list_length(maps->priv->maps));
   for (lst = maps->priv->maps; lst; lst = g_list_next(lst))
     _freeMapHandle(lst->data);
 
@@ -208,21 +274,14 @@ static void visu_gl_ext_maps_dispose(GObject* obj)
 }
 static void visu_gl_ext_maps_finalize(GObject* obj)
 {
-  VisuGlExtMaps *maps;
+  VisuGlExtMaps *maps = VISU_GL_EXT_MAPS(obj);
 
   g_return_if_fail(obj);
 
   DBG_fprintf(stderr, "Extension Maps: finalize object %p.\n", (gpointer)obj);
-
-  maps = VISU_GL_EXT_MAPS(obj);
-
   /* Free privs elements. */
   if (maps->priv)
-    {
-      DBG_fprintf(stderr, "Extension Maps: free private maps.\n");
-      g_list_free(maps->priv->maps);
-      g_free(maps->priv);
-    }
+    g_list_free(maps->priv->maps);
 
   /* Chain up to the parent class */
   DBG_fprintf(stderr, "Extension Maps: chain to parent.\n");
@@ -250,63 +309,60 @@ VisuGlExtMaps* visu_gl_ext_maps_new(const gchar *name)
   DBG_fprintf(stderr,"Extension Maps: new object.\n");
   
   extensionMaps = VISU_GL_EXT(g_object_new(VISU_TYPE_GL_EXT_MAPS,
-                                              "name", (name)?name:name_, "label", _(name),
-                                              "description", description, "nGlObj", 1,
-                                              "priority", VISU_GL_EXT_PRIORITY_NORMAL - 1,
-                                              "saveState", TRUE, NULL));
+                                           "name", (name)?name:name_, "label", _(name),
+                                           "description", description, "nGlObj", 1,
+                                           "priority", VISU_GL_EXT_PRIORITY_NORMAL - 1,
+                                           "saveState", TRUE, NULL));
 
   return VISU_GL_EXT_MAPS(extensionMaps);
 }
-/**
- * visu_gl_ext_maps_setGlView:
- * @maps: the #VisuGlExtMaps object to attached to rendering view.
- * @view: (transfer full) (allow-none): a #VisuGlView object.
- *
- * Attach @maps to @view, so it can be rendered there. See visu_gl_ext_maps_draw().
- *
- * Since: 3.7
- *
- * Returns: TRUE if visu_gl_ext_maps_draw() should be called and then 'OpenGLAskForReDraw'
- *          signal be emitted.
- **/
-gboolean visu_gl_ext_maps_setGlView(VisuGlExtMaps *maps, VisuGlView *view)
+
+static void _setZoomLevel(VisuGlExtMaps *maps)
 {
   GList *lst;
-
-  g_return_val_if_fail(VISU_IS_GL_EXT_MAPS(maps), FALSE);
-
-  /* No change to be done. */
-  if (view == maps->priv->view)
-    return FALSE;
-
-  if (maps->priv->view)
-    {
-      /* g_signal_handler_disconnect(G_OBJECT(maps->priv->view), maps->priv->gross_signal); */
-      g_signal_handler_disconnect(G_OBJECT(maps->priv->view), maps->priv->detail_signal);
-      g_object_unref(maps->priv->view);
-    }
-  if (view)
-    {
-      g_object_ref(view);
-      /* maps->priv->gross_signal = */
-      /*   g_signal_connect(G_OBJECT(view), "GrossChanged", */
-      /*                    G_CALLBACK(onViewChange), (gpointer)maps); */
-      maps->priv->detail_signal =
-        g_signal_connect(G_OBJECT(view), "DetailLevelChanged",
-                         G_CALLBACK(onViewChange), (gpointer)maps);
-    }
-  else
-    {
-      /* maps->priv->gross_signal     = 0; */
-      maps->priv->detail_signal     = 0;
-    }
-  maps->priv->view = view;
+  _MapHandle *mhd;
 
   /* Adjust zoom level for all maps. */
   for (lst = maps->priv->maps; lst; lst = g_list_next(lst))
-    _setZoomLevel((_MapHandle*)lst->data, view);
+    {
+      mhd = (_MapHandle*)lst->data;
+      visu_map_setLevel(mhd->map,
+                        visu_gl_view_getPrecision(maps->priv->view),
+                        maps->priv->view->camera.gross,
+                        visu_gl_camera_getRefLength(&maps->priv->view->camera, (ToolUnits*)0));
+      mhd->isBuilt = FALSE;
+    }
+
+  visu_gl_ext_setDirty(VISU_GL_EXT(maps), TRUE);
+}
+static gboolean visu_gl_ext_maps_setGlView(VisuGlExt *maps, VisuGlView *view)
+{
+  VisuGlExtMapsPrivate *priv = VISU_GL_EXT_MAPS(maps)->priv;
+
+  /* No change to be done. */
+  if (view == priv->view)
+    return FALSE;
+
+  if (priv->view)
+    {
+      g_signal_handler_disconnect(G_OBJECT(priv->view), priv->detail_signal);
+      g_object_unref(priv->view);
+    }
+  priv->view = view;
+  if (view)
+    {
+      g_object_ref(view);
+      priv->detail_signal =
+        g_signal_connect(G_OBJECT(view), "DetailLevelChanged",
+                         G_CALLBACK(onViewChange), (gpointer)maps);
+      _setZoomLevel(VISU_GL_EXT_MAPS(maps));
+    }
+  else
+    {
+      /* priv->gross_signal     = 0; */
+      priv->detail_signal     = 0;
+    }
 
-  maps->priv->isBuilt = FALSE;
   return TRUE;
 }
 
@@ -320,14 +376,25 @@ gboolean visu_gl_ext_maps_setGlView(VisuGlExtMaps *maps, VisuGlView *view)
  * @alpha: a boolean.
  *
  * Add a new map to the list of drawn maps. If @color is %NULL, then
- * iso-lines will be drawn in inverse color.
+ * iso-lines will be drawn in inverse color. If @alpha is TRUE, the
+ * map will be rendered with alpha blending when values go to zero.
  *
  * Since: 3.7
  *
  * Returns: FALSE if @surf was already reguistered.
  **/
 gboolean visu_gl_ext_maps_add(VisuGlExtMaps *maps, VisuMap *map,
-                              float prec, ToolShade *shade, ToolColor *color, gboolean alpha)
+                              float prec, ToolShade *shade,
+                              const ToolColor *color, gboolean alpha)
+{
+  VisuGlExtMapsClass *klass = VISU_GL_EXT_MAPS_GET_CLASS(maps);
+  g_return_val_if_fail(klass && klass->add, FALSE);
+
+  return klass->add(maps, map, prec, shade, color, alpha);
+}
+static gboolean _add(VisuGlExtMaps *maps, VisuMap *map,
+                     float prec, ToolShade *shade,
+                     const ToolColor *color, gboolean alpha)
 {
   GList *lst;
 
@@ -339,9 +406,12 @@ gboolean visu_gl_ext_maps_add(VisuGlExtMaps *maps, VisuMap *map,
 
   maps->priv->maps = g_list_prepend(maps->priv->maps,
                                     _newMapHandle(maps, map, prec, shade, color, alpha));
+  DBG_fprintf(stderr, "Extension MapSet: adding map %p (%d).\n",
+              (gpointer)map, g_list_length(maps->priv->maps));
+  g_signal_emit(G_OBJECT(maps), _signals[ADDED_SIGNAL], 0, map);
 
-  maps->priv->isBuilt = FALSE;
-  return visu_gl_ext_getActive(VISU_GL_EXT(maps));
+  visu_gl_ext_setDirty(VISU_GL_EXT(maps), TRUE);
+  return TRUE;
 }
 /**
  * visu_gl_ext_maps_remove:
@@ -352,7 +422,7 @@ gboolean visu_gl_ext_maps_add(VisuGlExtMaps *maps, VisuMap *map,
  *
  * Since: 3.7
  *
- * Returns: TRUE if visu_gl_ext_maps_draw(à should be called.
+ * Returns: TRUE if @map was part of drawn maps.
  **/
 gboolean visu_gl_ext_maps_remove(VisuGlExtMaps *maps, VisuMap *map)
 {
@@ -364,11 +434,31 @@ gboolean visu_gl_ext_maps_remove(VisuGlExtMaps *maps, VisuMap *map)
   if (!lst)
     return FALSE;
 
+  maps->priv->maps = g_list_remove_link(maps->priv->maps, lst);
   _freeMapHandle(lst->data);
-  maps->priv->maps = g_list_delete_link(maps->priv->maps, lst);
+  g_list_free(lst);
+  DBG_fprintf(stderr, "Extension MapSet: removing map %p (%d).\n",
+              (gpointer)map, g_list_length(maps->priv->maps));
 
-  maps->priv->isBuilt = FALSE;
-  return visu_gl_ext_getActive(VISU_GL_EXT(maps));
+  visu_gl_ext_setDirty(VISU_GL_EXT(maps), TRUE);
+  return TRUE;
+}
+/**
+ * visu_gl_ext_maps_removeAll:
+ * @maps: a #VisuGlExtMaps object.
+ *
+ * Removes all the #VisuMap stored in @maps.
+ *
+ * Since: 3.8
+ **/
+void visu_gl_ext_maps_removeAll(VisuGlExtMaps *maps)
+{
+  g_return_if_fail(VISU_IS_GL_EXT_MAPS(maps));
+  
+  g_list_free_full(maps->priv->maps, _freeMapHandle);
+  maps->priv->maps = (GList*)0;
+  DBG_fprintf(stderr, "Extension MapSet: removing all.\n");
+  visu_gl_ext_setDirty(VISU_GL_EXT(maps), TRUE);
 }
 
 static gboolean _getMapIter(VisuGlExtMaps *maps, VisuMap *map, GList *iter)
@@ -427,7 +517,8 @@ gboolean visu_gl_ext_maps_setPrecision(VisuGlExtMaps *maps, VisuMap *map, float
           diff = TRUE;
         }
     }
-  maps->priv->isBuilt = !diff;
+  if (diff)
+    visu_gl_ext_setDirty(VISU_GL_EXT(maps), TRUE);
   return diff;
 }
 /**
@@ -468,7 +559,8 @@ gboolean visu_gl_ext_maps_setShade(VisuGlExtMaps *maps, VisuMap *map, ToolShade
           diff = TRUE;
         }
     }
-  maps->priv->isBuilt = !diff;
+  if (diff)
+    visu_gl_ext_setDirty(VISU_GL_EXT(maps), TRUE);
   return diff;
 }
 /**
@@ -485,7 +577,8 @@ gboolean visu_gl_ext_maps_setShade(VisuGlExtMaps *maps, VisuMap *map, ToolShade
  *
  * Returns: TRUE if @color of @map is changed.
  **/
-gboolean visu_gl_ext_maps_setLineColor(VisuGlExtMaps *maps, VisuMap *map, ToolColor *color)
+gboolean visu_gl_ext_maps_setLineColor(VisuGlExtMaps *maps, VisuMap *map,
+                                       const ToolColor *color)
 {
   GList *lst, iter;
   _MapHandle *mhd;
@@ -503,12 +596,13 @@ gboolean visu_gl_ext_maps_setLineColor(VisuGlExtMaps *maps, VisuMap *map, ToolCo
       if (!tool_color_equal(mhd->color, color))
         {
           g_free(mhd->color);
-          mhd->color = g_boxed_copy(TOOL_TYPE_COLOR, color);
+          mhd->color = (color) ? g_boxed_copy(TOOL_TYPE_COLOR, color) : (ToolColor*)0;
           mhd->isBuilt = FALSE;
           diff = TRUE;
         }
     }
-  maps->priv->isBuilt = !diff;
+  if (diff)
+    visu_gl_ext_setDirty(VISU_GL_EXT(maps), TRUE);
   return diff;
 }
 /**
@@ -547,46 +641,12 @@ gboolean visu_gl_ext_maps_setTransparent(VisuGlExtMaps *maps, VisuMap *map, gboo
           diff = TRUE;
         }
     }
-  maps->priv->isBuilt = !diff;
+  if (diff)
+    visu_gl_ext_setDirty(VISU_GL_EXT(maps), TRUE);
   return diff;
 }
-/**
- * visu_gl_ext_maps_setDirty:
- * @maps: a #VisuGlExtMaps object.
- * @map: a #VisuMap object.
- *
- * Currently, #VisuMap are not objects, so @maps cannot react to a
- * change on them. Callers have to set by hand that @maps should be
- * redrawn with this routine.
- *
- * Since: 3.7
- *
- * Returns: TRUE is @map is a drawn #VisuMap of @maps.
- **/
-gboolean visu_gl_ext_maps_setDirty(VisuGlExtMaps *maps, VisuMap *map)
-{
-  GList *lst, iter;
 
-  g_return_val_if_fail(VISU_IS_GL_EXT_MAPS(maps), FALSE);
-
-  if (!_getMapIter(maps, map, &iter))
-    return FALSE;
-  
-  for (lst = &iter; lst; lst = g_list_next(lst))
-    ((_MapHandle*)lst->data)->isBuilt = FALSE;
-  maps->priv->isBuilt = FALSE;
-  return TRUE;
-}
-
-/**
- * visu_gl_ext_maps_draw:
- * @maps: a #VisuGlExtMaps object.
- *
- * Render the OpenGL list of @maps.
- *
- * Since: 3.7
- **/
-void visu_gl_ext_maps_draw(VisuGlExtMaps *maps)
+static void visu_gl_ext_maps_draw(VisuGlExt *maps)
 {
   _MapHandle *mhd;
   GList *lst;
@@ -594,42 +654,40 @@ void visu_gl_ext_maps_draw(VisuGlExtMaps *maps)
   GTimer *timer;
   gulong fractionTimer;
   #endif
+  VisuGlExtMapsPrivate *priv = VISU_GL_EXT_MAPS(maps)->priv;
 
-  g_return_if_fail(VISU_IS_GL_EXT_MAPS(maps));
-
-  /* Nothing to draw; */
-  if(!visu_gl_ext_getActive(VISU_GL_EXT(maps)) ||
-     maps->priv->isBuilt) return;
-   
   DBG_fprintf(stderr, "Extension Maps: rebuilding map list.\n");
-  maps->priv->isBuilt = TRUE;
+  glDeleteLists(visu_gl_ext_getGlList(maps), 1);
+  visu_gl_ext_setDirty(maps, FALSE);
 
-  glDeleteLists(visu_gl_ext_getGlList(VISU_GL_EXT(maps)), 1);
-  if (!maps->priv->maps)
+  if (!priv->view || !priv->maps)
     return;
 
 #if DEBUG == 1
   timer = g_timer_new();
   g_timer_start(timer);
 #endif
+
   /* Rebuild maps if required. */
-  for (lst = maps->priv->maps; lst; lst = g_list_next(lst))
+  for (lst = priv->maps; lst; lst = g_list_next(lst))
     {
       mhd = (_MapHandle*)lst->data;
       if (!mhd->isBuilt)
         {
           glNewList(mhd->glListId, GL_COMPILE);
           visu_map_draw(_getMap(lst->data), mhd->prec, mhd->shade,
-                        (mhd->color)?mhd->color->rgba:(float*)0, mhd->alpha);
+                        (mhd->color) ? mhd->color->rgba:(float*)0, mhd->alpha);
           glEndList();
+          mhd->isBuilt = TRUE;
         }
     }
 
   /* Call the map one by one. */
-  glNewList(visu_gl_ext_getGlList(VISU_GL_EXT(maps)), GL_COMPILE);  
-  for (lst = maps->priv->maps; lst; lst = g_list_next(lst))
+  visu_gl_ext_startDrawing(maps);
+  for (lst = priv->maps; lst; lst = g_list_next(lst))
     glCallList(((_MapHandle*)lst->data)->glListId);
-  glEndList();
+  visu_gl_ext_completeDrawing(maps);
+
 #if DEBUG == 1
   g_timer_stop(timer);
   fprintf(stderr, "Extension Maps: draw map(s) in %g micro-s.\n",
@@ -638,36 +696,66 @@ void visu_gl_ext_maps_draw(VisuGlExtMaps *maps)
 #endif
 }
 
-static void _setZoomLevel(_MapHandle *mhd, VisuGlView *view)
-{
-  mhd->isBuilt = FALSE;
-  visu_map_setLevel(mhd->map,
-                    visu_gl_view_class_getPrecision(),
-                    view->camera->gross,
-                    visu_gl_camera_getRefLength(view->camera, (ToolUnits*)0));
-}
-
 /* Callbacks. */
 static void visu_gl_ext_maps_rebuild(VisuGlExt *ext)
 {
   VisuGlExtMaps *maps = VISU_GL_EXT_MAPS(ext);
   GList *lst;
 
-  maps->priv->isBuilt = FALSE;
   for (lst = maps->priv->maps; lst; lst = g_list_next(lst))
     ((_MapHandle*)lst->data)->isBuilt = FALSE;
-  visu_gl_ext_maps_draw(maps);
+  visu_gl_ext_maps_draw(ext);
 }
-static void onViewChange(VisuGlView *view, gpointer data)
+static void onViewChange(VisuGlView *view _U_, gpointer data)
 {
-  VisuGlExtMaps *maps = VISU_GL_EXT_MAPS(data);
+  _setZoomLevel(VISU_GL_EXT_MAPS(data));
+}
+static void onMapChange(VisuMap *map, gpointer data)
+{
   GList *lst;
-  
-  maps->priv->isBuilt = FALSE;
-  for (lst = maps->priv->maps; lst; lst = g_list_next(lst))
-    {
-      _setZoomLevel((_MapHandle*)lst->data, view);
-      visu_map_compute(((_MapHandle*)lst->data)->map);
-    }
-  visu_gl_ext_maps_draw(maps);
+
+  for (lst = VISU_GL_EXT_MAPS(data)->priv->maps; lst; lst = g_list_next(lst))
+    if (((_MapHandle*)lst->data)->map == map)
+      {
+        DBG_fprintf(stderr, "Extension Maps: map %p is dirty.\n", (gpointer)map);
+        ((_MapHandle*)lst->data)->isBuilt = FALSE;
+        break;
+      }
+  DBG_fprintf(stderr, "Extension Maps: map changed, becoming dirty.\n");
+  visu_gl_ext_setDirty(VISU_GL_EXT(data), TRUE);
+}
+
+/**
+ * visu_gl_ext_maps_iter_new:
+ * @maps: a #VisuGlExtMaps object.
+ * @iter: (out caller-allocates): a location to #VisuGlExtMapsIter.
+ *
+ * Generate a new iterator to run over #VisuMap objects stored in @maps.
+ *
+ * Since: 3.8
+ **/
+void visu_gl_ext_maps_iter_new(VisuGlExtMaps *maps, VisuGlExtMapsIter *iter)
+{
+  g_return_if_fail(VISU_IS_GL_EXT_MAPS(maps) && iter);
+
+  iter->maps = maps;
+  iter->next = maps->priv->maps;
+  visu_gl_ext_maps_iter_next(iter);
+}
+
+/**
+ * visu_gl_ext_maps_iter_next:
+ * @iter: a #VisuGlExtMapsIter iterator.
+ *
+ * Go to the next #VisuMap in @iter.
+ *
+ * Since: 3.8
+ **/
+void visu_gl_ext_maps_iter_next(VisuGlExtMapsIter *iter)
+{
+  g_return_if_fail(iter);
+
+  iter->valid = (iter->next != (GList*)0);
+  iter->map = (iter->valid) ? _getMap(iter->next->data) : (VisuMap*)0;
+  iter->next = g_list_next(iter->next);
 }
