@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -46,7 +46,8 @@
 #define MARKS_H
 
 #include "infos.h"
-#include <visu_data.h>
+#include <iface_nodemasker.h>
+#include <renderingMethods/iface_nodeArrayRenderer.h>
 #include <openGLFunctions/interactive.h>
 
 /**
@@ -68,6 +69,22 @@ typedef enum
     MARKS_STATUS_SET,
     MARKS_STATUS_UNSET
   } VisuGlExtMarksStatus;
+/**
+ * VisuGlExtMarksHidingModes:
+ * @HIDE_NONE: don't hide nodes.
+ * @HIDE_HIGHLIGHT: hide highlighted nodes.
+ * @HIDE_NON_HIGHLIGHT: hide all non-highlighted nodes.
+ *
+ * Possible parameters used by visu_gl_ext_marks_setHidingMode().
+ *
+ * Since: 3.8
+ */
+typedef enum
+  {
+    HIDE_NONE,
+    HIDE_HIGHLIGHT,
+    HIDE_NON_HIGHLIGHT
+  } VisuGlExtMarksHidingModes;
 
 /**
  * VISU_TYPE_GL_EXT_MARKS:
@@ -123,6 +140,10 @@ typedef enum
  */
 #define VISU_GL_EXT_MARKS_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS((obj), VISU_TYPE_GL_EXT_MARKS, VisuGlExtMarksClass))
 
+typedef struct _VisuGlExtMarks            VisuGlExtMarks;
+typedef struct _VisuGlExtMarksClass       VisuGlExtMarksClass;
+typedef struct _VisuGlExtMarksPrivate     VisuGlExtMarksPrivate;
+
 /**
  * VisuGlExtMarks:
  *
@@ -130,8 +151,25 @@ typedef enum
  *
  * Since: 3.6
  */
-typedef struct _VisuGlExtMarks            VisuGlExtMarks;
-typedef struct _VisuGlExtMarksClass       VisuGlExtMarksClass;
+struct _VisuGlExtMarks
+{
+  VisuGlExt parent;
+
+  VisuGlExtMarksPrivate *priv;
+};
+
+/**
+ * VisuGlExtMarksClass:
+ * @parent: the parent class.
+ *
+ * An opaque structure defining the class of a #VisuGlExtMarks objects.
+ *
+ * Since: 3.6
+ */
+struct _VisuGlExtMarksClass
+{
+  VisuGlExtClass parent;
+};
 
 /**
  * visu_gl_ext_marks_get_type:
@@ -144,13 +182,13 @@ GType visu_gl_ext_marks_get_type(void);
 
 VisuGlExtMarks* visu_gl_ext_marks_new(const gchar *name);
 
-void visu_gl_ext_marks_setData(VisuGlExtMarks *marks, VisuData *data);
-void visu_gl_ext_marks_setGlView(VisuGlExtMarks *marks, VisuGlView *view);
+void visu_gl_ext_marks_setDataRenderer(VisuGlExtMarks *marks, VisuNodeArrayRenderer *renderer);
 void visu_gl_ext_marks_setInteractive(VisuGlExtMarks *marks, VisuInteractive *inter);
 
-gboolean visu_gl_ext_marks_setHighlightedList(VisuGlExtMarks *marks, GList *lst,
-				      VisuGlExtMarksStatus status);
-GList* visu_gl_ext_marks_getHighlightedList(VisuGlExtMarks *marks);
+gboolean visu_gl_ext_marks_setHighlight(VisuGlExtMarks *marks, GArray *nodes,
+                                        VisuGlExtMarksStatus status);
+gboolean visu_gl_ext_marks_unHighlight(VisuGlExtMarks *marks);
+GArray* visu_gl_ext_marks_getHighlighted(const VisuGlExtMarks *marks);
 gboolean visu_gl_ext_marks_setInfos(VisuGlExtMarks *marks, guint nodeId, gboolean status);
 gboolean visu_gl_ext_marks_getActive(VisuGlExtMarks *marks, guint nodeId);
 gboolean visu_gl_ext_marks_getHighlightStatus(VisuGlExtMarks *marks, guint nodeId);
@@ -161,10 +199,14 @@ gboolean visu_gl_ext_marks_parseXMLFile(VisuGlExtMarks *marks, const gchar* file
 				GList **infos, VisuGlExtInfosDrawId *drawingMode,
 				guint *drawingInfos, GError **error);
 gboolean visu_gl_ext_marks_exportXMLFile(VisuGlExtMarks *marks, const gchar* filename,
-				 int *nodes, VisuGlExtInfosDrawId drawingMode,
-				 guint drawingInfos, GError **error);
-gchar* visu_gl_ext_marks_getMeasurementStrings(VisuGlExtMarks *marks, VisuData *dataObj);
+                                         GArray *nodes, VisuGlExtInfosDrawId drawingMode,
+                                         guint drawingInfos, GError **error);
+gchar* visu_gl_ext_marks_getMeasurementStrings(VisuGlExtMarks *marks);
 gchar* visu_gl_ext_marks_getMeasurementLabels(VisuGlExtMarks *marks);
 VisuGlExt* visu_gl_ext_marks_getInternalList(VisuGlExtMarks *marks);
 
+VisuGlExtMarksHidingModes visu_gl_ext_marks_getHidingMode(const VisuGlExtMarks *marks);
+gboolean visu_gl_ext_marks_setHidingMode(VisuGlExtMarks *marks,
+                                         VisuGlExtMarksHidingModes mode);
+
 #endif
