@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -43,6 +43,8 @@
 */
 #include "paths.h"
 
+#include <visu_configFile.h>
+
 #include <openGLFunctions/text.h>
 #include <openGLFunctions/objectList.h>
 
@@ -78,29 +80,50 @@
 struct _VisuGlExtPathsPrivate
 {
   gboolean dispose_has_run;
-  gboolean areBuilt;
 
   /* Related objects. */
   VisuPaths *obj;
+  float width;
 };
 
-static void visu_gl_ext_paths_finalize(GObject* obj);
 static void visu_gl_ext_paths_dispose(GObject* obj);
 static void visu_gl_ext_paths_rebuild(VisuGlExt *ext);
+static void visu_gl_ext_paths_draw(VisuGlExt *paths);
+
+#define FLAG_RESOURCE_WIDTH "path_lineWidth"
+#define DESC_RESOURCE_WIDTH "Line width for drawing of paths ; float (positive)"
+static void exportResources(GString *data, VisuData *dataObj);
+
+/* Local variables. */
+static float pathWidth = 3.f;
 
 /* Local callbacks */
+static void onEntryUsed(VisuGlExtPaths *paths, VisuConfigFileEntry *entry, VisuConfigFile *obj);
 
-G_DEFINE_TYPE(VisuGlExtPaths, visu_gl_ext_paths, VISU_TYPE_GL_EXT)
+G_DEFINE_TYPE_WITH_CODE(VisuGlExtPaths, visu_gl_ext_paths, VISU_TYPE_GL_EXT,
+                        G_ADD_PRIVATE(VisuGlExtPaths))
 
 static void visu_gl_ext_paths_class_init(VisuGlExtPathsClass *klass)
 {
+  float rg[2] = {0.01f, 10.f};
+  VisuConfigFileEntry *conf;
+
   DBG_fprintf(stderr, "Extension Paths: creating the class of the object.\n");
   /* DBG_fprintf(stderr, "                - adding new signals ;\n"); */
 
   /* Connect the overloading methods. */
   G_OBJECT_CLASS(klass)->dispose  = visu_gl_ext_paths_dispose;
-  G_OBJECT_CLASS(klass)->finalize = visu_gl_ext_paths_finalize;
   VISU_GL_EXT_CLASS(klass)->rebuild = visu_gl_ext_paths_rebuild;
+  VISU_GL_EXT_CLASS(klass)->draw = visu_gl_ext_paths_draw;
+
+  DBG_fprintf(stderr, "Extension Paths: set the conf entries for this class.\n");
+  conf = visu_config_file_addFloatArrayEntry(VISU_CONFIG_FILE_RESOURCE,
+                                             FLAG_RESOURCE_WIDTH,
+                                             DESC_RESOURCE_WIDTH,
+                                             1, &pathWidth, rg, FALSE);
+  visu_config_file_entry_setVersion(conf, 3.7f);
+  visu_config_file_addExportFunction(VISU_CONFIG_FILE_RESOURCE,
+                                     exportResources);
 }
 
 static void visu_gl_ext_paths_init(VisuGlExtPaths *obj)
@@ -108,12 +131,15 @@ static void visu_gl_ext_paths_init(VisuGlExtPaths *obj)
   DBG_fprintf(stderr, "Extension Paths: initializing a new object (%p).\n",
 	      (gpointer)obj);
   
-  obj->priv = g_malloc(sizeof(VisuGlExtPathsPrivate));
+  obj->priv = visu_gl_ext_paths_get_instance_private(obj);
   obj->priv->dispose_has_run = FALSE;
 
   /* Private data. */
-  obj->priv->areBuilt = FALSE;
   obj->priv->obj      = (VisuPaths*)0;
+  obj->priv->width    = pathWidth;
+
+  g_signal_connect_object(VISU_CONFIG_FILE_RESOURCE, "parsed::" FLAG_RESOURCE_WIDTH,
+                          G_CALLBACK(onEntryUsed), (gpointer)obj, G_CONNECT_SWAPPED);
 }
 static void visu_gl_ext_paths_dispose(GObject* obj)
 {
@@ -132,26 +158,6 @@ static void visu_gl_ext_paths_dispose(GObject* obj)
   /* Chain up to the parent class */
   G_OBJECT_CLASS(visu_gl_ext_paths_parent_class)->dispose(obj);
 }
-static void visu_gl_ext_paths_finalize(GObject* obj)
-{
-  VisuGlExtPaths *paths;
-
-  g_return_if_fail(obj);
-
-  DBG_fprintf(stderr, "Extension Paths: finalize object %p.\n", (gpointer)obj);
-
-  paths = VISU_GL_EXT_PATHS(obj);
-  if (paths->priv)
-    {
-      DBG_fprintf(stderr, "Extension Paths: free private paths.\n");
-      g_free(paths->priv);
-    }
-
-  /* Chain up to the parent class */
-  DBG_fprintf(stderr, "Extension Paths: chain to parent.\n");
-  G_OBJECT_CLASS(visu_gl_ext_paths_parent_class)->finalize(obj);
-  DBG_fprintf(stderr, "Extension Paths: freeing ... OK.\n");
-}
 
 /**
  * visu_gl_ext_paths_new:
@@ -175,7 +181,7 @@ VisuGlExtPaths* visu_gl_ext_paths_new(const gchar *name)
   extensionPaths = VISU_GL_EXT(g_object_new(VISU_TYPE_GL_EXT_PATHS,
                                             "name", (name)?name:name_, "label", _(name),
                                             "description", description, "nGlObj", 1,
-                                            "priority", VISU_GL_EXT_PRIORITY_LAST - 1, NULL));
+                                            "priority", VISU_GL_EXT_PRIORITY_NODES - 1, NULL));
 
   return VISU_GL_EXT_PATHS(extensionPaths);
 }
@@ -189,8 +195,7 @@ VisuGlExtPaths* visu_gl_ext_paths_new(const gchar *name)
  *
  * Since: 3.7
  *
- * Returns: TRUE if visu_gl_ext_paths_draw() should be called and then 'OpenGLAskForReDraw'
- *          signal be emitted.
+ * Returns: TRUE if the model was actually changed.
  **/
 gboolean visu_gl_ext_paths_set(VisuGlExtPaths *paths, VisuPaths *obj)
 {
@@ -207,24 +212,47 @@ gboolean visu_gl_ext_paths_set(VisuGlExtPaths *paths, VisuPaths *obj)
   if (obj)
     visu_paths_ref(obj);
 
-  paths->priv->areBuilt = FALSE;
+  visu_gl_ext_setDirty(VISU_GL_EXT(paths), TRUE);
   return TRUE;
 }
 /**
- * visu_gl_ext_paths_setDirty:
+ * visu_gl_ext_paths_setWidth:
+ * @paths: a #VisuGlExtPaths object.
+ * @value: a positive float lower than 10.
+ *
+ * Change the rendering width of the @paths.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if the width has changed.
+ **/
+gboolean visu_gl_ext_paths_setWidth(VisuGlExtPaths *paths, float value)
+{
+  g_return_val_if_fail(VISU_IS_GL_EXT_PATHS(paths) && value > 0.f, FALSE);
+
+  value = CLAMP(value, 0.f, 10.f);
+  if (value == paths->priv->width)
+    return FALSE;
+
+  paths->priv->width = value;
+  visu_gl_ext_setDirty(VISU_GL_EXT(paths), TRUE);
+  return TRUE;
+}
+/**
+ * visu_gl_ext_paths_getWidth:
  * @paths: a #VisuGlExtPaths object.
  *
- * Currently, #VisuPath are not objects, so @paths cannot react to a
- * change on them. Callers have to set by hand that @paths should be
- * redrawn with this routine.
+ * Inquire the width used to render the @paths.
  *
- * Since: 3.7
+ * Since: 3.8
+ *
+ * Returns: the width used to render the path.
  **/
-void visu_gl_ext_paths_setDirty(VisuGlExtPaths *paths)
+float visu_gl_ext_paths_getWidth(VisuGlExtPaths *paths)
 {
-  g_return_if_fail(VISU_IS_GL_EXT_PATHS(paths));
+  g_return_val_if_fail(VISU_IS_GL_EXT_PATHS(paths), pathWidth);
 
-  paths->priv->areBuilt = FALSE;
+  return paths->priv->width;
 }
 
 /****************/
@@ -232,29 +260,30 @@ void visu_gl_ext_paths_setDirty(VisuGlExtPaths *paths)
 /****************/
 static void visu_gl_ext_paths_rebuild(VisuGlExt *ext)
 {
-  VisuGlExtPaths *paths = VISU_GL_EXT_PATHS(ext);
-
-  paths->priv->areBuilt = FALSE;
-  visu_gl_ext_paths_draw(paths);
+  visu_gl_ext_setDirty(ext, TRUE);
+  visu_gl_ext_paths_draw(ext);
 }
 
-/**
- * visu_gl_ext_paths_draw:
- * @paths: the #VisuBox object to build paths for.
- *
- * This method creates a compiled list that draws paths.
- */
-void visu_gl_ext_paths_draw(VisuGlExtPaths *paths)
+static void visu_gl_ext_paths_draw(VisuGlExt *paths)
 {
-  g_return_if_fail(VISU_IS_GL_EXT_PATHS(paths));
+  visu_gl_ext_startDrawing(paths);
+  if (VISU_GL_EXT_PATHS(paths)->priv->obj)
+    visu_paths_draw(VISU_GL_EXT_PATHS(paths)->priv->obj, pathWidth);
+  visu_gl_ext_completeDrawing(paths);
+}
 
-  /* Nothing to draw; */
-  if(!visu_gl_ext_getActive(VISU_GL_EXT(paths)) || paths->priv->areBuilt) return;
+/*************************/
+/* Resources management. */
+/*************************/
+static void exportResources(GString *data, VisuData *dataObj _U_)
+{
+  visu_config_file_exportComment(data, DESC_RESOURCE_WIDTH);
+  visu_config_file_exportEntry(data, FLAG_RESOURCE_WIDTH, NULL,
+                               "%f", pathWidth);
 
-  glNewList(visu_gl_ext_getGlList(VISU_GL_EXT(paths)), GL_COMPILE);
-  if (paths->priv->obj)
-    visu_paths_draw(paths->priv->obj);
-  glEndList();
-
-  paths->priv->areBuilt = TRUE;
+  visu_config_file_exportComment(data, "");
+}
+static void onEntryUsed(VisuGlExtPaths *paths, VisuConfigFileEntry *entry _U_, VisuConfigFile *obj _U_)
+{
+  visu_gl_ext_paths_setWidth(paths, pathWidth);
 }
