@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -44,6 +44,7 @@
 #ifndef SCALE_H
 #define SCALE_H
 
+#include "iface_lined.h"
 #include <visu_extension.h>
 #include <openGLFunctions/view.h>
 
@@ -105,12 +106,27 @@ typedef struct _VisuGlExtScale VisuGlExtScale;
 typedef struct _VisuGlExtScalePrivate VisuGlExtScalePrivate;
 typedef struct _VisuGlExtScaleClass VisuGlExtScaleClass;
 
+/**
+ * VisuGlExtScale:
+ *
+ * All fields are private, use the access routines.
+ *
+ * Since: 3.3
+ */
 struct _VisuGlExtScale
 {
   VisuGlExt parent;
 
   VisuGlExtScalePrivate *priv;
 };
+/**
+ * VisuGlExtScaleClass:
+ * @parent: parent structure.
+ *
+ * An opaque structure.
+ *
+ * Since: 3.3
+ */
 struct _VisuGlExtScaleClass
 {
   VisuGlExtClass parent;
@@ -127,17 +143,8 @@ struct _VisuGlExtScaleClass
  */
 GType visu_gl_ext_scale_get_type(void);
 
-VisuGlExtScale* visu_gl_ext_scale_getDefault();
+VisuGlExtScale* visu_gl_ext_scale_new(const gchar *name);
 
-gboolean visu_gl_ext_scale_setDefaultRGB(float rgba[4], int mask);
-gboolean visu_gl_ext_scale_setDefaultLineWidth(float width);
-gboolean visu_gl_ext_scale_setDefaultStipple(guint16 stipple);
-
-float*   visu_gl_ext_scale_getDefaultRGB();
-float    visu_gl_ext_scale_getDefaultLineWidth();
-guint16  visu_gl_ext_scale_getDefaultStipple();
-
-gboolean visu_gl_ext_scale_setGlView(VisuGlExtScale *scale, VisuGlView *view);
 guint visu_gl_ext_scale_add(VisuGlExtScale *scale, float origin[3], float orientation[3],
                             float length, const gchar *legend);
 
@@ -152,6 +159,4 @@ float visu_gl_ext_scale_getLength(VisuGlExtScale *scale, guint i);
 float* visu_gl_ext_scale_getOrigin(VisuGlExtScale *scale, guint i);
 float* visu_gl_ext_scale_getOrientation(VisuGlExtScale *scale, guint i);
 
-void visu_gl_ext_scale_draw(VisuGlExtScale *scale);
-
 #endif
