@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -46,10 +46,8 @@
 #include <string.h>
 
 #include <coreTools/toolMatrix.h>
-#include <coreTools/toolConfigFile.h>
 #include <coreTools/toolShade.h>
 #include <extensions/node_vectors.h>
-#include <visu_configFile.h>
 
 /**
  * SECTION:geometry
@@ -115,177 +113,6 @@ struct _VisuPaths
 
 #define GEOMETRY_PATH_ALLOC_SIZE 50
 
-#define GEOMETRY_DIFF_MINMAX_ID "max_" VISU_GEODIFF_ID
-
-#define FLAG_RESOURCE_WIDTH "path_lineWidth"
-#define DESC_RESOURCE_WIDTH "Line width for drawing of paths ; float (positive)"
-static void exportResources(GString *data, VisuData *dataObj, VisuGlView *view);
-
-/* Local variables. */
-static float pathWidth = 3.f;
-
-/**********************/
-/* Memory management. */
-/**********************/
-static void freeData(gpointer obj, gpointer data _U_)
-{
-#if GLIB_MINOR_VERSION > 9
-  g_slice_free1(sizeof(float) * 6, obj);
-#else
-  g_free(obj);
-#endif
-}
-static gpointer newOrCopyData(gconstpointer orig, gpointer user_data _U_)
-{
-  float *data;
-
-#if GLIB_MINOR_VERSION > 9
-  data = g_slice_alloc(sizeof(float) * 6);
-#else
-  data = g_malloc(sizeof(float) * 6);
-#endif
-  if (orig)
-    memcpy(data, orig, sizeof(float) * 6);
-  else
-    memset(data, 0, sizeof(float) * 6);
-
-  return (gpointer)data;
-}
-
-/*************************/
-/* Calculation routines. */
-/*************************/
-/**
- * visu_geodiff_getPeriodicDistance:
- * @diff: (out) (array fixed-size=3): a location to store the shift.
- * @data: a #VisuData object.
- * @node1: a #VisuNode object.
- * @node2: another #VisuNode object.
- *
- * Compute the shortest distance between @node1 and @node2 of @data
- * taking into account the periodic boundary conditions.
- *
- * Since: 3.5
- */
-void visu_geodiff_getPeriodicDistance(float diff[3], VisuData *data,
-                                      VisuNode *node1, VisuNode *node2)
-{
-  diff[0] = node1->xyz[0] + node1->translation[0] -
-    node2->xyz[0] - node2->translation[0];
-  diff[1] = node1->xyz[1] + node1->translation[1] -
-    node2->xyz[1] - node2->translation[1];
-  diff[2] = node1->xyz[2] + node1->translation[2] -
-    node2->xyz[2] - node2->translation[2];
-
-  visu_box_getPeriodicVector(visu_boxed_getBox(VISU_BOXED(data)), diff);
-}
-
-/**
- * visu_geodiff_new:
- * @dataRef: a #VisuData object ;
- * @data: another #VisuData object.
- * @reorder: a boolean.
- *
- * Compare the position of each #VisuNode of @dataRef and @data,
- * the result is store as a property of @data and can be visualise
- * using a #VisuGlExtNodeVectors object. If @reorder is TRUE, the nodes in
- * @data will be modified to follow the ordering of @dataRef.
- *
- * Since: 3.5
- *
- * Returns: TRUE if a difference is possible (same number of nodes).
- */
-gboolean visu_geodiff_new(VisuData *dataRef, VisuData *data, gboolean reorder)
-{
-  VisuNodeProperty *prop;
-  VisuNodeArrayIter iter, iterRef;
-  GValue diffValue = {0, {{0}, {0}}};
-  float *diff, align[3];
-  float *minMax;
-
-  g_return_val_if_fail(VISU_IS_DATA(dataRef), FALSE);
-  g_return_val_if_fail(VISU_IS_DATA(data), FALSE);
-
-  DBG_fprintf(stderr, "Geometry: making a diff between %p and %p.\n",
-	      (gpointer)dataRef, (gpointer)data);
-
-  /* Check compatibility of population. */
-  visu_node_array_iterNew(VISU_NODE_ARRAY(data), &iter);
-  visu_node_array_iterNew(VISU_NODE_ARRAY(dataRef), &iterRef);
-
-  DBG_fprintf(stderr, " | %d - %d.\n", iter.nElements, iterRef.nElements);
-  if (iter.nElements != iterRef.nElements)
-    return FALSE;
-
-  for (visu_node_array_iterStart(VISU_NODE_ARRAY(data), &iter), visu_node_array_iterStart(VISU_NODE_ARRAY(dataRef), &iterRef);
-       iter.element && iterRef.element;
-       visu_node_array_iterNextElement(VISU_NODE_ARRAY(data), &iter), visu_node_array_iterNextElement(VISU_NODE_ARRAY(dataRef), &iterRef))
-    {
-      DBG_fprintf(stderr, " | (%d) # %d - %d.\n",
-                  iter.iElement, iter.nStoredNodes, iterRef.nStoredNodes);
-      if (iter.nStoredNodes != iterRef.nStoredNodes)
-        return FALSE;
-    }
-
-  if (reorder)
-    visu_data_reorder(data, dataRef);
-
-  /* Ok, here the two files match with respect of number of nodes per
-     element. */
-  g_value_init(&diffValue, G_TYPE_POINTER);
-
-  /* If the two files are free BC, we align the first atom. */
-  align[0] = 0.f;
-  align[1] = 0.f;
-  align[2] = 0.f;
-  if (visu_box_getBoundary(visu_boxed_getBox(VISU_BOXED(dataRef))) == VISU_BOX_FREE &&
-      visu_box_getBoundary(visu_boxed_getBox(VISU_BOXED(data))) == VISU_BOX_FREE)
-    {
-      visu_geodiff_getPeriodicDistance(align, dataRef,
-                                       visu_node_array_getFromId(VISU_NODE_ARRAY(dataRef), 0),
-                                       visu_node_array_getFromId(VISU_NODE_ARRAY(data), 0));
-      DBG_fprintf(stderr, "Geometry: free BC boxes, applying translation %gx%gx%g.\n",
-                  align[0], align[1], align[2]);
-    }
-
-  /* We add a VisuData property to store the min max values. */
-  minMax = g_malloc(sizeof(float) * 2);
-  g_object_set_data_full(G_OBJECT(data), GEOMETRY_DIFF_MINMAX_ID,
-			 (gpointer)minMax, g_free);
-  minMax[0] = G_MAXFLOAT;
-  minMax[1] = 0.f;
-
-  /* Add a node property with the number of columns. */
-  prop = visu_node_array_property_newPointer(VISU_NODE_ARRAY(data), VISU_GEODIFF_ID,
-                                       freeData, newOrCopyData, (gpointer)0);
-
-  for (visu_node_array_iterStartNumber(VISU_NODE_ARRAY(data), &iter),
-         visu_node_array_iterStartNumber(VISU_NODE_ARRAY(dataRef), &iterRef);
-       iter.node && iterRef.node;
-       visu_node_array_iterNextNodeNumber(VISU_NODE_ARRAY(data), &iter),
-         visu_node_array_iterNextNodeNumber(VISU_NODE_ARRAY(dataRef), &iterRef))
-    {
-      /* We read the data from the line, if not void. */
-      diff = newOrCopyData((gconstpointer)0, (gpointer)0);
-      visu_geodiff_getPeriodicDistance(diff, data, iter.node, iterRef.node);
-      diff[0] += align[0];
-      diff[1] += align[1];
-      diff[2] += align[2];
-      tool_matrix_cartesianToSpherical(diff + 3, diff);
-      DBG_fprintf(stderr, "Geometry: diff atom %d, %9g %9g %9g (%9g %5g %5g).\n",
-		  iter.node->number, diff[0], diff[1], diff[2],
-		  diff[3], diff[4], diff[5]);
-      minMax[0] = MIN(minMax[0], diff[3]);
-      minMax[1] = MAX(minMax[1], diff[3]);
-      
-      /* Associates the values to the node. */
-      g_value_set_pointer(&diffValue, diff);
-      visu_node_property_setValue(prop, iter.node, &diffValue);
-    }
-
-  return TRUE;
-}
-
 /**
  * visu_paths_get_type:
  * @void: nothing.
@@ -500,6 +327,8 @@ void visu_paths_empty(VisuPaths *paths)
 void visu_paths_free(VisuPaths *paths)
 {
   visu_paths_empty(paths);
+  if (paths->shade)
+    tool_shade_free(paths->shade);
   g_free(paths);
 }
 /**
@@ -507,6 +336,7 @@ void visu_paths_free(VisuPaths *paths)
  * @data: a #VisuData object with a geometry difference (see
  * visu_geodiff_new()).
  * @paths: the set of paths to extend.
+ * @energy: the current total energy, if any, otherwise use %G_MAXFLOAT.
  *
  * This routine read the geometry difference hold in @data and add a
  * new step in the set of paths. If new paths are created, one
@@ -517,37 +347,31 @@ void visu_paths_free(VisuPaths *paths)
  *
  * Returns: TRUE if new paths have been added.
  */
-gboolean visu_paths_addFromDiff(VisuPaths *paths, VisuData *data)
+gboolean visu_paths_addFromDiff(VisuPaths *paths, VisuDataDiff *data, gdouble energy)
 {
-  GValue diffValue = {0, {{0}, {0}}};
-  VisuNodeProperty *prop;
-  VisuNodeArrayIter iter;
+  VisuNodeValuesIter iter;
   float *diff, xyz[3];
-  gdouble energy;
   gboolean new;
 
-  new = FALSE;
-  prop = visu_node_array_getProperty(VISU_NODE_ARRAY(data), VISU_GEODIFF_ID);
-  g_return_val_if_fail(prop, FALSE);
+  if (visu_data_diff_isEmpty(data))
+    return FALSE;
 
-  g_object_get(G_OBJECT(data), "totalEnergy", &energy, NULL);
   if (energy == G_MAXFLOAT)
     energy = paths->minE;
 
-  g_value_init(&diffValue, G_TYPE_POINTER);
-  visu_node_array_iterNew(VISU_NODE_ARRAY(data), &iter);
-  for (visu_node_array_iterStart(VISU_NODE_ARRAY(data), &iter); iter.node;
-       visu_node_array_iterNext(VISU_NODE_ARRAY(data), &iter))
+  new = FALSE;
+  for (visu_node_values_iter_new(&iter, ITER_NODES_BY_TYPE,
+                                 VISU_NODE_VALUES(data));
+       iter.iter.node; visu_node_values_iter_next(&iter))
     {
-      visu_node_property_getValue(prop, iter.node, &diffValue);
-      diff = (float*)g_value_get_pointer(&diffValue);
+      diff = (gfloat*)g_value_get_pointer(&iter.value);
       if (diff[3] > 0.01f)
 	{
-	  xyz[0] = iter.node->xyz[0] - diff[0];
-	  xyz[1] = iter.node->xyz[1] - diff[1];
-	  xyz[2] = iter.node->xyz[2] - diff[2];
-	  new = visu_paths_addNodeStep(paths, paths->time, iter.node->number,
-				 xyz, diff, (float)energy) || new;
+	  xyz[0] = iter.iter.node->xyz[0] - diff[0];
+	  xyz[1] = iter.iter.node->xyz[1] - diff[1];
+	  xyz[2] = iter.iter.node->xyz[2] - diff[2];
+	  new = visu_paths_addNodeStep(paths, paths->time, iter.iter.node->number,
+                                       xyz, diff, (float)energy) || new;
 	}
     }
   paths->time += 1;
@@ -620,65 +444,6 @@ void visu_paths_constrainInBox(VisuPaths *paths, VisuData *data)
       path->translation[2] = t[2] + paths->translation[2];
     }
 }
-/**
- * visu_geodiff_hasData:
- * @data: a #VisuData object.
- *
- * A set coordinate differences can be associated to a #VisuData using visu_geodiff_new().
- *
- * Since: 3.6
- *
- * Returns: TRUE if the given @data has a set of differences associated.
- */
-gboolean visu_geodiff_hasData(VisuData *data)
-{
-  return (g_object_get_data(G_OBJECT(data), GEOMETRY_DIFF_MINMAX_ID) != (gpointer)0);
-}
-/**
- * visu_geodiff_export:
- * @data: a #VisuData object.
- *
- * Create a string with differences of coordinates stored in @data in
- * cartesian coordinates.
- *
- * Since: 3.6
- *
- * Returns: a new string that should be freed after use.
- */
-gchar* visu_geodiff_export(VisuData *data)
-{
-  GString *output;
-  VisuNodeArrayIter iter;
-  GValue diffValue = {0, {{0}, {0}}};
-  float *diff;
-  gboolean start;
-  VisuNodeProperty *prop;
-
-  g_return_val_if_fail(VISU_IS_DATA(data), (gchar*)0);
-  
-  prop = visu_node_array_getProperty(VISU_NODE_ARRAY(data), VISU_GEODIFF_ID);
-  g_return_val_if_fail(prop, (gchar*)0);
-
-  start = TRUE;
-  output = g_string_new("#metaData: diff=[ \\\n");
-  g_value_init(&diffValue, G_TYPE_POINTER);
-  visu_node_array_iterNew(VISU_NODE_ARRAY(data), &iter);
-  for (visu_node_array_iterStart(VISU_NODE_ARRAY(data), &iter); iter.node;
-       visu_node_array_iterNext(VISU_NODE_ARRAY(data), &iter))
-    {
-      if (!start)
-	output = g_string_append(output, "; \\\n");
-      visu_node_property_getValue(prop, iter.node, &diffValue);
-      diff = (float*)g_value_get_pointer(&diffValue);
-
-      g_string_append_printf(output, "# %12.8f; %12.8f; %12.8f",
-			     diff[0], diff[1], diff[2]);
-      start = FALSE;
-    }
-  output = g_string_append(output, " \\\n# ]\n");
-
-  return g_string_free(output, FALSE);
-}
 /**
  * visu_paths_pinPositions:
  * @paths: a #VisuPaths object.
@@ -701,7 +466,7 @@ void visu_paths_pinPositions(VisuPaths *paths, VisuData *data)
     energy = paths->minE;
 
   DBG_fprintf(stderr, "Visu Geometry: pin current positions.\n");
-  visu_node_array_iterNew(VISU_NODE_ARRAY(data), &iter);
+  visu_node_array_iter_new(VISU_NODE_ARRAY(data), &iter);
   for (visu_node_array_iterStart(VISU_NODE_ARRAY(data), &iter); iter.node;
        visu_node_array_iterNext(VISU_NODE_ARRAY(data), &iter))
     {
@@ -730,14 +495,16 @@ void visu_paths_pinPositions(VisuPaths *paths, VisuData *data)
  *
  * Returns: TRUE is the scheme is changed.
  */
-gboolean visu_paths_setToolShade(VisuPaths *paths, ToolShade* shade)
+gboolean visu_paths_setToolShade(VisuPaths *paths, const ToolShade* shade)
 {
   g_return_val_if_fail(paths, FALSE);
 
-  if (paths->shade == shade)
+  if (tool_shade_compare(paths->shade, shade))
     return FALSE;
   
-  paths->shade = shade;
+  if (paths->shade)
+    tool_shade_free(paths->shade);
+  paths->shade = tool_shade_copy(shade);
   return TRUE;
 }
 /**
@@ -750,9 +517,9 @@ gboolean visu_paths_setToolShade(VisuPaths *paths, ToolShade* shade)
  *
  * Returns: the #ToolShade used by the @paths.
  */
-ToolShade* visu_paths_getToolShade(VisuPaths *paths)
+const ToolShade* visu_paths_getToolShade(const VisuPaths *paths)
 {
-  g_return_val_if_fail(paths, (ToolShade*)0);
+  g_return_val_if_fail(paths, (const ToolShade*)0);
 
   return paths->shade;
 }
@@ -828,12 +595,13 @@ static void drawPath(Path *path, ToolShade *shade, float min, float max)
 /**
  * visu_paths_draw:
  * @paths: a set of paths.
+ * @pathWidth: the width for the drawn path
  *
  * OpenGL calls to create the paths.
  *
  * Since: 3.6
  */
-void visu_paths_draw(VisuPaths *paths)
+void visu_paths_draw(VisuPaths *paths, float pathWidth)
 {
   GList *tmpLst;
   ToolShade *shade;
@@ -854,44 +622,6 @@ void visu_paths_draw(VisuPaths *paths)
   glEnable(GL_LIGHTING);
 }
 
-/*****************/
-/* Init routine. */
-/*****************/
-/**
- * visu_geometry_init: (skip)
- *
- * Initialise the geometry routines. Should not be called except at
- * initialisation time.
- *
- * Since: 3.5
- */
-void visu_geometry_init()
-{
-  float rg[2] = {0.01f, 10.f};
-  VisuConfigFileEntry *conf;
-
-  DBG_fprintf(stderr, "Geometry: set the conf entries for this module.\n");
-  conf = visu_config_file_addFloatArrayEntry(VISU_CONFIG_FILE_RESOURCE,
-                                             FLAG_RESOURCE_WIDTH,
-                                             DESC_RESOURCE_WIDTH,
-                                             1, &pathWidth, rg);
-  visu_config_file_entry_setVersion(conf, 3.7f);
-  visu_config_file_addExportFunction(VISU_CONFIG_FILE_RESOURCE,
-				   exportResources);
-}
-
-/*************************/
-/* Resources management. */
-/*************************/
-static void exportResources(GString *data, VisuData *dataObj _U_, VisuGlView *view _U_)
-{
-  visu_config_file_exportComment(data, DESC_RESOURCE_WIDTH);
-  visu_config_file_exportEntry(data, FLAG_RESOURCE_WIDTH, NULL,
-                               "%f", pathWidth);
-
-  visu_config_file_exportComment(data, "");
-}
-
 /*****************************/
 /* XML files for iso-values. */
 /*****************************/
