@@ -1,20 +1,20 @@
 /*   EXTRAITS DE LA LICENCE
 	Copyright CEA, contributeurs : Damien CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
+	Adresse mèl :
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -47,56 +47,56 @@
 
 
 /* Various tests for the surface routines. */
-static gboolean test_visu_surfaces_points_init(VisuSurfacesPoints *points);
-static gboolean test_visu_surfaces_points_allocate_0(VisuSurfacesPoints *points);
-static gboolean test_visu_surfaces_points_allocate(VisuSurfacesPoints *points);
-static gboolean test_visu_surfaces_points_remove_1(VisuSurfacesPoints *points);
-static gboolean test_visu_surfaces_points_remove_all(VisuSurfacesPoints *points);
-static void local_populate(VisuSurfacesPoints *points);
-static gboolean test_visu_surfaces_new(VisuSurfaces **surf);
+static gboolean test_visu_surface_points_init(VisuSurfacePoints *points);
+static gboolean test_visu_surface_points_allocate_0(VisuSurfacePoints *points);
+static gboolean test_visu_surface_points_allocate(VisuSurfacePoints *points);
+static gboolean test_visu_surface_points_remove_1(VisuSurfacePoints *points);
+static gboolean test_visu_surface_points_remove_all(VisuSurfacePoints *points);
+static void local_populate(VisuSurfacePoints *points);
+static gboolean test_visu_surface_new(VisuSurface **surf);
 
 int main(int argc, char** argv)
 {
-  VisuSurfacesPoints points;
-  VisuSurfaces *surf;
+  VisuSurfacePoints points;
+  VisuSurface *surf;
 
   /* To be removed later, needed for the link. */
   getGeneralPaths();
 
-  /* Test the VisuSurfacesPoints structure. */
-  visu_surfaces_points_init(&points, BUFFERSIZE);
-  g_return_val_if_fail(test_visu_surfaces_points_init(&points), 1);
+  /* Test the VisuSurfacePoints structure. */
+  visu_surface_points_init(&points, BUFFERSIZE);
+  g_return_val_if_fail(test_visu_surface_points_init(&points), 1);
 
   /* Try to allocate a points with zero points. */
-  visu_surfaces_points_allocate(&points, NB_SURFS + 1, 0, 0);
-  g_return_val_if_fail(test_visu_surfaces_points_allocate_0(&points), 1);
-  visu_surfaces_points_free(&points);
+  visu_surface_points_allocate(&points, NB_SURFS + 1, 0, 0);
+  g_return_val_if_fail(test_visu_surface_points_allocate_0(&points), 1);
+  visu_surface_points_free(&points);
   /* We try to allocate with some points this time. */
-  visu_surfaces_points_allocate(&points, NB_SURFS + 1, NB_POLYS, NB_POINTS);
-  g_return_val_if_fail(test_visu_surfaces_points_allocate(&points), 1);
+  visu_surface_points_allocate(&points, NB_SURFS + 1, NB_POLYS, NB_POINTS);
+  g_return_val_if_fail(test_visu_surface_points_allocate(&points), 1);
 
   /* We populate the surfaces. */
   local_populate(&points);
 
   /* We try to remove the second surface. */
   g_message("IsosurfacesPoints: remove one surface.");
-  visu_surfaces_points_remove(&points, 1);
-  g_return_val_if_fail(test_visu_surfaces_points_remove_1(&points), 1);
+  visu_surface_points_remove(&points, 1);
+  g_return_val_if_fail(test_visu_surface_points_remove_1(&points), 1);
 
   /* We try to remove the last two surfaces. */
   g_message("IsosurfacesPoints: remove all remaining surfaces.");
-  visu_surfaces_points_remove(&points, 1);
-  visu_surfaces_points_remove(&points, 0);
-  g_return_val_if_fail(test_visu_surfaces_points_remove_all(&points), 1);
-  visu_surfaces_points_free(&points);
+  visu_surface_points_remove(&points, 1);
+  visu_surface_points_remove(&points, 0);
+  g_return_val_if_fail(test_visu_surface_points_remove_all(&points), 1);
+  visu_surface_points_free(&points);
 
-  /* Test the VisuSurfaces structure. */
-  g_return_val_if_fail(test_visu_surfaces_new(&surf), 1);
+  /* Test the VisuSurface structure. */
+  g_return_val_if_fail(test_visu_surface_new(&surf), 1);
 
   return 0;
 }
 
-static gboolean test_visu_surfaces_points_init(VisuSurfacesPoints *points)
+static gboolean test_visu_surface_points_init(VisuSurfacePoints *points)
 {
   /* We check all the scalars. */
   g_return_val_if_fail(points->nsurf      == 0, FALSE);
@@ -115,7 +115,7 @@ static gboolean test_visu_surfaces_points_init(VisuSurfacesPoints *points)
   return TRUE;
 }
 
-static gboolean test_visu_surfaces_points_allocate_0(VisuSurfacesPoints *points)
+static gboolean test_visu_surface_points_allocate_0(VisuSurfacePoints *points)
 {
   /* We check the allocated arrays. */
   g_return_val_if_fail(points->num_polys_surf, FALSE);
@@ -132,7 +132,7 @@ static gboolean test_visu_surfaces_points_allocate_0(VisuSurfacesPoints *points)
 
   return TRUE;
 }
-static gboolean test_visu_surfaces_points_allocate(VisuSurfacesPoints *points)
+static gboolean test_visu_surface_points_allocate(VisuSurfacePoints *points)
 {
   /* We check the allocated arrays. */
   g_return_val_if_fail(points->num_polys_surf, FALSE);
@@ -150,7 +150,7 @@ static gboolean test_visu_surfaces_points_allocate(VisuSurfacesPoints *points)
   return TRUE;
 }
 
-static void local_populate(VisuSurfacesPoints *points)
+static void local_populate(VisuSurfacePoints *points)
 {
   int i, j;
 
@@ -192,7 +192,7 @@ static void local_populate(VisuSurfacesPoints *points)
       points->poly_normals[i][j] = i + j;
 }
 
-static gboolean test_visu_surfaces_points_remove_1(VisuSurfacesPoints *points)
+static gboolean test_visu_surface_points_remove_1(VisuSurfacePoints *points)
 {
   gboolean valid;
   int i, j;
@@ -246,7 +246,7 @@ static gboolean test_visu_surfaces_points_remove_1(VisuSurfacesPoints *points)
 
   return TRUE;
 }
-static gboolean test_visu_surfaces_points_remove_all(VisuSurfacesPoints *points)
+static gboolean test_visu_surface_points_remove_all(VisuSurfacePoints *points)
 {
   /* We check the scalar values. */
   g_message(" | check scalar values.");
@@ -266,12 +266,12 @@ static gboolean test_visu_surfaces_points_remove_all(VisuSurfacesPoints *points)
   return TRUE;
 }
 
-static gboolean test_visu_surfaces_new(VisuSurfaces **surf)
+static gboolean test_visu_surface_new(VisuSurface **surf)
 {
-  *surf = visu_surfaces_new(BUFFERSIZE);
+  *surf = visu_surface_new(BUFFERSIZE);
 
-  g_return_val_if_fail(test_visu_surfaces_points_init(&(*surf)->basePoints), FALSE);
-  g_return_val_if_fail(test_visu_surfaces_points_init(&(*surf)->volatilePlanes), FALSE);
+  g_return_val_if_fail(test_visu_surface_points_init(&(*surf)->basePoints), FALSE);
+  g_return_val_if_fail(test_visu_surface_points_init(&(*surf)->volatilePlanes), FALSE);
 
   /* We check the null pointers. */
   g_return_val_if_fail(!(*surf)->ids, FALSE);
