@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -46,7 +46,6 @@
 #include "gtk_colorComboBoxWidget.h"
 #include <support.h>
 #include <visu_tools.h>
-#include <visu_object.h>
 
 /**
  * SECTION:gtk_colorComboBoxWidget
@@ -96,6 +95,15 @@ enum {
   MATERIAL_VALUE_CHANGED_SIGNAL,
   LAST_SIGNAL
 };
+static guint signals[LAST_SIGNAL] = { 0 };
+enum
+  {
+    PROP_0,
+    COLOR_PROP,
+    MATERIAL_PROP,
+    N_PROP
+  };
+static GParamSpec *properties[N_PROP];
 
 /* This enum is used to access the column of the GtkListStore
    that contains the informations of stroed colors. */
@@ -131,8 +139,10 @@ enum
 static void visu_ui_color_combobox_changed (GtkWidget *widget, VisuUiColorCombobox *colorComboBox);
 static void visu_ui_color_combobox_dispose (GObject *obj);
 static void visu_ui_color_combobox_finalize(GObject *obj);
-
-static guint visu_ui_color_combobox_signals[LAST_SIGNAL] = { 0 };
+static void visu_ui_color_combobox_get_property(GObject* obj, guint property_id,
+                                                GValue *value, GParamSpec *pspec);
+static void visu_ui_color_combobox_set_property(GObject* obj, guint property_id,
+                                                const GValue *value, GParamSpec *pspec);
 
 /**
  * VisuUiColorCombobox
@@ -149,9 +159,9 @@ struct _VisuUiColorCombobox
   gboolean withRanges;
   GtkWidget *expandRanges;
   GtkWidget *rgbRanges[4];
-  GtkWidget *materialRanges[VISU_GL_LIGHT_MATERIAL_N_VALUES];
+  GtkWidget *materialRanges[TOOL_MATERIAL_N_VALUES];
   gulong rgbSignals[4];
-  gulong materialSignals[VISU_GL_LIGHT_MATERIAL_N_VALUES];
+  gulong materialSignals[TOOL_MATERIAL_N_VALUES];
   gulong comboSignal;
   GtkWidget *addButton;
 
@@ -191,7 +201,7 @@ static void visu_ui_color_combobox_addButtonClicked(GtkButton *button, gpointer
 /* Local methods. */
 static void addColorToModel(GtkTreeIter *iter, VisuUiColorComboboxClass* klass,
 			    ToolColor* color);
-static void onNewColorAvailable(GObject *obj, ToolColor* newColor, gpointer data);
+static void onNewColorAvailable(ToolPool *pool, ToolColor* newColor, gpointer data);
 
 /**
  * visu_ui_color_combobox_get_type
@@ -221,7 +231,7 @@ static void visu_ui_color_combobox_class_init(VisuUiColorComboboxClass *klass)
    *
    * Since: 3.1
    */
-  visu_ui_color_combobox_signals[COLOR_SELECTED_SIGNAL] =
+  signals[COLOR_SELECTED_SIGNAL] =
     g_signal_new ("color-selected",
 		  G_TYPE_FROM_CLASS (klass),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
@@ -239,7 +249,7 @@ static void visu_ui_color_combobox_class_init(VisuUiColorComboboxClass *klass)
    *
    * Since: 3.3
    */
-  visu_ui_color_combobox_signals[COLOR_VALUE_CHANGED_SIGNAL] =
+  signals[COLOR_VALUE_CHANGED_SIGNAL] =
     g_signal_new ("color-value-changed",
 		  G_TYPE_FROM_CLASS (klass),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
@@ -251,13 +261,13 @@ static void visu_ui_color_combobox_class_init(VisuUiColorComboboxClass *klass)
   /**
    * VisuUiColorCombobox::material-value-changed:
    * @combo: the #VisuUiColorCombobox that emits the signal ;
-   * @mat: the modified material channel (see #VisuGlLightMaterial).
+   * @mat: the modified material channel (see #ToolMaterialIds).
    *
    * This signal is emitted when the range of a material is modified.
    *
    * Since: 3.3
    */
-  visu_ui_color_combobox_signals[MATERIAL_VALUE_CHANGED_SIGNAL] =
+  signals[MATERIAL_VALUE_CHANGED_SIGNAL] =
     g_signal_new ("material-value-changed",
 		  G_TYPE_FROM_CLASS (klass),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
@@ -283,11 +293,11 @@ static void visu_ui_color_combobox_class_init(VisuUiColorComboboxClass *klass)
 		     COLUMN_COLOR_LABEL       , _("New / modify"),
 		     COLUMN_COLOR_POINTER_TO  , NULL,
 		     -1);
-  klass->colorAddedSignalId = g_signal_connect(VISU_OBJECT_INSTANCE, "colorNewAvailable",
+  klass->colorAddedSignalId = g_signal_connect(tool_color_getStorage(), "new-element",
 					       G_CALLBACK(onNewColorAvailable),
 					       (gpointer)klass);
   DBG_fprintf(stderr, "                     - add stored colours.\n");
-  colorLst = tool_color_getStoredColors();
+  colorLst = tool_pool_asList(tool_color_getStorage());
   while (colorLst)
     {
       addColorToModel(&iter, klass, (ToolColor*)colorLst->data);
@@ -297,6 +307,31 @@ static void visu_ui_color_combobox_class_init(VisuUiColorComboboxClass *klass)
   /* Connect freeing methods. */
   G_OBJECT_CLASS(klass)->dispose = visu_ui_color_combobox_dispose;
   G_OBJECT_CLASS(klass)->finalize = visu_ui_color_combobox_finalize;
+  G_OBJECT_CLASS(klass)->set_property = visu_ui_color_combobox_set_property;
+  G_OBJECT_CLASS(klass)->get_property = visu_ui_color_combobox_get_property;
+
+  /**
+   * VisuUiColorCombobox::color:
+   *
+   * Store the color of the current selection.
+   *
+   * Since: 3.8
+   */
+  properties[COLOR_PROP] = g_param_spec_boxed("color", "Color",
+                                              "color of the current selection",
+                                              TOOL_TYPE_COLOR, G_PARAM_READWRITE);
+  /**
+   * VisuUiColorCombobox::material:
+   *
+   * Store the material of the current selection.
+   *
+   * Since: 3.8
+   */
+  properties[MATERIAL_PROP] = g_param_spec_boxed("material", "Material",
+                                                 "material of the current selection",
+                                                 TOOL_TYPE_MATERIAL, G_PARAM_READWRITE);
+
+  g_object_class_install_properties(G_OBJECT_CLASS(klass), N_PROP, properties);
 }
 
 static void visu_ui_color_combobox_dispose(GObject *obj)
@@ -327,6 +362,70 @@ static void visu_ui_color_combobox_finalize(GObject *obj)
 
   DBG_fprintf(stderr, "Gtk VisuUiColorCombobox: freeing ... OK.\n");
 }
+static void visu_ui_color_combobox_get_property(GObject* obj, guint property_id,
+                                                GValue *value, GParamSpec *pspec)
+{
+  VisuUiColorCombobox *self = VISU_UI_COLOR_COMBOBOX(obj);
+  const ToolColor *color;
+  ToolColor _color;
+
+  DBG_fprintf(stderr, "Gtk VisuUiColorCombobox: get property '%s'.\n",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case COLOR_PROP:
+      color = visu_ui_color_combobox_getSelection(self);
+      if (color)
+        g_value_set_static_boxed(value, color);
+      else
+        {
+          _color.rgba[0] = gtk_range_get_value(GTK_RANGE(self->rgbRanges[0]));
+          _color.rgba[1] = gtk_range_get_value(GTK_RANGE(self->rgbRanges[1]));
+          _color.rgba[2] = gtk_range_get_value(GTK_RANGE(self->rgbRanges[2]));
+          _color.rgba[3] = gtk_range_get_value(GTK_RANGE(self->rgbRanges[3]));
+          g_value_set_boxed(value, &_color);
+        }
+      DBG_fprintf(stderr, " | color pointer is %p.\n",
+                  (gpointer)g_value_get_boxed(value));
+      break;
+    case MATERIAL_PROP:
+      g_value_take_boxed(value, visu_ui_color_combobox_getRangeMaterial(self));
+      DBG_fprintf(stderr, " | material pointer is %p.\n",
+                  (gpointer)g_value_get_boxed(value));
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
+static void visu_ui_color_combobox_set_property(GObject* obj, guint property_id,
+                                                const GValue *value, GParamSpec *pspec)
+{
+  GtkTreeIter iter;
+  VisuUiColorCombobox *self = VISU_UI_COLOR_COMBOBOX(obj);
+
+  DBG_fprintf(stderr, "Gtk VisuUiColorCombobox: set property '%s'.\n",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case COLOR_PROP:
+      if (!visu_ui_color_combobox_setSelection(self, (ToolColor*)g_value_get_boxed(value)))
+        {
+          addColorToModel(&iter, VISU_UI_COLOR_COMBOBOX_GET_CLASS(obj),
+                          (ToolColor*)g_value_get_boxed(value));
+          gtk_combo_box_set_active_iter(GTK_COMBO_BOX(obj), &iter);
+        }
+      break;
+    case MATERIAL_PROP:
+      visu_ui_color_combobox_setRangeMaterial(self, (float*)g_value_get_boxed(value), FALSE);
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
 
 
 static void visu_ui_color_combobox_init(VisuUiColorCombobox *colorComboBox)
@@ -336,7 +435,7 @@ static void visu_ui_color_combobox_init(VisuUiColorCombobox *colorComboBox)
 
   colorComboBox->hasAlphaChannel = TRUE;
   colorComboBox->dispose_has_run = FALSE;
-  colorComboBox->previouslySelectedColor = tool_color_getById(0);
+  colorComboBox->previouslySelectedColor = tool_pool_getById(tool_color_getStorage(), 0);
 }
 
 static void _drawPix(GtkCellLayout *layout _U_, GtkCellRenderer *cell,
@@ -383,7 +482,7 @@ static void buildWidgets(VisuUiColorCombobox *colorComboBox)
   /*   gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(colorComboBox), renderer, */
   /*       			  "pixbuf", COLUMN_COLOR_PIXBUF); */
   renderer = gtk_cell_renderer_text_new();
-  g_object_set(G_OBJECT(renderer), "scale", 0.67, NULL);
+  g_object_set(G_OBJECT(renderer), "scale", 0.85, NULL);
   gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(colorComboBox), renderer, FALSE);
   if (colorComboBox->hasAlphaChannel)
     gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(colorComboBox), renderer,
@@ -420,78 +519,73 @@ static void buildWidgets(VisuUiColorCombobox *colorComboBox)
       hbox = gtk_hbox_new(FALSE, 0);
       gtk_box_pack_start(GTK_BOX(vboxExpand), hbox, FALSE, FALSE, 5);
 
-      table = gtk_table_new(3, 2, FALSE);
+      table = gtk_grid_new();
+      tool_grid_resize(table, 3, 2);
       gtk_box_pack_start(GTK_BOX(hbox), table, TRUE, TRUE, 0);
       gtk_widget_show(table);
       for (i = 0; i < 3; i++)
 	{
 	  label = gtk_label_new(rgb[i]);
-	  gtk_table_attach(GTK_TABLE(table), label, 0, 1, i, i + 1,
-			   GTK_SHRINK, GTK_SHRINK, 5, 0);
+	  gtk_grid_attach(GTK_GRID(table), label, 0, i, 1, 1);
 	  colorComboBox->rgbRanges[i] = gtk_hscale_new_with_range(0., 1., 0.001);
+          gtk_widget_set_hexpand(colorComboBox->rgbRanges[i], TRUE);
 	  gtk_scale_set_value_pos(GTK_SCALE(colorComboBox->rgbRanges[i]),
 				  GTK_POS_RIGHT);
 	  gtk_widget_set_name(colorComboBox->rgbRanges[i], rgbName[i]);
-	  gtk_table_attach(GTK_TABLE(table), colorComboBox->rgbRanges[i],
-			   1, 2, i, i + 1,
-			   GTK_EXPAND | GTK_FILL, GTK_SHRINK, 5, 0);
+	  gtk_grid_attach(GTK_GRID(table), colorComboBox->rgbRanges[i],
+                          1, i, 1, 1);
 	}
       colorComboBox->addButton = gtk_button_new();
       gtk_box_pack_start(GTK_BOX(hbox), colorComboBox->addButton, FALSE, FALSE, 2);
-      image = gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_BUTTON);
+      image = gtk_image_new_from_icon_name("list-add", GTK_ICON_SIZE_BUTTON);
       gtk_container_add(GTK_CONTAINER(colorComboBox->addButton), image);
       DBG_fprintf(stderr, " | color OK\n");
 
-      table = gtk_table_new(3, 4, FALSE);
+      table = gtk_grid_new();
+      tool_grid_resize(table, 3, 4);
       gtk_box_pack_start(GTK_BOX(vboxExpand), table, FALSE, FALSE, 5);
       for (i = 0; i < 2; i++)
 	{
 	  for (j = 0; j < 2; j++)
 	    {
 	      label = gtk_label_new(material[i * 2 + j]);
-	      gtk_misc_set_alignment(GTK_MISC(label), 1., 0.5);
-	      gtk_table_attach(GTK_TABLE(table), label, j * 2, j * 2 + 1, i, i + 1,
-			       GTK_SHRINK, GTK_SHRINK, 1, 0);
+	      gtk_label_set_xalign(GTK_LABEL(label), 1.);
+	      gtk_grid_attach(GTK_GRID(table), label, j * 2, i, 1, 1);
 	      colorComboBox->materialRanges[i * 2 + j] =
 		gtk_hscale_new_with_range(0., 1., 0.01);
+              gtk_widget_set_hexpand(colorComboBox->materialRanges[i * 2 + j], TRUE);
 	      gtk_scale_set_value_pos(GTK_SCALE(colorComboBox->materialRanges[i * 2 + j]),
 				      GTK_POS_RIGHT);
 	      gtk_widget_set_name(colorComboBox->materialRanges[i * 2 +j], "scroll_mat");
-	      gtk_table_attach(GTK_TABLE(table), colorComboBox->materialRanges[i * 2 + j],
-			       2 * j + 1, 2 * j + 2, i, i + 1,
-			       GTK_EXPAND | GTK_FILL, GTK_SHRINK, 1, 0);
+	      gtk_grid_attach(GTK_GRID(table), colorComboBox->materialRanges[i * 2 + j],
+                              2 * j + 1, i, 1, 1);
 	    }
 	}
       label = gtk_label_new(material[4]);
-      gtk_misc_set_alignment(GTK_MISC(label), 1., 0.5);
-      gtk_table_attach(GTK_TABLE(table), label, 0, 1, i, i + 1,
-		       GTK_SHRINK, GTK_SHRINK, 1, 0);
+      gtk_label_set_xalign(GTK_LABEL(label), 1);
+      gtk_grid_attach(GTK_GRID(table), label, 0, i, 1, 1);
       colorComboBox->materialRanges[4] =
 	gtk_hscale_new_with_range(0., 1., 0.01);
       gtk_scale_set_value_pos(GTK_SCALE(colorComboBox->materialRanges[4]),
 			      GTK_POS_RIGHT);
       gtk_widget_set_name(colorComboBox->materialRanges[4], "scroll_mat");
-      gtk_table_attach(GTK_TABLE(table), colorComboBox->materialRanges[4],
-		       1, 2, i, i + 1,
-		       GTK_EXPAND | GTK_FILL, GTK_SHRINK, 1, 0);
+      gtk_grid_attach(GTK_GRID(table), colorComboBox->materialRanges[4],
+                      1, i, 1, 1);
       label = gtk_label_new(rgb[3]);
-      gtk_misc_set_alignment(GTK_MISC(label), 1., 0.5);
-      gtk_table_attach(GTK_TABLE(table), label, 2, 3, i, i + 1,
-		       GTK_SHRINK, GTK_SHRINK, 5, 0);
+      gtk_label_set_xalign(GTK_LABEL(label), 1.);
+      gtk_grid_attach(GTK_GRID(table), label, 2, i, 1, 1);
       colorComboBox->rgbRanges[3] = gtk_hscale_new_with_range(0., 1., 0.01);
       gtk_scale_set_value_pos(GTK_SCALE(colorComboBox->rgbRanges[3]),
 			      GTK_POS_RIGHT);
       gtk_widget_set_name(colorComboBox->rgbRanges[3], rgbName[3]);
-      gtk_table_attach(GTK_TABLE(table), colorComboBox->rgbRanges[3],
-		       3, 4, i, i + 1,
-		       GTK_EXPAND | GTK_FILL, GTK_SHRINK, 1, 0);
+      gtk_grid_attach(GTK_GRID(table), colorComboBox->rgbRanges[3], 3, i, 1, 1);
       DBG_fprintf(stderr, " | material OK\n");
       /* Attach the callbacks. */
       for (i = 0; i < 4; i++)
 	colorComboBox->rgbSignals[i] = 
 	  g_signal_connect(G_OBJECT(colorComboBox->rgbRanges[i]), "value-changed",
 			   G_CALLBACK(visu_ui_color_combobox_rgbChanged), (gpointer)colorComboBox);
-      for (i = 0; i < VISU_GL_LIGHT_MATERIAL_N_VALUES; i++)
+      for (i = 0; i < TOOL_MATERIAL_N_VALUES; i++)
 	colorComboBox->materialSignals[i] =
 	  g_signal_connect(G_OBJECT(colorComboBox->materialRanges[i]), "value-changed",
 			   G_CALLBACK(visu_ui_color_combobox_materialChanged), (gpointer)colorComboBox);
@@ -572,7 +666,7 @@ GtkWidget* visu_ui_color_combobox_new(gboolean hasAlphaChannel)
  */
 void visu_ui_color_combobox_setExpanded(VisuUiColorCombobox *colorComboBox, gboolean value)
 {
-  g_return_if_fail(VISU_UI_IS_COLOR_COMBOBOX(colorComboBox));
+  g_return_if_fail(VISU_IS_UI_COLOR_COMBOBOX(colorComboBox));
   g_return_if_fail(colorComboBox->withRanges);
 
   gtk_expander_set_expanded(GTK_EXPANDER(colorComboBox->expandRanges), value);
@@ -604,7 +698,7 @@ void visu_ui_color_combobox_setPrintValues(VisuUiColorCombobox *colorComboBox, g
  */
 GtkWidget* visu_ui_color_combobox_getRangeWidgets(VisuUiColorCombobox *colorComboBox)
 {
-  g_return_val_if_fail(VISU_UI_IS_COLOR_COMBOBOX(colorComboBox), (GtkWidget*)0);
+  g_return_val_if_fail(VISU_IS_UI_COLOR_COMBOBOX(colorComboBox), (GtkWidget*)0);
 
   return colorComboBox->expandRanges;
 }
@@ -612,15 +706,13 @@ GtkWidget* visu_ui_color_combobox_getRangeWidgets(VisuUiColorCombobox *colorComb
 static void visu_ui_color_combobox_changed(GtkWidget *widget _U_, VisuUiColorCombobox *colorComboBox)
 {
   int selected, i;
-  GdkColor gdkcolor;
-  guint alpha;
+  GdkRGBA gdkcolor;
   GtkWidget *selection;
   gint code;
   float rgba[4];
   GtkTreeIter iter;
   GObjectClass *klass;
   ToolColor *color;
-  GtkColorSelection *colorsel;
 
   selected = gtk_combo_box_get_active(GTK_COMBO_BOX(colorComboBox));
   DBG_fprintf(stderr, "Gtk VisuUiColorCombobox: internal combobox changed signal -> %d.\n", selected);
@@ -657,8 +749,9 @@ static void visu_ui_color_combobox_changed(GtkWidget *widget _U_, VisuUiColorCom
 					 colorComboBox->rgbSignals[i]);
 	      }
 	  DBG_fprintf(stderr, "Gtk VisuUiColorCombobox: emitting 'color-selected' signal.\n");
+          g_object_notify_by_pspec(G_OBJECT(colorComboBox), properties[COLOR_PROP]);
 	  g_signal_emit(G_OBJECT(colorComboBox),
-			visu_ui_color_combobox_signals[COLOR_SELECTED_SIGNAL], 0, (gpointer)color, NULL);
+			signals[COLOR_SELECTED_SIGNAL], 0, (gpointer)color, NULL);
 	}
       else
 	DBG_fprintf(stderr, "Gtk VisuUiColorCombobox: aborting 'color-selected' signal.\n");
@@ -666,50 +759,42 @@ static void visu_ui_color_combobox_changed(GtkWidget *widget _U_, VisuUiColorCom
     }
   if (colorComboBox->previouslySelectedColor)
     {
-      gdkcolor.red = 
-	(guint16)((colorComboBox->previouslySelectedColor->rgba[0]) * 65535.);
-      gdkcolor.green =
-	(guint16)((colorComboBox->previouslySelectedColor->rgba[1]) * 65535.);
-      gdkcolor.blue =
-	(guint16)((colorComboBox->previouslySelectedColor->rgba[2]) * 65535.);
-      alpha = (guint16)((colorComboBox->previouslySelectedColor->rgba[3]) * 65535.);
+      gdkcolor.red = colorComboBox->previouslySelectedColor->rgba[0];
+      gdkcolor.green = colorComboBox->previouslySelectedColor->rgba[1];
+      gdkcolor.blue = colorComboBox->previouslySelectedColor->rgba[2];
+      gdkcolor.alpha = colorComboBox->previouslySelectedColor->rgba[3];
     }
   else
     {
-      gdkcolor.red = (guint16)0.;
-      gdkcolor.green = (guint16)0.;
-      gdkcolor.blue = (guint16)0.;
-      alpha = 65535.;
+      gdkcolor.red = 0.;
+      gdkcolor.green = 0.;
+      gdkcolor.blue = 0.;
+      gdkcolor.alpha = 1.;
     }
 
   /* Create the selection. */
-  selection = gtk_color_selection_dialog_new(_("Select a color"));
-  colorsel = GTK_COLOR_SELECTION
-    (gtk_color_selection_dialog_get_color_selection
-     (GTK_COLOR_SELECTION_DIALOG(selection)));
-  gtk_color_selection_set_has_opacity_control(colorsel,
-					      colorComboBox->hasAlphaChannel);
+  selection = gtk_color_chooser_dialog_new(_("Select a color"), NULL);
+  gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(selection),
+                                  colorComboBox->hasAlphaChannel);
 /*   createColorSelectionCustomList(GTK_COLOR_SELECTION_DIALOG(selection)); */
 
   /* Initialise its values. */
-  if (colorComboBox->hasAlphaChannel)
-    gtk_color_selection_set_current_alpha(colorsel, alpha);
-  gtk_color_selection_set_current_color(colorsel, &gdkcolor);
+  gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(selection), &gdkcolor);
 
   /* Run the dialog window. */
   code = gtk_dialog_run(GTK_DIALOG(selection));
   if (code == GTK_RESPONSE_OK || code == GTK_RESPONSE_ACCEPT)
     {
-      gtk_color_selection_get_current_color(colorsel, &gdkcolor);
-      rgba[0] = (float)gdkcolor.red / 65535.;
-      rgba[1] = (float)gdkcolor.green / 65535.;
-      rgba[2] = (float)gdkcolor.blue / 65535.;
-      rgba[3] = (float)gtk_color_selection_get_current_alpha(colorsel) / 65535.;
+      gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(selection), &gdkcolor);
+      rgba[0] = (float)gdkcolor.red;
+      rgba[1] = (float)gdkcolor.green;
+      rgba[2] = (float)gdkcolor.blue;
+      rgba[3] = (float)gdkcolor.alpha;
 
       klass = G_OBJECT_GET_CLASS(colorComboBox);
-      g_signal_handler_block(VISU_OBJECT_INSTANCE, VISU_UI_COLOR_COMBOBOX_CLASS(klass)->colorAddedSignalId);
+      g_signal_handler_block(tool_color_getStorage(), VISU_UI_COLOR_COMBOBOX_CLASS(klass)->colorAddedSignalId);
       color = tool_color_addFloatRGBA(rgba, &selected);
-      g_signal_handler_unblock(VISU_OBJECT_INSTANCE, VISU_UI_COLOR_COMBOBOX_CLASS(klass)->colorAddedSignalId);
+      g_signal_handler_unblock(tool_color_getStorage(), VISU_UI_COLOR_COMBOBOX_CLASS(klass)->colorAddedSignalId);
       addColorToModel(&iter, VISU_UI_COLOR_COMBOBOX_CLASS(klass), color);
       gtk_combo_box_set_active_iter(GTK_COMBO_BOX(colorComboBox), &iter);
     }
@@ -718,7 +803,7 @@ static void visu_ui_color_combobox_changed(GtkWidget *widget _U_, VisuUiColorCom
       /* Return the combobox to the previously selected color. */
       if (colorComboBox->previouslySelectedColor)
 	visu_ui_color_combobox_setSelection(colorComboBox,
-					  colorComboBox->previouslySelectedColor);
+                                            colorComboBox->previouslySelectedColor);
       else
 	gtk_combo_box_set_active(GTK_COMBO_BOX(colorComboBox), -1);
     }
@@ -730,18 +815,20 @@ static void visu_ui_color_combobox_materialChanged(GtkRange *rg, gpointer data)
   int i;
   VisuUiColorCombobox *colorComboBox;
 
-  g_return_if_fail(VISU_UI_IS_COLOR_COMBOBOX(data));
+  g_return_if_fail(VISU_IS_UI_COLOR_COMBOBOX(data));
+
+  g_object_notify_by_pspec(G_OBJECT(data), properties[MATERIAL_PROP]);
 
   colorComboBox = VISU_UI_COLOR_COMBOBOX(data);
   DBG_fprintf(stderr, "Gtk VisuUiColorCombobox: internal material range changed signal.\n");
 
   DBG_fprintf(stderr, "Gtk VisuUiColorCombobox: emitting 'material-value-changed' signal.\n");
-  for (i = 0; i < VISU_GL_LIGHT_MATERIAL_N_VALUES; i++)
+  for (i = 0; i < TOOL_MATERIAL_N_VALUES; i++)
     if (GTK_WIDGET(rg) == colorComboBox->materialRanges[i])
       {
 	g_signal_emit(G_OBJECT(colorComboBox),
-		      visu_ui_color_combobox_signals[MATERIAL_VALUE_CHANGED_SIGNAL], 0,
-		      (VisuGlLightMaterial)i, NULL);
+		      signals[MATERIAL_VALUE_CHANGED_SIGNAL], 0,
+		      (ToolMaterialIds)i, NULL);
 	return;
       }
   g_warning("Internal error, unrecognized range.");
@@ -752,14 +839,17 @@ static void visu_ui_color_combobox_rgbChanged(GtkRange *rg, gpointer data)
   VisuUiColorCombobox *colorComboBox;
   float *rgba;
 
-  g_return_if_fail(VISU_UI_IS_COLOR_COMBOBOX(data));
+  g_return_if_fail(VISU_IS_UI_COLOR_COMBOBOX(data));
 
   colorComboBox = VISU_UI_COLOR_COMBOBOX(data);
   DBG_fprintf(stderr, "Gtk VisuUiColorCombobox: internal color range changed signal.\n");
   rgba = visu_ui_color_combobox_getRangeColor(colorComboBox);
   tool_color_getByValues(&i, rgba[0], rgba[1], rgba[2], rgba[3]);
   if (i < 0)
-    gtk_combo_box_set_active(GTK_COMBO_BOX(colorComboBox), -1);
+    {
+      gtk_combo_box_set_active(GTK_COMBO_BOX(colorComboBox), -1);
+      g_object_notify_by_pspec(G_OBJECT(data), properties[COLOR_PROP]);
+    }
   else
     gtk_combo_box_set_active(GTK_COMBO_BOX(colorComboBox), i + 1);
   g_free(rgba);
@@ -769,8 +859,8 @@ static void visu_ui_color_combobox_rgbChanged(GtkRange *rg, gpointer data)
     if (GTK_WIDGET(rg) == colorComboBox->rgbRanges[i])
       {
 	g_signal_emit(G_OBJECT(colorComboBox),
-		      visu_ui_color_combobox_signals[COLOR_VALUE_CHANGED_SIGNAL], 0,
-		      (VisuGlLightMaterial)i, NULL);
+		      signals[COLOR_VALUE_CHANGED_SIGNAL], 0,
+		      (ToolMaterialIds)i, NULL);
 	return;
       }
   g_warning("Internal error, unrecognized range.");
@@ -784,16 +874,16 @@ static void visu_ui_color_combobox_addButtonClicked(GtkButton *button _U_, gpoin
   float *rgba;
   int selected;
 
-  g_return_if_fail(VISU_UI_IS_COLOR_COMBOBOX(data));
+  g_return_if_fail(VISU_IS_UI_COLOR_COMBOBOX(data));
   colorComboBox = VISU_UI_COLOR_COMBOBOX(data);
 
   DBG_fprintf(stderr, "Gtk VisuUiColorCombobox: adding a new color from ranges.\n");
 
   rgba = visu_ui_color_combobox_getRangeColor(colorComboBox);
   klass = G_OBJECT_GET_CLASS(colorComboBox);
-  g_signal_handler_block(VISU_OBJECT_INSTANCE, VISU_UI_COLOR_COMBOBOX_CLASS(klass)->colorAddedSignalId);
+  g_signal_handler_block(tool_color_getStorage(), VISU_UI_COLOR_COMBOBOX_CLASS(klass)->colorAddedSignalId);
   color = tool_color_addFloatRGBA(rgba, &selected);
-  g_signal_handler_unblock(VISU_OBJECT_INSTANCE, VISU_UI_COLOR_COMBOBOX_CLASS(klass)->colorAddedSignalId);
+  g_signal_handler_unblock(tool_color_getStorage(), VISU_UI_COLOR_COMBOBOX_CLASS(klass)->colorAddedSignalId);
   addColorToModel(&iter, VISU_UI_COLOR_COMBOBOX_CLASS(klass), color);
   gtk_combo_box_set_active_iter(GTK_COMBO_BOX(colorComboBox), &iter);
   g_free(rgba);
@@ -808,11 +898,11 @@ static void addColorToModel(GtkTreeIter *iter, VisuUiColorComboboxClass* klass,
 
   if (!color || !klass)
     return;
-  sprintf(strAlpha, "(%3d;%3d;%3d;%3d)", (int)(color->rgba[0] * 255.),
+  sprintf(strAlpha, "(#%02x%02x%02x%02x)", (int)(color->rgba[0] * 255.),
 	  (int)(color->rgba[1] * 255.),
 	  (int)(color->rgba[2] * 255.),
 	  (int)(color->rgba[3] * 255.));
-  sprintf(str, "(%3d;%3d;%3d)", (int)(color->rgba[0] * 255.),
+  sprintf(str, "(#%02x%02x%02x)", (int)(color->rgba[0] * 255.),
 	  (int)(color->rgba[1] * 255.),
 	  (int)(color->rgba[2] * 255.));
   pixbufColorAlphaBox = tool_color_get_stamp(color, TRUE);
@@ -827,6 +917,8 @@ static void addColorToModel(GtkTreeIter *iter, VisuUiColorComboboxClass* klass,
 		     -1);
   DBG_fprintf(stderr, "Gtk VisuUiColorCombobox: appending a new color '%s'.\n",
               strAlpha);
+  g_object_unref(pixbufColorAlphaBox);
+  g_object_unref(pixbufColorBox);
 }
 /**
  * visu_ui_color_combobox_setSelection:
@@ -849,7 +941,7 @@ gboolean visu_ui_color_combobox_setSelection(VisuUiColorCombobox* colorComboBox,
   GtkListStore *model;
   ToolColor *tmpColor;
 
-  g_return_val_if_fail(color && VISU_UI_IS_COLOR_COMBOBOX(colorComboBox), FALSE);
+  g_return_val_if_fail(color && VISU_IS_UI_COLOR_COMBOBOX(colorComboBox), FALSE);
 
   DBG_fprintf(stderr, "Gtk VisuUiColorCombobox: select a new color %p.\n", (gpointer)color);
   klass = G_OBJECT_GET_CLASS(colorComboBox);
@@ -882,8 +974,9 @@ gboolean visu_ui_color_combobox_setSelection(VisuUiColorCombobox* colorComboBox,
  *
  * Since: 3.3
  */
-void visu_ui_color_combobox_setRangeColor(VisuUiColorCombobox *colorComboBox, float rgba[4],
-			    gboolean raiseSignal)
+void visu_ui_color_combobox_setRangeColor(VisuUiColorCombobox *colorComboBox,
+                                          const float rgba[4],
+                                          gboolean raiseSignal)
 {
   int pos, i;
   ToolColor *color;
@@ -933,14 +1026,14 @@ void visu_ui_color_combobox_setRangeColor(VisuUiColorCombobox *colorComboBox, fl
 }
 
 
-static void onNewColorAvailable(GObject *obj _U_, ToolColor* newColor, gpointer data)
+static void onNewColorAvailable(ToolPool *pool _U_, ToolColor* newColor, gpointer data)
 {
   VisuUiColorComboboxClass *klass;
   GtkTreeIter iter;
 
   g_return_if_fail(data);
 
-  DBG_fprintf(stderr, "Gtk VisuUiColorComboboxClass: catch the 'colorNewAvailable' signal.\n");
+  DBG_fprintf(stderr, "Gtk VisuUiColorComboboxClass: catch the 'new-element' signal.\n");
   klass = VISU_UI_COLOR_COMBOBOX_CLASS(data);
   addColorToModel(&iter, klass, newColor);
 }
@@ -955,18 +1048,18 @@ static void onNewColorAvailable(GObject *obj _U_, ToolColor* newColor, gpointer
  *
  * Since: 3.1
  */
-ToolColor* visu_ui_color_combobox_getSelection(VisuUiColorCombobox *colorComboBox)
+const ToolColor* visu_ui_color_combobox_getSelection(VisuUiColorCombobox *colorComboBox)
 {
   gboolean validIter;
   GtkTreeIter iter;
   ToolColor *color;
   GObjectClass *klass;
 
-  g_return_val_if_fail(VISU_UI_IS_COLOR_COMBOBOX(colorComboBox), (ToolColor*)0);
+  g_return_val_if_fail(VISU_IS_UI_COLOR_COMBOBOX(colorComboBox), (ToolColor*)0);
 
   validIter = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(colorComboBox), &iter);
   if (!validIter)
-    return (ToolColor*)0;
+    return (const ToolColor*)0;
 
   color = (ToolColor*)0;
   klass = G_OBJECT_GET_CLASS(colorComboBox);
@@ -983,7 +1076,7 @@ ToolColor* visu_ui_color_combobox_getSelection(VisuUiColorCombobox *colorComboBo
  * The @colorComboBox has little pixbufs to represent the color. User methods can
  * use these pixbufs but should considered them read-only.
  *
- * Returns: (transfer none): a pixbuf pointer corresponding to the
+ * Returns: (transfer full): a pixbuf pointer corresponding to the
  * little image shown on the @colorComboBox.
  *
  * Since: 3.1
@@ -1016,6 +1109,8 @@ GdkPixbuf* visu_ui_color_combobox_getPixbufFromColor(VisuUiColorCombobox *colorC
 			   -1);
       if (cl && tool_color_equal(color, cl))
 	return pixbuf;
+      if (pixbuf)
+        g_object_unref(pixbuf);
       validIter = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
     }
   return (GdkPixbuf*)0;
@@ -1023,7 +1118,7 @@ GdkPixbuf* visu_ui_color_combobox_getPixbufFromColor(VisuUiColorCombobox *colorC
 /**
  * visu_ui_color_combobox_setRangeMaterial:
  * @colorComboBox: a #VisuUiColorCombobox widget ;
- * @material: VISU_GL_LIGHT_MATERIAL_N_VALUES (see #VisuGlLightMaterial) floating point values ;
+ * @material: TOOL_MATERIAL_N_VALUES (see #ToolMaterialIds) floating point values ;
  * @raiseSignal: if TRUE a material-value-changed can be raised.
  *
  * Change the values for the ranges that control the light (emission, diffuse...).
@@ -1032,20 +1127,21 @@ GdkPixbuf* visu_ui_color_combobox_getPixbufFromColor(VisuUiColorCombobox *colorC
  *
  * Since: 3.3
  */
-void visu_ui_color_combobox_setRangeMaterial(VisuUiColorCombobox *colorComboBox, float material[5],
-			       gboolean raiseSignal)
+void visu_ui_color_combobox_setRangeMaterial(VisuUiColorCombobox *colorComboBox,
+                                             const float material[TOOL_MATERIAL_N_VALUES],
+                                             gboolean raiseSignal)
 {
   int i;
 
-  g_return_if_fail(VISU_UI_IS_COLOR_COMBOBOX(colorComboBox));
+  g_return_if_fail(VISU_IS_UI_COLOR_COMBOBOX(colorComboBox));
   g_return_if_fail(colorComboBox->withRanges);
 
   if (raiseSignal)
-    for (i = 0; i < VISU_GL_LIGHT_MATERIAL_N_VALUES; i++)
+    for (i = 0; i < TOOL_MATERIAL_N_VALUES; i++)
       gtk_range_set_value(GTK_RANGE(colorComboBox->materialRanges[i]),
 			  (gdouble)material[i]);
   else
-    for (i = 0; i < VISU_GL_LIGHT_MATERIAL_N_VALUES; i++)
+    for (i = 0; i < TOOL_MATERIAL_N_VALUES; i++)
       {
 	g_signal_handler_block(G_OBJECT(colorComboBox->materialRanges[i]),
 			       colorComboBox->materialSignals[i]);
@@ -1063,7 +1159,7 @@ void visu_ui_color_combobox_setRangeMaterial(VisuUiColorCombobox *colorComboBox,
  * is used to get the values from the material ranges.
  *
  * Returns: (array fixed-size=5) (transfer full): a newly created array of size
- * VISU_GL_LIGHT_MATERIAL_N_VALUES (see #VisuGlLightMaterial). Use g_free() to delete it.
+ * TOOL_MATERIAL_N_VALUES (see #ToolMaterialIds). Use g_free() to delete it.
  *
  * Since: 3.3
  */
@@ -1072,11 +1168,11 @@ float* visu_ui_color_combobox_getRangeMaterial(VisuUiColorCombobox *colorComboBo
   int i;
   float *values;
 
-  g_return_val_if_fail(VISU_UI_IS_COLOR_COMBOBOX(colorComboBox), (float*)0);
+  g_return_val_if_fail(VISU_IS_UI_COLOR_COMBOBOX(colorComboBox), (float*)0);
   g_return_val_if_fail(colorComboBox->withRanges, (float*)0);
 
-  values = g_malloc(sizeof(float) * VISU_GL_LIGHT_MATERIAL_N_VALUES);
-  for (i = 0; i < VISU_GL_LIGHT_MATERIAL_N_VALUES; i++)
+  values = g_malloc(sizeof(float) * TOOL_MATERIAL_N_VALUES);
+  for (i = 0; i < TOOL_MATERIAL_N_VALUES; i++)
     values[i] = (float)gtk_range_get_value(GTK_RANGE(colorComboBox->materialRanges[i]));
 
   return values;
@@ -1098,7 +1194,7 @@ float* visu_ui_color_combobox_getRangeColor(VisuUiColorCombobox *colorComboBox)
   int i;
   float *values;
 
-  g_return_val_if_fail(VISU_UI_IS_COLOR_COMBOBOX(colorComboBox), (float*)0);
+  g_return_val_if_fail(VISU_IS_UI_COLOR_COMBOBOX(colorComboBox), (float*)0);
   g_return_val_if_fail(colorComboBox->withRanges, (float*)0);
 
   values = g_malloc(sizeof(float) * 4);
