@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -50,8 +50,8 @@
 #include <support.h>
 #include <visu_tools.h>
 #include <visu_elements.h>
-#include <visu_pairs.h>
 #include <coreTools/toolMatrix.h>
+#include <renderingMethods/elementAtomic.h>
 
 /**
  * SECTION: gtk_curveWidget
@@ -75,15 +75,19 @@ struct _VisuUiCurveFrame
 {
   GtkDrawingArea parent;
 
-  gboolean dispose_has_run;
+  gboolean dispose_has_run, dirty;
+
+  VisuPairSet *model;
+  gulong pair_sig;
   
   ToolMatrixScalingFlag scale;
+  float zoom;
   float dists[2];
   float heights[2];
   float hlRange[2];
 
   VisuUiCurveFrameStyle style;
-  gchar *filter;
+  VisuElement *filter;
   GHashTable *data;
   guint nSteps;
   float init, step;
@@ -104,10 +108,26 @@ struct _VisuUiCurveFrameClass
 #define SPACER "\302\240-\302\240"
 #define ALL    _("All")
 
+enum
+  {
+    PROP_0,
+    MIN_PROP,
+    MAX_PROP,
+    ZOOM_PROP,
+    MIN_HL_PROP,
+    MAX_HL_PROP,
+    INT_HL_PROP,
+    MEAN_HL_PROP,
+    FILTER_PROP,
+    LABEL_PROP,
+    N_PROP
+  };
+static GParamSpec *_properties[N_PROP];
+
 /**
  * visu_ui_curve_frame_get_type:
  *
- * Internal routine to get #VISU_UI_TYPE_CURVE_FRAME value.
+ * Internal routine to get #VISU_TYPE_UI_CURVE_FRAME value.
  *
  * Since: 3.6
  */
@@ -117,45 +137,260 @@ G_DEFINE_TYPE (VisuUiCurveFrame, visu_ui_curve_frame, GTK_TYPE_DRAWING_AREA)
 static gboolean visu_ui_curve_frame_expose(GtkWidget *curve, GdkEventExpose *event);
 #endif
 static gboolean visu_ui_curve_frame_drawCairo(GtkWidget *curve, cairo_t *cr);
+static void visu_ui_curve_frame_get_property(GObject* obj, guint property_id,
+                                             GValue *value, GParamSpec *pspec);
+static void visu_ui_curve_frame_set_property(GObject* obj, guint property_id,
+                                             const GValue *value, GParamSpec *pspec);
 static void visu_ui_curve_frame_dispose(GObject *obj);
 static void visu_ui_curve_frame_finalize(GObject *obj);
-static void redraw(GtkWidget *widget);
 static void hashDraw(gpointer key, gpointer value, gpointer usre_data);
 static void drawData(VisuUiCurveFrame *curve, cairo_t *cr, const gchar *name,
 		     const guint *data, double w, double h, double dw,
 		     VisuUiCurveFrameStyle style);
+static void _addData(VisuUiCurveFrame *curve, const gchar *eleName, const gchar *lkName,
+                     const guint *data, guint nSteps, float init, float step);
+static void _setNNodes(VisuUiCurveFrame *curve, const gchar *ele, guint n);
 
-static void visu_ui_curve_frame_class_init (VisuUiCurveFrameClass *class)
+static void visu_ui_curve_frame_class_init (VisuUiCurveFrameClass *klass)
 {
-  GtkWidgetClass *widget_class;
-
-  widget_class = GTK_WIDGET_CLASS (class);
-
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
-  widget_class->expose_event = visu_ui_curve_frame_expose;
+  GTK_WIDGET_CLASS(klass)->expose_event = visu_ui_curve_frame_expose;
 #else
-  widget_class->draw = visu_ui_curve_frame_drawCairo;
+  GTK_WIDGET_CLASS(klass)->draw = visu_ui_curve_frame_drawCairo;
 #endif
-  G_OBJECT_CLASS(class)->dispose  = visu_ui_curve_frame_dispose;
-  G_OBJECT_CLASS(class)->finalize = visu_ui_curve_frame_finalize;
+  G_OBJECT_CLASS(klass)->dispose  = visu_ui_curve_frame_dispose;
+  G_OBJECT_CLASS(klass)->finalize = visu_ui_curve_frame_finalize;
+  G_OBJECT_CLASS(klass)->get_property  = visu_ui_curve_frame_get_property;
+  G_OBJECT_CLASS(klass)->set_property = visu_ui_curve_frame_set_property;
+
+  /**
+   * VisuUiCurveFrame::minimum:
+   *
+   * Store the minimum distance to get the g(r) from.
+   *
+   * Since: 3.8
+   */
+  _properties[MIN_PROP] = g_param_spec_float("minimum", "Minimum", "minimum distance",
+                                             0.f, G_MAXFLOAT, 0.f, G_PARAM_READWRITE);
+  /**
+   * VisuUiCurveFrame::maximum:
+   *
+   * Store the maximum distance to get the g(r) to.
+   *
+   * Since: 3.8
+   */
+  _properties[MAX_PROP] = g_param_spec_float("maximum", "Maximum", "maximum distance",
+                                             0.f, G_MAXFLOAT, 10.f, G_PARAM_READWRITE);
+  /**
+   * VisuUiCurveFrame::zoom:
+   *
+   * Store the zoom factor to discretise the g(r).
+   *
+   * Since: 3.8
+   */
+  _properties[ZOOM_PROP] = g_param_spec_float("zoom", "Zoom", "zoom factor",
+                                              1.f, G_MAXFLOAT, 5.f, G_PARAM_READWRITE);
+  /**
+   * VisuUiCurveFrame::minimum-highlight:
+   *
+   * Store the minimum distance for the highlight region.
+   *
+   * Since: 3.8
+   */
+  _properties[MIN_HL_PROP] = g_param_spec_float("minimum-highlight", "Minimum highlight",
+                                                "minimum highlight distance",
+                                                0.f, G_MAXFLOAT, 1.f, G_PARAM_READWRITE);
+  /**
+   * VisuUiCurveFrame::maximum-highlight:
+   *
+   * Store the maximum distance for the highlight region.
+   *
+   * Since: 3.8
+   */
+  _properties[MAX_HL_PROP] = g_param_spec_float("maximum-highlight", "Maximum highlight",
+                                                "maximum highlight distance",
+                                                0.f, G_MAXFLOAT, 1.f, G_PARAM_READWRITE);
+  /**
+   * VisuUiCurveFrame::integral-in-range:
+   *
+   * Store the integral value in the highlight range.
+   *
+   * Since: 3.8
+   */
+  _properties[INT_HL_PROP] = g_param_spec_float("integral-in-range", "Integral in range",
+                                                "integral value in highlight range",
+                                                0.f, G_MAXFLOAT, 0.f, G_PARAM_READABLE);
+  /**
+   * VisuUiCurveFrame::mean-in-range:
+   *
+   * Store the mean value in the highlight range.
+   *
+   * Since: 3.8
+   */
+  _properties[MEAN_HL_PROP] = g_param_spec_float("mean-in-range", "Mean in range",
+                                                 "mean value in highlight range",
+                                                 0.f, G_MAXFLOAT, 0.f, G_PARAM_READABLE);
+  /**
+   * VisuUiCurveFrame::filter:
+   *
+   * Store the filter.
+   *
+   * Since: 3.8
+   */
+  _properties[FILTER_PROP] = g_param_spec_object("filter", "Filter",
+                                                 "filter by element",
+                                                 VISU_TYPE_ELEMENT, G_PARAM_READWRITE);
+  /**
+   * VisuUiCurveFrame::label:
+   *
+   * Store the label used by the filter.
+   *
+   * Since: 3.8
+   */
+  _properties[LABEL_PROP] = g_param_spec_string("label", "Label",
+                                                "label describing the filter",
+                                                "", G_PARAM_READABLE);
+
+  g_object_class_install_properties(G_OBJECT_CLASS(klass), N_PROP, _properties);
 }
 
 static void visu_ui_curve_frame_init(VisuUiCurveFrame *curve)
 {
   curve->dispose_has_run = FALSE;
 
+  curve->model = (VisuPairSet*)0;
+  curve->dirty = TRUE;
+
   curve->style = CURVE_LINEAR;
   curve->scale = TOOL_MATRIX_SCALING_LOG;
 
   curve->heights[0] = 0.;
   curve->heights[1] = 5.;
 
+  curve->dists[0] = 0.f;
+  curve->dists[1] = G_MAXFLOAT;
+
   curve->hlRange[0] = -1.f;
 
-  curve->filter = (gchar*)0;
+  curve->zoom = 5.f;
+
+  curve->filter = (VisuElement*)0;
   curve->data = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
 }
+static void visu_ui_curve_frame_get_property(GObject* obj, guint property_id,
+                                             GValue *value, GParamSpec *pspec)
+{
+  VisuUiCurveFrame *self = VISU_UI_CURVE_FRAME(obj);
+  guint *data, i, n;
+  gfloat d, val;
 
+  switch (property_id)
+    {
+    case MIN_PROP:
+      g_value_set_float(value, self->dists[0]);
+      break;
+    case MAX_PROP:
+      g_value_set_float(value, self->dists[1]);
+      break;
+    case ZOOM_PROP:
+      g_value_set_float(value, self->zoom);
+      break;
+    case MIN_HL_PROP:
+      g_value_set_float(value, self->hlRange[0]);
+      break;
+    case MAX_HL_PROP:
+      g_value_set_float(value, self->hlRange[1]);
+      break;
+    case INT_HL_PROP:
+      if (self->filter)
+        data = (guint*)g_hash_table_lookup(self->data, visu_element_getName(self->filter));
+      else
+        data = (guint*)g_hash_table_lookup(self->data, ALL);
+      if (data)
+        {
+          val = 0.f;
+          for (i = 0, d = self->init; i < self->nSteps - 1; i++, d += self->step)
+            if (d >= self->hlRange[0] && d < self->hlRange[1])
+              val += (float)data[i];
+
+          g_value_set_float(value, val / (float)data[self->nSteps - 1]);
+        }
+      else
+        g_value_set_float(value, 0.f);
+      break;
+    case MEAN_HL_PROP:
+      if (self->filter)
+        data = (guint*)g_hash_table_lookup(self->data, visu_element_getName(self->filter));
+      else
+        data = (guint*)g_hash_table_lookup(self->data, ALL);
+      if (data)
+        {
+          val = 0.f;
+          n = 0;
+          for (i = 0, d = self->init; i < self->nSteps - 1; i++, d += self->step)
+            if (d >= self->hlRange[0] && d < self->hlRange[1])
+              {
+                val += (float)data[i] * (d + self->step * 0.5f);
+                n += data[i];
+              }
+
+          g_value_set_float(value, val / (float)n);
+        }
+      else
+        g_value_set_float(value, 0.f);
+      break;
+    case FILTER_PROP:
+      g_value_set_object(value, self->filter);
+      break;
+    case LABEL_PROP:
+      g_value_set_string(value, self->filter ? visu_element_getName(self->filter) : ALL);
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
+static void visu_ui_curve_frame_set_property(GObject* obj, guint property_id,
+                                             const GValue *value, GParamSpec *pspec)
+{
+  VisuUiCurveFrame *self = VISU_UI_CURVE_FRAME(obj);
+  float rg[2];
+
+  switch (property_id)
+    {
+    case MIN_PROP:
+      rg[0] = g_value_get_float(value);
+      rg[1] = self->dists[1];
+      visu_ui_curve_frame_setSpan(self, rg);
+      break;
+    case MAX_PROP:
+      rg[0] = self->dists[0];
+      rg[1] = g_value_get_float(value);
+      visu_ui_curve_frame_setSpan(self, rg);
+      break;
+    case ZOOM_PROP:
+      visu_ui_curve_frame_setZoomFactor(self, g_value_get_float(value));
+      break;
+    case MIN_HL_PROP:
+      rg[0] = g_value_get_float(value);
+      rg[1] = self->hlRange[1];
+      visu_ui_curve_frame_setHighlightRange(self, rg);
+      break;
+    case MAX_HL_PROP:
+      rg[0] = self->hlRange[0];
+      rg[1] = g_value_get_float(value);
+      visu_ui_curve_frame_setHighlightRange(self, rg);
+      break;
+    case FILTER_PROP:
+      visu_ui_curve_frame_setFilter(self, VISU_ELEMENT(g_value_get_object(value)));
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
 static void visu_ui_curve_frame_dispose(GObject *obj)
 {
   DBG_fprintf(stderr, "Gtk Curve: dispose object %p.\n", (gpointer)obj);
@@ -164,6 +399,10 @@ static void visu_ui_curve_frame_dispose(GObject *obj)
     return;
 
   VISU_UI_CURVE_FRAME(obj)->dispose_has_run = TRUE;
+
+  visu_ui_curve_frame_setModel(VISU_UI_CURVE_FRAME(obj), (VisuPairSet*)0);
+  visu_ui_curve_frame_setFilter(VISU_UI_CURVE_FRAME(obj), (VisuElement*)0);
+
   /* Chain up to the parent class */
   G_OBJECT_CLASS(visu_ui_curve_frame_parent_class)->dispose(obj);
 }
@@ -180,21 +419,6 @@ static void visu_ui_curve_frame_finalize(GObject *obj)
 
   DBG_fprintf(stderr, " | freeing ... OK.\n");
 }
-static void redraw(GtkWidget *widget)
-{
-  cairo_region_t *region;
-  GdkWindow *window;
-
-  if (!gtk_widget_get_mapped(widget)) return;
-
-  window = gtk_widget_get_window(widget);
-  region = gdk_window_get_clip_region(GDK_WINDOW(window));
-  /* redraw the cairo canvas completely by exposing it */
-  gdk_window_invalidate_region(window, region, TRUE);
-  gdk_window_process_updates(window, TRUE);
-
-  cairo_region_destroy (region);
-}
 
 static double tickDist(float dists[2], int length, ToolMatrixScalingFlag scale)
 {
@@ -224,27 +448,26 @@ static double tickDist(float dists[2], int length, ToolMatrixScalingFlag scale)
   return (double)s;
 }
 
-static gboolean isValidData(const gchar* filter, const gchar *data)
+static gboolean isValidData(VisuElement* filter, const gchar *data)
 {
   gchar *tmp;
   gboolean res;
   
   if (filter)
     {
-      tmp = g_strdup_printf("%s"SPACER, filter);
-      res = (!strcmp(data, filter) ||
-	     strstr(data, tmp));
+      tmp = g_strdup_printf("%s"SPACER, visu_element_getName(filter));
+      res = (!strcmp(data, visu_element_getName(filter)) || strstr(data, tmp));
       g_free(tmp);
     }
   else
-    res = (!strcmp(data, _("All")) ||
-	   !strstr(data, SPACER));
+    res = (!strcmp(data, ALL) || !strstr(data, SPACER));
   return res;
 }
 
-static void setCairoColor(cairo_t *cr, const gchar *filter, const gchar *data)
+static void setCairoColor(cairo_t *cr, const VisuElement *filter, const gchar *data)
 {
   VisuElement *ele;
+  const ToolColor *color;
   gchar *tmp;
   const gchar *name;
 
@@ -252,18 +475,61 @@ static void setCairoColor(cairo_t *cr, const gchar *filter, const gchar *data)
     name = data;
   else
     {
-      tmp = g_strdup_printf("%s"SPACER, filter);
+      tmp = g_strdup_printf("%s"SPACER, visu_element_getName(filter));
       name = data + strlen(tmp);
       g_free(tmp);
     }
 
   ele = visu_element_lookup(name);
   if (ele)
-    cairo_set_source_rgb (cr, ele->rgb[0], ele->rgb[1], ele->rgb[2]);
+    {
+      color = visu_element_renderer_getColor(visu_element_renderer_getFromPool(ele));
+      cairo_set_source_rgb (cr, color->rgba[0], color->rgba[1], color->rgba[2]);
+    }
   else
     cairo_set_source_rgb (cr, 0.5, 0.5, 0.5);
 }
 
+static void _compute(VisuUiCurveFrame *curve)
+{
+  VisuPair *pair;
+  VisuData *dataObj;
+  VisuPairDistribution *dd;
+  guint i, *storage;
+
+  curve->dirty = FALSE;
+
+  g_hash_table_remove_all(curve->data);
+  if (!curve->model)
+    return;
+
+  g_object_get(curve->model, "data", &dataObj, NULL);
+  if (!dataObj)
+    return;
+
+  curve->nSteps = 0;
+  curve->init = -1.f;
+  curve->step = (curve->dists[1] - curve->dists[0]) / curve->zoom / 50.f;
+  i = 0;
+  while ((pair = visu_pair_set_getNthPair(curve->model, i++)))
+    {
+      dd = visu_pair_getDistanceDistribution(pair, dataObj, curve->step,
+                                             curve->dists[0], curve->dists[1]);
+      if (i == 1)
+        {
+          curve->init = dd->initValue;
+          curve->nSteps = dd->nValues;
+          storage = g_malloc0(sizeof(guint) * curve->nSteps);
+          g_hash_table_insert(curve->data, g_strdup(ALL), storage);
+        }
+      _addData(curve, dd->ele1->name, dd->ele2->name,
+               dd->histo, dd->nValues, dd->initValue, dd->stepValue);
+      if (dd->ele1 == dd->ele2)
+        _setNNodes(curve, dd->ele1->name, dd->nNodesEle1);
+    };
+  g_object_unref(dataObj);
+}
+
 struct _drawData
 {
   VisuUiCurveFrame *curve;
@@ -288,6 +554,10 @@ static gboolean visu_ui_curve_frame_drawCairo(GtkWidget *wd, cairo_t *cr)
   DBG_fprintf(stderr, "Gtk Curve: general redraw.\n");
 
   curve = VISU_UI_CURVE_FRAME(wd);
+
+  if (curve->dirty)
+    _compute(curve);
+
   dists = curve->dists;
   heights = curve->heights;
   gtk_widget_get_allocation(wd, &allocation);
@@ -301,7 +571,7 @@ static gboolean visu_ui_curve_frame_drawCairo(GtkWidget *wd, cairo_t *cr)
   dh = ext.height + BUF * 2.;
   w = (double)allocation.width - dw;
   h = (double)allocation.height - dh;
-  data = (guint*)g_hash_table_lookup(curve->data, (curve->filter)?curve->filter:ALL);
+  data = (guint*)g_hash_table_lookup(curve->data, (curve->filter)?visu_element_getName(curve->filter):ALL);
 
   /* the frame itself. */
   cairo_set_line_width(cr, 1.);
@@ -332,10 +602,10 @@ static gboolean visu_ui_curve_frame_drawCairo(GtkWidget *wd, cairo_t *cr)
   dt.dw    = dw;
   dt.h     = h;
   if (data && curve->style != CURVE_BAR)
-    drawData(curve, cr, (curve->filter)?curve->filter:ALL, data, w, h, dw, CURVE_BAR);
+    drawData(curve, cr, (curve->filter)?visu_element_getName(curve->filter):ALL, data, w, h, dw, CURVE_BAR);
   g_hash_table_foreach(curve->data, hashDraw, &dt);
   if (data && curve->style == CURVE_BAR)
-    drawData(curve, cr, (curve->filter)?curve->filter:ALL, data, w, h, dw, CURVE_LINEAR);
+    drawData(curve, cr, (curve->filter)?visu_element_getName(curve->filter):ALL, data, w, h, dw, CURVE_LINEAR);
   DBG_fprintf(stderr, "Gtk Curve: plots done.\n");
 
   /* the ticks & the labels */
@@ -467,7 +737,7 @@ static void hashDraw(gpointer key, gpointer value, gpointer user_data)
     }
   else
     {
-      tmp = g_strdup_printf("%s"SPACER, dt->curve->filter);
+      tmp = g_strdup_printf("%s"SPACER, visu_element_getName(dt->curve->filter));
       ret = (!strstr((gchar*)key, tmp));
       g_free(tmp);
       if (ret) return;
@@ -594,18 +864,10 @@ static gboolean visu_ui_curve_frame_expose(GtkWidget *curve, GdkEventExpose *eve
  */
 GtkWidget *visu_ui_curve_frame_new(float distMin, float distMax)
 {
-  GtkWidget *obj;
-
   g_return_val_if_fail(distMin >= 0.f && distMax > distMin, (GtkWidget*)0);
 
-  obj = g_object_new(VISU_UI_TYPE_CURVE_FRAME, NULL);
-  g_return_val_if_fail(obj, (GtkWidget*)0);
-
-  visu_ui_curve_frame_init(VISU_UI_CURVE_FRAME(obj));
-  VISU_UI_CURVE_FRAME(obj)->dists[0] = distMin;
-  VISU_UI_CURVE_FRAME(obj)->dists[1] = distMax;
-
-  return obj;
+  return g_object_new(VISU_TYPE_UI_CURVE_FRAME,
+                      "minimum", distMin, "maximum", distMax, NULL);
 }
 /**
  * visu_ui_curve_frame_setSpan:
@@ -620,18 +882,40 @@ GtkWidget *visu_ui_curve_frame_new(float distMin, float distMax)
  */
 gboolean visu_ui_curve_frame_setSpan(VisuUiCurveFrame *curve, float span[2])
 {
-  gboolean update;
+  gboolean updateMin, updateMax;
 
-  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_CURVE_FRAME(curve), FALSE);
   g_return_val_if_fail(span[0] >= 0.f && span[1] > span[0], FALSE);
 
-  update = (curve->dists[0] != span[0] ||
-	    curve->dists[1] != span[1]);
+  updateMin = (curve->dists[0] != span[0]);
+  updateMax = (curve->dists[1] != span[1]);
 
   curve->dists[0] = span[0];
   curve->dists[1] = span[1];
 
-  return update;
+  if (updateMin)
+    g_object_notify_by_pspec(G_OBJECT(curve), _properties[MIN_PROP]);
+  if (updateMax)
+    g_object_notify_by_pspec(G_OBJECT(curve), _properties[MAX_PROP]);
+
+  if (curve->hlRange[0] < curve->dists[0])
+    {
+      curve->hlRange[0] = curve->dists[0];
+      g_object_notify_by_pspec(G_OBJECT(curve), _properties[MIN_HL_PROP]);
+    }
+  if (curve->hlRange[1] > curve->dists[1])
+    {
+      curve->hlRange[1] = curve->dists[1];
+      g_object_notify_by_pspec(G_OBJECT(curve), _properties[MAX_HL_PROP]);
+    }
+  
+  if (updateMin || updateMax)
+    {
+      curve->dirty = TRUE;
+      gtk_widget_queue_draw(GTK_WIDGET(curve));
+    }
+
+  return updateMin || updateMax;
 }
 /**
  * visu_ui_curve_frame_getSpan:
@@ -644,59 +928,73 @@ gboolean visu_ui_curve_frame_setSpan(VisuUiCurveFrame *curve, float span[2])
  */
 void visu_ui_curve_frame_getSpan(VisuUiCurveFrame *curve, float span[2])
 {
-  g_return_if_fail(VISU_UI_IS_CURVE_FRAME(curve));
+  g_return_if_fail(VISU_IS_UI_CURVE_FRAME(curve));
 
   span[0] = curve->dists[0];
   span[1] = curve->dists[1];
 }
 /**
- * visu_ui_curve_frame_hasData:
+ * visu_ui_curve_frame_setZoomFactor:
  * @curve: a #VisuUiCurveFrame widget.
+ * @zoom: the zoom factor.
  *
- * Retrieve if some distance data have been added to the @curve.
+ * Adjusts the zoom factor.
  *
- * Since: 3.6
+ * Since: 3.8
  *
- * Returns: TRUE if the @curve has some data associated.
+ * Returns: TRUE if value is actually changed.
  */
-gboolean visu_ui_curve_frame_hasData(VisuUiCurveFrame *curve)
+gboolean visu_ui_curve_frame_setZoomFactor(VisuUiCurveFrame *curve, float zoom)
 {
-  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_CURVE_FRAME(curve) && zoom >= 0.f, FALSE);
 
-  return (g_hash_table_size(curve->data) > 0 && curve->step > 0.f);
+  if (zoom == curve->zoom)
+    return FALSE;
+
+  curve->zoom = zoom;
+  g_object_notify_by_pspec(G_OBJECT(curve), _properties[ZOOM_PROP]);
+  curve->dirty = TRUE;
+  gtk_widget_queue_draw(GTK_WIDGET(curve));
+
+  return TRUE;
+}
+static void onPairsNotify(VisuPairSet *set _U_, GParamSpec *pspec _U_, gpointer data)
+{
+  VISU_UI_CURVE_FRAME(data)->dirty = TRUE;
+  gtk_widget_queue_draw(GTK_WIDGET(data));
 }
 /**
- * visu_ui_curve_frame_setData:
- * @curve: a #VisuUiCurveFrame widget.
- * @step: the stepping distance.
- * @min: the minimum distance for the distribution.
- * @max: the maximum distance for the distribution.
+ * visu_ui_curve_frame_setModel:
+ * @curve: a #VisuUiCurveFrame object.
+ * @model: a #VisuPairSet object.
  *
- * Compute and allocate the required size to store distributions, see
- * visu_ui_curve_frame_addData() to actually setup the distribution values.
+ * Bind the #VisuPairLink of @model to @curve.
  *
- * Since: 3.6
- */
-void visu_ui_curve_frame_setData(VisuUiCurveFrame *curve, float step, float min, float max)
+ * Since: 3.8
+ *
+ * Returns: TRUE if the value actually changed.
+ **/
+gboolean visu_ui_curve_frame_setModel(VisuUiCurveFrame *curve, VisuPairSet *model)
 {
-  guint *storage;
+  g_return_val_if_fail(VISU_IS_UI_CURVE_FRAME(curve), FALSE);
 
-  g_return_if_fail(VISU_UI_IS_CURVE_FRAME(curve));
-  g_return_if_fail(min >= 0.f && step >= 0.f && max > min);
+  if (curve->model == model)
+    return FALSE;
 
-  g_hash_table_remove_all(curve->data);
-
-  curve->heights[1] = 5.;
-  curve->init = min;
-  curve->step = step;
-  if (step > 0.f)
+  if (curve->model)
     {
-      curve->nSteps = (int)((max - min) / step) + 1;
-      storage = g_malloc0(sizeof(guint) * curve->nSteps);
-      g_hash_table_insert(curve->data, g_strdup(ALL), storage);
+      g_signal_handler_disconnect(curve->model, curve->pair_sig);
+      g_object_unref(curve->model);
     }
-  else
-    redraw(GTK_WIDGET(curve));
+  if (model)
+    {
+      g_object_ref(model);
+      curve->pair_sig = g_signal_connect(model, "notify::pairs",
+                                         G_CALLBACK(onPairsNotify), curve);
+    }
+  curve->model = model;
+
+  return TRUE;
 }
 /**
  * visu_ui_curve_frame_addData:
@@ -714,14 +1012,14 @@ void visu_ui_curve_frame_setData(VisuUiCurveFrame *curve, float step, float min,
  * 
  * Since: 3.6
  */
-void visu_ui_curve_frame_addData(VisuUiCurveFrame *curve, const gchar *eleName, const gchar *lkName,
-			const guint *data, guint nSteps, float init, float step)
+static void _addData(VisuUiCurveFrame *curve, const gchar *eleName, const gchar *lkName,
+                     const guint *data, guint nSteps, float init, float step)
 {
   guint max, i;
   guint *storage, *all, *ele1, *ele2;
   gchar *link1, *link2;
 
-  g_return_if_fail(VISU_UI_IS_CURVE_FRAME(curve));
+  g_return_if_fail(VISU_IS_UI_CURVE_FRAME(curve));
   g_return_if_fail(eleName && eleName[0] && lkName && lkName[0] && data);
   g_return_if_fail(curve->nSteps == nSteps &&
 		   curve->init == init &&
@@ -803,11 +1101,11 @@ void visu_ui_curve_frame_addData(VisuUiCurveFrame *curve, const gchar *eleName,
  *
  * Since: 3.6
  */
-void visu_ui_curve_frame_setNNodes(VisuUiCurveFrame *curve, const gchar *ele, guint n)
+static void _setNNodes(VisuUiCurveFrame *curve, const gchar *ele, guint n)
 {
   guint *data;
 
-  g_return_if_fail(VISU_UI_IS_CURVE_FRAME(curve));
+  g_return_if_fail(VISU_IS_UI_CURVE_FRAME(curve));
 
   data = (guint*)g_hash_table_lookup(curve->data, ele);
   g_return_if_fail(data);
@@ -833,13 +1131,16 @@ void visu_ui_curve_frame_setNNodes(VisuUiCurveFrame *curve, const gchar *ele, gu
  */
 gboolean visu_ui_curve_frame_setStyle(VisuUiCurveFrame *curve, VisuUiCurveFrameStyle style)
 {
-  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_CURVE_FRAME(curve), FALSE);
 
   if (curve->style == style)
     return FALSE;
 
   curve->style = style;
 
+  curve->dirty = TRUE;
+  gtk_widget_queue_draw(GTK_WIDGET(curve));
+
   return TRUE;
 }
 /**
@@ -854,19 +1155,24 @@ gboolean visu_ui_curve_frame_setStyle(VisuUiCurveFrame *curve, VisuUiCurveFrameS
  *
  * Returns: TRUE if filter is actually changed.
  */
-gboolean visu_ui_curve_frame_setFilter(VisuUiCurveFrame *curve, const gchar* filter)
+gboolean visu_ui_curve_frame_setFilter(VisuUiCurveFrame *curve, VisuElement* filter)
 {
-  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_CURVE_FRAME(curve), FALSE);
 
-  if (curve->filter && filter && !strcmp(curve->filter, filter))
+  if (curve->filter == filter)
     return FALSE;
 
   if (curve->filter)
-    g_free(curve->filter);
-  curve->filter = (gchar*)0;
-
+    g_object_unref(curve->filter);
+  curve->filter = filter;
   if (filter)
-    curve->filter = g_strdup(filter);
+    g_object_ref(filter);
+
+  g_object_notify_by_pspec(G_OBJECT(curve), _properties[FILTER_PROP]);
+  g_object_notify_by_pspec(G_OBJECT(curve), _properties[LABEL_PROP]);
+
+  curve->dirty = TRUE;
+  gtk_widget_queue_draw(GTK_WIDGET(curve));
 
   return TRUE;
 }
@@ -884,23 +1190,33 @@ gboolean visu_ui_curve_frame_setFilter(VisuUiCurveFrame *curve, const gchar* fil
  */
 gboolean visu_ui_curve_frame_setHighlightRange(VisuUiCurveFrame *curve, float range[2])
 {
-  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), FALSE);
+  gboolean updateMin, updateMax;
+
+  g_return_val_if_fail(VISU_IS_UI_CURVE_FRAME(curve), FALSE);
 
   DBG_fprintf(stderr, "Gtk Curve: set highlight range to %gx%g.\n",
 	      range[0], range[1]);
-  if (range[0] >= 0.f && range[1] > range[0])
-    {
-      if (curve->hlRange[0] == range[0] && curve->hlRange[1] == range[1])
-	return FALSE;
-      curve->hlRange[0] = range[0];
-      curve->hlRange[1] = range[1];
-    }
-  else
-    {
-      if (curve->hlRange[0] == -1.f)
-	return FALSE;
-      curve->hlRange[0] = -1.f;
-    }
+
+  updateMin = (curve->hlRange[0] != range[0]);
+  updateMax = (curve->hlRange[1] != range[1]);
+
+  if (!updateMin && !updateMax)
+    return FALSE;
+
+  if (range[0] < 0.f || range[1] <= range[0])
+    return FALSE;
+
+  curve->hlRange[0] = range[0];
+  curve->hlRange[1] = range[1];
+  if (updateMin)
+    g_object_notify_by_pspec(G_OBJECT(curve), _properties[MIN_HL_PROP]);
+  if (updateMax)
+    g_object_notify_by_pspec(G_OBJECT(curve), _properties[MAX_HL_PROP]);
+  g_object_notify_by_pspec(G_OBJECT(curve), _properties[INT_HL_PROP]);
+  g_object_notify_by_pspec(G_OBJECT(curve), _properties[MEAN_HL_PROP]);
+
+  curve->dirty = TRUE;
+  gtk_widget_queue_draw(GTK_WIDGET(curve));
 
   return TRUE;
 }
@@ -918,7 +1234,7 @@ gboolean visu_ui_curve_frame_setHighlightRange(VisuUiCurveFrame *curve, float ra
  */
 gboolean visu_ui_curve_frame_getHighlightRange(VisuUiCurveFrame *curve, float range[2])
 {
-  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_CURVE_FRAME(curve), FALSE);
 
   DBG_fprintf(stderr, "Gtk Curve: get highlight range of %gx%g.\n",
 	      curve->hlRange[0], curve->hlRange[1]);
@@ -929,111 +1245,3 @@ gboolean visu_ui_curve_frame_getHighlightRange(VisuUiCurveFrame *curve, float ra
   range[1] = curve->hlRange[1];
   return TRUE;
 }
-/**
- * visu_ui_curve_frame_draw:
- * @curve: a #VisuUiCurveFrame widget.
- *
- * Forces to redraw the widget.
- *
- * Since: 3.6
- */
-void visu_ui_curve_frame_draw(VisuUiCurveFrame *curve)
-{
-  g_return_if_fail(VISU_UI_IS_CURVE_FRAME(curve));
-
-  redraw(GTK_WIDGET(curve));
-}
-/**
- * visu_ui_curve_frame_getIntegralInRange:
- * @curve: a #VisuUiCurveFrame widget.
- * @label: a location to a string.
- *
- * Calculates the integral of the displayed distribution (see
- * visu_ui_curve_frame_setFilter()) in the given range (see
- * visu_ui_curve_frame_setHighlightRange()). If @label is present, it will points on a
- * string labeling the displayed distribution. The string is owned by V_Sim.
- *
- * Since: 3.6
- *
- * Returns: the integral.
- */
-float visu_ui_curve_frame_getIntegralInRange(VisuUiCurveFrame *curve, gchar **label)
-{
-  guint *data;
-  float val, d;
-  guint i;
-  
-  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), 0.f);
-
-  if (label && curve->filter)
-    *label = curve->filter;
-  else if (label)
-    *label = ALL;
-
-  if (curve->filter)
-    data = (guint*)g_hash_table_lookup(curve->data, curve->filter);
-  else
-    data = (guint*)g_hash_table_lookup(curve->data, ALL);
-  if (!data)
-    return 0.f;
-
-  val = 0.f;
-  d = curve->init;
-  for (i = 0; i < curve->nSteps - 1; i++)
-    {
-      if (d >= curve->hlRange[0] && d < curve->hlRange[1])
-	val += (float)data[i];
-      d += curve->step;
-    }
-
-  DBG_fprintf(stderr, "Gtk Curve: get %d pairs for %d elements.\n",
-	      (int)val, data[curve->nSteps - 1]);
-  return val / (float)data[curve->nSteps - 1];
-}
-/**
- * visu_ui_curve_frame_getMeanInRange:
- * @curve: a #VisuUiCurveFrame widget.
- * @label: a location to a string.
- *
- * Calculates the average distance value of the displayed distribution (see
- * visu_ui_curve_frame_setFilter()) in the given range (see
- * visu_ui_curve_frame_setHighlightRange()). If @label is present, it will points on a
- * string labeling the displayed distribution. The string is owned by V_Sim.
- *
- * Since: 3.6
- *
- * Returns: the average distance value.
- */
-float visu_ui_curve_frame_getMeanInRange(VisuUiCurveFrame *curve, gchar **label)
-{
-  guint *data;
-  float val, d;
-  guint i, n;
-  
-  g_return_val_if_fail(VISU_UI_IS_CURVE_FRAME(curve), 0.f);
-
-  if (label && curve->filter)
-    *label = curve->filter;
-  else if (label)
-    *label = ALL;
-
-  if (curve->filter)
-    data = (guint*)g_hash_table_lookup(curve->data, curve->filter);
-  else
-    data = (guint*)g_hash_table_lookup(curve->data, ALL);
-  if (!data)
-    return 0.f;
-
-  val = 0.f;
-  n = 0;
-  for (i = 0, d = curve->init; i < curve->nSteps - 1; i++, d += curve->step)
-    if (d >= curve->hlRange[0] && d < curve->hlRange[1])
-      {
-        val += (float)data[i] * (d + curve->step * 0.5f);
-        n += data[i];
-      }
-
-  DBG_fprintf(stderr, "Gtk Curve: get mean (%f) for %d elements.\n",
-	      val / (float)n, n);
-  return val / (float)n;
-}
