@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -44,8 +44,11 @@
 #include <gtk/gtk.h>
 
 #include <visu_gtk.h>
+#include <gtk_main.h>
 #include "gtk_dumpDialogWidget.h"
 #include <support.h>
+#include <dumpModules/fileDump.h>
+#include <dumpModules/glDump.h>
 
 /**
  * SECTION:gtk_dumpDialogWidget
@@ -203,7 +206,7 @@ GtkWidget* visu_ui_dump_dialog_new(VisuData *dataObj, GtkWindow *parent,
 {
   VisuUiDumpDialog *dumpDialog;
   VisuUiDumpDialogClass *klass;
-  gchar *directory;
+  const gchar *directory;
   const gchar *filename, *labelType;
   GList *format;
   GtkWidget *hbox2, *hbox;
@@ -216,7 +219,7 @@ GtkWidget* visu_ui_dump_dialog_new(VisuData *dataObj, GtkWindow *parent,
 
   DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: creating a new VisuUiDumpDialog object.\n");
 
-  dumpDialog = VISU_UI_DUMP_DIALOG(g_object_new(VISU_UI_TYPE_DUMP_DIALOG, NULL));
+  dumpDialog = VISU_UI_DUMP_DIALOG(g_object_new(VISU_TYPE_UI_DUMP_DIALOG, NULL));
   gtk_window_set_title(GTK_WINDOW(dumpDialog),
 		       _("Export to a file (image, atomic structures...)"));
   klass = VISU_UI_DUMP_DIALOG_CLASS(G_OBJECT_GET_CLASS(dumpDialog));
@@ -228,8 +231,8 @@ GtkWidget* visu_ui_dump_dialog_new(VisuData *dataObj, GtkWindow *parent,
   gtk_window_set_position(GTK_WINDOW(dumpDialog), GTK_WIN_POS_CENTER_ON_PARENT);
 
   dumpDialog->cancelButton = gtk_dialog_add_button(GTK_DIALOG(dumpDialog),
-					       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-  gtk_dialog_add_button(GTK_DIALOG(dumpDialog), GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT);
+                                                   TOOL_ICON_CANCEL, GTK_RESPONSE_CANCEL);
+  gtk_dialog_add_button(GTK_DIALOG(dumpDialog), TOOL_ICON_SAVE, GTK_RESPONSE_ACCEPT);
   gtk_dialog_set_default_response(GTK_DIALOG(dumpDialog), GTK_RESPONSE_ACCEPT);
 
   /* Create the file chooser part. */
@@ -268,7 +271,7 @@ GtkWidget* visu_ui_dump_dialog_new(VisuData *dataObj, GtkWindow *parent,
 		     hbox, FALSE, FALSE, 0);
   /* Label to introduce the combobox which allow to choose the format */
   label = gtk_label_new(_("Choose the file format : "));
-  gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
+  gtk_label_set_xalign(GTK_LABEL(label), 0.);
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
   dumpDialog->comboType = gtk_combo_box_text_new();
   /* Set the combo entry that let V_Sim detect the desired format through the extension. */
@@ -296,7 +299,7 @@ GtkWidget* visu_ui_dump_dialog_new(VisuData *dataObj, GtkWindow *parent,
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
   label = gtk_label_new(_("Width: "));
-  gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
+  gtk_label_set_xalign(GTK_LABEL(label), 0.);
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
   dumpDialog->spinWidth = gtk_spin_button_new_with_range(1., 2000., 1.);
   if (klass->width > 0)
@@ -311,7 +314,7 @@ GtkWidget* visu_ui_dump_dialog_new(VisuData *dataObj, GtkWindow *parent,
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
   label = gtk_label_new(_("Height: "));
-  gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
+  gtk_label_set_xalign(GTK_LABEL(label), 0.);
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
   dumpDialog->spinHeight = gtk_spin_button_new_with_range(1., 2000., 1.);
   if (klass->height > 0)
@@ -335,7 +338,7 @@ GtkWidget* visu_ui_dump_dialog_new(VisuData *dataObj, GtkWindow *parent,
 		     hbox2, FALSE, FALSE, 2);
   /* Label to introduce the progress bar */
   label = gtk_label_new(_("Dump progress : "));
-  gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
+  gtk_label_set_xalign(GTK_LABEL(label), 0.);
   gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
   dumpDialog->progressBar = gtk_progress_bar_new();
   gtk_box_pack_start(GTK_BOX(hbox2), dumpDialog->progressBar, TRUE, TRUE, 2);
@@ -358,14 +361,14 @@ GtkWidget* visu_ui_dump_dialog_new(VisuData *dataObj, GtkWindow *parent,
 
   /* Setting default values. */
   gtk_widget_set_name(GTK_WIDGET(dumpDialog), "filesel");
-  directory = visu_ui_getLastOpenDirectory();
+  directory = visu_ui_main_getLastOpenDirectory(visu_ui_main_class_getCurrentPanel());
   if (klass->current_dir)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dumpDialog->fileChooser),
 					klass->current_dir);
   else if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dumpDialog->fileChooser),
 					directory);
-  for (format = visu_dump_getAllModules(); format; format = g_list_next(format))
+  for (format = visu_dump_pool_getAllModules(); format; format = g_list_next(format))
     {
       labelType = tool_file_format_getLabel(TOOL_FILE_FORMAT(format->data));
       if (labelType)
@@ -407,14 +410,14 @@ static void onComboToolFileFormatChange(GtkComboBox *combo, gpointer data)
   ToolFileFormatIter iter;
   GtkWidget *wd, *label, *hbox, *vbox;
 
-  g_return_if_fail(VISU_UI_IS_DUMP_DIALOG(data));
+  g_return_if_fail(VISU_IS_UI_DUMP_DIALOG(data));
 
   /* Empty the expander for properties. */
   wd = gtk_bin_get_child(GTK_BIN(VISU_UI_DUMP_DIALOG(data)->expanderToolFileFormat));
   if (wd)
     gtk_widget_destroy(wd);
 
-  dumpTypes = visu_dump_getAllModules();
+  dumpTypes = visu_dump_pool_getAllModules();
   formatInt = gtk_combo_box_get_active(combo);
   VISU_UI_DUMP_DIALOG_GET_CLASS(data)->formatId = (guint)formatInt;
   DBG_fprintf(stderr, "Gtk VisuUiDumpDialog: On file format change (%d).\n", formatInt);
@@ -448,8 +451,8 @@ static void onComboToolFileFormatChange(GtkComboBox *combo, gpointer data)
       hbox = gtk_hbox_new(FALSE, 0);
       gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
       label = gtk_label_new(iter.label);
-      gtk_misc_set_alignment(GTK_MISC(label), 1., 0.5);
-      gtk_misc_set_padding(GTK_MISC(label), 10, 0);
+      gtk_label_set_xalign(GTK_LABEL(label), 1.);
+      gtk_widget_set_margin_start(label, 10);
       gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
       switch (G_VALUE_TYPE(iter.val))
 	{
@@ -485,7 +488,7 @@ static void onVisuUiDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *dat
   VisuUiDumpDialog *dumpDialog;
   VisuUiDumpDialogClass *klass;
 
-  g_return_if_fail(VISU_UI_IS_DUMP_DIALOG(data));
+  g_return_if_fail(VISU_IS_UI_DUMP_DIALOG(data));
 
   dumpDialog = VISU_UI_DUMP_DIALOG(data);
 
@@ -511,7 +514,7 @@ static void onVisuUiDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *dat
 
   if (formatInt >= 0)
     {
-      dumpTypes = visu_dump_getAllModules();
+      dumpTypes = visu_dump_pool_getAllModules();
       if (formatInt == 0)
 	/* The automatic format has been selected, we look in the pattern list to
 	   find a matching pattern. */
@@ -534,8 +537,8 @@ static void onVisuUiDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *dat
 
       /* Special warning for non bitmap exportation with translations. */
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 17
-      if (!visu_dump_getBitmapStatus(VISU_DUMP(dumpTypes->data)) &&
-          visu_data_getTranslationStatus(dumpDialog->dataObj) &&
+      if (VISU_IS_DUMP_DATA(dumpTypes->data) &&
+          visu_pointset_getTranslationPeriodicStatus(VISU_POINTSET(dumpDialog->dataObj)) &&
           !gtk_widget_get_visible(dumpDialog->infoBar))
         {
           gtk_widget_show(dumpDialog->infoBar);
