@@ -45,9 +45,7 @@
 
 #include "gtk_elementComboBox.h"
 #include <visu_tools.h>
-#include <visu_object.h>
 #include <visu_elements.h>
-#include <visu_data.h>
 
 /**
  * SECTION:gtk_elementComboBox
@@ -68,20 +66,28 @@ enum {
    that contains the informations of stroed shades. */
 enum
   {
-    /* This is a pointer to a label that describes the element. */
-    COLUMN_ELEMENT_LABEL,
     /* This a pointer to the VisuElement */
     COLUMN_ELEMENT_POINTER_TO,
-    /* This column control the visibility of the VisuElement. */
-    COLUMN_ELEMENT_VISIBLE,
-
     N_COLUMN_ELEMENT
   };
 
+enum
+  {
+    PROP_0,
+    NODES_PROP,
+    ELEMENT_PROP,
+    N_PROP
+  };
+static GParamSpec *_properties[N_PROP];
+
 static void visu_ui_element_combobox_dispose (GObject *obj);
 static void visu_ui_element_combobox_finalize(GObject *obj);
+static void visu_ui_element_combobox_get_property(GObject* obj, guint property_id,
+                                                  GValue *value, GParamSpec *pspec);
+static void visu_ui_element_combobox_set_property(GObject* obj, guint property_id,
+                                                  const GValue *value, GParamSpec *pspec);
 
-static guint visu_ui_element_combobox_signals[LAST_SIGNAL] = { 0 };
+static guint _signals[LAST_SIGNAL] = { 0 };
 
 /**
  * VisuUiElementCombobox:
@@ -92,9 +98,13 @@ static guint visu_ui_element_combobox_signals[LAST_SIGNAL] = { 0 };
  */
 struct _VisuUiElementCombobox
 {
-  GtkComboBox comboElement;
+  GtkComboBox parent;
+
   GtkTreeModel *filter;
 
+  VisuNodeArray *nodes;
+  gulong popDef_signal;
+
   gulong onChanged;
   gpointer previousSelection;
 
@@ -125,22 +135,13 @@ struct _VisuUiElementComboboxClass
      as TreeModel for the combobox in the widget. */
   GtkListStore *storedElements;
 
-  gulong newElementSignalId, popDef_signal;
-  gboolean disableChangeSignal;
+  gulong newElementSignalId;
 };
-static VisuUiElementComboboxClass *my_class = (VisuUiElementComboboxClass*)0;
 
 /* Local callbacks. */
 static void onChanged(GtkComboBox *widget, gpointer user_data);
 static gboolean onElementNewHook(GSignalInvocationHint *ihint, guint nvalues,
                                  const GValue *param_values, gpointer data);
-static void onDataReady(VisuUiElementComboboxClass *klass, VisuData *data,
-                        VisuGlView *view, gpointer user_data);
-static void onDataNotReady(VisuUiElementComboboxClass *klass, VisuData *data,
-                           VisuGlView *view, gpointer user_data);
-static void onPopulationDefined(VisuNodeArray *array, guint nEle, gpointer data);
-static void onDataReadySelection(VisuUiElementCombobox *combo, VisuData *data,
-                                 VisuGlView *view, gpointer user_data);
 
 /* Local methods. */
 static void addElementToModel(GtkTreeIter *iter, VisuUiElementComboboxClass* klass,
@@ -153,7 +154,7 @@ static gboolean showLabel(GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
  * visu_ui_element_combobox_get_type:
  *
  * Internal routine, retrieves the type of #VisuUiElementCombobox
- * objects. Use VISU_UI_TYPE_ELEMENT_COMBOBOX macro instead.
+ * objects. Use VISU_TYPE_UI_ELEMENT_COMBOBOX macro instead.
  *
  * Since: 3.6
  */
@@ -175,7 +176,7 @@ static void visu_ui_element_combobox_class_init(VisuUiElementComboboxClass *klas
    *
    * Since: 3.6
    */
-  visu_ui_element_combobox_signals[ELEMENT_SELECTED_SIGNAL] =
+  _signals[ELEMENT_SELECTED_SIGNAL] =
     g_signal_new ("element-selected",
 		  G_TYPE_FROM_CLASS (klass),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
@@ -188,9 +189,7 @@ static void visu_ui_element_combobox_class_init(VisuUiElementComboboxClass *klas
   DBG_fprintf(stderr, "                     - initializing the listStore of elements.\n");
   /* Init the listStore of elements. */
   klass->storedElements = gtk_list_store_new(N_COLUMN_ELEMENT,
-                                             G_TYPE_STRING,
-                                             G_TYPE_POINTER,
-                                             G_TYPE_BOOLEAN);
+                                             G_TYPE_POINTER);
   addElementToModel(&iter, klass, (gpointer)0);
   addElementToModel(&iter, klass, GINT_TO_POINTER(1));
   for (elementLst = (GList*)visu_element_getAllElements(); elementLst;
@@ -200,16 +199,35 @@ static void visu_ui_element_combobox_class_init(VisuUiElementComboboxClass *klas
   /* Connect freeing methods. */
   G_OBJECT_CLASS(klass)->dispose  = visu_ui_element_combobox_dispose;
   G_OBJECT_CLASS(klass)->finalize = visu_ui_element_combobox_finalize;
+  G_OBJECT_CLASS(klass)->set_property = visu_ui_element_combobox_set_property;
+  G_OBJECT_CLASS(klass)->get_property = visu_ui_element_combobox_get_property;
 
+  /**
+   * VisuUiElementCombobox::nodes:
+   *
+   * Store the #VisuNodeArray object used to filter the elements.
+   *
+   * Since: 3.8
+   */
+  _properties[NODES_PROP] = g_param_spec_object("nodes", "Nodes",
+                                                "storing nodes used as filter model",
+                                                VISU_TYPE_NODE_ARRAY, G_PARAM_READWRITE);
+  /**
+   * VisuUiElementCombobox::element:
+   *
+   * Store the #VisuElement currently selected.
+   *
+   * Since: 3.8
+   */
+  _properties[ELEMENT_PROP] = g_param_spec_object("element", "Element",
+                                                "currently selected element",
+                                                  VISU_TYPE_ELEMENT, G_PARAM_READWRITE);
+
+  g_object_class_install_properties(G_OBJECT_CLASS(klass), N_PROP, _properties);
+
+  g_type_class_ref(VISU_TYPE_ELEMENT);
   g_signal_add_emission_hook(g_signal_lookup("ElementNew", VISU_TYPE_ELEMENT),
                              0, onElementNewHook, (gpointer)klass, (GDestroyNotify)0);
-  g_signal_connect_swapped(VISU_OBJECT_INSTANCE, "dataRendered",
-                           G_CALLBACK(onDataReady), (gpointer)klass);
-  g_signal_connect_swapped(VISU_OBJECT_INSTANCE, "dataUnRendered",
-                           G_CALLBACK(onDataNotReady), (gpointer)klass);
-
-  my_class = klass;
-  klass->disableChangeSignal = FALSE;
 }
 
 static void visu_ui_element_combobox_dispose(GObject *obj)
@@ -220,6 +238,8 @@ static void visu_ui_element_combobox_dispose(GObject *obj)
     return;
 
   VISU_UI_ELEMENT_COMBOBOX(obj)->dispose_has_run = TRUE;
+  visu_ui_element_combobox_setModel(VISU_UI_ELEMENT_COMBOBOX(obj), (VisuNodeArray*)0);
+
   /* Chain up to the parent class */
   G_OBJECT_CLASS(visu_ui_element_combobox_parent_class)->dispose(obj);
 }
@@ -228,14 +248,67 @@ static void visu_ui_element_combobox_finalize(GObject *obj)
   g_return_if_fail(obj);
 
   DBG_fprintf(stderr, "VisuUi ElementCombobox: finalize object %p.\n", (gpointer)obj);
-  if (VISU_UI_ELEMENT_COMBOBOX(obj)->format)
-    g_free(VISU_UI_ELEMENT_COMBOBOX(obj)->format);
+  g_free(VISU_UI_ELEMENT_COMBOBOX(obj)->format);
 
   /* Chain up to the parent class */
   G_OBJECT_CLASS(visu_ui_element_combobox_parent_class)->finalize(obj);
 
   DBG_fprintf(stderr, " | freeing ... OK.\n");
 }
+static void visu_ui_element_combobox_get_property(GObject* obj, guint property_id,
+                                                  GValue *value, GParamSpec *pspec)
+{
+  VisuUiElementCombobox *self = VISU_UI_ELEMENT_COMBOBOX(obj);
+  GtkTreeIter iter;
+  gpointer data;
+
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: get property '%s' -> ",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case NODES_PROP:
+      g_value_set_object(value, self->nodes);
+      DBG_fprintf(stderr, "%p.\n", g_value_get_object(value));
+      break;
+    case ELEMENT_PROP:
+      if (gtk_combo_box_get_active_iter(GTK_COMBO_BOX(obj), &iter))
+        {
+          gtk_tree_model_get(self->filter, &iter, COLUMN_ELEMENT_POINTER_TO, &data, -1);
+          g_value_set_object(value, (GPOINTER_TO_INT(data) == 1) ? NULL : data);
+        }
+      else
+        g_value_set_object(value, (GObject*)0);
+      DBG_fprintf(stderr, "%p.\n", g_value_get_object(value));
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
+static void visu_ui_element_combobox_set_property(GObject* obj, guint property_id,
+                                         const GValue *value, GParamSpec *pspec)
+{
+  VisuUiElementCombobox *self = VISU_UI_ELEMENT_COMBOBOX(obj);
+
+  DBG_fprintf(stderr, "VisuUi ElementCombobox: set property '%s' -> ",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case NODES_PROP:
+      DBG_fprintf(stderr, "%p\n", g_value_get_object(value));
+      visu_ui_element_combobox_setModel(self, VISU_NODE_ARRAY(g_value_get_object(value)));
+      break;
+    case ELEMENT_PROP:
+      DBG_fprintf(stderr, "%p\n", g_value_get_object(value));
+      visu_ui_element_combobox_setElement(self, VISU_ELEMENT(g_value_get_object(value)));
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
 
 
 static void visu_ui_element_combobox_init(VisuUiElementCombobox *elementComboBox)
@@ -249,10 +322,7 @@ static void visu_ui_element_combobox_init(VisuUiElementCombobox *elementComboBox
   elementComboBox->format            = g_strdup("%s");
   elementComboBox->dispose_has_run   = FALSE;
   elementComboBox->previousSelection = (gpointer)0;
-
-  g_signal_connect_swapped(VISU_OBJECT_INSTANCE, "dataRendered",
-                           G_CALLBACK(onDataReadySelection),
-                           (gpointer)elementComboBox);
+  elementComboBox->nodes             = (VisuNodeArray*)0;
 }
 
 /**
@@ -272,7 +342,7 @@ static void visu_ui_element_combobox_init(VisuUiElementCombobox *elementComboBox
  * Returns: (transfer full): a newly created widget.
  */
 GtkWidget* visu_ui_element_combobox_new(gboolean hasAllSelector, gboolean hasNoneSelector,
-                               const gchar *format)
+                                        const gchar *format)
 {
   VisuUiElementCombobox *wd;
   GObjectClass *klass;
@@ -280,7 +350,7 @@ GtkWidget* visu_ui_element_combobox_new(gboolean hasAllSelector, gboolean hasNon
 
   DBG_fprintf(stderr, "VisuUi ElementCombobox: creating new object with format: '%s'.\n",
 	      format);
-  wd = VISU_UI_ELEMENT_COMBOBOX(g_object_new(visu_ui_element_combobox_get_type (), NULL));
+  wd = VISU_UI_ELEMENT_COMBOBOX(g_object_new(VISU_TYPE_UI_ELEMENT_COMBOBOX, NULL));
   wd->hasAllSelector  = hasAllSelector;
   wd->hasNoneSelector = hasNoneSelector;
   if (format)
@@ -313,6 +383,49 @@ GtkWidget* visu_ui_element_combobox_new(gboolean hasAllSelector, gboolean hasNon
   return GTK_WIDGET(wd);
 }
 
+/**
+ * visu_ui_element_combobox_setModel:
+ * @combo: a #VisuUiElementCombobox object.
+ * @nodes: a #VisuNodeArray object.
+ *
+ * Binds @nodes to @combo, so the list is always displaying the
+ * #VisuElement used by @nodes.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if model is actually changed.
+ **/
+gboolean visu_ui_element_combobox_setModel(VisuUiElementCombobox *combo,
+                                           VisuNodeArray *nodes)
+{
+  g_return_val_if_fail(VISU_IS_UI_ELEMENT_COMBOBOX(combo), FALSE);
+
+  if (combo->nodes == nodes)
+    return FALSE;
+
+  if (combo->nodes)
+    {
+      g_signal_handler_disconnect(combo->nodes, combo->popDef_signal);
+      g_object_unref(combo->nodes);
+    }
+  combo->nodes = nodes;
+  if (nodes)
+    {
+      g_object_ref(nodes);
+      combo->popDef_signal =
+        g_signal_connect_swapped(nodes, "notify::elements",
+                                 G_CALLBACK(gtk_tree_model_filter_refilter),
+                                 combo->filter);
+    }
+  gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(combo->filter));
+  if (gtk_combo_box_get_active(GTK_COMBO_BOX(combo)) < 0)
+    gtk_combo_box_set_active(GTK_COMBO_BOX(combo),
+                             MIN((combo->hasAllSelector)?1:0,
+                                 gtk_tree_model_iter_n_children(combo->filter,
+                                                                (GtkTreeIter*)0) - 1));
+  return TRUE;
+}
+
 static gboolean onElementNewHook(GSignalInvocationHint *ihint _U_, guint nvalues _U_,
                                  const GValue *param_values, gpointer data)
 {
@@ -331,9 +444,6 @@ static void onChanged(GtkComboBox *widget, gpointer user_data _U_)
   gpointer *data;
   GList *lst;
 
-  if (VISU_UI_ELEMENT_COMBOBOX_GET_CLASS(widget)->disableChangeSignal)
-    return;
-
   if (!gtk_combo_box_get_active_iter(widget, &iter))
     return;
 
@@ -348,13 +458,12 @@ static void onChanged(GtkComboBox *widget, gpointer user_data _U_)
       lst = visu_ui_element_combobox_getSelection(VISU_UI_ELEMENT_COMBOBOX(widget));
       DBG_fprintf(stderr, "VisuUi ElementCombobox: emitting 'element-selected'"
                   " signal with list %p.\n", (gpointer)lst);
-      g_signal_emit(G_OBJECT(widget),
-		    visu_ui_element_combobox_signals[ELEMENT_SELECTED_SIGNAL],
-                    0, (gpointer)lst, NULL);
+      g_signal_emit(widget, _signals[ELEMENT_SELECTED_SIGNAL], 0, (gpointer)lst);
       DBG_fprintf(stderr, " | free list\n");
       if (lst)
         g_list_free(lst);
       DBG_fprintf(stderr, " | OK\n");
+      g_object_notify_by_pspec(G_OBJECT(widget), _properties[ELEMENT_PROP]);
     }
   else
     DBG_fprintf(stderr, "VisuUi ElementCombobox: aborting 'element-selected' signal.\n");
@@ -363,16 +472,12 @@ static void onChanged(GtkComboBox *widget, gpointer user_data _U_)
 static void addElementToModel(GtkTreeIter *iter, VisuUiElementComboboxClass* klass,
                               gpointer element)
 {
-  gboolean visible;
-
   g_return_if_fail(iter && klass);
 
   DBG_fprintf(stderr, "VisuUi ElementCombobox: appending a new element '%p'.\n",
 	      element);
-  visible = (element && GPOINTER_TO_INT(element) != 1)?FALSE:TRUE;
   gtk_list_store_append(klass->storedElements, iter);
   gtk_list_store_set(klass->storedElements, iter,
-		     COLUMN_ELEMENT_VISIBLE    , visible,
 		     COLUMN_ELEMENT_POINTER_TO , element,
 		     -1);
 }
@@ -399,21 +504,18 @@ static void printLabel(GtkCellLayout *layout _U_, GtkCellRenderer *cell,
 static gboolean showLabel(GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 {
   gpointer pt;
-  gboolean visible;
+  VisuUiElementCombobox *combo;
 
-  gtk_tree_model_get(model, iter, COLUMN_ELEMENT_POINTER_TO, &pt,
-                     COLUMN_ELEMENT_VISIBLE, &visible, -1);
-  DBG_fprintf(stderr, "VisuUi ElementCombobox: filter entry '%s' %p for model %p -> %d.\n",
-              (GPOINTER_TO_INT(pt) != 0 &&
-               GPOINTER_TO_INT(pt) != 1)?VISU_ELEMENT(pt)->name:"None", (gpointer)pt,
-              (gpointer)model, (!pt && VISU_UI_ELEMENT_COMBOBOX(data)->hasNoneSelector) ||
-              (pt && GPOINTER_TO_INT(pt) == 1 && VISU_UI_ELEMENT_COMBOBOX(data)->hasAllSelector) ||
-              (pt && GPOINTER_TO_INT(pt) != 1 && visible));
-  return (!pt && VISU_UI_ELEMENT_COMBOBOX(data)->hasNoneSelector) ||
-    (pt && GPOINTER_TO_INT(pt) == 1 && VISU_UI_ELEMENT_COMBOBOX(data)->hasAllSelector) ||
+  combo = VISU_UI_ELEMENT_COMBOBOX(data);
+  if (!combo->nodes)
+    return FALSE;
+
+  gtk_tree_model_get(model, iter, COLUMN_ELEMENT_POINTER_TO, &pt, -1);
+  return (!pt && combo->hasNoneSelector) ||
+    (pt && GPOINTER_TO_INT(pt) == 1 && combo->hasAllSelector) ||
     (pt && GPOINTER_TO_INT(pt) != 1 &&
-     visible && (VISU_UI_ELEMENT_COMBOBOX(data)->showUnPhysical ||
-                 visu_element_getPhysical(VISU_ELEMENT(pt))));
+     visu_node_array_containsElement(combo->nodes, VISU_ELEMENT(pt)) &&
+     (combo->showUnPhysical || visu_element_getPhysical(VISU_ELEMENT(pt))));
 }
 
 /**
@@ -433,7 +535,7 @@ gboolean visu_ui_element_combobox_setSelection(VisuUiElementCombobox* wd, const
   gboolean valid;
   gpointer *pt;
 
-  g_return_val_if_fail(VISU_UI_IS_ELEMENT_COMBOBOX(wd) && name, FALSE);
+  g_return_val_if_fail(VISU_IS_UI_ELEMENT_COMBOBOX(wd) && name, FALSE);
 
   DBG_fprintf(stderr, "VisuUi ElementCombobox: select a new element '%s'.\n",
               name);
@@ -442,7 +544,8 @@ gboolean visu_ui_element_combobox_setSelection(VisuUiElementCombobox* wd, const
        valid; valid = gtk_tree_model_iter_next(wd->filter, &iter))
     {
       gtk_tree_model_get(wd->filter, &iter, COLUMN_ELEMENT_POINTER_TO, &pt, -1);
-      if (pt && GPOINTER_TO_INT(pt) != 1 && !strcmp(((VisuElement*)pt)->name, name))
+      if (pt && GPOINTER_TO_INT(pt) != 1 &&
+          !strcmp(visu_element_getName(VISU_ELEMENT(pt)), name))
 	{
 	  gtk_combo_box_set_active_iter(GTK_COMBO_BOX(wd), &iter);
 	  return TRUE;
@@ -450,6 +553,39 @@ gboolean visu_ui_element_combobox_setSelection(VisuUiElementCombobox* wd, const
     }
   return FALSE;
 }
+/**
+ * visu_ui_element_combobox_setElement:
+ * @wd: a #VisuUiElementCombobox widget.
+ * @element: a #VisuElement object.
+ *
+ * Select a #VisuElement.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if the given element exists.
+ */
+gboolean visu_ui_element_combobox_setElement(VisuUiElementCombobox* wd,
+                                             const VisuElement *element)
+{
+  GtkTreeIter iter;
+  gboolean valid;
+  gpointer pt;
+
+  g_return_val_if_fail(VISU_IS_UI_ELEMENT_COMBOBOX(wd), FALSE);
+
+  for (valid = gtk_tree_model_get_iter_first(wd->filter, &iter);
+       valid; valid = gtk_tree_model_iter_next(wd->filter, &iter))
+    {
+      gtk_tree_model_get(wd->filter, &iter, COLUMN_ELEMENT_POINTER_TO, &pt, -1);
+      if (pt == element)
+	{
+	  gtk_combo_box_set_active_iter(GTK_COMBO_BOX(wd), &iter);
+	  return TRUE;
+	}
+    }
+  gtk_combo_box_set_active(GTK_COMBO_BOX(wd), -1);
+  return FALSE;
+}
 /**
  * visu_ui_element_combobox_getSelection:
  * @wd: a #VisuUiElementCombobox widget.
@@ -469,7 +605,7 @@ GList* visu_ui_element_combobox_getSelection(VisuUiElementCombobox *wd)
   GList *lst;
   gboolean valid;
 
-  g_return_val_if_fail(VISU_UI_IS_ELEMENT_COMBOBOX(wd), (GList*)0);
+  g_return_val_if_fail(VISU_IS_UI_ELEMENT_COMBOBOX(wd), (GList*)0);
 
   if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(wd), &iter))
     return (GList*)0;
@@ -497,71 +633,6 @@ GList* visu_ui_element_combobox_getSelection(VisuUiElementCombobox *wd)
   return lst;
 }
 
-static void refreshCombo(VisuUiElementComboboxClass *klass, VisuNodeArray *array)
-{
-  gboolean valid;
-  GtkTreeIter child;
-  GtkTreeModel *model;
-  gpointer pt;
-
-  klass->disableChangeSignal = TRUE;
-
-  model = GTK_TREE_MODEL(klass->storedElements);
-  for (valid = gtk_tree_model_get_iter_first(model, &child); valid;
-       valid = gtk_tree_model_iter_next(model, &child))
-    {
-      gtk_tree_model_get(model, &child, COLUMN_ELEMENT_POINTER_TO, &pt, -1);
-      if (pt && GPOINTER_TO_INT(pt) != 1 && array &&
-          visu_node_array_getElementId(array, VISU_ELEMENT(pt)) >= 0)
-        gtk_list_store_set(klass->storedElements, &child,
-                           COLUMN_ELEMENT_VISIBLE, TRUE, -1);
-      else
-        gtk_list_store_set(klass->storedElements, &child,
-                           COLUMN_ELEMENT_VISIBLE, FALSE, -1);
-    }
-
-  klass->disableChangeSignal = FALSE;
-}
-static void onDataReady(VisuUiElementComboboxClass *klass, VisuData *data,
-                        VisuGlView *view _U_, gpointer user_data _U_)
-{  
-  DBG_fprintf(stderr, "VisuUi ElementCombobox: set visible elements from data %p.\n",
-              (gpointer)data);
-
-  if (data)
-    refreshCombo(klass, VISU_NODE_ARRAY(data));
-  else
-  refreshCombo(klass, (VisuNodeArray*)0);
-  if (data)
-    klass->popDef_signal =
-      g_signal_connect(G_OBJECT(data), "PopulationDefined",
-                       G_CALLBACK(onPopulationDefined), (gpointer)klass);
-}
-static void onDataNotReady(VisuUiElementComboboxClass *klass, VisuData *data,
-                           VisuGlView *view _U_, gpointer user_data _U_)
-{  
-  DBG_fprintf(stderr, "VisuUi ElementCombobox: unset visible elements from data %p.\n",
-              (gpointer)data);
-  g_signal_handler_disconnect(G_OBJECT(data), klass->popDef_signal);
-}
-static void onPopulationDefined(VisuNodeArray *array, guint nEle _U_, gpointer data)
-{
-  DBG_fprintf(stderr, "VisuUi ElementCombobox: refresh list on population defined.\n");
-  refreshCombo(VISU_UI_ELEMENT_COMBOBOX_CLASS(data), array);
-}
-
-static void onDataReadySelection(VisuUiElementCombobox *combo, VisuData *data,
-                                 VisuGlView *view _U_, gpointer user_data _U_)
-{
-  if (!data)
-    return;
-
-  if (gtk_combo_box_get_active(GTK_COMBO_BOX(combo)) < 0)
-    gtk_combo_box_set_active(GTK_COMBO_BOX(combo),
-                             MIN((combo->hasAllSelector)?1:0,
-                                 gtk_tree_model_iter_n_children(combo->filter,
-                                                                (GtkTreeIter*)0) - 1));
-}
 /**
  * visu_ui_element_combobox_setUnphysicalStatus:
  * @wd: a #VisuUiElementCombobox object ;
@@ -575,7 +646,7 @@ static void onDataReadySelection(VisuUiElementCombobox *combo, VisuData *data,
 void visu_ui_element_combobox_setUnphysicalStatus(VisuUiElementCombobox* wd,
                                                   gboolean status)
 {
-  g_return_if_fail(VISU_UI_IS_ELEMENT_COMBOBOX(wd));
+  g_return_if_fail(VISU_IS_UI_ELEMENT_COMBOBOX(wd));
 
   wd->showUnPhysical = status;
 }
