@@ -44,17 +44,18 @@
 #define GTK_ELEMENTCOMBOBOX_H
 
 #include <gtk/gtk.h>
+#include <visu_nodes.h>
 
 G_BEGIN_DECLS
 
 /**
- * VISU_UI_TYPE_ELEMENT_COMBOBOX:
+ * VISU_TYPE_UI_ELEMENT_COMBOBOX:
  *
  * Return the associated #GType to the #VisuUiElementCombobox objects.
  *
  * Since: 3.6
  */
-#define VISU_UI_TYPE_ELEMENT_COMBOBOX         (visu_ui_element_combobox_get_type ())
+#define VISU_TYPE_UI_ELEMENT_COMBOBOX         (visu_ui_element_combobox_get_type ())
 /**
  * VISU_UI_ELEMENT_COMBOBOX:
  * @obj: the widget to cast.
@@ -63,7 +64,7 @@ G_BEGIN_DECLS
  *
  * Since: 3.6
  */
-#define VISU_UI_ELEMENT_COMBOBOX(obj)         (G_TYPE_CHECK_INSTANCE_CAST ((obj), VISU_UI_TYPE_ELEMENT_COMBOBOX, VisuUiElementCombobox))
+#define VISU_UI_ELEMENT_COMBOBOX(obj)         (G_TYPE_CHECK_INSTANCE_CAST ((obj), VISU_TYPE_UI_ELEMENT_COMBOBOX, VisuUiElementCombobox))
 /**
  * VISU_UI_ELEMENT_COMBOBOX_CLASS:
  * @klass: the class to cast.
@@ -72,25 +73,25 @@ G_BEGIN_DECLS
  *
  * Since: 3.6
  */
-#define VISU_UI_ELEMENT_COMBOBOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VISU_UI_TYPE_ELEMENT_COMBOBOX, VisuUiElementComboboxClass))
+#define VISU_UI_ELEMENT_COMBOBOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VISU_TYPE_UI_ELEMENT_COMBOBOX, VisuUiElementComboboxClass))
 /**
- * VISU_UI_IS_ELEMENT_COMBOBOX:
+ * VISU_IS_UI_ELEMENT_COMBOBOX:
  * @obj: the object to test.
  *
  * Return if the given object is a valid #VisuUiElementCombobox object.
  *
  * Since: 3.6
  */
-#define VISU_UI_IS_ELEMENT_COMBOBOX(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VISU_UI_TYPE_ELEMENT_COMBOBOX))
+#define VISU_IS_UI_ELEMENT_COMBOBOX(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VISU_TYPE_UI_ELEMENT_COMBOBOX))
 /**
- * VISU_UI_IS_ELEMENT_COMBOBOX_CLASS:
+ * VISU_IS_UI_ELEMENT_COMBOBOX_CLASS:
  * @klass: the class to test.
  *
  * Return if the given class is a valid #VisuUiElementComboboxClass class.
  *
  * Since: 3.6
  */
-#define VISU_UI_IS_ELEMENT_COMBOBOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VISU_UI_TYPE_ELEMENT_COMBOBOX))
+#define VISU_IS_UI_ELEMENT_COMBOBOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VISU_TYPE_UI_ELEMENT_COMBOBOX))
 /**
  * VISU_UI_ELEMENT_COMBOBOX_GET_CLASS:
  * @obj: the widget to get the class of.
@@ -99,7 +100,7 @@ G_BEGIN_DECLS
  *
  * Since: 3.6
  */
-#define VISU_UI_ELEMENT_COMBOBOX_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_UI_TYPE_ELEMENT_COMBOBOX, VisuUiElementComboboxClass))
+#define VISU_UI_ELEMENT_COMBOBOX_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_TYPE_UI_ELEMENT_COMBOBOX, VisuUiElementComboboxClass))
 
 typedef struct _VisuUiElementCombobox VisuUiElementCombobox;
 typedef struct _VisuUiElementComboboxClass VisuUiElementComboboxClass;
@@ -108,9 +109,12 @@ GType      visu_ui_element_combobox_get_type(void);
 GtkWidget* visu_ui_element_combobox_new(gboolean hasAllSelector,
                                         gboolean hasNoneSelector,
                                         const gchar *format);
+gboolean visu_ui_element_combobox_setModel(VisuUiElementCombobox *combo, VisuNodeArray *nodes);
 GList*     visu_ui_element_combobox_getSelection(VisuUiElementCombobox *wd);
 gboolean   visu_ui_element_combobox_setSelection(VisuUiElementCombobox* wd,
                                                  const gchar *name);
+gboolean visu_ui_element_combobox_setElement(VisuUiElementCombobox* wd,
+                                             const VisuElement *element);
 void       visu_ui_element_combobox_setUnphysicalStatus(VisuUiElementCombobox* wd,
                                                         gboolean status);
 
