@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -60,8 +60,14 @@ enum {
   VALUE_CHANGED_SIGNAL,
   LAST_SIGNAL
 };
-
-static guint visu_ui_numerical_entry_signals[LAST_SIGNAL] = { 0 };
+static guint _signals[LAST_SIGNAL] = { 0 };
+enum
+  {
+    PROP_0,
+    VALUE_PROP,
+    N_PROP
+  };
+static GParamSpec *properties[N_PROP];
 
 #define VISU_UI_NUMERICAL_ENTRY_FORMAT_DEFAULT "%g"
 
@@ -73,32 +79,29 @@ struct _VisuUiNumericalEntry
   double printed_value;
   gchar *format;
 /*   VisuUiNumericalEntryPrivate *private; */
-
-  gboolean dispose_has_run;
 };
 
 struct _VisuUiNumericalEntryClass
 {
   GtkEntryClass parent_class;
 
-  void (*numericalEntry) (VisuUiNumericalEntry *numEntry);
-
-  gulong valueChangedSignalId;
+  void (*changed) (VisuUiNumericalEntry *numEntry, double oldValue);
 };
 
-static void visu_ui_numerical_entry_dispose (GObject *obj);
 static void visu_ui_numerical_entry_finalize(GObject *obj);
+static void visu_ui_numerical_entry_get_property(GObject* obj, guint property_id,
+                                                 GValue *value, GParamSpec *pspec);
+static void visu_ui_numerical_entry_set_property(GObject* obj, guint property_id,
+                                                 const GValue *value, GParamSpec *pspec);
+static gboolean visu_ui_numerical_entry_focus_in(GtkWidget *wd, GdkEventFocus *event);
+static gboolean visu_ui_numerical_entry_focus_out(GtkWidget *wd, GdkEventFocus *event);
+static void visu_ui_numerical_entry_activate(GtkEntry *entry);
 
 G_DEFINE_TYPE(VisuUiNumericalEntry, visu_ui_numerical_entry, GTK_TYPE_ENTRY)
 
 /* Local methods. */
-void printStoredValue(VisuUiNumericalEntry* numericalEntry);
-gboolean parsePrintedValue(VisuUiNumericalEntry *numericalEntry, double *value);
-void onEntryValueChange(VisuUiNumericalEntry *numericalEntry, gpointer data);
-gboolean onEntryLeaveFocus(VisuUiNumericalEntry *numericalEntry,
-			   GdkEventFocus *event, gpointer data);
-gboolean onEntryGetFocus(VisuUiNumericalEntry *numericalEntry,
-			 GdkEventFocus *event, gpointer data);
+static void printStoredValue(VisuUiNumericalEntry* numericalEntry);
+static gboolean parsePrintedValue(VisuUiNumericalEntry *numericalEntry, double *value);
 
 static void visu_ui_numerical_entry_class_init(VisuUiNumericalEntryClass *klass)
 {
@@ -114,32 +117,37 @@ static void visu_ui_numerical_entry_class_init(VisuUiNumericalEntryClass *klass)
    *
    * Since: 3.1
    */
-  visu_ui_numerical_entry_signals[VALUE_CHANGED_SIGNAL] =
+  _signals[VALUE_CHANGED_SIGNAL] =
     g_signal_new ("value-changed",
 		  G_TYPE_FROM_CLASS (klass),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
-		  G_STRUCT_OFFSET (VisuUiNumericalEntryClass, numericalEntry),
+		  G_STRUCT_OFFSET (VisuUiNumericalEntryClass, changed),
 		  NULL, 
 		  NULL,                
 		  g_cclosure_marshal_VOID__DOUBLE,
 		  G_TYPE_NONE, 1, G_TYPE_DOUBLE);
 
   /* Connect freeing methods. */
-  G_OBJECT_CLASS(klass)->dispose = visu_ui_numerical_entry_dispose;
   G_OBJECT_CLASS(klass)->finalize = visu_ui_numerical_entry_finalize;
+  G_OBJECT_CLASS(klass)->set_property = visu_ui_numerical_entry_set_property;
+  G_OBJECT_CLASS(klass)->get_property = visu_ui_numerical_entry_get_property;
+  GTK_WIDGET_CLASS(klass)->focus_in_event  = visu_ui_numerical_entry_focus_in;
+  GTK_WIDGET_CLASS(klass)->focus_out_event = visu_ui_numerical_entry_focus_out;
+  GTK_ENTRY_CLASS(klass)->activate = visu_ui_numerical_entry_activate;
+
+  /**
+   * VisuUiNumericalEntry::value:
+   *
+   * Store the value in the entry.
+   *
+   * Since: 3.8
+   */
+  properties[VALUE_PROP] = g_param_spec_double("value", "Value", "numerical value",
+                                               -G_MAXFLOAT, G_MAXFLOAT, 0.,
+                                               G_PARAM_CONSTRUCT | G_PARAM_READWRITE);
+  g_object_class_install_properties(G_OBJECT_CLASS(klass), N_PROP, properties);
 }
 
-static void visu_ui_numerical_entry_dispose(GObject *obj)
-{
-  DBG_fprintf(stderr, "Gtk VisuUiNumericalEntry: dispose object %p.\n", (gpointer)obj);
-
-  if (VISU_UI_NUMERICAL_ENTRY(obj)->dispose_has_run)
-    return;
-
-  VISU_UI_NUMERICAL_ENTRY(obj)->dispose_has_run = TRUE;
-  /* Chain up to the parent class */
-  G_OBJECT_CLASS(visu_ui_numerical_entry_parent_class)->dispose(obj);
-}
 static void visu_ui_numerical_entry_finalize(GObject *obj)
 {
   VisuUiNumericalEntry *entry;
@@ -156,21 +164,49 @@ static void visu_ui_numerical_entry_finalize(GObject *obj)
 
   DBG_fprintf(stderr, "Gtk VisuUiNumericalEntry: freeing ... OK.\n");
 }
+static void visu_ui_numerical_entry_get_property(GObject* obj, guint property_id,
+                                                 GValue *value, GParamSpec *pspec)
+{
+  VisuUiNumericalEntry *self = VISU_UI_NUMERICAL_ENTRY(obj);
+
+  DBG_fprintf(stderr, "Gtk VisuUiNumericalEntry: get property '%s'.\n",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case VALUE_PROP:
+      g_value_set_double(value, self->value);
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
+static void visu_ui_numerical_entry_set_property(GObject* obj, guint property_id,
+                                                 const GValue *value, GParamSpec *pspec)
+{
+  VisuUiNumericalEntry *self = VISU_UI_NUMERICAL_ENTRY(obj);
+
+  DBG_fprintf(stderr, "Gtk VisuUiNumericalEntry: set property '%s'.\n",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case VALUE_PROP:
+      visu_ui_numerical_entry_setValue(self, g_value_get_double(value));
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
 
 static void visu_ui_numerical_entry_init(VisuUiNumericalEntry *numericalEntry)
 {
   DBG_fprintf(stderr, "Gtk VisuUiNumericalEntry : initializing new object (%p).\n",
 	      (gpointer)numericalEntry);
 
-  numericalEntry->dispose_has_run = FALSE;
   numericalEntry->format = g_strdup(VISU_UI_NUMERICAL_ENTRY_FORMAT_DEFAULT);
-
-  g_signal_connect_swapped(G_OBJECT(numericalEntry), "activate",
-			   G_CALLBACK(onEntryValueChange), (gpointer)numericalEntry);
-  g_signal_connect_swapped(G_OBJECT(numericalEntry), "focus-out-event",
-			   G_CALLBACK(onEntryLeaveFocus), (gpointer)numericalEntry);
-  g_signal_connect_swapped(G_OBJECT(numericalEntry), "focus-in-event",
-			   G_CALLBACK(onEntryGetFocus), (gpointer)numericalEntry);
 }
 
 /**
@@ -188,24 +224,14 @@ static void visu_ui_numerical_entry_init(VisuUiNumericalEntry *numericalEntry)
  */
 GtkWidget* visu_ui_numerical_entry_new(double value)
 {
-  VisuUiNumericalEntry *numericalEntry;
-
-  DBG_fprintf(stderr, "Gtk VisuUiNumericalEntry : creating new object with value : %g.\n",
-	      value);
-
-  numericalEntry = VISU_UI_NUMERICAL_ENTRY(g_object_new(visu_ui_numerical_entry_get_type(), NULL));
-  numericalEntry->value = value;
-  
-  printStoredValue(numericalEntry);
-
-  return GTK_WIDGET(numericalEntry);
+  return g_object_new(VISU_TYPE_UI_NUMERICAL_ENTRY, "value", value, NULL);
 }
 
-void printStoredValue(VisuUiNumericalEntry* numericalEntry)
+static void printStoredValue(VisuUiNumericalEntry* numericalEntry)
 {
   gchar *str;
 
-  g_return_if_fail(VISU_UI_IS_NUMERICAL_ENTRY(numericalEntry));
+  g_return_if_fail(VISU_IS_UI_NUMERICAL_ENTRY(numericalEntry));
 
   str = g_strdup_printf(numericalEntry->format, numericalEntry->value);
   gtk_entry_set_text(GTK_ENTRY(numericalEntry), str);
@@ -214,20 +240,19 @@ void printStoredValue(VisuUiNumericalEntry* numericalEntry)
   if (!parsePrintedValue(numericalEntry, &numericalEntry->printed_value))
     numericalEntry->printed_value = G_MAXFLOAT;
 }
-gboolean parsePrintedValue(VisuUiNumericalEntry *numericalEntry, double *value)
+static gboolean parsePrintedValue(VisuUiNumericalEntry *numericalEntry, double *value)
 {
   double valueDouble;
   gchar *last;
 
-  g_return_val_if_fail(VISU_UI_IS_NUMERICAL_ENTRY(numericalEntry) && value, FALSE);
+  g_return_val_if_fail(VISU_IS_UI_NUMERICAL_ENTRY(numericalEntry) && value, FALSE);
   
   valueDouble = g_ascii_strtod(gtk_entry_get_text(GTK_ENTRY(numericalEntry)),
 			  &last);
   if (*last != '\0')
     {
       /* Wrong number. */
-      g_warning("Can't read a number from '%s'.\n",
-		gtk_entry_get_text(GTK_ENTRY(numericalEntry)));
+      visu_ui_numerical_entry_warnValue(numericalEntry, numericalEntry->value);
       return FALSE;
     }
 
@@ -246,7 +271,7 @@ void visu_ui_numerical_entry_setValue(VisuUiNumericalEntry* numericalEntry, doub
 {
   double valueOld;
 
-  g_return_if_fail(VISU_UI_IS_NUMERICAL_ENTRY(numericalEntry));
+  g_return_if_fail(VISU_IS_UI_NUMERICAL_ENTRY(numericalEntry));
 
   if (value == numericalEntry->value)
     return;
@@ -257,8 +282,9 @@ void visu_ui_numerical_entry_setValue(VisuUiNumericalEntry* numericalEntry, doub
   printStoredValue(numericalEntry);
 
   DBG_fprintf(stderr, "Gtk VisuUiNumericalEntry : emitting 'value-changed' signal.\n");
+  g_object_notify_by_pspec(G_OBJECT(numericalEntry), properties[VALUE_PROP]);
   g_signal_emit(G_OBJECT(numericalEntry),
-		visu_ui_numerical_entry_signals[VALUE_CHANGED_SIGNAL], 0, valueOld, NULL);
+		_signals[VALUE_CHANGED_SIGNAL], 0, valueOld, NULL);
 }
 /**
  * visu_ui_numerical_entry_getValue:
@@ -270,35 +296,52 @@ void visu_ui_numerical_entry_setValue(VisuUiNumericalEntry* numericalEntry, doub
  */
 double visu_ui_numerical_entry_getValue(VisuUiNumericalEntry *numericalEntry)
 {
-  g_return_val_if_fail(VISU_UI_IS_NUMERICAL_ENTRY(numericalEntry), 0.);
+  g_return_val_if_fail(VISU_IS_UI_NUMERICAL_ENTRY(numericalEntry), 0.);
 
   return numericalEntry->value;
 }
 
-void onEntryValueChange(VisuUiNumericalEntry *numericalEntry, gpointer data _U_)
+static void visu_ui_numerical_entry_activate(GtkEntry *entry)
 {
-  gboolean valid;
+  VisuUiNumericalEntry *numericalEntry = VISU_UI_NUMERICAL_ENTRY(entry);
   double valueDouble;
 
-  valid = parsePrintedValue(numericalEntry, &valueDouble);
-
-  if (!valid)
-    printStoredValue(numericalEntry);
-  else
-    {
-      if (valueDouble != numericalEntry->printed_value)
-        visu_ui_numerical_entry_setValue(numericalEntry, valueDouble);
-    }
+  if (parsePrintedValue(numericalEntry, &valueDouble) &&
+      valueDouble != numericalEntry->printed_value)
+    visu_ui_numerical_entry_setValue(numericalEntry, valueDouble);
 }
-gboolean onEntryLeaveFocus(VisuUiNumericalEntry *numericalEntry,
-			   GdkEventFocus *event _U_, gpointer data _U_)
+static gboolean visu_ui_numerical_entry_focus_out(GtkWidget *wd, GdkEventFocus *event)
 {
-  onEntryValueChange(numericalEntry, (gpointer)0);
-  return FALSE;
+  visu_ui_numerical_entry_activate(GTK_ENTRY(wd));
+  return GTK_WIDGET_CLASS(visu_ui_numerical_entry_parent_class)->focus_in_event(wd, event);
 }
-gboolean onEntryGetFocus(VisuUiNumericalEntry *numericalEntry _U_,
-			 GdkEventFocus *event _U_, gpointer data _U_)
+static gboolean visu_ui_numerical_entry_focus_in(GtkWidget *wd, GdkEventFocus *event)
 {
   /* gtk_editable_select_region(GTK_EDITABLE(numericalEntry), 0, -1); */
+  return GTK_WIDGET_CLASS(visu_ui_numerical_entry_parent_class)->focus_out_event(wd, event);
+}
+static gboolean _removeWarning(gpointer data)
+{
+  gtk_entry_set_icon_from_icon_name(GTK_ENTRY(data), GTK_ENTRY_ICON_SECONDARY, NULL);
   return FALSE;
 }
+/**
+ * visu_ui_numerical_entry_warnValue:
+ * @numericalEntry: a #VisuUiNumericalEntry object.
+ * @fallback: a floating point value.
+ *
+ * Display a warning sign in the entry and fallback to the given value.
+ *
+ * Since: 3.8
+ **/
+void visu_ui_numerical_entry_warnValue(VisuUiNumericalEntry *numericalEntry, float fallback)
+{
+  g_return_if_fail(VISU_IS_UI_NUMERICAL_ENTRY(numericalEntry));
+
+  gtk_entry_set_icon_from_icon_name(GTK_ENTRY(numericalEntry),
+                                    GTK_ENTRY_ICON_SECONDARY, "dialog-warning");
+  g_timeout_add_seconds(2, _removeWarning, (gpointer)numericalEntry);
+
+  numericalEntry->value = G_MAXDOUBLE;
+  visu_ui_numerical_entry_setValue(numericalEntry, fallback);
+}
