@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -45,10 +45,9 @@
 
 #include "gtk_shadeComboBoxWidget.h"
 #include <visu_tools.h>
-#include <visu_object.h>
 #include <visu_data.h>
 #include <visu_configFile.h>
-#include <coreTools/toolConfigFile.h>
+
 
 /**
  * SECTION:gtk_shadeComboBoxWidget
@@ -72,6 +71,13 @@ enum {
   SHADE_SELECTED_SIGNAL,
   LAST_SIGNAL
 };
+enum
+  {
+    PROP_0,
+    SHADE_PROP,
+    N_PROP
+  };
+static GParamSpec *properties[N_PROP];
 
 /* This enum is used to access the column of the GtkListStore
    that contains the informations of stroed shades. */
@@ -101,6 +107,10 @@ enum
 
 static void visu_ui_shade_combobox_dispose (GObject *obj);
 static void visu_ui_shade_combobox_finalize(GObject *obj);
+static void visu_ui_shade_combobox_get_property(GObject* obj, guint property_id,
+                                                GValue *value, GParamSpec *pspec);
+static void visu_ui_shade_combobox_set_property(GObject* obj, guint property_id,
+                                                const GValue *value, GParamSpec *pspec);
 
 static guint visu_ui_shade_combobox_signals[LAST_SIGNAL] = { 0 };
 
@@ -140,8 +150,6 @@ struct _VisuUiShadeComboboxClass
   GtkListStore *listStoredToolShades;
 
   guint favToolShade;
-
-  gulong shadeAddedSignalId;
 };
 static VisuUiShadeComboboxClass *my_class = (VisuUiShadeComboboxClass*)0;
 
@@ -151,11 +159,9 @@ static void visu_ui_shade_combobox_changed(GtkWidget *widget, VisuUiShadeCombobo
 /* Local methods. */
 static void addToolShadeToModel(GtkTreeIter *iter, VisuUiShadeComboboxClass* klass,
                                 ToolShade* shade);
-static void onNewShadeAvailable(GObject *obj, ToolShade* newColor, gpointer data);
+static void onNewShadeAvailable(ToolPool *obj, ToolShade* newColor, gpointer data);
 static void buildWidgets(VisuUiShadeCombobox *shadeComboBox, gboolean showNames);
-static gboolean readFavToolShade(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
-                                 VisuData *dataObj, VisuGlView *view, GError **error);
-static void exportParameters(GString *data, VisuData* dataObj, VisuGlView *view);
+static void exportParameters(GString *data, VisuData* dataObj);
 
 /**
  * visu_ui_shade_combobox_get_type
@@ -173,6 +179,7 @@ static void visu_ui_shade_combobox_class_init(VisuUiShadeComboboxClass *klass)
   GtkTreeIter iter;
   GList *shadeLst;
   VisuConfigFileEntry *resourceEntry;
+  int rgShade[2] = {0, 128};
   
   DBG_fprintf(stderr, "Gtk VisuUiShadeCombobox: creating the class of the widget.\n");
   DBG_fprintf(stderr, "                     - adding new signals ;\n");
@@ -195,9 +202,8 @@ static void visu_ui_shade_combobox_class_init(VisuUiShadeComboboxClass *klass)
 		  g_cclosure_marshal_VOID__POINTER,
 		  G_TYPE_NONE, 1, G_TYPE_POINTER);
 
-  klass->shadeAddedSignalId = g_signal_connect(VISU_OBJECT_INSTANCE, "shadeNewAvailable",
-					       G_CALLBACK(onNewShadeAvailable),
-					       (gpointer)klass);
+  g_signal_connect(tool_shade_getStorage(), "new-element",
+                   G_CALLBACK(onNewShadeAvailable), (gpointer)klass);
 
   DBG_fprintf(stderr, "                     - initializing the listStore of shades.\n");
   /* Init the listStore of shades. */
@@ -206,15 +212,16 @@ static void visu_ui_shade_combobox_class_init(VisuUiShadeComboboxClass *klass)
 					       G_TYPE_STRING,
 					       G_TYPE_STRING,
 					       G_TYPE_POINTER);
-  for (shadeLst = tool_shade_getList(); shadeLst; shadeLst = g_list_next(shadeLst))
+  for (shadeLst = tool_pool_asList(tool_shade_getStorage());
+       shadeLst; shadeLst = g_list_next(shadeLst))
     addToolShadeToModel(&iter, klass, (ToolShade*)shadeLst->data);
   klass->favToolShade = 0;
 
   /* Dealing with parameters. */
-  resourceEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
-					  FLAG_PARAMETER_FAVSHADE,
-					  DESC_PARAMETER_FAVSHADE,
-					  1, readFavToolShade);
+  resourceEntry = visu_config_file_addIntegerArrayEntry(VISU_CONFIG_FILE_PARAMETER,
+                                                        FLAG_PARAMETER_FAVSHADE,
+                                                        DESC_PARAMETER_FAVSHADE,
+                                                        1, (int*)&klass->favToolShade, rgShade, FALSE);
   visu_config_file_entry_setVersion(resourceEntry, 3.5f);
   visu_config_file_addExportFunction(VISU_CONFIG_FILE_PARAMETER,
 				   exportParameters);
@@ -222,6 +229,22 @@ static void visu_ui_shade_combobox_class_init(VisuUiShadeComboboxClass *klass)
   /* Connect freeing methods. */
   G_OBJECT_CLASS(klass)->dispose  = visu_ui_shade_combobox_dispose;
   G_OBJECT_CLASS(klass)->finalize = visu_ui_shade_combobox_finalize;
+  G_OBJECT_CLASS(klass)->set_property = visu_ui_shade_combobox_set_property;
+  G_OBJECT_CLASS(klass)->get_property = visu_ui_shade_combobox_get_property;
+
+  /**
+   * VisuUiShadeCombobox::shade:
+   *
+   * Store the shade of the current selection.
+   *
+   * Since: 3.8
+   */
+  properties[SHADE_PROP] = g_param_spec_boxed("shade", "Shade",
+                                              "shade of the current selection",
+                                              TOOL_TYPE_SHADE,
+                                              G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+  g_object_class_install_property(G_OBJECT_CLASS(klass), SHADE_PROP,
+				  properties[SHADE_PROP]);
 
   my_class = klass;
 }
@@ -248,6 +271,44 @@ static void visu_ui_shade_combobox_finalize(GObject *obj)
 
   DBG_fprintf(stderr, " | freeing ... OK.\n");
 }
+static void visu_ui_shade_combobox_get_property(GObject* obj, guint property_id,
+                                                GValue *value, GParamSpec *pspec)
+{
+  VisuUiShadeCombobox *self = VISU_UI_SHADE_COMBOBOX(obj);
+
+  DBG_fprintf(stderr, "Gtk VisuUiShadeCombobox: get property '%s'.\n",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case SHADE_PROP:
+      g_value_set_static_boxed(value, visu_ui_shade_combobox_getSelection(self));
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
+static void visu_ui_shade_combobox_set_property(GObject* obj, guint property_id,
+                                                const GValue *value, GParamSpec *pspec)
+{
+  VisuUiShadeCombobox *self = VISU_UI_SHADE_COMBOBOX(obj);
+
+  DBG_fprintf(stderr, "Gtk VisuUiShadeCombobox: set property '%s'.\n",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case SHADE_PROP:
+      if (!visu_ui_shade_combobox_setSelectionByShade(self,
+                                                      (ToolShade*)g_value_get_boxed(value)))
+        gtk_combo_box_set_active(GTK_COMBO_BOX(obj), -1);
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
 
 
 static void visu_ui_shade_combobox_init(VisuUiShadeCombobox *shadeComboBox)
@@ -356,6 +417,7 @@ static void visu_ui_shade_combobox_changed(GtkWidget *widget _U_, VisuUiShadeCom
     {
       shadeComboBox->previouslySelectedToolShade = shade;
       DBG_fprintf(stderr, "Gtk VisuUiShadeCombobox: emitting 'shade-selected' signal for shade (%p).\n", (gpointer)shade);
+      g_object_notify_by_pspec(G_OBJECT(shadeComboBox), properties[SHADE_PROP]);
       g_signal_emit(G_OBJECT(shadeComboBox),
 		    visu_ui_shade_combobox_signals[SHADE_SELECTED_SIGNAL], 0, (gpointer)shade, NULL);
     }
@@ -430,7 +492,7 @@ GdkPixbuf* visu_ui_shade_combobox_buildStamp(ToolShade *shade, GdkPixbuf *pixbuf
   return pixbufToolShadeBox;
 }
 
-static void onNewShadeAvailable(GObject *obj _U_, ToolShade* newShade, gpointer data)
+static void onNewShadeAvailable(ToolPool *obj _U_, ToolShade* newShade, gpointer data)
 {
   VisuUiShadeComboboxClass *klass;
   GtkTreeIter iter;
@@ -447,6 +509,7 @@ static void addToolShadeToModel(GtkTreeIter *iter, VisuUiShadeComboboxClass* kla
   GtkTreePath *path;
   gint *ids;
   gchar *idLbl;
+  GdkPixbuf *pix;
 
   g_return_if_fail(iter && klass && shade);
 
@@ -457,12 +520,14 @@ static void addToolShadeToModel(GtkTreeIter *iter, VisuUiShadeComboboxClass* kla
   ids = gtk_tree_path_get_indices(path);
   idLbl = g_strdup_printf("<span size=\"small\">(%d)</span>", ids[0]);
   gtk_tree_path_free(path);
+  pix = visu_ui_shade_combobox_buildStamp(shade, (GdkPixbuf*)0);
   gtk_list_store_set(klass->listStoredToolShades, iter,
-		     COLUMN_SHADE_PIXBUF      , visu_ui_shade_combobox_buildStamp(shade, (GdkPixbuf*)0),
+		     COLUMN_SHADE_PIXBUF      , pix,
 		     COLUMN_SHADE_LABEL       , tool_shade_getLabel(shade),
 		     COLUMN_SHADE_ID          , idLbl,
 		     COLUMN_SHADE_POINTER_TO  , (gpointer)shade,
 		     -1);
+  g_object_unref(G_OBJECT(pix));
   g_free(idLbl);
   DBG_fprintf(stderr, "Gtk VisuUiShadeCombobox: appending a new shade '%s'.\n",
 	      tool_shade_getLabel(shade));
@@ -489,7 +554,7 @@ gboolean visu_ui_shade_combobox_setSelectionByShade(VisuUiShadeCombobox* shadeCo
   GtkListStore *model;
   ToolShade *tmpToolShade;
 
-  g_return_val_if_fail(VISU_UI_IS_SHADE_COMBOBOX(shadeComboBox), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_SHADE_COMBOBOX(shadeComboBox), FALSE);
 
   DBG_fprintf(stderr, "Gtk VisuUiShadeCombobox: select a new shade %p.\n", (gpointer)shade);
   if (!shade)
@@ -521,7 +586,7 @@ GdkPixbuf* shadeComboBoxGet_selectedPixbuf(VisuUiShadeCombobox *shadeComboBox)
   GdkPixbuf *pixbuf;
   GObjectClass *klass;
 
-  g_return_val_if_fail(VISU_UI_IS_SHADE_COMBOBOX(shadeComboBox), (GdkPixbuf*)0);
+  g_return_val_if_fail(VISU_IS_UI_SHADE_COMBOBOX(shadeComboBox), (GdkPixbuf*)0);
 
   validIter = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(shadeComboBox), &iter);
   if (!validIter)
@@ -552,7 +617,7 @@ ToolShade* visu_ui_shade_combobox_getSelection(VisuUiShadeCombobox *shadeComboBo
   ToolShade *shade;
   GObjectClass *klass;
 
-  g_return_val_if_fail(VISU_UI_IS_SHADE_COMBOBOX(shadeComboBox), (ToolShade*)0);
+  g_return_val_if_fail(VISU_IS_UI_SHADE_COMBOBOX(shadeComboBox), (ToolShade*)0);
 
   validIter = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(shadeComboBox), &iter);
   if (!validIter)
@@ -587,7 +652,7 @@ GdkPixbuf* visu_ui_shade_combobox_getStamp(VisuUiShadeCombobox *shadeComboBox,
   ToolShade *cl;
   GtkListStore *model;
 
-  g_return_val_if_fail(VISU_UI_IS_SHADE_COMBOBOX(shadeComboBox) && shade, (GdkPixbuf*)0);
+  g_return_val_if_fail(VISU_IS_UI_SHADE_COMBOBOX(shadeComboBox) && shade, (GdkPixbuf*)0);
 
   model = VISU_UI_SHADE_COMBOBOX_CLASS(G_OBJECT_GET_CLASS(shadeComboBox))->listStoredToolShades;
   validIter = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
@@ -607,29 +672,7 @@ GdkPixbuf* visu_ui_shade_combobox_getStamp(VisuUiShadeCombobox *shadeComboBox,
 }
 
 
-static gboolean readFavToolShade(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
-                                 VisuData *dataObj _U_, VisuGlView *view _U_,
-                                 GError **error)
-{
-  int val;
-  
-  g_return_val_if_fail(my_class, FALSE);
-  g_return_val_if_fail(nbLines == 1, FALSE);
-
-  if (!tool_config_file_readInteger(lines[0], position, &val, 1, error))
-    return FALSE;
-  if (val < 0)
-    {
-      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_VALUE,
-			   _("Parse error at line %d: prefered shade must be positive.\n"),
-			   position);
-      return FALSE;
-    }
-  my_class->favToolShade = (guint)val;
-
-  return TRUE;
-}
-static void exportParameters(GString *data, VisuData* dataObj _U_, VisuGlView *view _U_)
+static void exportParameters(GString *data, VisuData* dataObj _U_)
 {
   g_return_if_fail(my_class);
 
