@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -67,6 +67,15 @@ enum {
   STIPPLE_SELECTED_SIGNAL,
   LAST_SIGNAL
 };
+static guint signals[LAST_SIGNAL] = { 0 };
+
+enum
+  {
+    PROP_0,
+    VALUE_PROP,
+    N_PROP
+  };
+static GParamSpec *properties[N_PROP];
 
 /* This enum is used to access the column of the GtkListStore
    that contains the informations of stroed shades. */
@@ -89,8 +98,11 @@ enum
 
 static void visu_ui_stipple_combobox_dispose (GObject *obj);
 static void visu_ui_stipple_combobox_finalize(GObject *obj);
+static void visu_ui_stipple_combobox_get_property(GObject* obj, guint property_id,
+                                                  GValue *value, GParamSpec *pspec);
+static void visu_ui_stipple_combobox_set_property(GObject* obj, guint property_id,
+                                                  const GValue *value, GParamSpec *pspec);
 
-static guint visu_ui_stipple_combobox_signals[LAST_SIGNAL] = { 0 };
 
 /**
  * VisuUiStippleCombobox:
@@ -168,7 +180,7 @@ static void visu_ui_stipple_combobox_class_init(VisuUiStippleComboboxClass *klas
    *
    * Since: 3.4
    */
-  visu_ui_stipple_combobox_signals[STIPPLE_SELECTED_SIGNAL] =
+  signals[STIPPLE_SELECTED_SIGNAL] =
     g_signal_new ("stipple-selected",
 		  G_TYPE_FROM_CLASS (klass),
 		  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
@@ -190,6 +202,22 @@ static void visu_ui_stipple_combobox_class_init(VisuUiStippleComboboxClass *klas
   /* Connect freeing methods. */
   G_OBJECT_CLASS(klass)->dispose = visu_ui_stipple_combobox_dispose;
   G_OBJECT_CLASS(klass)->finalize = visu_ui_stipple_combobox_finalize;
+  G_OBJECT_CLASS(klass)->set_property = visu_ui_stipple_combobox_set_property;
+  G_OBJECT_CLASS(klass)->get_property = visu_ui_stipple_combobox_get_property;
+
+  /**
+   * VisuUiStippleCombobox::value:
+   *
+   * Store the current stipple.
+   *
+   * Since: 3.8
+   */
+  properties[VALUE_PROP] = g_param_spec_uint("value", "stipple value",
+                                             "stipple pattern for OpenGL",
+                                             0, 65535, (guint)builtInStipples[0],
+                                             G_PARAM_READWRITE);
+  g_object_class_install_property(G_OBJECT_CLASS(klass), VALUE_PROP,
+				  properties[VALUE_PROP]);
 }
 
 static void visu_ui_stipple_combobox_dispose(GObject *obj)
@@ -216,6 +244,48 @@ static void visu_ui_stipple_combobox_finalize(GObject *obj)
 
   DBG_fprintf(stderr, " | freeing ... OK.\n");
 }
+static void visu_ui_stipple_combobox_get_property(GObject* obj, guint property_id,
+                                                  GValue *value, GParamSpec *pspec)
+{
+  guint16 stipple;
+  VisuUiStippleCombobox *self = VISU_UI_STIPPLE_COMBOBOX(obj);
+
+  DBG_fprintf(stderr, "Gtk VisuUiStippleCombobox: get property '%s' -> ",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case VALUE_PROP:
+      stipple = visu_ui_stipple_combobox_getSelection(self);
+      g_value_set_uint(value, (guint)stipple);
+      DBG_fprintf(stderr, "%d.\n", stipple);
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
+static void visu_ui_stipple_combobox_set_property(GObject* obj, guint property_id,
+                                                  const GValue *value, GParamSpec *pspec)
+{
+  guint16 stipple;
+  VisuUiStippleCombobox *self = VISU_UI_STIPPLE_COMBOBOX(obj);
+
+  DBG_fprintf(stderr, "Gtk VisuUiStippleCombobox: set property '%s' -> ",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case VALUE_PROP:
+      stipple = (guint16)g_value_get_uint(value);
+      visu_ui_stipple_combobox_set(self, stipple);
+      DBG_fprintf(stderr, "%d.\n", stipple);
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
 
 static void visu_ui_stipple_combobox_init(VisuUiStippleCombobox *stippleComboBox)
 {
@@ -267,7 +337,7 @@ GtkWidget* visu_ui_stipple_combobox_new()
 
   DBG_fprintf(stderr, "Gtk VisuUiStippleCombobox: creating new object.\n");
 
-  stippleComboBox = VISU_UI_STIPPLE_COMBOBOX(g_object_new(VISU_UI_TYPE_STIPPLE_COMBOBOX, NULL));
+  stippleComboBox = VISU_UI_STIPPLE_COMBOBOX(g_object_new(VISU_TYPE_UI_STIPPLE_COMBOBOX, NULL));
 
   DBG_fprintf(stderr, "Gtk VisuUiStippleCombobox: build widgets.\n");
   buildWidgets(stippleComboBox);
@@ -276,12 +346,10 @@ GtkWidget* visu_ui_stipple_combobox_new()
 }
 
 static void visu_ui_stipple_combobox_changed(VisuUiStippleCombobox *stippleComboBox,
-				    gpointer data _U_)
+                                             gpointer data _U_)
 {
   int selected;
-  GtkTreeIter iter;
-  GObjectClass *klass;
-  guint stipple;
+  guint16 stipple;
 
   selected = gtk_combo_box_get_active(GTK_COMBO_BOX(stippleComboBox));
   DBG_fprintf(stderr, "Gtk VisuUiStippleCombobox: internal combobox changed signal -> %d.\n", selected);
@@ -290,22 +358,20 @@ static void visu_ui_stipple_combobox_changed(VisuUiStippleCombobox *stippleCombo
       stippleComboBox->previousStipple = (guint16)0;
 /*       DBG_fprintf(stderr, "Gtk VisuUiStippleCombobox : emitting 'stipple-selected' signal.\n"); */
 /*       g_signal_emit(G_OBJECT(stippleComboBox), */
-/* 		    visu_ui_stipple_combobox_signals[STIPPLE_SELECTED_SIGNAL], 0, (gpointer)0, NULL); */
+/* 		    signals[STIPPLE_SELECTED_SIGNAL], 0, (gpointer)0, NULL); */
       return;
     }
 
-  gtk_combo_box_get_active_iter(GTK_COMBO_BOX(stippleComboBox), &iter);
-  klass = G_OBJECT_GET_CLASS(stippleComboBox);
-  gtk_tree_model_get(GTK_TREE_MODEL(VISU_UI_STIPPLE_COMBOBOX_CLASS(klass)->listStoredStipples), &iter,
-		     COLUMN_STIPPLE_VALUE, &stipple,
-		     -1);
-  if ((guint16)(stipple) != stippleComboBox->previousStipple)
+  stipple = visu_ui_stipple_combobox_getSelection(stippleComboBox);
+  if (stipple && stipple != stippleComboBox->previousStipple)
     {
-      stippleComboBox->previousStipple = (guint16)(stipple);
+      stippleComboBox->previousStipple = stipple;
       DBG_fprintf(stderr, "Gtk VisuUiStippleCombobox: emitting 'stipple-selected'"
 		  " signal for value %d.\n", stipple);
+      g_object_notify_by_pspec(G_OBJECT(stippleComboBox), properties[VALUE_PROP]);
       g_signal_emit(G_OBJECT(stippleComboBox),
-		    visu_ui_stipple_combobox_signals[STIPPLE_SELECTED_SIGNAL], 0, stipple, NULL);
+		    signals[STIPPLE_SELECTED_SIGNAL],
+                    0, (guint)stipple, NULL);
     }
   else
     DBG_fprintf(stderr, "Gtk VisuUiStippleCombobox: aborting 'stipple-selected' signal.\n");
@@ -392,7 +458,7 @@ gboolean visu_ui_stipple_combobox_setSelection(VisuUiStippleCombobox* stippleCom
   GtkListStore *model;
   guint tmpStipple;
 
-  g_return_val_if_fail(stipple && VISU_UI_IS_STIPPLE_COMBOBOX(stippleComboBox), FALSE);
+  g_return_val_if_fail(stipple && VISU_IS_UI_STIPPLE_COMBOBOX(stippleComboBox), FALSE);
 
   DBG_fprintf(stderr, "Gtk VisuUiStippleCombobox: select a new stipple %d.\n", stipple);
   klass = G_OBJECT_GET_CLASS(stippleComboBox);
@@ -419,7 +485,7 @@ GdkPixbuf* stippleComboBoxGet_selectedPixbuf(VisuUiStippleCombobox *stippleCombo
   GdkPixbuf *pixbuf;
   GObjectClass *klass;
 
-  g_return_val_if_fail(VISU_UI_IS_STIPPLE_COMBOBOX(stippleComboBox), (GdkPixbuf*)0);
+  g_return_val_if_fail(VISU_IS_UI_STIPPLE_COMBOBOX(stippleComboBox), (GdkPixbuf*)0);
 
   validIter = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(stippleComboBox), &iter);
   if (!validIter)
@@ -449,7 +515,7 @@ guint16 visu_ui_stipple_combobox_getSelection(VisuUiStippleCombobox *stippleComb
   guint stipple;
   GObjectClass *klass;
 
-  g_return_val_if_fail(VISU_UI_IS_STIPPLE_COMBOBOX(stippleComboBox), (guint16)0);
+  g_return_val_if_fail(VISU_IS_UI_STIPPLE_COMBOBOX(stippleComboBox), (guint16)0);
 
   validIter = gtk_combo_box_get_active_iter(GTK_COMBO_BOX(stippleComboBox), &iter);
   if (!validIter)
@@ -482,7 +548,7 @@ GdkPixbuf* visu_ui_stipple_combobox_getStamp(VisuUiStippleCombobox *stippleCombo
   guint cl;
   GtkListStore *model;
 
-  g_return_val_if_fail(VISU_UI_IS_STIPPLE_COMBOBOX(stippleComboBox) && stipple, (GdkPixbuf*)0);
+  g_return_val_if_fail(VISU_IS_UI_STIPPLE_COMBOBOX(stippleComboBox) && stipple, (GdkPixbuf*)0);
 
   model = VISU_UI_STIPPLE_COMBOBOX_CLASS(G_OBJECT_GET_CLASS(stippleComboBox))->listStoredStipples;
   validIter = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
@@ -517,7 +583,7 @@ void visu_ui_stipple_combobox_add(VisuUiStippleCombobox *stippleComboBox, guint1
   GtkListStore *model;
   guint tmpStipple;
 
-  g_return_if_fail(VISU_UI_IS_STIPPLE_COMBOBOX(stippleComboBox));
+  g_return_if_fail(VISU_IS_UI_STIPPLE_COMBOBOX(stippleComboBox));
 
   /* We test if the stipple already exist or not. */
   klass = G_OBJECT_GET_CLASS(stippleComboBox);
@@ -534,3 +600,22 @@ void visu_ui_stipple_combobox_add(VisuUiStippleCombobox *stippleComboBox, guint1
     }
   addStippleToModel(&iter, VISU_UI_STIPPLE_COMBOBOX_CLASS(klass), stipple);
 }
+/**
+ * visu_ui_stipple_combobox_set:
+ * @stippleComboBox: a #VisuUiStippleCombobox object.
+ * @stipple: a stipple value.
+ *
+ * Select the given stipple, if not exists in the model, add it. See
+ * visu_ui_stipple_combobox_setSelection() for a set method that do
+ * not add.
+ *
+ * Since: 3.8
+ **/
+void visu_ui_stipple_combobox_set(VisuUiStippleCombobox *stippleComboBox, guint16 stipple)
+{
+  if (!visu_ui_stipple_combobox_setSelection(stippleComboBox, stipple))
+    {
+      visu_ui_stipple_combobox_add(stippleComboBox, stipple);
+      visu_ui_stipple_combobox_setSelection(stippleComboBox, stipple);
+    }
+}
