@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -49,7 +49,9 @@
 #include "gtk_toolPanelWidget.h"
 
 #include <support.h>
+#include <visu_basic.h>
 #include <visu_tools.h>
+#include <visu_configFile.h>
 #include <gtk_main.h>
 #include <visu_gtk.h>
 #include <gtk_renderingWindowWidget.h>
@@ -120,7 +122,7 @@ struct _VisuUiDockWindow
  */
 struct _VisuUiPanel
 {
-  GtkAlignment alignment;
+  GtkFrame alignment;
 
   /* Set if the visu_ui_panel can be separate from the main
      window and be hosted in its own window. */
@@ -159,7 +161,7 @@ struct _VisuUiPanel
  */
 struct _VisuUiPanelClass
 {
-  GtkAlignmentClass parent_class;
+  GtkFrameClass parent_class;
 
   void (*visu_ui_panel) (VisuUiPanel *tool);
 
@@ -191,10 +193,15 @@ struct _VisuUiPanelClass
  *
  * Returns: the #GType associated with #VisuUiPanel objects.
  */
-G_DEFINE_TYPE(VisuUiPanel, visu_ui_panel, GTK_TYPE_ALIGNMENT)
+G_DEFINE_TYPE(VisuUiPanel, visu_ui_panel, GTK_TYPE_FRAME)
 
 #define MAIN_PANEL_NAME _("Command panel")
 
+#define FLAG_PARAMETER_TABVIEW_CONFIG   "config_subPanelTabView"
+#define DESC_PARAMETER_TABVIEW_CONFIG   "See or not the labels on tabs ; boolean 0 or 1"
+#define PARAMETER_CONFIG_TABVIEW_DEFAULT   FALSE
+static gboolean _tabView = PARAMETER_CONFIG_TABVIEW_DEFAULT;
+
 /* Local variables. */
 static VisuUiPanelClass *local_class = NULL;
 static GQuark CURRENT_TOOLPANEL_POINTER;
@@ -210,6 +217,7 @@ static GtkWidget* buildMainMenu(VisuUiDockWindow *window);
 static VisuUiDockWindow* dock_window_new(gchar *name, gboolean withWindow);
 static VisuUiDockWindow* dock_window_ref(VisuUiDockWindow *dock);
 static void dock_window_unref(VisuUiDockWindow *dock);
+static void exportParameters(GString *data, VisuData* dataObj);
 
 /* Local callbacks. */
 static gboolean onHomePressed(GtkWidget *widget _U_, GdkEventKey *event,
@@ -229,6 +237,7 @@ static gboolean onKillVisuUiDockWindowEvent(GtkWidget *widget, GdkEvent *event,
 static void onPageChanged(GtkNotebook *book, GtkWidget *child,
 			  gint num, gpointer data);
 static void onComboChanged(GtkComboBox *combo, gpointer data);
+static void onEntryTabview(VisuConfigFile *obj, VisuConfigFileEntry *entry, VisuUiPanelClass *klass);
 
 static void visu_ui_panel_class_init(VisuUiPanelClass *klass)
 {
@@ -264,11 +273,23 @@ static void visu_ui_panel_class_init(VisuUiPanelClass *klass)
   klass->viewObj = (VisuGlView*)0;
   klass->allVisuUiPanels = g_hash_table_new_full(g_str_hash, g_str_equal,
 					       NULL, NULL);
-  klass->showHeader = FALSE;
+  klass->showHeader = PARAMETER_CONFIG_TABVIEW_DEFAULT;
+
+  visu_config_file_addBooleanEntry(VISU_CONFIG_FILE_PARAMETER,
+                                   FLAG_PARAMETER_TABVIEW_CONFIG,
+                                   DESC_PARAMETER_TABVIEW_CONFIG,
+                                   &_tabView, FALSE);
+  g_signal_connect(VISU_CONFIG_FILE_PARAMETER, "parsed::" FLAG_PARAMETER_TABVIEW_CONFIG,
+                   G_CALLBACK(onEntryTabview), klass);
+  visu_config_file_addExportFunction(VISU_CONFIG_FILE_PARAMETER,
+                                     exportParameters);
 
   CURRENT_TOOLPANEL_POINTER =
     g_quark_from_static_string("VisuUiPanel_currentVisuUiPanel");
 
+  /* Set the pixmap directory for the Glade stuff. */
+  add_pixmap_directory(visu_basic_getPixmapsDir());
+
   /* Connect freeing methods. */
   G_OBJECT_CLASS(klass)->dispose = visu_ui_panel_dispose;
   G_OBJECT_CLASS(klass)->finalize = visu_ui_panel_finalize;
@@ -336,6 +357,8 @@ static void visu_ui_panel_init(VisuUiPanel *visu_ui_panel)
   visu_ui_panel->stockIcon    = (gchar*)0;
   visu_ui_panel->headerWidget = (GtkWidget*)0;
   visu_ui_panel->container    = (VisuUiDockWindow*)0;
+
+  gtk_frame_set_shadow_type(GTK_FRAME(visu_ui_panel), GTK_SHADOW_NONE);
 }
 
 /**
@@ -398,18 +421,18 @@ GtkWidget* visu_ui_panel_newWithIconFromPath(gchar *id, gchar* name, gchar *tabN
     return (GtkWidget*)0;
 
   /* TODO : mettre un truc qui limite la taille des images
-     effiches  20x20 par exemple en chargeant de GdkImage et en
+     effichées à 20x20 par exemple en chargeant de GdkImage et en
      regardant sa taille. */
   visu_ui_panel->icon = create_pixmap((GtkWidget*)0, iconPath);
   return GTK_WIDGET(visu_ui_panel);
 }
 /**
- * visu_ui_panel_newWithIconFromStock:
+ * visu_ui_panel_newWithIconFromIconName:
  * @id: a string without space and non internationalised ;
  * @name: a string in UTF-8 that can be internationalised ;
  * @tabName: a shorter name than @name, in UTF-8 that can be
  * internationalised ;
- * @stock: the name of a stock icon.
+ * @icon: the name of a stock icon.
  *
  * Create a new #VisuUiPanel with the given @id, displaying @name in the
  * combo box of a #VisuUiDockWindow and @tabName in the tab of the page
@@ -417,8 +440,8 @@ GtkWidget* visu_ui_panel_newWithIconFromPath(gchar *id, gchar* name, gchar *tabN
  *
  * Returns: (transfer full): a newly created widget.
  */
-GtkWidget* visu_ui_panel_newWithIconFromStock(gchar *id, gchar* name, gchar *tabName,
-					  const gchar* stock)
+GtkWidget* visu_ui_panel_newWithIconFromIconName(gchar *id, gchar* name, gchar *tabName,
+                                                 const gchar* icon)
 {
   VisuUiPanel *visu_ui_panel;
 
@@ -426,8 +449,8 @@ GtkWidget* visu_ui_panel_newWithIconFromStock(gchar *id, gchar* name, gchar *tab
   if (!visu_ui_panel)
     return (GtkWidget*)0;
 
-  visu_ui_panel->stockIcon = g_strdup(stock);
-  visu_ui_panel->icon = gtk_image_new_from_stock(stock, GTK_ICON_SIZE_MENU);
+  visu_ui_panel->stockIcon = g_strdup(icon);
+  visu_ui_panel->icon = gtk_image_new_from_icon_name(icon, GTK_ICON_SIZE_MENU);
   return GTK_WIDGET(visu_ui_panel);
 }
 /**
@@ -443,7 +466,7 @@ GtkWidget* visu_ui_panel_newWithIconFromStock(gchar *id, gchar* name, gchar *tab
  */
 GtkWidget* visu_ui_panel_getHeaderWidget(VisuUiPanel *visu_ui_panel)
 {
-  GtkWidget *label, *wd, *image, *align;
+  GtkWidget *label, *wd, *image;
 #if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips;
 #endif
@@ -468,35 +491,32 @@ GtkWidget* visu_ui_panel_getHeaderWidget(VisuUiPanel *visu_ui_panel)
 	gtk_container_add(GTK_CONTAINER(wd), visu_ui_panel->icon);
       else
 	gtk_container_add(GTK_CONTAINER(wd),
-			  gtk_image_new_from_stock(GTK_STOCK_MISSING_IMAGE,
-						   GTK_ICON_SIZE_MENU));
+			  gtk_image_new_from_icon_name("image-missing",
+                                                       GTK_ICON_SIZE_MENU));
       label = gtk_label_new(visu_ui_panel->tabLabel);
-      gtk_misc_set_padding(GTK_MISC(label), 2, 0);
+      gtk_widget_set_margin_start(label, 2);
       gtk_box_pack_start(GTK_BOX(visu_ui_panel->headerWidget), label, FALSE, FALSE, 0);
 
       if (visu_ui_panel->dockable)
 	{
 	  wd = gtk_button_new();
+          gtk_widget_set_no_show_all(wd, TRUE);
+	  gtk_box_pack_start(GTK_BOX(visu_ui_panel->headerWidget), wd, TRUE, TRUE, 0);
 	  gtk_button_set_relief(GTK_BUTTON(wd), GTK_RELIEF_NONE);
 	  g_signal_connect_swapped(G_OBJECT(wd), "clicked",
 				   G_CALLBACK(onDockButtonClicked), (gpointer)visu_ui_panel);
-	  align = gtk_alignment_new(1.0, 0.5, 0., 0.);
-	  gtk_box_pack_start(GTK_BOX(visu_ui_panel->headerWidget), align, TRUE, TRUE, 0);
 	  image = create_pixmap((GtkWidget*)0, "stock-menu-detach.png");
 	  gtk_container_add(GTK_CONTAINER(wd), image);
-	  gtk_container_add(GTK_CONTAINER(align), wd);
 
 	  gtk_widget_set_tooltip_text(wd,
 			       _("Manage this subpanel: attach/detach"
 				 " or hide it."));
+          gtk_widget_show(image);
 	}
-      else
-	align = (GtkWidget*)0;
 
       g_object_ref(G_OBJECT(visu_ui_panel->headerWidget));
       gtk_widget_show_all(visu_ui_panel->headerWidget);
       gtk_widget_hide(label);
-      if (align) gtk_widget_hide(align);
     }
 
   return visu_ui_panel->headerWidget;
@@ -561,7 +581,7 @@ void visu_ui_panel_setDockable(VisuUiPanel *visu_ui_panel, gboolean value)
  */
 VisuUiDockWindow* visu_ui_panel_getContainer(VisuUiPanel *visu_ui_panel)
 {
-  g_return_val_if_fail(VISU_UI_IS_PANEL(visu_ui_panel), (VisuUiDockWindow*)0);
+  g_return_val_if_fail(VISU_IS_UI_PANEL(visu_ui_panel), (VisuUiDockWindow*)0);
 
   return visu_ui_panel->container;
 }
@@ -576,7 +596,7 @@ VisuUiDockWindow* visu_ui_panel_getContainer(VisuUiPanel *visu_ui_panel)
  */
 GtkWindow* visu_ui_panel_getContainerWindow(VisuUiPanel *visu_ui_panel)
 {
-  g_return_val_if_fail(VISU_UI_IS_PANEL(visu_ui_panel), (GtkWindow*)0);
+  g_return_val_if_fail(VISU_IS_UI_PANEL(visu_ui_panel), (GtkWindow*)0);
 
   if (visu_ui_panel->container)
     {
@@ -598,7 +618,7 @@ GtkWindow* visu_ui_panel_getContainerWindow(VisuUiPanel *visu_ui_panel)
  */
 void visu_ui_panel_setContainer(VisuUiPanel *visu_ui_panel, VisuUiDockWindow *container)
 {
-  g_return_if_fail(VISU_UI_IS_PANEL(visu_ui_panel));
+  g_return_if_fail(VISU_IS_UI_PANEL(visu_ui_panel));
 
   if (container == visu_ui_panel->container)
     return;
@@ -632,7 +652,7 @@ void visu_ui_panel_setContainer(VisuUiPanel *visu_ui_panel, VisuUiDockWindow *co
  */
 const gchar* visu_ui_panel_getContainerId(VisuUiPanel *visu_ui_panel)
 {
-  g_return_val_if_fail(VISU_UI_IS_PANEL(visu_ui_panel), (gchar*)0);
+  g_return_val_if_fail(VISU_IS_UI_PANEL(visu_ui_panel), (gchar*)0);
 
   if (!visu_ui_panel->container)
     return "None";
@@ -652,7 +672,7 @@ const gchar* visu_ui_panel_getContainerId(VisuUiPanel *visu_ui_panel)
  */
 void visu_ui_panel_setContainerId(VisuUiPanel *visu_ui_panel, const gchar *id)
 {
-  g_return_if_fail(VISU_UI_IS_PANEL(visu_ui_panel) && id && id[0]);
+  g_return_if_fail(VISU_IS_UI_PANEL(visu_ui_panel) && id && id[0]);
 
   visu_ui_panel_setContainer(visu_ui_panel, visu_ui_panel_class_getDockById(id));
 }
@@ -667,7 +687,7 @@ void visu_ui_panel_setContainerId(VisuUiPanel *visu_ui_panel, const gchar *id)
  */
 VisuData* visu_ui_panel_getData(VisuUiPanel *visu_ui_panel)
 {
-  g_return_val_if_fail(VISU_UI_IS_PANEL(visu_ui_panel), (VisuData*)0);
+  g_return_val_if_fail(VISU_IS_UI_PANEL(visu_ui_panel), (VisuData*)0);
   
   return VISU_UI_PANEL_CLASS(G_OBJECT_GET_CLASS(visu_ui_panel))->dataObj;
 }
@@ -684,7 +704,7 @@ VisuData* visu_ui_panel_getData(VisuUiPanel *visu_ui_panel)
  */
 VisuBoxed* visu_ui_panel_getFocused(VisuUiPanel *visu_ui_panel)
 {
-  g_return_val_if_fail(VISU_UI_IS_PANEL(visu_ui_panel), (VisuBoxed*)0);
+  g_return_val_if_fail(VISU_IS_UI_PANEL(visu_ui_panel), (VisuBoxed*)0);
   
   return VISU_BOXED(VISU_UI_PANEL_CLASS(G_OBJECT_GET_CLASS(visu_ui_panel))->dataObj);
 }
@@ -701,7 +721,7 @@ VisuBoxed* visu_ui_panel_getFocused(VisuUiPanel *visu_ui_panel)
  */
 VisuGlView* visu_ui_panel_getView(VisuUiPanel *visu_ui_panel)
 {
-  g_return_val_if_fail(VISU_UI_IS_PANEL(visu_ui_panel), (VisuGlView*)0);
+  g_return_val_if_fail(VISU_IS_UI_PANEL(visu_ui_panel), (VisuGlView*)0);
   
   return VISU_UI_PANEL_CLASS(G_OBJECT_GET_CLASS(visu_ui_panel))->viewObj;
 }
@@ -716,7 +736,7 @@ VisuGlView* visu_ui_panel_getView(VisuUiPanel *visu_ui_panel)
  */
 gboolean visu_ui_panel_getVisible(VisuUiPanel *visu_ui_panel)
 {
-  g_return_val_if_fail(VISU_UI_IS_PANEL(visu_ui_panel), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_PANEL(visu_ui_panel), FALSE);
 
   /* If the tool panel is not shown, we return fFALSE. */
   if (!visu_ui_panel->container || !visu_ui_panel->container->show)
@@ -734,19 +754,24 @@ gboolean visu_ui_panel_getVisible(VisuUiPanel *visu_ui_panel)
 /*****************/
 /* Menu gestion. */
 /*****************/
-static void onDockButtonClicked(VisuUiPanel *visu_ui_panel, gpointer data _U_)
+static void onDockButtonClicked(VisuUiPanel *visu_ui_panel, gpointer data)
 {
   GtkWidget *wd;
 
-  g_return_if_fail(VISU_UI_IS_PANEL(visu_ui_panel));
+  g_return_if_fail(VISU_IS_UI_PANEL(visu_ui_panel));
 
   wd = buildDockMenu(visu_ui_panel, VISU_UI_PANEL_CLASS(G_OBJECT_GET_CLASS(visu_ui_panel))->hostingWindows);
   g_signal_connect(G_OBJECT(wd), "selection-done",
 		   G_CALLBACK(onDockMenuSelected), (gpointer)0);
 
   gtk_widget_show_all(wd);
+#if GTK_MAJOR_VERSION < 2 || (GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 22)
   gtk_menu_popup(GTK_MENU(wd), NULL, NULL, NULL, NULL, 
 		 1, gtk_get_current_event_time());
+  (void)data;
+#else
+  gtk_menu_popup_at_widget(GTK_MENU(wd), GTK_WIDGET(data), GDK_GRAVITY_SOUTH, GDK_GRAVITY_NORTH, NULL);
+#endif
 }
 
 static GtkWidget* buildDockMenu(VisuUiPanel *visu_ui_panel, GList *listOfDocks)
@@ -803,7 +828,7 @@ static void onDockMenuClicked(GtkMenuItem *menuitem, gpointer user_data)
   visu_ui_panel = (VisuUiPanel*)0;
   visu_ui_panel = VISU_UI_PANEL(g_object_get_qdata(G_OBJECT(menuitem),
 					    CURRENT_TOOLPANEL_POINTER));
-  g_return_if_fail(VISU_UI_IS_PANEL(visu_ui_panel));
+  g_return_if_fail(VISU_IS_UI_PANEL(visu_ui_panel));
 
   visu_ui_panel_setContainer(visu_ui_panel, (VisuUiDockWindow*)user_data);
 }
@@ -841,7 +866,7 @@ static void onDockMenuSelected(GtkMenuShell *menushell, gpointer user_data _U_)
 
 static gboolean emitPageEnter(gpointer data)
 {
-  g_return_val_if_fail(VISU_UI_IS_PANEL(data), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_PANEL(data), FALSE);
 
   DBG_fprintf(stderr, "Gtk VisuUiPanel: '%s' (%p) emits 'page-entered' signal.\n",
 	      VISU_UI_PANEL(data)->id, data);
@@ -855,7 +880,7 @@ static void changeHeaderVisibility(VisuUiPanel *panel, gboolean status)
 {
   GList *list, *tmpLst;
   
-  g_return_if_fail(VISU_UI_IS_PANEL(panel) && panel->headerWidget);
+  g_return_if_fail(VISU_IS_UI_PANEL(panel) && panel->headerWidget);
 
   list = gtk_container_get_children(GTK_CONTAINER(panel->headerWidget));
   tmpLst = list->next;
@@ -892,7 +917,7 @@ static void onPageChanged(GtkNotebook *book, GtkWidget *child,
 
   window = (VisuUiDockWindow*)data;
   g_return_if_fail(window);
-  g_return_if_fail(VISU_UI_IS_PANEL(child));
+  g_return_if_fail(VISU_IS_UI_PANEL(child));
 
   DBG_fprintf(stderr, "Gtk VisuUiPanel: caught 'page-switch' signal, jump to %d.\n", num);
   /* Change the visibility of the header labels. */
@@ -901,7 +926,7 @@ static void onPageChanged(GtkNotebook *book, GtkWidget *child,
       numOld = gtk_combo_box_get_active(GTK_COMBO_BOX(window->combo));
       if ((gint)num != numOld)
 	{
-	  /* We don't come from the combo so we cahnge the
+	  /* We don't come from the combo so we change the
 	     visibility. */
 	  changeHeaderVisibility
 	    (VISU_UI_PANEL(gtk_notebook_get_nth_page(book, numOld)), FALSE);
@@ -1069,7 +1094,7 @@ void visu_ui_panel_detach(VisuUiPanel *visu_ui_panel)
 	      g_list_length(klass->orphanVisuUiPanel));
 }
 
-static void onMainButtonClicked(GtkButton *button _U_, gpointer data)
+static void onMainButtonClicked(GtkButton *button, gpointer data)
 {
   GtkWidget *wd;
 
@@ -1078,8 +1103,13 @@ static void onMainButtonClicked(GtkButton *button _U_, gpointer data)
 		   G_CALLBACK(onMainMenuSelected), (gpointer)0);
 
   gtk_widget_show_all(wd);
+#if GTK_MAJOR_VERSION < 2 || (GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 22)
   gtk_menu_popup(GTK_MENU(wd), NULL, NULL, NULL, NULL, 
 		 1, gtk_get_current_event_time());
+  (void)button;
+#else
+  gtk_menu_popup_at_widget(GTK_MENU(wd), GTK_WIDGET(button), GDK_GRAVITY_SOUTH, GDK_GRAVITY_NORTH, NULL);
+#endif
 }
 
 static GtkWidget* buildMainMenu(VisuUiDockWindow *window)
@@ -1165,7 +1195,7 @@ static void onMainMenuClicked(GtkMenuItem *menuitem, gpointer user_data)
   visu_ui_panel = (VisuUiPanel*)0;
   visu_ui_panel = VISU_UI_PANEL(g_object_get_qdata(G_OBJECT(menuitem),
 					    CURRENT_TOOLPANEL_POINTER));
-  g_return_if_fail(VISU_UI_IS_PANEL(visu_ui_panel));
+  g_return_if_fail(VISU_IS_UI_PANEL(visu_ui_panel));
 
   window = (VisuUiDockWindow*)user_data;
   
@@ -1227,7 +1257,7 @@ static void onRaiseButtonClicked(GtkButton *button _U_, gpointer data _U_)
 VisuUiDockWindow* visu_ui_panel_class_getCommandPanel(void)
 {
   if (!local_class)
-    g_type_class_ref(VISU_UI_TYPE_PANEL);
+    g_type_class_ref(VISU_TYPE_UI_PANEL);
 
   if (!local_class->commandPanel)
     {
@@ -1251,7 +1281,7 @@ VisuUiDockWindow* visu_ui_panel_class_getCommandPanel(void)
 void visu_ui_panel_class_setCurrent(VisuData *dataObj, VisuGlView *view)
 {
   if (!local_class)
-    g_type_class_ref(VISU_UI_TYPE_PANEL);
+    g_type_class_ref(VISU_TYPE_UI_PANEL);
 
   local_class->dataObj = dataObj;
   local_class->viewObj = view;
@@ -1270,7 +1300,7 @@ VisuUiPanel* visu_ui_panel_class_getPanelById(const gchar *id)
   gpointer panel;
 
   if (!local_class)
-    g_type_class_ref(VISU_UI_TYPE_PANEL);
+    g_type_class_ref(VISU_TYPE_UI_PANEL);
 
   DBG_fprintf(stderr, "Gtk VisuUiPanel: search panel '%s'.\n", id);
   panel = g_hash_table_lookup(local_class->allVisuUiPanels, id);
@@ -1294,7 +1324,7 @@ VisuUiDockWindow* visu_ui_panel_class_getDockById(const gchar *id)
   GList *tmplst;
 
   if (!local_class)
-    g_type_class_ref(VISU_UI_TYPE_PANEL);
+    g_type_class_ref(VISU_TYPE_UI_PANEL);
 
   if (!strcmp(id, "None"))
     return (VisuUiDockWindow*)0;
@@ -1333,7 +1363,7 @@ GList* visu_ui_panel_class_getAllPanels(void)
   GtkTreeModel *treeModel;
 
   if (!local_class)
-    g_type_class_ref(VISU_UI_TYPE_PANEL);
+    g_type_class_ref(VISU_TYPE_UI_PANEL);
   
   DBG_fprintf(stderr, "Gtk VisuUiPanel: create list of all panels.\n");
   returnlst = (GList*)0;
@@ -1367,7 +1397,7 @@ GList* visu_ui_panel_class_getAllWindows(void)
   GList *returnlst;
 
   if (!local_class)
-    g_type_class_ref(VISU_UI_TYPE_PANEL);
+    g_type_class_ref(VISU_TYPE_UI_PANEL);
   
   DBG_fprintf(stderr, "Gtk VisuUiPanel : create list of all windows.\n");
   returnlst = g_list_copy(local_class->hostingWindows);
@@ -1388,7 +1418,7 @@ void visu_ui_panel_class_setHeaderVisibility(gboolean status)
   GtkNotebook *notebook;
 
   if (!local_class)
-    g_type_class_ref(VISU_UI_TYPE_PANEL);
+    g_type_class_ref(VISU_TYPE_UI_PANEL);
   
   DBG_fprintf(stderr, "Gtk VisuUiPanel : set the header visibility.\n");
   if (local_class->showHeader == status)
@@ -1406,6 +1436,23 @@ void visu_ui_panel_class_setHeaderVisibility(gboolean status)
     }
   local_class->showHeader = status;
 }
+/**
+ * visu_ui_panel_class_getHeaderVisibility:
+ *
+ * The header can be represented using the full image and label always
+ * or only the image when the tab is not on top.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if the header uses text and label.
+ **/
+gboolean visu_ui_panel_class_getHeaderVisibility(void)
+{
+  if (!local_class)
+    g_type_class_ref(VISU_TYPE_UI_PANEL);
+  
+  return local_class->showHeader;
+}
 
 /************************/
 /* Dock window methods. */
@@ -1424,7 +1471,7 @@ GType visu_ui_dock_window_get_type(void)
 static VisuUiDockWindow* dock_window_new(gchar *name, gboolean withWindow)
 {
   VisuUiDockWindow *window;
-  GtkWidget *wd, *image, *align;
+  GtkWidget *wd, *image;
   GtkCellRenderer *renderer;
 /*   GtkBindingSet *keys; */
 #if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
@@ -1466,13 +1513,10 @@ static VisuUiDockWindow* dock_window_new(gchar *name, gboolean withWindow)
   else
     window->window = (GtkWidget*)0;
 
-  align = gtk_alignment_new(0.5, 0.5, 1.0, 1.0);
-  gtk_alignment_set_padding(GTK_ALIGNMENT(align), 5, 0, 0, 0);
-  gtk_box_pack_end(GTK_BOX(window->vbox), align, TRUE, TRUE, 0);
-  
   window->notebook = gtk_notebook_new();
+  gtk_widget_set_margin_top(window->notebook, 5);
   gtk_notebook_set_scrollable(GTK_NOTEBOOK(window->notebook), TRUE);
-  gtk_container_add(GTK_CONTAINER(align), window->notebook);  
+  gtk_box_pack_end(GTK_BOX(window->vbox), window->notebook, TRUE, TRUE, 0);
   window->notebookChanged =
     g_signal_connect(G_OBJECT(window->notebook), "switch-page",
 		     G_CALLBACK(onPageChanged), (gpointer)window);
@@ -1492,7 +1536,7 @@ static VisuUiDockWindow* dock_window_new(gchar *name, gboolean withWindow)
   gtk_box_pack_start(GTK_BOX(window->hbox), wd, FALSE, FALSE, 0);
   g_signal_connect(G_OBJECT(wd), "clicked",
 		   G_CALLBACK(onRaiseButtonClicked), (gpointer)window);
-  image = gtk_image_new_from_stock(GTK_STOCK_GO_UP, GTK_ICON_SIZE_MENU);
+  image = gtk_image_new_from_icon_name("go-up", GTK_ICON_SIZE_MENU);
   gtk_container_add(GTK_CONTAINER(wd), image);
   gtk_widget_set_tooltip_text(wd, _("Raise the rendering window.\n"
 				    "  Use <home> as key binding."));
@@ -1542,7 +1586,7 @@ static VisuUiDockWindow* dock_window_new(gchar *name, gboolean withWindow)
 			 " windows are stored in the parameters file, " \
 			 "see the 'Config. files' button on the command panel."));
   gtk_box_pack_end(GTK_BOX(window->hbox), wd, FALSE, FALSE, 2);
-  image = gtk_image_new_from_stock(GTK_STOCK_HELP, GTK_ICON_SIZE_MENU);
+  image = gtk_image_new_from_icon_name("help-browser", GTK_ICON_SIZE_MENU);
   gtk_container_add(GTK_CONTAINER(wd), image);
 
   gtk_widget_show_all(window->vbox);
@@ -1668,8 +1712,14 @@ void visu_ui_dock_window_setSize(VisuUiDockWindow *dock, guint width, guint heig
       (GDK_WINDOW(gtk_widget_get_window(dock->window)));
   else
     screen = gdk_screen_get_default();
+#if GTK_MAJOR_VERSION < 3 || (GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 22)
   widthScreen = gdk_screen_get_width(screen);
   heightScreen = gdk_screen_get_height(screen);
+#else
+  (void)screen;
+  widthScreen = 10240;
+  heightScreen = 10240;
+#endif
 
   widthSet = ((gint)width > widthScreen)?widthScreen:(gint)width;
   heightSet = ((gint)height > heightScreen)?heightScreen:(gint)height;
@@ -1705,8 +1755,14 @@ void visu_ui_dock_window_setPosition(VisuUiDockWindow *dock, guint x, guint y)
       (GDK_WINDOW(gtk_widget_get_window(dock->window)));
   else
     screen = gdk_screen_get_default();
+#if GTK_MAJOR_VERSION < 3 || (GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 22)
   xScreen = gdk_screen_get_width(screen);
   yScreen = gdk_screen_get_height(screen);
+#else
+  (void)screen;
+  xScreen = 10240;
+  yScreen = 10240;
+#endif
   gtk_window_get_size(GTK_WINDOW(dock->window), &width, &height);
 
   xPosition = ((gint)x + width > xScreen)?xScreen - width:(gint)x;
@@ -1738,3 +1794,15 @@ void visu_ui_dock_window_setVisibility(VisuUiDockWindow *dock, gboolean visible)
   else
     gtk_widget_show(dock->window);
 }
+
+static void onEntryTabview(VisuConfigFile *obj _U_, VisuConfigFileEntry *entry _U_, VisuUiPanelClass *klass _U_)
+{
+  visu_ui_panel_class_setHeaderVisibility(_tabView);
+}
+/* These functions write all the element list to export there associated resources. */
+static void exportParameters(GString *data, VisuData *dataObj _U_)
+{
+  g_string_append_printf(data, "# %s\n", DESC_PARAMETER_TABVIEW_CONFIG);
+  g_string_append_printf(data, "%s[gtk]: %d\n\n", FLAG_PARAMETER_TABVIEW_CONFIG,
+			 local_class->showHeader);
+}
