@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -47,6 +47,7 @@
 #include <support.h>
 #include <visu_tools.h>
 #include <visu_gtk.h>
+#include <gtk_main.h>
 
 /**
  * SECTION:gtk_valueIOWidget
@@ -58,8 +59,20 @@
  * Since: 3.5
  */
 
+enum
+  {
+    PROP_0,
+    SAVE_SENSITIVE_PROP,
+    N_PROP
+  };
+static GParamSpec *properties[N_PROP];
+
 static void visu_ui_value_io_dispose (GObject *obj);
 static void visu_ui_value_io_finalize(GObject *obj);
+static void visu_ui_value_io_get_property(GObject* obj, guint property_id,
+                                          GValue *value, GParamSpec *pspec);
+static void visu_ui_value_io_set_property(GObject* obj, guint property_id,
+                                          const GValue *value, GParamSpec *pspec);
 
 /**
  * VisuUiValueIo:
@@ -70,7 +83,7 @@ static void visu_ui_value_io_finalize(GObject *obj);
  */
 struct _VisuUiValueIo
 {
-  GtkHBox hbox;
+  GtkBox hbox;
 
   GtkWidget *btExportOpen, *btExportSave, *btExportSaveAs;
 #if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
@@ -96,7 +109,7 @@ struct _VisuUiValueIo
  */
 struct _VisuUiValueIoClass
 {
-  GtkComboBoxClass parent_class;
+  GtkBoxClass parent_class;
 
   void (*valueio) (VisuUiValueIo *hbox);
 };
@@ -123,7 +136,7 @@ static void onExportXML(GtkButton *button, gpointer data);
  *
  * Since: 3.5
  */
-G_DEFINE_TYPE(VisuUiValueIo, visu_ui_value_io, GTK_TYPE_HBOX)
+G_DEFINE_TYPE(VisuUiValueIo, visu_ui_value_io, GTK_TYPE_BOX)
 
 static void visu_ui_value_io_class_init(VisuUiValueIoClass *klass)
 {
@@ -132,6 +145,22 @@ static void visu_ui_value_io_class_init(VisuUiValueIoClass *klass)
   /* Connect freeing methods. */
   G_OBJECT_CLASS(klass)->dispose = visu_ui_value_io_dispose;
   G_OBJECT_CLASS(klass)->finalize = visu_ui_value_io_finalize;
+  G_OBJECT_CLASS(klass)->set_property = visu_ui_value_io_set_property;
+  G_OBJECT_CLASS(klass)->get_property = visu_ui_value_io_get_property;
+
+  /**
+   * VisuUiValueIo::sensitive-save:
+   *
+   * The save and save-as buttons sensitivity.
+   *
+   * Since: 3.8
+   */
+  properties[SAVE_SENSITIVE_PROP] = g_param_spec_boolean("sensitive-save", "Sensitive save",
+                                                         "sensitivity of save buttons",
+                                                         FALSE, G_PARAM_READWRITE |
+                                                         G_PARAM_STATIC_STRINGS);
+  g_object_class_install_property(G_OBJECT_CLASS(klass), SAVE_SENSITIVE_PROP,
+				  properties[SAVE_SENSITIVE_PROP]);
 }
 
 static void visu_ui_value_io_dispose(GObject *obj)
@@ -156,6 +185,42 @@ static void visu_ui_value_io_finalize(GObject *obj)
 
   DBG_fprintf(stderr, " | freeing ... OK.\n");
 }
+static void visu_ui_value_io_get_property(GObject* obj, guint property_id,
+                                          GValue *value, GParamSpec *pspec)
+{
+  VisuUiValueIo *self = VISU_UI_VALUE_IO(obj);
+
+  DBG_fprintf(stderr, "Gtk VisuUiValueIo: get property '%s'.\n",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case SAVE_SENSITIVE_PROP:
+      g_value_set_boolean(value, gtk_widget_get_sensitive(self->btExportSaveAs));
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
+static void visu_ui_value_io_set_property(GObject* obj, guint property_id,
+                                          const GValue *value, GParamSpec *pspec)
+{
+  VisuUiValueIo *self = VISU_UI_VALUE_IO(obj);
+
+  DBG_fprintf(stderr, "Gtk VisuUiValueIo: set property '%s'.\n",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case SAVE_SENSITIVE_PROP:
+      visu_ui_value_io_setSensitiveSave(self, g_value_get_boolean(value));
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
 
 
 static void visu_ui_value_io_init(VisuUiValueIo *valueio)
@@ -175,13 +240,15 @@ static void buildWidgets(VisuUiValueIo *valueio, GtkWindow *parent,
 			 const gchar*tipsSaveAs)
 {
   GtkFileFilter *filter1, *filter2;
-  char *directory;
+  const gchar *directory;
 #if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 12
   GtkTooltips *tooltips;
 
   tooltips = gtk_tooltips_new();
 #endif
 
+  gtk_box_set_spacing(GTK_BOX(valueio), 2);
+  
   valueio->parent = parent;
 
   /* The save as button. */
@@ -189,7 +256,7 @@ static void buildWidgets(VisuUiValueIo *valueio, GtkWindow *parent,
   gtk_widget_set_tooltip_text(valueio->btExportSaveAs, tipsSaveAs);
   gtk_widget_set_sensitive(valueio->btExportSaveAs, FALSE);
   gtk_container_add(GTK_CONTAINER(valueio->btExportSaveAs),
-		    gtk_image_new_from_stock(GTK_STOCK_SAVE_AS, GTK_ICON_SIZE_MENU));
+		    gtk_image_new_from_icon_name("document-save-as", GTK_ICON_SIZE_MENU));
   gtk_box_pack_end(GTK_BOX(valueio), valueio->btExportSaveAs, FALSE, FALSE, 0);
 
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
@@ -198,7 +265,7 @@ static void buildWidgets(VisuUiValueIo *valueio, GtkWindow *parent,
   gtk_widget_set_tooltip_text(valueio->btExportSave, tipsSave);
   gtk_widget_set_sensitive(valueio->btExportSave, FALSE);
   gtk_container_add(GTK_CONTAINER(valueio->btExportSave),
-		    gtk_image_new_from_stock(GTK_STOCK_SAVE, GTK_ICON_SIZE_MENU));
+		    gtk_image_new_from_icon_name("document-save", GTK_ICON_SIZE_MENU));
   gtk_box_pack_end(GTK_BOX(valueio), valueio->btExportSave, FALSE, FALSE, 0);
 #endif
 
@@ -228,7 +295,7 @@ static void buildWidgets(VisuUiValueIo *valueio, GtkWindow *parent,
 #endif
 #endif
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
-  directory = visu_ui_getLastOpenDirectory();
+  directory = visu_ui_main_getLastOpenDirectory(visu_ui_main_class_getCurrentPanel());
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(valueio->btExportOpen),
 					directory);
@@ -283,7 +350,7 @@ GtkWidget* visu_ui_value_io_new(GtkWindow *parent, const gchar*tipsOpen,
  */
 void visu_ui_value_io_connectOnOpen(VisuUiValueIo *valueio, VisuUiValueIoCallback open)
 {
-  g_return_if_fail(VISU_UI_IS_VALUE_IO(valueio));
+  g_return_if_fail(VISU_IS_UI_VALUE_IO(valueio));
 
   if (valueio->openSignalId)
     {
@@ -329,7 +396,7 @@ void visu_ui_value_io_connectOnOpen(VisuUiValueIo *valueio, VisuUiValueIoCallbac
  */
 void visu_ui_value_io_connectOnSave(VisuUiValueIo *valueio, VisuUiValueIoCallback save)
 {
-  g_return_if_fail(VISU_UI_IS_VALUE_IO(valueio));
+  g_return_if_fail(VISU_IS_UI_VALUE_IO(valueio));
 
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   if (valueio->saveSignalId)
@@ -356,7 +423,7 @@ static gboolean loadXMLFile(gpointer data)
   gchar *filename;
   GError *error;
 
-  g_return_val_if_fail(VISU_UI_IS_VALUE_IO(data), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_VALUE_IO(data), FALSE);
   g_return_val_if_fail(VISU_UI_VALUE_IO(data)->ioOpen, FALSE);
 
   filename = g_object_get_data(G_OBJECT(data), "filename");
@@ -371,7 +438,6 @@ static gboolean loadXMLFile(gpointer data)
       g_error_free(error);
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
       gtk_file_chooser_unselect_all(GTK_FILE_CHOOSER(VISU_UI_VALUE_IO(data)->btExportOpen));
-      gtk_widget_set_sensitive(VISU_UI_VALUE_IO(data)->btExportSave, FALSE);
 #endif
     }
   g_free(filename);
@@ -435,18 +501,19 @@ static void onOpenXMLClicked(GtkButton *bt _U_, gpointer data)
 gchar* visu_ui_value_io_getFilename(GtkWindow *parent)
 {
   GtkWidget *saveDialog;
-  gchar *filename, *directory;
+  gchar *filename;
+  const gchar *directory;
   GtkFileFilter *filter;
 
   saveDialog = gtk_file_chooser_dialog_new
     (_("Export V_Sim values to a file."), parent,
      GTK_FILE_CHOOSER_ACTION_SAVE,
-     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-     GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT, NULL);
+     TOOL_ICON_CANCEL, GTK_RESPONSE_CANCEL,
+     TOOL_ICON_SAVE, GTK_RESPONSE_ACCEPT, NULL);
   gtk_window_set_modal(GTK_WINDOW(saveDialog), TRUE);
   gtk_window_set_transient_for(GTK_WINDOW(saveDialog), GTK_WINDOW(parent));
   gtk_window_set_position(GTK_WINDOW(saveDialog), GTK_WIN_POS_CENTER_ON_PARENT);
-  directory = visu_ui_getLastOpenDirectory();
+  directory = visu_ui_main_getLastOpenDirectory(visu_ui_main_class_getCurrentPanel());
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(saveDialog), directory);
   gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(saveDialog), FALSE);
@@ -481,7 +548,7 @@ static gboolean saveXMLFile(gpointer data)
   gchar *filename;
   GError *error;
 
-  g_return_val_if_fail(VISU_UI_IS_VALUE_IO(data), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_VALUE_IO(data), FALSE);
   g_return_val_if_fail(VISU_UI_VALUE_IO(data)->ioSave, FALSE);
 
   filename = g_object_get_data(G_OBJECT(data), "filename");
@@ -544,7 +611,7 @@ static void onExportXML(GtkButton *button, gpointer data)
  */
 void visu_ui_value_io_setSensitiveOpen(VisuUiValueIo *valueio, gboolean status)
 {
-  g_return_if_fail(VISU_UI_IS_VALUE_IO(valueio));
+  g_return_if_fail(VISU_IS_UI_VALUE_IO(valueio));
 
   gtk_widget_set_sensitive(valueio->btExportOpen, status);
 }
@@ -561,7 +628,7 @@ void visu_ui_value_io_setSensitiveSave(VisuUiValueIo *valueio, gboolean status)
 {
   gchar *filename;
 
-  g_return_if_fail(VISU_UI_IS_VALUE_IO(valueio));
+  g_return_if_fail(VISU_IS_UI_VALUE_IO(valueio));
 
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(valueio->btExportOpen));
@@ -570,6 +637,7 @@ void visu_ui_value_io_setSensitiveSave(VisuUiValueIo *valueio, gboolean status)
     g_free(filename);
 #endif
   gtk_widget_set_sensitive(valueio->btExportSaveAs, status);
+  g_object_notify_by_pspec(G_OBJECT(valueio), properties[SAVE_SENSITIVE_PROP]);
 }
 /**
  * visu_ui_value_io_setFilename:
@@ -588,7 +656,7 @@ gboolean visu_ui_value_io_setFilename(VisuUiValueIo *valueio, const gchar *filen
   gboolean valid;
   GError *error;
 
-  g_return_val_if_fail(VISU_UI_IS_VALUE_IO(valueio), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_VALUE_IO(valueio), FALSE);
   g_return_val_if_fail(valueio->ioOpen, FALSE);
   
   error = (GError*)0;
