@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -49,7 +49,6 @@
 #include "interface.h"
 #include "support.h"
 
-#include "visu_object.h"
 #include "visu_tools.h"
 #include "visu_basic.h"
 #include "visu_plugins.h"
@@ -316,6 +315,7 @@ static void buildPluginsTab(VisuUiMain *main)
   gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(liststore),
 				       GTK_PLUGINS_COLUMN_NAME, GTK_SORT_ASCENDING);
 
+  DBG_fprintf(stderr, "Gtk About: plugins:\n");
   for (pnt = visu_plugins_getListLoaded(); pnt; pnt = g_list_next(pnt))
     {
       plug = (VisuPlugin*)pnt->data;
@@ -331,6 +331,9 @@ static void buildPluginsTab(VisuUiMain *main)
 			 GTK_PLUGINS_COLUMN_DESCRIPTION, visu_plugin_getDescription(plug),
 			 GTK_PLUGINS_COLUMN_AUTHORS, visu_plugin_getAuthors(plug),
 			 -1);
+      DBG_fprintf(stderr, " - %s (%s) from %s\n",
+                  visu_plugin_getName(plug), visu_plugin_getDescription(plug),
+                  visu_plugin_getAuthors(plug));
     }
 
   /* Build the treeview. */
@@ -497,6 +500,7 @@ static void aboutXML_end(GMarkupParseContext *context _U_,
   g_return_if_fail(user_data);
   text = GTK_TEXT_BUFFER(user_data);
 
+  DBG_fprintf(stderr, "ChangeLog parser: close '%s' element.\n", element_name);
   if (!strcmp(element_name, PICK_PARSER_ELEMENT_MILESTONE))
     startAbout = FALSE;
   else if (!strcmp(element_name, PICK_PARSER_ELEMENT_ENTRY) && startAbout)
@@ -563,6 +567,8 @@ static void setChangelog(const gchar* buffer, gssize size, GtkTextBuffer *text)
   /* Free buffers. */
   g_markup_parse_context_free(xmlContext);
 
+  DBG_fprintf(stderr, "ChangeLog parser: done, status %d (%s).\n",
+              status, (error)?error->message:"no error");
   if (!status && error)
     g_warning("%s", error->message);
 
