@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -48,7 +48,6 @@
 #include "gtk_interactive.h"
 #include "gtk_main.h"
 #include "visu_gtk.h"
-#include "visu_object.h"
 
 #include "gtk_pick.h"
 #include "gtk_move.h"
@@ -90,36 +89,29 @@ typedef struct ActionInterface_
 static ActionInterface* currentAction;
 static guint n_actions = 0;
 static GList *actions;
-static VisuInteractive *interObserve;
-static gulong angles_signal, trans_signal, gross_signal, persp_signal;
+static VisuInteractive *interObserve = NULL;
+static GBinding *theta_bind, *phi_bind, *omega_bind;
+static GBinding *xs_bind, *ys_bind, *gross_bind, *persp_bind;
 
 /* Callbacks. */
 static gboolean onHomePressed(GtkWidget *widget _U_, GdkEventKey *event,
 			      gpointer data);
-static void onDataReady(GObject *obj, VisuData *dataObj,
-                        VisuGlView *view, gpointer data);
-static void onDataNotReady(GObject *obj, VisuData *dataObj,
-                           VisuGlView *view, gpointer data);
+static void onDataNotify(GtkButton *button, GParamSpec *pspec, VisuGlNodeScene *scene);
 static void observeMethodChanged(GtkToggleButton* button, gpointer data);
 static void radioObserveToggled(GtkToggleButton *togglebutton, gpointer user_data);
 static void onCloseButtonClicked(GtkButton *button, gpointer user_data);
-static void onCameraChanged(VisuGlView *view, gpointer data);
 static void onTabActionChanged(GtkNotebook *book, GtkWidget *child,
 			       gint num, gpointer data);
 static void onVisuUiOrientationChooser(GtkButton *button, gpointer data);
-static void onAngleChanged(GtkSpinButton *spin, gpointer data);
-static void onTranslationChanged(GtkSpinButton *spin, gpointer data);
-static void onZoomChanged(GtkSpinButton *spin, gpointer data);
-static void onPerspChanged(GtkSpinButton *spin, gpointer data);
 static gboolean onKillWindowEvent(GtkWidget *widget, GdkEvent *event,
 				  gpointer user_data);
 static void onRadioToggled(GtkToggleButton *toggle, gpointer data);
 static void onObserveStart(VisuUiRenderingWindow *window);
 static void onObserveStop(VisuUiRenderingWindow *window);
-static void onObserveClickStop(VisuInteractive *inter _U_, gpointer data);
 
 /* Local methods. */
-static void connectSignalsObservePick();
+static void _setGlView(VisuGlView *view);
+static void connectSignalsObservePick(VisuUiRenderingWindow *window);
 static void setNamesGtkWidgetObservePick(VisuUiMain *main);
 static GtkWidget* gtkObserveBuild_interface(VisuUiMain *main, gchar **label,
 					    gchar **help, GtkWidget **radio);
@@ -127,10 +119,7 @@ static GtkWidget* gtkObserveBuild_interface(VisuUiMain *main, gchar **label,
 /* Widgets */
 static GtkWidget *observeWindow, *infoBar;
 static GtkWidget *orientationChooser;
-static GtkWidget *spinTheta, *spinPhi, *spinOmega;
-static GtkWidget *spinXs, *spinYs;
-static GtkWidget *spinGross;
-static GtkWidget *spinPersp;
+static GtkWidget *spinOmega;
 
 
 /* Help message used in the help area. */
@@ -155,14 +144,14 @@ void visu_ui_interactive_init()
   actions = (GList*)0;
 
   visu_ui_interactive_addAction(gtkObserveBuild_interface,
-			   onObserveStart, onObserveStop);
+                                onObserveStart, onObserveStop);
   currentAction = (ActionInterface*)actions->data;
 
   visu_ui_interactive_addAction(visu_ui_interactive_pick_initBuild,
-			   visu_ui_interactive_pick_start, visu_ui_interactive_pick_stop);
+                                visu_ui_interactive_pick_start, visu_ui_interactive_pick_stop);
 
   visu_ui_interactive_addAction(visu_ui_interactive_move_initBuild,
-			   visu_ui_interactive_move_start, visu_ui_interactive_move_stop);
+                                visu_ui_interactive_move_start, visu_ui_interactive_move_stop);
 }
 
 /**
@@ -217,24 +206,28 @@ void visu_ui_interactive_initBuild(VisuUiMain *main)
 {
   GtkWidget *labelHelp, *wd;
   VisuUiRenderingWindow *window;
-  VisuData *data;
+  VisuGlNodeScene *scene;
   VisuGlView *view;
   GList *tmpLst;
   ActionInterface *action;
   gchar *msg;
   GSList *lst;
  
-  window = visu_ui_main_class_getDefaultRendering();
-  data = visu_ui_rendering_window_getData(window);
-  view = visu_ui_rendering_window_getGlView(window);
+  window = visu_ui_main_getRendering(main);
+  scene = visu_ui_rendering_window_getGlScene(window);
+  view = visu_gl_node_scene_getGlView(scene);
+
+  DBG_fprintf(stderr, "Gtk Interactive: init build.\n");
 
   interObserve = visu_interactive_new(interactive_observe);
-  g_object_ref(G_OBJECT(interObserve));
-  g_signal_connect(G_OBJECT(interObserve), "stop",
-		   G_CALLBACK(onObserveClickStop), (gpointer)window);
+  g_signal_connect_swapped(G_OBJECT(interObserve), "stop",
+                           G_CALLBACK(visu_ui_interactive_toggle), (gpointer)0);
 
   DBG_fprintf(stderr, "Gtk observePick: creating the window.\n");
   main->interactiveDialog = create_observeDialog();
+  gtk_window_set_default_size(GTK_WINDOW(main->interactiveDialog), 100, -1);
+  g_signal_connect_swapped(G_OBJECT(main->interactiveDialog), "destroy",
+                           G_CALLBACK(g_object_unref), interObserve);
   observeWindow = main->interactiveDialog;
   gtk_window_set_type_hint(GTK_WINDOW(main->interactiveDialog),
 			   GDK_WINDOW_TYPE_HINT_NORMAL);
@@ -275,11 +268,11 @@ void visu_ui_interactive_initBuild(VisuUiMain *main)
   infoBar = gtk_info_bar_new();
   gtk_widget_set_no_show_all(infoBar, TRUE);
   gtk_info_bar_add_button(GTK_INFO_BAR(infoBar),
-                          GTK_STOCK_OK, GTK_RESPONSE_OK);
+                          _("_Ok"), GTK_RESPONSE_OK);
   g_signal_connect(infoBar, "response",
                    G_CALLBACK(gtk_widget_hide), NULL);
   wd = gtk_label_new("");
-  gtk_misc_set_alignment(GTK_MISC(wd), 0., 0.5);
+  gtk_label_set_xalign(GTK_LABEL(wd), 0.);
   gtk_container_add(GTK_CONTAINER(gtk_info_bar_get_content_area(GTK_INFO_BAR(infoBar))), wd);
   gtk_widget_show(wd);
 #else
@@ -290,16 +283,21 @@ void visu_ui_interactive_initBuild(VisuUiMain *main)
                    infoBar, FALSE, FALSE, 2);
 
   /* connect the signals to the spins. */
-  connectSignalsObservePick(main);
+  connectSignalsObservePick(window);
+  theta_bind = NULL;
+  phi_bind   = NULL;
+  omega_bind = NULL;
+  xs_bind    = NULL;
+  ys_bind    = NULL;
+  gross_bind = NULL;
+  persp_bind = NULL;
 
   DBG_fprintf(stderr, "Gtk Interactive: Setup initial values.\n");
-  if (data)
-    {
-      visu_interactive_apply(interObserve, VISU_NODE_ARRAY(data));
-      onDataReady((GObject*)0, data, view, (gpointer)0);
-    }
-  /* set the initial values for the spins. */
-  onCameraChanged(view, (gpointer)0);
+  _setGlView(view);
+
+  g_signal_connect_object(scene, "notify::data", G_CALLBACK(onDataNotify),
+                          lookup_widget(observeWindow, "buttonBackToCommandPanel"),
+                          G_CONNECT_SWAPPED);
 }
 
 /**
@@ -310,7 +308,7 @@ void visu_ui_interactive_initBuild(VisuUiMain *main)
  *
  * Since: 3.6
  */
-void visu_ui_interactive_toggle()
+void visu_ui_interactive_toggle(void)
 {
   GtkWidget *wd;
   guint id;
@@ -339,18 +337,21 @@ void visu_ui_interactive_start(VisuUiRenderingWindow *window)
 {
   DBG_fprintf(stderr, "Gtk Interactive: initialise session.\n");
 
-  /* We empty the status bar. */
   visu_ui_rendering_window_pushMessage(window, "");
-
-  /* We start the new mode. */
   currentAction->onStart(window);
 }
 
-static void gtkInteractiveStop()
+/**
+ * visu_ui_interactive_stop:
+ * @window: a #VisuUiRenderingWindow object.
+ *
+ * Stop the observe and pick session from @window.
+ *
+ * Since: 3.8
+ **/
+void visu_ui_interactive_stop(VisuUiRenderingWindow *window)
 {
-  VisuUiRenderingWindow *window;
-
-  window = visu_ui_main_class_getDefaultRendering();
+  DBG_fprintf(stderr, "Gtk Interactive: stop session.\n");
 
   visu_ui_rendering_window_popMessage(window);
   currentAction->onStop(window);
@@ -392,21 +393,20 @@ void visu_ui_interactive_unsetMessage()
 }
 
 static gboolean onKillWindowEvent(GtkWidget *widget _U_, GdkEvent *event _U_,
-				  gpointer user_data _U_)
+				  gpointer user_data)
 {
   DBG_fprintf(stderr, "Gtk interactive: window killed.\n");
 
-  gtkInteractiveStop();
-
+  visu_ui_interactive_stop(VISU_UI_RENDERING_WINDOW(user_data));
   return FALSE;
 }
-static void onCloseButtonClicked(GtkButton *button _U_, gpointer user_data _U_)
+static void onCloseButtonClicked(GtkButton *button _U_, gpointer user_data)
 {
   DBG_fprintf(stderr, "Gtk interactive: click on close button.\n");
 
   if (!gtk_widget_get_visible(observeWindow))
     return;
-  gtkInteractiveStop();
+  visu_ui_interactive_stop(VISU_UI_RENDERING_WINDOW(user_data));
 }
 
 /****************/
@@ -414,22 +414,18 @@ static void onCloseButtonClicked(GtkButton *button _U_, gpointer user_data _U_)
 /****************/
 
 /* Connect the listeners on the signal emitted by the OpenGL server. */
-static void connectSignalsObservePick()
+static void connectSignalsObservePick(VisuUiRenderingWindow *window)
 {
   GtkWidget *wd;
 
   g_signal_connect(G_OBJECT(observeWindow), "delete-event",
-		   G_CALLBACK(onKillWindowEvent), (gpointer)0);
+		   G_CALLBACK(onKillWindowEvent), window);
   g_signal_connect(G_OBJECT(observeWindow), "destroy-event",
-		   G_CALLBACK(onKillWindowEvent), (gpointer)0);
+		   G_CALLBACK(onKillWindowEvent), window);
 
   wd = lookup_widget(observeWindow, "buttonBackToCommandPanel");
   g_signal_connect(G_OBJECT(wd), "clicked",
-		   G_CALLBACK(onCloseButtonClicked), (gpointer)0);
-  g_signal_connect(VISU_OBJECT_INSTANCE, "dataRendered",
-		   G_CALLBACK(onDataReady), (gpointer)wd);
-  g_signal_connect(VISU_OBJECT_INSTANCE, "dataUnRendered",
-		   G_CALLBACK(onDataNotReady), (gpointer)wd);
+		   G_CALLBACK(onCloseButtonClicked), window);
   wd = lookup_widget(observeWindow, "radioObserve");
   g_signal_connect(G_OBJECT(wd), "toggled",
 		   G_CALLBACK(radioObserveToggled), (gpointer)0);
@@ -439,27 +435,6 @@ static void connectSignalsObservePick()
 		   G_CALLBACK(onVisuUiOrientationChooser), (gpointer)0);
 
   /* The observe widgets. */
-  wd = lookup_widget(observeWindow, "spinTheta");
-  g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(VISU_GL_CAMERA_THETA));
-  wd = lookup_widget(observeWindow, "spinPhi");
-  g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(VISU_GL_CAMERA_PHI));
-  wd = lookup_widget(observeWindow, "spinOmega");
-  g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onAngleChanged), GINT_TO_POINTER(VISU_GL_CAMERA_OMEGA));
-  wd = lookup_widget(observeWindow, "spinDx");
-  g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onTranslationChanged), GINT_TO_POINTER(VISU_GL_CAMERA_XS));
-  wd = lookup_widget(observeWindow, "spinDy");
-  g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onTranslationChanged), GINT_TO_POINTER(VISU_GL_CAMERA_YS));
-  wd = lookup_widget(observeWindow, "spinGross");
-  g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onZoomChanged), (gpointer)0);
-  wd = lookup_widget(observeWindow, "spinPersp");
-  g_signal_connect(G_OBJECT(wd), "value_changed",
-		   G_CALLBACK(onPerspChanged), (gpointer)0);
   wd = lookup_widget(observeWindow, "radioObserveConstrained");
   g_signal_connect(G_OBJECT(wd), "toggled", G_CALLBACK(observeMethodChanged),
 		   GINT_TO_POINTER(interactive_constrained));
@@ -472,42 +447,76 @@ static void connectSignalsObservePick()
 		   G_CALLBACK(onTabActionChanged), (gpointer)0);
 }
 
-static void onDataReady(GObject *obj _U_, VisuData *dataObj,
-                        VisuGlView *view, gpointer data)
+static void _setGlView(VisuGlView *view)
 {
-  if (!dataObj)
-    gtk_button_clicked(GTK_BUTTON(data));
+  if (theta_bind)
+    g_object_unref(theta_bind);
+  theta_bind = (GBinding*)0;
+  if (phi_bind)
+    g_object_unref(phi_bind);
+  phi_bind = (GBinding*)0;
+  if (omega_bind)
+    g_object_unref(omega_bind);
+  omega_bind = (GBinding*)0;
+  if (xs_bind)
+    g_object_unref(xs_bind);
+  xs_bind = (GBinding*)0;
+  if (ys_bind)
+    g_object_unref(ys_bind);
+  ys_bind = (GBinding*)0;
+  if (gross_bind)
+    g_object_unref(gross_bind);
+  gross_bind = (GBinding*)0;
+  if (persp_bind)
+    g_object_unref(persp_bind);
+  persp_bind = (GBinding*)0;
 
-  if (dataObj && view)
+  if (view)
     {
-      angles_signal =
-        g_signal_connect(G_OBJECT(view), "ThetaPhiOmegaChanged",
-                         G_CALLBACK(onCameraChanged), (gpointer)0);
-      trans_signal =
-        g_signal_connect(G_OBJECT(view), "XsYsChanged",
-                         G_CALLBACK(onCameraChanged), (gpointer)0);
-      gross_signal =
-        g_signal_connect(G_OBJECT(view), "GrossChanged",
-                         G_CALLBACK(onCameraChanged), (gpointer)0);
-      persp_signal =
-        g_signal_connect(G_OBJECT(view), "PerspChanged",
-                         G_CALLBACK(onCameraChanged), (gpointer)0);
+      theta_bind = g_object_bind_property(view, "theta",
+                                          lookup_widget(observeWindow,
+                                                        "spinTheta"), "value",
+                                          G_BINDING_BIDIRECTIONAL |
+                                          G_BINDING_SYNC_CREATE);
+      phi_bind   = g_object_bind_property(view, "phi",
+                                          lookup_widget(observeWindow,
+                                                        "spinPhi"), "value",
+                                          G_BINDING_BIDIRECTIONAL |
+                                          G_BINDING_SYNC_CREATE);
+      omega_bind = g_object_bind_property(view, "omega",
+                                          lookup_widget(observeWindow,
+                                                        "spinOmega"), "value",
+                                          G_BINDING_BIDIRECTIONAL |
+                                          G_BINDING_SYNC_CREATE);
+      xs_bind    = g_object_bind_property(view, "trans-x",
+                                          lookup_widget(observeWindow,
+                                                        "spinDx"), "value",
+                                          G_BINDING_BIDIRECTIONAL |
+                                          G_BINDING_SYNC_CREATE);
+      ys_bind    = g_object_bind_property(view, "trans-y",
+                                          lookup_widget(observeWindow,
+                                                        "spinDy"), "value",
+                                          G_BINDING_BIDIRECTIONAL |
+                                          G_BINDING_SYNC_CREATE);
+      gross_bind = g_object_bind_property(view, "zoom",
+                                          lookup_widget(observeWindow,
+                                                        "spinGross"), "value",
+                                          G_BINDING_BIDIRECTIONAL |
+                                          G_BINDING_SYNC_CREATE);
+      persp_bind = g_object_bind_property(view, "perspective",
+                                          lookup_widget(observeWindow,
+                                                        "spinPersp"), "value",
+                                          G_BINDING_BIDIRECTIONAL |
+                                          G_BINDING_SYNC_CREATE);
     }
 }
-static void onDataNotReady(GObject *obj _U_, VisuData *dataObj _U_,
-                           VisuGlView *view, gpointer data _U_)
+
+static void onDataNotify(GtkButton *button, GParamSpec *pspec _U_, VisuGlNodeScene *scene)
 {
-  DBG_fprintf(stderr, "Gtk Interactive: caught the 'dataUnRendered' signal.\n");
-  g_signal_handler_disconnect(G_OBJECT(view), angles_signal);
-  g_signal_handler_disconnect(G_OBJECT(view), trans_signal);
-  g_signal_handler_disconnect(G_OBJECT(view), gross_signal);
-  g_signal_handler_disconnect(G_OBJECT(view), persp_signal);
+  if (!visu_gl_node_scene_getData(scene))
+    gtk_button_clicked(button);
 }
 
-static void onObserveClickStop(VisuInteractive *inter _U_, gpointer data)
-{
-  visu_ui_interactive_toggle(VISU_UI_RENDERING_WINDOW(data));
-}
 static void onObserveStart(VisuUiRenderingWindow *window)
 {
   visu_ui_rendering_window_pushInteractive(window, interObserve);
@@ -529,32 +538,15 @@ static void observeMethodChanged(GtkToggleButton* button, gpointer data)
   if (method == interactive_constrained)
     {
       gtk_widget_set_sensitive(spinOmega, FALSE);
-      if (visu_gl_view_setThetaPhiOmega(visu_ui_rendering_window_getGlView
-                                        (visu_ui_main_class_getDefaultRendering()),
-                                        0., 0., 0., VISU_GL_CAMERA_OMEGA))
-	VISU_REDRAW_ADD;
+      g_object_set(visu_gl_node_scene_getGlView(visu_ui_rendering_window_getGlScene
+                                                (visu_ui_main_class_getDefaultRendering())),
+                   "omega", 0., NULL);
     }
   else
     gtk_widget_set_sensitive(spinOmega, TRUE);
 }
 
 
-/* Ask the OpenGL server to refresh the values of the spins
-   controlling the position of the camera. */
-static void onCameraChanged(VisuGlView *view, gpointer data _U_)
-{
-  g_return_if_fail(view && view->camera);
-
-  DBG_fprintf(stderr, "Gtk Observe/pick : set values of spins.\n");
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinTheta), (gdouble)view->camera->theta);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPhi),   (gdouble)view->camera->phi);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinOmega), (gdouble)view->camera->omega);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinXs),    (gdouble)view->camera->xs);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinYs),    (gdouble)view->camera->ys);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinGross), (gdouble)view->camera->gross);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPersp), (gdouble)view->camera->d_red);
-}
-
 /* Give a name to the widgets present in this window
    to be able to affect them with a theme. */
 static void setNamesGtkWidgetObservePick(VisuUiMain *main)
@@ -580,13 +572,7 @@ static void setNamesGtkWidgetObservePick(VisuUiMain *main)
   wd = lookup_widget(main->interactiveDialog, "radioMove");
   gtk_widget_set_name(wd, "message_radio");
 
-  spinTheta = lookup_widget(main->interactiveDialog, "spinTheta");
-  spinPhi = lookup_widget(main->interactiveDialog, "spinPhi");
   spinOmega = lookup_widget(main->interactiveDialog, "spinOmega");
-  spinXs = lookup_widget(main->interactiveDialog, "spinDx");
-  spinYs = lookup_widget(main->interactiveDialog, "spinDy");
-  spinGross = lookup_widget(main->interactiveDialog, "spinGross");
-  spinPersp = lookup_widget(main->interactiveDialog, "spinPersp");
 
   method = visu_interactive_class_getPreferedObserveMethod();
   if (method == interactive_constrained)
@@ -620,67 +606,6 @@ static gboolean onHomePressed(GtkWidget *widget _U_, GdkEventKey *event,
     }
   return FALSE;
 }
-static void onAngleChanged(GtkSpinButton *spin, gpointer data)
-{
-  int reDrawNeeded;
-
-  if (!gtk_window_is_active(GTK_WINDOW(observeWindow)))
-    return;
-
-  reDrawNeeded =
-    visu_gl_view_setThetaPhiOmega(visu_ui_rendering_window_getGlView
-                                  (visu_ui_main_class_getDefaultRendering()),
-                                  (float)gtk_spin_button_get_value(spin),
-                                  (float)gtk_spin_button_get_value(spin),
-                                  (float)gtk_spin_button_get_value(spin),
-                                  GPOINTER_TO_INT(data));
-  if (reDrawNeeded)
-    VISU_REDRAW_ADD;
-}
-static void onTranslationChanged(GtkSpinButton *spin, gpointer data)
-{
-  int reDrawNeeded;
-
-  if (!gtk_window_is_active(GTK_WINDOW(observeWindow)))
-    return;
-
-  reDrawNeeded =
-    visu_gl_view_setXsYs(visu_ui_rendering_window_getGlView
-                         (visu_ui_main_class_getDefaultRendering()),
-                         (float)gtk_spin_button_get_value(spin),
-                         (float)gtk_spin_button_get_value(spin),
-                         GPOINTER_TO_INT(data));
-  if (reDrawNeeded)
-    VISU_REDRAW_ADD;
-}
-static void onZoomChanged(GtkSpinButton *spin, gpointer data _U_)
-{
-  int reDrawNeeded;
-
-  if (!gtk_window_is_active(GTK_WINDOW(observeWindow)))
-    return;
-
-  reDrawNeeded =
-    visu_gl_view_setGross(visu_ui_rendering_window_getGlView
-                          (visu_ui_main_class_getDefaultRendering()),
-                          (float)gtk_spin_button_get_value(spin));
-  if (reDrawNeeded)
-    VISU_REDRAW_ADD;
-}
-static void onPerspChanged(GtkSpinButton *spin, gpointer data _U_)
-{
-  int reDrawNeeded;
-
-  if (!gtk_window_is_active(GTK_WINDOW(observeWindow)))
-    return;
-
-  reDrawNeeded =
-    visu_gl_view_setPersp(visu_ui_rendering_window_getGlView
-                          (visu_ui_main_class_getDefaultRendering()),
-                          (float)gtk_spin_button_get_value(spin));
-  if (reDrawNeeded)
-    VISU_REDRAW_ADD;
-}
 
 static void onRadioToggled(GtkToggleButton *toggle, gpointer data)
 {
@@ -740,40 +665,29 @@ static void onOrientationChanged(VisuUiOrientationChooser *orientationChooser,
 				 gpointer data _U_)
 {
   float values[2];
-  gboolean reDrawNeeded;
 
   DBG_fprintf(stderr, "Gtk Observe: orientation changed.\n");
   visu_ui_orientation_chooser_getAnglesValues(orientationChooser, values);
 
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinTheta), values[0]);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPhi), values[1]);
-
-  reDrawNeeded =
-    visu_gl_view_setThetaPhiOmega(visu_ui_rendering_window_getGlView
-                                  (visu_ui_main_class_getDefaultRendering()),
-                                  values[0], values[1], 0.,
-                                  VISU_GL_CAMERA_THETA | VISU_GL_CAMERA_PHI);
-  if (reDrawNeeded)
-    VISU_REDRAW_ADD;
+  g_object_set(visu_gl_node_scene_getGlView(visu_ui_rendering_window_getGlScene
+                                            (visu_ui_main_class_getDefaultRendering())),
+               "theta", values[0], "phi", values[1], NULL);
 }
 static void onVisuUiOrientationChooser(GtkButton *button _U_, gpointer data _U_)
 {
   float values[2];
-  gboolean reDrawNeeded;
   VisuUiRenderingWindow *window;
-  VisuData *dataObj;
   VisuGlView *view;
 
   window = visu_ui_main_class_getDefaultRendering();
-  dataObj = visu_ui_rendering_window_getData(window);
-  view = visu_ui_rendering_window_getGlView(window);
+  view = visu_gl_node_scene_getGlView(visu_ui_rendering_window_getGlScene(window));
   if (!orientationChooser)
     {
       orientationChooser = visu_ui_orientation_chooser_new
-	(VISU_UI_ORIENTATION_DIRECTION, TRUE, dataObj, GTK_WINDOW(observeWindow));
+	(VISU_UI_ORIENTATION_DIRECTION, TRUE, VISU_BOXED(view), GTK_WINDOW(observeWindow));
 /*       gtk_window_set_modal(GTK_WINDOW(orientationChooser), TRUE); */
-      values[0] = (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinTheta));
-      values[1] = (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinPhi));
+      values[0] = (float)view->camera.theta;
+      values[1] = (float)view->camera.phi;
       visu_ui_orientation_chooser_setAnglesValues(VISU_UI_ORIENTATION_CHOOSER(orientationChooser),
 					 values);
       g_signal_connect(G_OBJECT(orientationChooser), "values-changed",
@@ -790,13 +704,7 @@ static void onVisuUiOrientationChooser(GtkButton *button _U_, gpointer data _U_)
       break;
     default:
       DBG_fprintf(stderr, "Gtk Observe: reset values on orientation.\n");
-      gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinTheta), values[0]);
-      gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPhi), values[1]);
-      reDrawNeeded = visu_gl_view_setThetaPhiOmega
-	(view, values[0], values[1], 0.,
-         VISU_GL_CAMERA_THETA | VISU_GL_CAMERA_PHI);
-      if (reDrawNeeded)
-	VISU_REDRAW_ADD;
+      g_object_set(view, "theta", values[0], "phi", values[1], NULL);
     }
   DBG_fprintf(stderr, "Gtk Observe: orientation object destroy.\n");
   gtk_widget_destroy(orientationChooser);
