@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2006)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -45,12 +45,13 @@
 #include <config.h>
 #endif
 
-#include "gtk/gtk.h"
+#include <cairo.h>
+#include <gtk/gtk.h>
 
 #include <GL/gl.h>
 #include <GL/glu.h>
 
-#include "support.h"
+#include "visu_basic.h"
 #include "gtk_openGLWidget.h"
 #include "OSOpenGL/visu_openGL.h"
 #include "visu_tools.h"
@@ -102,11 +103,10 @@ struct _VisuUiGlWidget
   gboolean dispose_has_run;
 
   /* Redraw method and user data. */
-  VisuUiGlWidgetRedrawMethod redraw;
-  VisuGlView *redrawView;
+  VisuGlExtSet *model;
 
   /* Default background pixbuf. */
-  GdkPixbuf *backLogo;
+  cairo_surface_t *backLogo;
 
   /* OpenGL part, OS dependent. */
   gboolean isContextDirect;
@@ -157,13 +157,15 @@ static void visu_ui_gl_widgetEvent_getHeight(GtkWidget *widget, gint *minHeight,
 static gboolean visu_ui_gl_widgetEvent_visibility(GtkWidget *widget, GdkEventVisibility *event);
 static void visu_ui_gl_widgetEvent_sizeAllocate(GtkWidget *widget, GtkAllocation *allocation);
 static void visu_ui_gl_widgetEvent_realise(GtkWidget *widget);
+static void drawToGl(VisuUiGlWidget *render);
+static void drawToEmpty(VisuUiGlWidget *render, cairo_t *cr);
+static void swapGl(VisuUiGlWidget *render);
 
 /* Initialisation methods. */
 static void visu_ui_gl_widgetInit_context(VisuUiGlWidget *render, gboolean contextIsDirect);
 
 /* Freeing methods. */
 static void visu_ui_gl_widgetEvent_dispose(GObject *obj);
-static void visu_ui_gl_widgetEvent_finalize(GObject *obj);
 static void visu_ui_gl_widgetFree_openGL(VisuUiGlWidget *render);
 
 /* Miscellaneous methods. */
@@ -182,7 +184,6 @@ static void visu_ui_gl_widget_class_init(VisuUiGlWidgetClass *class)
   /* Dealing with GObject events. */
   gobject_class = G_OBJECT_CLASS(class);
   gobject_class->dispose  = visu_ui_gl_widgetEvent_dispose;
-  gobject_class->finalize = visu_ui_gl_widgetEvent_finalize;
 
   /* Dealing with widget events. */
   widget_class = GTK_WIDGET_CLASS(class);
@@ -209,10 +210,9 @@ static void visu_ui_gl_widget_init(VisuUiGlWidget *render)
   render->sizeAllocation_has_run = FALSE;
   render->dispose_has_run = FALSE;
 
-  render->redraw = (VisuUiGlWidgetRedrawMethod)0;
-  render->redrawView  = (VisuGlView*)0;
+  render->model = (VisuGlExtSet*)0;
 
-  render->backLogo = (GdkPixbuf*)0;
+  render->backLogo = (cairo_surface_t*)0;
 
   render->isContextDirect = FALSE;
   render->visual   = (GdkVisual*)0;
@@ -234,7 +234,9 @@ static void visu_ui_gl_widget_init(VisuUiGlWidget *render)
 
   /* Cancel the GTK double buffering since it is taken into
      account by OpenGL itself. */
+#if GTK_MAJOR_VERSION < 3 || (GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 14)
   gtk_widget_set_double_buffered(GTK_WIDGET(render), FALSE);
+#endif
   gtk_widget_set_has_window(GTK_WIDGET(render), TRUE);
 }
 
@@ -242,7 +244,7 @@ GtkWidget* visu_ui_gl_widget_new(gboolean contextIsDirect)
 {
   VisuUiGlWidget *render;
 
-  render = VISU_UI_GL_WIDGET(g_object_new(VISU_UI_TYPE_GL_WIDGET, NULL));
+  render = VISU_UI_GL_WIDGET(g_object_new(VISU_TYPE_UI_GL_WIDGET, NULL));
 
   render->isContextDirect = contextIsDirect;
 
@@ -252,39 +254,43 @@ GtkWidget* visu_ui_gl_widget_new(gboolean contextIsDirect)
 /* Methods to deals with the events. */
 static void visu_ui_gl_widgetEvent_dispose(GObject *obj)
 {
+  VisuUiGlWidget *self;
+
   DBG_fprintf(stderr, "Gtk OpenGL (events) : dispose event for object %p.\n", (gpointer)obj);
 
-  if (VISU_UI_GL_WIDGET(obj)->dispose_has_run)
-    return;
-  VISU_UI_GL_WIDGET(obj)->dispose_has_run = TRUE;
+  self = VISU_UI_GL_WIDGET(obj);
 
-  if (VISU_UI_GL_WIDGET(obj)->backLogo)
-    g_object_unref(VISU_UI_GL_WIDGET(obj)->backLogo);
-  visu_ui_gl_widgetFree_openGL(VISU_UI_GL_WIDGET(obj));
+  if (self->dispose_has_run)
+    return;
+  self->dispose_has_run = TRUE;
+
+  visu_ui_gl_widgetFree_openGL(self);
+
+  if (self->backLogo)
+    cairo_surface_destroy(self->backLogo);
+  if (self->model)
+    g_object_unref(self->model);
 
   /* Chain up to the parent class */
   G_OBJECT_CLASS(visu_ui_gl_widget_parent_class)->dispose(obj);
 }
-static void visu_ui_gl_widgetEvent_finalize(GObject *obj)
-{
-  DBG_fprintf(stderr, "Gtk OpenGL (events): finalize event for object %p.\n", (gpointer)obj);
-
-  /* Chain up to the parent class */
-  G_OBJECT_CLASS(visu_ui_gl_widget_parent_class)->finalize(obj);
-}
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
 static gboolean visu_ui_gl_widgetEvent_expose(GtkWidget *widget, GdkEventExpose *event _U_)
 {
   DBG_fprintf(stderr, "Gtk OpenGL (events): expose event for object %p.\n", (gpointer)widget);
-  visu_ui_gl_widget_redraw(VISU_UI_GL_WIDGET(widget));
+  if (VISU_UI_GL_WIDGET(widget)->model)
+    drawToGl(VISU_UI_GL_WIDGET(widget));
 
   return FALSE;
 }
 #else
-static gboolean visu_ui_gl_widgetEvent_draw(GtkWidget *widget, cairo_t *cr _U_)
+static gboolean visu_ui_gl_widgetEvent_draw(GtkWidget *widget, cairo_t *cr)
 {
   DBG_fprintf(stderr, "Gtk OpenGL (events): draw event for object %p.\n", (gpointer)widget);
-  visu_ui_gl_widget_redraw(VISU_UI_GL_WIDGET(widget));
+  if (VISU_UI_GL_WIDGET(widget)->model)
+    drawToGl(VISU_UI_GL_WIDGET(widget));
+  else
+    drawToEmpty(VISU_UI_GL_WIDGET(widget), cr);
 
   return FALSE;
 }
@@ -295,7 +301,7 @@ static gboolean visu_ui_gl_widgetEvent_visibility(GtkWidget *widget, GdkEventVis
     return FALSE;
 
   DBG_fprintf(stderr, "Gtk OpenGL (events): visibility event for object %p.\n", (gpointer)widget);
-  visu_ui_gl_widget_redraw(VISU_UI_GL_WIDGET(widget));
+  gtk_widget_queue_draw(widget);
   DBG_fprintf(stderr, "Gtk OpenGL (events): visibility OK.\n");
 
   return FALSE;
@@ -427,7 +433,8 @@ static void visu_ui_gl_widgetEvent_realise(GtkWidget *widget)
     GDK_SCROLL_MASK |
     GDK_KEY_PRESS_MASK |
     GDK_POINTER_MOTION_MASK |
-    GDK_POINTER_MOTION_HINT_MASK;
+    GDK_POINTER_MOTION_HINT_MASK |
+    GDK_ENTER_NOTIFY_MASK;
 
 #ifdef IMPL_GTKGLEXT
   attributes_mask = GDK_WA_X | GDK_WA_Y;
@@ -440,17 +447,38 @@ static void visu_ui_gl_widgetEvent_realise(GtkWidget *widget)
   gtk_widget_set_window(widget, window);
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
   gdk_window_set_back_pixmap(window, NULL, FALSE);
-#else
+#elseif GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 22
   gdk_window_set_background_pattern(window, NULL);
 #endif
+#if GTK_MAJOR_VERSION < 3 || (GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 8)
   gdk_window_set_user_data(window, widget);
-
+#else
+  gtk_widget_register_window(widget, window);
+#endif
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  gtk_widget_set_double_buffered(widget, FALSE);
+  G_GNUC_END_IGNORE_DEPRECATIONS
   DBG_fprintf(stderr, "Gtk OpenGL (debug): GdkWindow is %p.\n",
 	      (gpointer)window);
 
+#if GTK_MAJOR_VERSION < 3
   gtk_widget_style_attach(widget);
+#endif
+#if GTK_MAJOR_VERSION < 3 || (GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 4)
   gdk_window_set_background(window,
                             &gtk_widget_get_style(widget)->base[GTK_STATE_NORMAL]);
+#else
+  {
+    GtkCssProvider *css = gtk_css_provider_new();
+    gtk_css_provider_load_from_data(css, "VisuUiGlWidget {background-color: @theme_bg_color;}", -1, (GError**)0);
+    
+    gtk_style_context_add_provider(gtk_widget_get_style_context(widget),
+                                   GTK_STYLE_PROVIDER(css),
+                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
+    g_object_unref(css);
+  }
+#endif
 
   gtk_widget_set_can_focus(widget, TRUE);
   gtk_widget_set_can_default(widget, TRUE);
@@ -485,7 +513,7 @@ VisuUiGlWidget* visu_ui_gl_widget_class_getCurrentContext()
 static void setViewport(VisuUiGlWidget *render, guint width,
 			guint height, gboolean redraw)
 {
-  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
+  g_return_if_fail(VISU_IS_UI_GL_WIDGET(render));
 
   if (VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent != render)
     return;
@@ -499,117 +527,73 @@ static void setViewport(VisuUiGlWidget *render, guint width,
       /* We clear the back buffer and swap because this buffer has
 	 still the wrong size. */
       glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-      visu_ui_gl_widget_swapBuffers(render);
+      swapGl(render);
     }
 }
-static void drawToEmpty(VisuUiGlWidget *render)
+static void drawToEmpty(VisuUiGlWidget *render, cairo_t *cr)
 {
-  int widthImg, heightImg;
-  guchar *imageData;
-  gboolean alpha;
-  int x, y;
-  float rgb[3];
-  int viewport[4];
-  GtkStyle *style;
+  GtkAllocation allocation;
+  gchar *path;
 
   DBG_fprintf(stderr, "Gtk OpenGL (action): Rebuild default background.\n");
 
-  style = gtk_widget_get_style(GTK_WIDGET(render));
-  rgb[0] = (float)style->bg[0].red / 65536.;
-  rgb[1] = (float)style->bg[0].green / 65536.;
-  rgb[2] = (float)style->bg[0].blue / 65536.;
-  DBG_fprintf(stderr, "Gtk OpenGL (action): set background color to (%f,%f,%f).\n",
-	      rgb[0], rgb[1], rgb[2]);
-
+  gtk_widget_get_allocation(GTK_WIDGET(render), &allocation);
+  gtk_render_background(gtk_widget_get_style_context(GTK_WIDGET(render)),
+                        cr, allocation.x, allocation.y, allocation.width, allocation.height);
+  
   if (!render->backLogo)
     {
-      DBG_fprintf(stderr, "Gtk OpenGL (action): load the pixbuf 'logo_grey.png'.\n");
-      render->backLogo = visu_ui_createPixbuf("logo_grey.png");
+      path = g_build_filename(visu_basic_getPixmapsDir(), "logo_grey.png", NULL);
+      render->backLogo = cairo_image_surface_create_from_png(path);
+      g_free(path);
     }
-
-  glPushAttrib(GL_ENABLE_BIT);
-  glClearColor(rgb[0], rgb[1], rgb[2], 0.25f);
-  glDrawBuffer(GL_BACK);
-  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-  if (render->backLogo)
-    {
-      imageData = gdk_pixbuf_get_pixels(render->backLogo);
-      alpha = gdk_pixbuf_get_has_alpha(render->backLogo);
-      widthImg = gdk_pixbuf_get_width(render->backLogo);
-      heightImg = gdk_pixbuf_get_height(render->backLogo);
-
-      glDisable(GL_FOG);
-      glEnable(GL_BLEND);
-      glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-
-      /* We can use fixed value for widthImg and heightImg since we project then
-	 in a 2D ortho with these values. */
-      glGetIntegerv(GL_VIEWPORT, viewport);
-      DBG_fprintf(stderr, "Gtk OpenGL (action): Get viewport %dx%d.\n", viewport[2], viewport[3]);
-      x = (viewport[2] - widthImg) / 2;
-      y = (viewport[3] + heightImg) / 2;
-      DBG_fprintf(stderr, "Gtk OpenGL (action): draw at %dx%d.\n", x, y);
-      glMatrixMode(GL_PROJECTION);
-      glPushMatrix();
-      glLoadIdentity();
-      gluOrtho2D(0.0, (float)viewport[2], 0., (float)viewport[3]);
-   
-      glMatrixMode(GL_MODELVIEW);
-      glPushMatrix();
-      glLoadIdentity();
-
-      glRasterPos2i(x, y);
-
-      glPixelZoom(1., -1.);
-      if (alpha)
-	glDrawPixels(widthImg, heightImg, GL_RGBA, GL_UNSIGNED_BYTE, imageData);
-      else
-	glDrawPixels(widthImg, heightImg, GL_RGB, GL_UNSIGNED_BYTE, imageData);
-      glPixelZoom(1., 1.);
-
-      glPopMatrix();
-      glMatrixMode(GL_PROJECTION);
-      glPopMatrix();
-      glMatrixMode(GL_MODELVIEW);
-    }
-  glPopAttrib();
+  cairo_set_source_surface(cr, render->backLogo, allocation.x + allocation.width / 2 - cairo_image_surface_get_width(render->backLogo) / 2,
+                           allocation.y + allocation.height / 2 - cairo_image_surface_get_height(render->backLogo) / 2);
+  cairo_paint(cr);
 }
 /**
- * visu_ui_gl_widget_setRedraw:
+ * visu_ui_gl_widget_setModel:
  * @render: a #VisuUiGlWidget object ;
- * @method: (scope call): a redraw method ;
- * @view: the #VisuGlView object.
+ * @model: a #VisuGlExtSet object.
  *
  * This method is used to defined a redraw method for the OpenGL area. By doing this
  * the area will automatically redraw itself when necessary. Before doing it
  * it calls visu_ui_gl_widget_setCurrent(), and after it calls
- * visu_ui_gl_widget_swapBuffers().
+ * swapGl().
  */
-void visu_ui_gl_widget_setRedraw(VisuUiGlWidget *render,
-                                 VisuUiGlWidgetRedrawMethod method,
-                                 VisuGlView *view)
+void visu_ui_gl_widget_setModel(VisuUiGlWidget *render, VisuGlExtSet *model)
 {
-  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
+  VisuGlExtSet *current;
+
+  g_return_if_fail(VISU_IS_UI_GL_WIDGET(render));
   
   DBG_fprintf(stderr, "Gtk OpenGL (action) : set redraw method for OpenGL area %p.\n", (gpointer)render);
-  render->redraw      = method;
-  render->redrawView  = view;
+
+  if (render->model == model)
+    return;
+
+  current = render->model;
+  render->model = model;
+  
+  if (current)
+    {
+      g_object_unref(current);
+    }
+  if (model)
+    {
+      g_object_ref(model);
+    }
+
+  gtk_widget_queue_draw(GTK_WIDGET(render));
 }
-/**
- * visu_ui_gl_widget_redraw:
- * @render: a #VisuUiGlWidget object.
- *
- * Force redraw on the given surface, if a redraw method have been given (see
- * visu_ui_gl_widget_setRedraw()).
- */
-void visu_ui_gl_widget_redraw(VisuUiGlWidget *render)
+static void drawToGl(VisuUiGlWidget *render)
 {
 #if DEBUG == 1
   GTimer *timer;
   gulong fractionTimer;
 #endif
 
-  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
+  g_return_if_fail(VISU_IS_UI_GL_WIDGET(render));
 
 #if DEBUG == 1
   timer = g_timer_new();
@@ -620,12 +604,9 @@ void visu_ui_gl_widget_redraw(VisuUiGlWidget *render)
   DBG_fprintf(stderr, " | set current.\n");
   visu_ui_gl_widget_setCurrent(render, FALSE);
   DBG_fprintf(stderr, " | redraw inside.\n");
-  if (render->redraw)
-    render->redraw(render->redrawView, (GList*)0);
-  else
-    drawToEmpty(render);
+  visu_gl_ext_set_draw(render->model);
   DBG_fprintf(stderr, " | swap buffers.\n");
-  visu_ui_gl_widget_swapBuffers(render);
+  swapGl(render);
 #if DEBUG == 1
   g_timer_stop(timer);
   fprintf(stderr, "Gtk OpenGL: total redraw in %g micro-s.\n",
@@ -633,81 +614,6 @@ void visu_ui_gl_widget_redraw(VisuUiGlWidget *render)
   g_timer_destroy(timer);
 #endif
 }
-/**
- * visu_ui_gl_widget_getPixmapData:
- * @render: a #VisuUiGlWidget object ;
- * @width: a pointer to the desired width or -1 ;
- * @height: a pointer to the desired height or -1 ;
- * @offScreen: a boolean ;
- * @hasAlpha: if TRUE, the returned data is RGBA, else only RGB.
- *
- * Create an image from the OpenGL area. The size can  be changed, using @width and
- * @height. If these pointers contains positive values, then they are used to set the
- * size for the image. If not, the current size is used and stored in these pointers.
- * The boolean offScreen is used to tell if the image is taken from current context
- * or if an offscreen pixmap is created for the rendering.
- *
- * Returns: (transfer full): image data, row by row.
- */
-GArray* visu_ui_gl_widget_getPixmapData(VisuUiGlWidget *render, int *width,
-                                        int *height, gboolean offScreen,
-                                        gboolean hasAlpha)
-{
-  GtkWidget *wd;
-  GArray *image;
-  VisuPixmapContext *dumpData;
-  GtkAllocation allocation;
-
-  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), (GArray*)0);
-  g_return_val_if_fail(VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render, (GArray*)0);
-  g_return_val_if_fail(render->redraw, (GArray*)0);
-  g_return_val_if_fail(width && height, (GArray*)0);
-  g_return_val_if_fail(render->redrawView, (GArray*)0);
-
-  wd = GTK_WIDGET(render);
-  gtk_widget_get_allocation(wd, &allocation);
-
-  if (!offScreen)
-    {
-      *width = allocation.width;
-      *height = allocation.height;
-      return visu_pixmap_getData(*width, *height, hasAlpha);
-    }
-
-  /* If a method is given, then we draw
-     in memory to a pixmap. */
-  *width = (*width > 0)?*width:allocation.width;
-  *height = (*height > 0)?*height:allocation.height;
-  
-  /* We create a pixmap context and make this context current. */
-  dumpData = visu_pixmap_context_new((guint)*width, (guint)*height);
-  if (!dumpData)
-    {
-      /* Switch back to on-screen copy. */
-      g_warning("can't create off-screen pixmap, will screenshot"
-		" the rendering area instead. Make sure that it is"
-		" free of any other windows.");
-      *width = allocation.width;
-      *height = allocation.height;
-      return visu_pixmap_getData(*width, *height, hasAlpha);
-    }
-  /* We set the glViewport of this new context. */
-  visu_gl_initContext();
-  visu_gl_camera_modelize(render->redrawView->camera);
-  visu_gl_view_setViewport(render->redrawView, (guint)*width, (guint)*height);
-  visu_gl_window_project(render->redrawView->window, render->redrawView->camera);
-  visu_gl_ext_rebuildAll();
-  /* We call the given draw method. */
-  render->redraw(render->redrawView, (GList*)0);
-  /* We copy the pixmap into generic data. */
-  image = visu_pixmap_getData((guint)*width, (guint)*height, hasAlpha);
-  /* We change back the context to the current rendering area. */
-  visu_ui_gl_widget_setCurrent(render, TRUE);
-  /* We free the pixmap context. */
-  visu_pixmap_context_free(dumpData);
-
-  return image;
-}
 
 /* OpenGL functions, OS dependent. */
 #ifdef IMPL_GTKGLEXT
@@ -766,7 +672,7 @@ static void visu_ui_gl_widgetInit_context(VisuUiGlWidget *render, gboolean conte
 }
 static void visu_ui_gl_widgetFree_openGL(VisuUiGlWidget *render)
 {
-  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
+  g_return_if_fail(VISU_IS_UI_GL_WIDGET(render));
 
   DBG_fprintf(stderr, "Gtk OpenGL (glext): freeing context & window.\n");
   if (render->glwindow)
@@ -779,7 +685,7 @@ gboolean visu_ui_gl_widget_setCurrent(VisuUiGlWidget *render, gboolean force)
   gboolean res;
   GtkWidget *wd;
   
-  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_GL_WIDGET(render), FALSE);
 
   if (!force && VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render)
     return TRUE;
@@ -804,7 +710,7 @@ gboolean visu_ui_gl_widget_setCurrent(VisuUiGlWidget *render, gboolean force)
 
   return TRUE;
 }
-void visu_ui_gl_widget_swapBuffers(VisuUiGlWidget *render)
+static void swapGl(VisuUiGlWidget *render)
 {
   g_return_if_fail(VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render);
 
@@ -840,7 +746,7 @@ static void visu_ui_gl_widgetSet_pixelFormat(VisuUiGlWidget *render)
     screen = gtk_widget_get_screen(GTK_WIDGET(render));
   else
     screen = gdk_screen_get_default();
-  screenId = gdk_screen_get_number(screen);
+  screenId = gdk_x11_screen_get_screen_number(screen);
   DBG_fprintf(stderr, " | get a screen number %d.\n", screenId);
 
   render->vinfo = visu_gl_getVisualInfo(render->dpy, screenId);
@@ -884,13 +790,20 @@ static void visu_ui_gl_widgetInit_context(VisuUiGlWidget *render, gboolean conte
 }
 static void visu_ui_gl_widgetFree_openGL(VisuUiGlWidget *render)
 {
-  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
+  g_return_if_fail(VISU_IS_UI_GL_WIDGET(render));
 
   if (render->dpy)
     {
-      DBG_fprintf(stderr, "Free (X11): freeing context.\n");
+      DBG_fprintf(stderr, "Free (X11): freeing context (%p).\n",
+                  (gpointer)render->context);
       if (render->context)
-	glXDestroyContext(render->dpy, render->context);
+        {
+          glXMakeCurrent(render->dpy, None, NULL);
+          glXWaitX();
+          glXDestroyContext(render->dpy, render->context);
+        }
+      if (render->vinfo)
+        XFree(render->vinfo);
       /* We do NOT close the display since it is shared
 	 by all the application and thus dpy structure
 	 is unique and will be closed by GTK when quiting. */
@@ -904,12 +817,13 @@ gboolean visu_ui_gl_widget_setCurrent(VisuUiGlWidget *render, gboolean force)
   XID windowId;
   GtkAllocation alloc;
   
-  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_GL_WIDGET(render), FALSE);
 
   if (!force && VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render)
     return TRUE;
 
   DBG_fprintf(stderr, "Gtk OpenGL (X11): unset the context.\n");
+  g_return_val_if_fail(render->dpy, FALSE);
   glXMakeCurrent(render->dpy, None, NULL);
   glXWaitX();
   
@@ -950,7 +864,7 @@ gboolean visu_ui_gl_widget_setCurrent(VisuUiGlWidget *render, gboolean force)
 
   return TRUE;
 }
-void visu_ui_gl_widget_swapBuffers(VisuUiGlWidget *render)
+static void swapGl(VisuUiGlWidget *render)
 {
   g_return_if_fail(VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render);
 
@@ -962,7 +876,7 @@ void visu_ui_gl_widget_swapBuffers(VisuUiGlWidget *render)
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
 static GdkColormap* visu_ui_gl_widgetGet_openGLColormap(VisuUiGlWidget *render)
 {
-  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), (GdkColormap*)0);
+  g_return_val_if_fail(VISU_IS_UI_GL_WIDGET(render), (GdkColormap*)0);
   g_return_val_if_fail(render->vinfo, (GdkColormap*)0);
 
   return gdk_colormap_new(gdkx_visual_get(render->vinfo->visualid), FALSE);
@@ -974,7 +888,7 @@ static void visu_ui_gl_widgetSet_pixelFormat(VisuUiGlWidget *render)
 {
   DBG_fprintf(stderr, "Gtk OpenGL (Win32): choose visual for %p.\n", render);
 
-  render->windowId = (HWND)gdk_win32_drawable_get_handle(GDK_DRAWABLE(GTK_WIDGET(render)->window));
+  render->windowId = (HWND)gdk_win32_window_get_handle(GDK_WINDOW(gtk_widget_get_window(GTK_WIDGET(render))));
   render->hdc = GetDC(render->windowId);
   DBG_fprintf(stderr, " | get the hdc %d.\n", (int)render->hdc);
 
@@ -989,7 +903,7 @@ static void visu_ui_gl_widgetInit_context(VisuUiGlWidget *render, gboolean conte
 }
 static void visu_ui_gl_widgetFree_openGL(VisuUiGlWidget *render)
 {
-  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
+  g_return_if_fail(VISU_IS_UI_GL_WIDGET(render));
 
   if (render->context)
     wglDeleteContext(render->context);
@@ -999,8 +913,9 @@ static void visu_ui_gl_widgetFree_openGL(VisuUiGlWidget *render)
 gboolean visu_ui_gl_widget_setCurrent(VisuUiGlWidget *render, gboolean force _U_)
 {
   GtkWidget *wd;
+  GtkAllocation alloc;
 
-  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_GL_WIDGET(render), FALSE);
 
   DBG_fprintf(stderr, "Gtk OpenGL (action) : %p is set current.\n", (gpointer)render);
   wglMakeCurrent(NULL, NULL);
@@ -1010,11 +925,12 @@ gboolean visu_ui_gl_widget_setCurrent(VisuUiGlWidget *render, gboolean force _U_
   VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent = render;
 
   wd = GTK_WIDGET(render);
-  setViewport(render, wd->allocation.width, wd->allocation.height, FALSE);
+  gtk_widget_get_allocation(wd, &alloc);
+  setViewport(render, alloc.width, alloc.height, FALSE);
 
   return TRUE;
 }
-void visu_ui_gl_widget_swapBuffers(VisuUiGlWidget *render)
+static void swapGl(VisuUiGlWidget *render)
 {
   g_return_if_fail(VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render);
 
@@ -1024,7 +940,7 @@ void visu_ui_gl_widget_swapBuffers(VisuUiGlWidget *render)
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
 static GdkColormap* visu_ui_gl_widgetGet_openGLColormap(VisuUiGlWidget *render)
 {
-  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), (GdkColormap*)0);
+  g_return_val_if_fail(VISU_IS_UI_GL_WIDGET(render), (GdkColormap*)0);
   
   return gdk_screen_get_system_colormap(gdk_screen_get_default());
 }
@@ -1076,7 +992,7 @@ static void visu_ui_gl_widgetInit_context(VisuUiGlWidget *render, gboolean conte
 }
 static void visu_ui_gl_widgetFree_openGL(VisuUiGlWidget *render)
 {
-  g_return_if_fail(VISU_UI_IS_GL_WIDGET(render));
+  g_return_if_fail(VISU_IS_UI_GL_WIDGET(render));
 
   if (render->context)
     aglDestroyContext(render->context);
@@ -1087,7 +1003,7 @@ gboolean visu_ui_gl_widget_setCurrent(VisuUiGlWidget *render, gboolean force _U_
 {
   GtkWidget *wd;
 
-  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), FALSE);
+  g_return_val_if_fail(VISU_IS_UI_GL_WIDGET(render), FALSE);
 
   DBG_fprintf(stderr, "Gtk OpenGL (Quartz): %p is set current.\n", (gpointer)render);
   aglMakeCurrent((AGLDrawable)render->windowId, render->context);
@@ -1100,7 +1016,7 @@ gboolean visu_ui_gl_widget_setCurrent(VisuUiGlWidget *render, gboolean force _U_
 
   return TRUE;
 }
-void visu_ui_gl_widget_swapBuffers(VisuUiGlWidget *render)
+static void swapGl(VisuUiGlWidget *render)
 {
   g_return_if_fail(VISU_UI_GL_WIDGET_GET_CLASS(render)->contextCurrent == render);
 
@@ -1110,7 +1026,7 @@ void visu_ui_gl_widget_swapBuffers(VisuUiGlWidget *render)
 #if GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 26
 static GdkColormap* visu_ui_gl_widgetGet_openGLColormap(VisuUiGlWidget *render)
 {
-  g_return_val_if_fail(VISU_UI_IS_GL_WIDGET(render), (GdkColormap*)0);
+  g_return_val_if_fail(VISU_IS_UI_GL_WIDGET(render), (GdkColormap*)0);
   
   return gdk_screen_get_system_colormap(gdk_screen_get_default());
 }
