@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -49,15 +49,14 @@
 
 #include "gtk_main.h"
 #include "gtk_renderingWindowWidget.h"
+#include "uiElements/ui_selection.h"
 
 GtkWidget* visu_ui_interactive_pick_initBuild(VisuUiMain *main, gchar **label,
                                               gchar **help, GtkWidget **radio);
+VisuUiSelection* visu_ui_interactive_pick_getSelection(void);
+GtkWidget* visu_ui_interactive_pick_getSelectionLabel(void);
 void visu_ui_interactive_pick_start(VisuUiRenderingWindow *window);
 void visu_ui_interactive_pick_stop(VisuUiRenderingWindow *window);
-GList* visu_ui_interactive_pick_getNodeSelection();
-gboolean visu_ui_interactive_pick_parseXMLFile(const gchar* filename,
-                                               VisuData *data, GError **error);
-gboolean visu_ui_interactive_pick_exportXMLFile(const gchar *filename, GError **error);
 
 void visu_ui_interactive_pick_init();
 
