@@ -53,12 +53,11 @@
 #include "visu_gtk.h"
 #include "gtk_main.h"
 #include "visu_configFile.h"
-#include "visu_object.h"
 #include "visu_tools.h"
 #include "visu_basic.h"
 #include "gtk_renderingWindowWidget.h"
 #include "visu_commandLine.h"
-#include "gtk_pick.h"
+#include "extensions/planes.h"
 #include "panelModules/panelPlanes.h"
 #include "panelModules/panelSurfaces.h"
 #include "panelModules/panelGeometry.h"
@@ -87,8 +86,8 @@ static void onTextEntryChange(GtkEditable *entry, gpointer data);
 static void onSaveParButtonClicked(GtkButton *button, gpointer data);
 
 /* Local methods. */
-static void showAlertMessage(GtkWidget *saveDialog, gchar* message, gboolean warning, int type);
-static void saveAction(int type, GtkWidget *saveDialog, GtkEntry *entry);
+static void showAlertMessage(GtkWidget *saveDialog, gchar* message, gboolean warning, VisuConfigFileKind type);
+static void saveAction(VisuConfigFileKind kind, GtkWidget *saveDialog, GtkEntry *entry);
 
 /* The completion tree model. */
 enum
@@ -107,7 +106,8 @@ void visu_ui_save_initBuild()
   GtkWidget *saveDialog;
   GtkWidget *wd, *label;
   GtkEntryCompletion *completion;
-  gchar *directory, *file;
+  const gchar *directory;
+  gchar *file, *dir;
   GList *resList;
   GtkListStore *listOfFiles;
   const gchar *currentResPath;
@@ -147,10 +147,8 @@ void visu_ui_save_initBuild()
 
   /* Set default values. */
   wd = lookup_widget(saveDialog, "checkLimitOnVisuData");
-  if (visu_ui_rendering_window_getData(visu_ui_main_class_getDefaultRendering()))
-    gtk_widget_set_sensitive(wd, TRUE);
-  else
-    gtk_widget_set_sensitive(wd, FALSE);
+  g_object_bind_property(visu_ui_main_class_getDefaultRendering(), "data",
+                         wd, "sensitive", G_BINDING_SYNC_CREATE);
   gtk_widget_set_name(wd, "message_radio");
   wd = lookup_widget(saveDialog, "notebookResources");
   gtk_notebook_set_current_page(GTK_NOTEBOOK(wd), 1);
@@ -166,7 +164,7 @@ void visu_ui_save_initBuild()
 
   /* Set initial values. */
   wd = lookup_widget(saveDialog, "filechooserwidgetResources");
-  directory = visu_ui_getLastOpenDirectory();
+  directory = visu_ui_main_getLastOpenDirectory(visu_ui_main_class_getCurrentPanel());
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(wd), directory);
   g_signal_connect(G_OBJECT(wd), "selection-changed",
@@ -201,7 +199,7 @@ void visu_ui_save_initBuild()
 
   wd = lookup_widget(saveDialog, "comboboxentryResources");
   gtk_widget_set_name(wd, "message_entry");
-  currentResPath = visu_config_file_getPathToResources();
+  currentResPath = visu_config_file_getPath(VISU_CONFIG_FILE_RESOURCE);
   DBG_fprintf(stderr, " | current resource path '%s'.\n", currentResPath);
   j = i = 0;
   resList = visu_config_file_getPathList(VISU_CONFIG_FILE_RESOURCE);
@@ -219,8 +217,8 @@ void visu_ui_save_initBuild()
     }
   /* Add all res file of the cwd. */
   DBG_fprintf(stderr, "Gtk Save: looking for res files in '%s'.\n", currentResPath);
-  directory = g_get_current_dir();
-  gdir = g_dir_open(directory, 0, NULL);
+  dir = g_get_current_dir();
+  gdir = g_dir_open(dir, 0, NULL);
   if (gdir)
     {
       fileFromDir = g_dir_read_name(gdir);
@@ -239,7 +237,7 @@ void visu_ui_save_initBuild()
         }
       g_dir_close(gdir);
     }
-  g_free(directory);
+  g_free(dir);
 
   completion = gtk_entry_completion_new();
   gtk_entry_completion_set_model(completion, GTK_TREE_MODEL(listOfFiles));
@@ -319,7 +317,7 @@ void visu_ui_save_initBuild()
 					   "   <span font_desc=\"monospace\"><u>"
 					   VISU_WEB_SITE"/sample.html#parameters"
 					   "</u></span>."));
-  gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
+  gtk_label_set_xalign(GTK_LABEL(label), 0.);
   gtk_box_pack_end(GTK_BOX(wd), label, FALSE, FALSE, 10);
   gtk_widget_show(label);
 
@@ -364,9 +362,6 @@ static void onLoadResButtonClicked(GtkButton *button _U_, gpointer data)
   int res;
   GString *message;
   GError *error;
-  VisuUiRenderingWindow *window;
-  VisuData *dataObj;
-  VisuGlView *view;
 
   g_return_if_fail(GTK_DIALOG(data));
 
@@ -375,14 +370,12 @@ static void onLoadResButtonClicked(GtkButton *button _U_, gpointer data)
 
   filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_selector));
   directory = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(file_selector));
-  visu_ui_setLastOpenDirectory(directory, VISU_UI_DIR_CONF);
+  visu_ui_main_setLastOpenDirectory(visu_ui_main_class_getCurrentPanel(),
+                                    directory, VISU_UI_DIR_CONF);
   g_free(directory);
 
-  window = visu_ui_main_class_getDefaultRendering();
-  dataObj = visu_ui_rendering_window_getData(window);
-  view = visu_ui_rendering_window_getGlView(window);
   error = (GError*)0;
-  res = visu_config_file_load(VISU_CONFIG_FILE_RESOURCE, filename, dataObj, view, &error);
+  res = visu_config_file_load(VISU_CONFIG_FILE_RESOURCE, filename, &error);
   if (error)
     {
       visu_ui_raiseWarningLong(_("Loading a file"), error->message,
@@ -398,16 +391,9 @@ static void onLoadResButtonClicked(GtkButton *button _U_, gpointer data)
   else
     g_string_append_printf(message, _("File '%s' not or partially loaded."),
 			   basename);
-  showAlertMessage(GTK_WIDGET(data), message->str, !res, VISU_CONFIG_FILE_RESOURCE);
+  showAlertMessage(GTK_WIDGET(data), message->str, !res, VISU_CONFIG_FILE_KIND_RESOURCE);
   g_string_free(message, TRUE);
   g_free(basename);
-
-  if (res && dataObj)
-    {
-      /* We rebuild all list. */
-      visu_gl_ext_rebuildAll();
-      VISU_REDRAW_ADD;
-    }
 }
 
 static void onSaveResButtonClicked(GtkButton *button _U_, gpointer data)
@@ -422,11 +408,11 @@ static void onSaveResButtonClicked(GtkButton *button _U_, gpointer data)
   if (!strstr(gtk_entry_get_text(GTK_ENTRY(entry)), ".xml") &&
       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkExportXML)))
     {
-      showAlertMessage(GTK_WIDGET(data), _("Choose a filename with '.xml' to append other settings."), TRUE, VISU_CONFIG_FILE_RESOURCE);
+      showAlertMessage(GTK_WIDGET(data), _("Choose a filename with '.xml' to append other settings."), TRUE, VISU_CONFIG_FILE_KIND_RESOURCE);
     }
   else
     {
-      saveAction(VISU_CONFIG_FILE_RESOURCE, GTK_WIDGET(data), GTK_ENTRY(entry));
+      saveAction(VISU_CONFIG_FILE_KIND_RESOURCE, GTK_WIDGET(data), GTK_ENTRY(entry));
       gtk_widget_grab_default(lookup_widget(GTK_WIDGET(data), "closeButtonSave"));
     }
 }
@@ -439,37 +425,33 @@ static void onSaveParButtonClicked(GtkButton *button _U_, gpointer data)
 
   entry = gtk_bin_get_child
     (GTK_BIN(lookup_widget(GTK_WIDGET(data), "comboboxentryParameters")));
-  saveAction(VISU_CONFIG_FILE_PARAMETER, GTK_WIDGET(data), GTK_ENTRY(entry));
+  saveAction(VISU_CONFIG_FILE_KIND_PARAMETER, GTK_WIDGET(data), GTK_ENTRY(entry));
   gtk_widget_grab_default(lookup_widget(GTK_WIDGET(data), "closeButtonSave"));
 }
 
 static gboolean _appendAllSettings(const gchar *filename, GError **error)
 {
-  VisuPlane **planes;
-  VisuPaths *paths;
+  VisuGlNodeScene *scene;
+  VisuGlExtPlanes *planes;
 
-  planes = visu_ui_panel_planes_getAll(FALSE);
-  if (!visu_plane_class_exportXMLFile(filename, planes, error))
-    {
-      g_free(planes);
-      return FALSE;
-    }
-  g_free(planes);
+  scene = visu_ui_rendering_window_getGlScene(visu_ui_main_class_getDefaultRendering());
+  planes = visu_gl_node_scene_addPlanes(scene);
+  if (!visu_plane_set_exportXMLFile(planes->planes, filename, error))
+    return FALSE;
 
-  if (!visu_ui_interactive_pick_exportXMLFile(filename, error))
+  if (!visu_gl_node_scene_marksToFile(scene, filename, error))
     return FALSE;
 
   if (!visu_ui_panel_surfaces_exportXMLFile(filename, error))
     return FALSE;
 
-  paths = visu_ui_panel_geometry_getPaths();
-  if (!visu_paths_exportXMLFile(paths, filename, error))
+  if (!visu_gl_node_scene_exportPathsToXML(scene, filename, error))
     return FALSE;
 
   return TRUE;
 }
 
-static void saveAction(int type, GtkWidget *saveDialog, GtkEntry *entry)
+static void saveAction(VisuConfigFileKind kind, GtkWidget *saveDialog, GtkEntry *entry)
 {
   GtkWidget *wd;
   gchar *file, *tmpFile, *basename, *fileUTF8;
@@ -479,14 +461,11 @@ static void saveAction(int type, GtkWidget *saveDialog, GtkEntry *entry)
   int lines;
   VisuUiRenderingWindow *window;
   VisuData *dataObj;
-  VisuGlView *view;
   GError *error;
   GtkTreeIter iter;
   GtkListStore *listOfFiles;
   GtkEntryCompletion *completion;
 
-  g_return_if_fail(type == VISU_CONFIG_FILE_RESOURCE ||
-		   type == VISU_CONFIG_FILE_PARAMETER);
   g_return_if_fail(saveDialog && entry);
 
   file = g_filename_from_utf8(gtk_entry_get_text(entry), -1, &lu, &ecrit, NULL);
@@ -494,41 +473,41 @@ static void saveAction(int type, GtkWidget *saveDialog, GtkEntry *entry)
   if (g_file_test(file, G_FILE_TEST_IS_DIR))
     {
       tmpFile=
-	g_build_filename(file, visu_config_file_getDefaultFilename(type), NULL);
+	g_build_filename(file, visu_config_file_getDefaultFilename(kind), NULL);
       g_free(file);
       file = tmpFile;
     }
   
   wd = lookup_widget(saveDialog, "checkLimitOnVisuData");
   dataObj = (VisuData*)0;
-  view = (VisuGlView*)0;
-  if (type == VISU_CONFIG_FILE_RESOURCE)
+  if (kind == VISU_CONFIG_FILE_KIND_RESOURCE)
     {
       window = visu_ui_main_class_getDefaultRendering();
       if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wd)))
-        dataObj = visu_ui_rendering_window_getData(window);
-      view = visu_ui_rendering_window_getGlView(window);
+        dataObj = visu_gl_node_scene_getData(visu_ui_rendering_window_getGlScene(window));
     }
 
   error = (GError*)0;
   lines = 0;
-  if (type == VISU_CONFIG_FILE_RESOURCE && checkXMLResources &&
+  if (kind == VISU_CONFIG_FILE_KIND_RESOURCE && checkXMLResources &&
       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkXMLResources)))
-    resOk = visu_config_file_exportToXML(file, VISU_CONFIG_FILE_RESOURCE, &error);
-  else if (type == VISU_CONFIG_FILE_RESOURCE && strstr(file, ".xml"))
+    resOk = visu_config_file_exportToXML(VISU_CONFIG_FILE_RESOURCE, file, &error);
+  else if (kind == VISU_CONFIG_FILE_KIND_RESOURCE && strstr(file, ".xml"))
     {
-      resOk = visu_config_file_saveResourcesToXML(file, &lines, dataObj, view, &error);
+      resOk = visu_config_file_saveResourcesToXML(file, &lines, dataObj, &error);
       resOk = resOk && _appendAllSettings(file, &error);
     }
-  else if (type == VISU_CONFIG_FILE_PARAMETER && checkXMLParameters &&
+  else if (kind == VISU_CONFIG_FILE_KIND_PARAMETER && checkXMLParameters &&
 	   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkXMLParameters)))
-    resOk = visu_config_file_exportToXML(file, VISU_CONFIG_FILE_PARAMETER, &error);
-  else if (type == VISU_CONFIG_FILE_PARAMETER && checkXMLCommandLine &&
+    resOk = visu_config_file_exportToXML(VISU_CONFIG_FILE_PARAMETER, file, &error);
+  else if (kind == VISU_CONFIG_FILE_KIND_PARAMETER && checkXMLCommandLine &&
 	   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkXMLCommandLine)))
     resOk = commandLineExport(file, &error);
+  else if (kind == VISU_CONFIG_FILE_KIND_PARAMETER)
+    resOk = visu_config_file_save(VISU_CONFIG_FILE_PARAMETER, file, &lines, dataObj, &error);
   else
-    resOk = visu_config_file_save(type, file, &lines, dataObj, view, &error);
-  if (!resOk)
+    resOk = visu_config_file_save(VISU_CONFIG_FILE_RESOURCE, file, &lines, dataObj, &error);
+  if (!resOk && error)
     {
       visu_ui_raiseWarningLong(_("Saving a file"), error->message,
 			       GTK_WINDOW(saveDialog));
@@ -542,7 +521,7 @@ static void saveAction(int type, GtkWidget *saveDialog, GtkEntry *entry)
 			   basename, lines);
   else
     g_string_append_printf(message, _("File '%s' not written."), basename);
-  showAlertMessage(saveDialog, message->str, !resOk, type);
+  showAlertMessage(saveDialog, message->str, !resOk, kind);
   g_string_free(message, TRUE);
   g_free(basename);
 
@@ -569,15 +548,13 @@ static void saveAction(int type, GtkWidget *saveDialog, GtkEntry *entry)
   g_free(file);
 }
 
-static void showAlertMessage(GtkWidget *saveDialog, gchar* message, gboolean warning, int type)
+static void showAlertMessage(GtkWidget *saveDialog, gchar* message, gboolean warning, VisuConfigFileKind type)
 {
   GtkWidget *wd;
 
-  g_return_if_fail(type == VISU_CONFIG_FILE_RESOURCE ||
-		   type == VISU_CONFIG_FILE_PARAMETER);
   g_return_if_fail(saveDialog);
 
-  if (type == VISU_CONFIG_FILE_RESOURCE)
+  if (type == VISU_CONFIG_FILE_KIND_RESOURCE)
     wd = lookup_widget(saveDialog, "imageWarningResources");
   else
     wd = lookup_widget(saveDialog, "imageWarningParameters");
@@ -586,7 +563,7 @@ static void showAlertMessage(GtkWidget *saveDialog, gchar* message, gboolean war
   else
     gtk_widget_hide(wd);
 
-  if (type == VISU_CONFIG_FILE_RESOURCE)
+  if (type == VISU_CONFIG_FILE_KIND_RESOURCE)
     {
       wd = lookup_widget(saveDialog, "statusbarResources");
       gtk_statusbar_pop(GTK_STATUSBAR(wd), saveResourcesContextId);
