@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -47,6 +47,8 @@
 #include <glib.h>
 #include <glib-object.h>
 
+G_BEGIN_DECLS
+
 typedef struct _VisuGlLights VisuGlLights;
 
 GType visu_gl_lights_get_type(void);
@@ -62,27 +64,6 @@ VisuGlLights* visu_gl_lights_ref(VisuGlLights *env);
 void visu_gl_lights_unref(VisuGlLights *env);
 void visu_gl_lights_free(VisuGlLights *env);
 
-/**
- * VisuGlLightMaterial:
- * @VISU_GL_LIGHT_MATERIAL_AMB: the ambient identifier ;
- * @VISU_GL_LIGHT_MATERIAL_DIF: the diffuse identifier ;
- * @VISU_GL_LIGHT_MATERIAL_SHI: the shiningness identifier ;
- * @VISU_GL_LIGHT_MATERIAL_SPE: the specular identifier ;
- * @VISU_GL_LIGHT_MATERIAL_EMI: the emissivity identifier ;
- * @VISU_GL_LIGHT_MATERIAL_N_VALUES: number of used material identifiers.
- *
- * This enum is used to address the OpenGL parameters for light rendering.
- */
-typedef enum
-  {
-    VISU_GL_LIGHT_MATERIAL_AMB,
-    VISU_GL_LIGHT_MATERIAL_DIF,
-    VISU_GL_LIGHT_MATERIAL_SHI,
-    VISU_GL_LIGHT_MATERIAL_SPE,
-    VISU_GL_LIGHT_MATERIAL_EMI,
-    VISU_GL_LIGHT_MATERIAL_N_VALUES
-  } VisuGlLightMaterial;
-
 typedef struct _VisuGlLight VisuGlLight;
 struct _VisuGlLight
 {  
@@ -101,6 +82,7 @@ GType visu_gl_light_get_type(void);
  */
 #define VISU_TYPE_GL_LIGHT (visu_gl_light_get_type())
 
+gboolean visu_gl_lights_available(VisuGlLights *env);
 gboolean visu_gl_lights_add(VisuGlLights *env, VisuGlLight *light);
 gboolean visu_gl_lights_remove(VisuGlLights *env, VisuGlLight *light);
 GList* visu_gl_lights_getList(VisuGlLights *env);
@@ -109,6 +91,6 @@ gboolean visu_gl_lights_apply(VisuGlLights *env);
 
 VisuGlLight* visu_gl_light_newDefault();
 
-
+G_END_DECLS
 
 #endif
