@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -49,6 +49,7 @@
 #include <GL/glu.h>
 
 #include <visu_tools.h>
+#include <opengl.h>
 #include <coreTools/toolColor.h>
 
 #include "text.h"
@@ -228,27 +229,27 @@ static void drawEdgedTail(float tail_length, float tail_height)
 /**
  * visu_gl_drawSmoothArrow:
  * @obj: (type gpointer): ...
- * @material_id: an OpenGL list id for material change.
  * @centering: a flag.
  * @tailLength: length of tail part.
  * @tailRadius: length of edge of tail part.
  * @tailN: number of edges in the approximation.
- * @tailUseMat: use the material colour for the tail part.
+ * @tailRenderer: (allow-none): a given #VisuElementRenderer to take
+ * the rendering properties of.
  * @hatLength: length of hat part.
  * @hatRadius: length of edge of hat part.
  * @hatN: number of edges in the approximation.
- * @hatUseMat: use the material colour for the hat part.
+ * @hatRenderer: (allow-none): a given #VisuElementRenderer to take
+ * the rendering properties of.
  *
  * Draw arrows, using sqaure edges. For rounded arrows, see
  * visu_gl_drawEdgeArrow().
  * 
  * Since: 3.6
  */
-void visu_gl_drawSmoothArrow(GLUquadricObj *obj, int material_id,
-				      VisuGlArrowCentering centering,
-				      float tailLength, float tailRadius, float tailN,
-				      gboolean tailUseMat, float hatLength,
-				      float hatRadius, float hatN, gboolean hatUseMat)
+void visu_gl_drawSmoothArrow(GLUquadricObj *obj, VisuGlArrowCentering centering,
+                             float tailLength, float tailRadius, float tailN,
+                             const VisuElementRenderer *tailRenderer, float hatLength,
+                             float hatRadius, float hatN, const VisuElementRenderer *hatRenderer)
 {
   switch (centering)
     {
@@ -264,25 +265,30 @@ void visu_gl_drawSmoothArrow(GLUquadricObj *obj, int material_id,
     default:
       break;
     }
-  if(tailUseMat && hatUseMat)
+  if (tailRenderer && hatRenderer)
     {
-      glCallList(material_id);
+      visu_gl_setColor((VisuGl*)0, visu_element_renderer_getMaterial(hatRenderer),
+                       visu_element_renderer_getColor(hatRenderer)->rgba);
       drawRoundedHat(obj, hatRadius,
 		     hatLength, MAX(hatRadius, tailRadius)*1.03, hatN);
+      visu_gl_setColor((VisuGl*)0, visu_element_renderer_getMaterial(tailRenderer),
+                       visu_element_renderer_getColor(tailRenderer)->rgba);
       drawRoundedTail(obj, tailRadius, tailLength, tailN);
     }
-  else if(tailUseMat)
+  else if (tailRenderer)
     {
       drawRoundedHat(obj, hatRadius, hatLength,
 		     MAX(hatRadius, tailRadius)*1.03, hatN);
-      glCallList(material_id);
+      visu_gl_setColor((VisuGl*)0, visu_element_renderer_getMaterial(tailRenderer),
+                       visu_element_renderer_getColor(tailRenderer)->rgba);
       drawRoundedTail(obj, tailRadius, tailLength, tailN);
     }
-  else if(hatUseMat)
+  else if (hatRenderer)
     {
       drawRoundedTail(obj, tailRadius, tailLength, tailN);
       glTranslatef(0, 0, tailLength);
-      glCallList(material_id);
+      visu_gl_setColor((VisuGl*)0, visu_element_renderer_getMaterial(hatRenderer),
+                       visu_element_renderer_getColor(hatRenderer)->rgba);
       drawRoundedHat(obj, hatRadius, hatLength,
 		     MAX(hatRadius, tailRadius)*1.03, hatN);
     }
@@ -295,24 +301,25 @@ void visu_gl_drawSmoothArrow(GLUquadricObj *obj, int material_id,
 }
 /**
  * visu_gl_drawEdgeArrow:
- * @material_id: an OpenGL list id for material change.
  * @centering: a flag.
  * @tailLength: length of tail part.
  * @tailRadius: length of edge of tail part.
- * @tailUseMat: use the material colour for the tail part.
+ * @tailRenderer: (allow-none): a given #VisuElementRenderer to take
+ * the rendering properties of.
  * @hatLength: length of hat part.
  * @hatRadius: length of edge of hat part.
- * @hatUseMat: use the material colour for the hat part.
+ * @hatRenderer: (allow-none): a given #VisuElementRenderer to take
+ * the rendering properties of.
  *
  * Draw arrows, using sqaure edges. For rounded arrows, see
  * visu_gl_drawSmoothArrow().
  * 
  * Since: 3.6
  */
-void visu_gl_drawEdgeArrow(int material_id, VisuGlArrowCentering centering,
-				    float tailLength, float tailRadius,
-				    gboolean tailUseMat, float hatLength,
-				    float hatRadius, gboolean hatUseMat)
+void visu_gl_drawEdgeArrow(VisuGlArrowCentering centering,
+                           float tailLength, float tailRadius,
+                           const VisuElementRenderer *tailRenderer, float hatLength,
+                           float hatRadius, const VisuElementRenderer *hatRenderer)
 {
   /* This one is a edged arrow. */
   switch (centering)
@@ -329,22 +336,27 @@ void visu_gl_drawEdgeArrow(int material_id, VisuGlArrowCentering centering,
     default:
       break;
     }
-  if(tailUseMat && hatUseMat)
+  if (tailRenderer && hatRenderer)
     {
-      glCallList(material_id);
+      visu_gl_setColor((VisuGl*)0, visu_element_renderer_getMaterial(hatRenderer),
+                       visu_element_renderer_getColor(hatRenderer)->rgba);
       drawEdgedHat(hatRadius, hatLength);
+      visu_gl_setColor((VisuGl*)0, visu_element_renderer_getMaterial(tailRenderer),
+                       visu_element_renderer_getColor(tailRenderer)->rgba);
       drawEdgedTail(tailRadius, tailLength);
     }
-  else if(tailUseMat)
+  else if (tailRenderer)
     {
       drawEdgedHat(hatRadius, hatLength);
-      glCallList(material_id);
+      visu_gl_setColor((VisuGl*)0, visu_element_renderer_getMaterial(tailRenderer),
+                       visu_element_renderer_getColor(tailRenderer)->rgba);
       drawEdgedTail(tailRadius, tailLength);
     }
-  else if(hatUseMat)
+  else if (hatRenderer)
     {
       drawEdgedTail(tailRadius, tailLength);
-      glCallList(material_id);
+      visu_gl_setColor((VisuGl*)0, visu_element_renderer_getMaterial(hatRenderer),
+                       visu_element_renderer_getColor(hatRenderer)->rgba);
       drawEdgedHat(hatRadius, hatLength);
     }
   else
@@ -356,51 +368,53 @@ void visu_gl_drawEdgeArrow(int material_id, VisuGlArrowCentering centering,
 /**
  * visu_gl_drawEllipsoid:
  * @obj: (type gpointer): ...
- * @material_id:  an OpenGL list id for material change.
  * @aAxis: length of long axis.
  * @bAxis: length of short axis.
  * @n: number of edges for the sphere approximation.
- * @useMat: a flag to use the material definition or not.
+ * @renderer: (allow-none): a given #VisuElementRenderer to take
+ * the rendering properties of.
  *
  * Draw  an ellipsoid.
  *
  * Since: 3.6
  */
-void visu_gl_drawEllipsoid(GLUquadricObj *obj, int material_id,
-				    float aAxis, float bAxis,
-				    float n, gboolean useMat)
+void visu_gl_drawEllipsoid(GLUquadricObj *obj,
+                           float aAxis, float bAxis,
+                           float n, const VisuElementRenderer *renderer)
 {
   if (bAxis == 0.f)
     glScalef(1.f, 1.f, 10.f);
   else
     glScalef(1.f, 1.f, aAxis / bAxis);
-  if (useMat)
-    glCallList(material_id);
+  if (renderer)
+    visu_gl_setColor((VisuGl*)0, visu_element_renderer_getMaterial(renderer),
+                     visu_element_renderer_getColor(renderer)->rgba);
   gluSphere(obj, bAxis, n, n);
 }
 /**
  * visu_gl_drawTorus:
  * @obj: (type gpointer): ...
- * @material_id:  an OpenGL list id for material change.
  * @radius: global radius.
  * @ratio: ratio on internal radius over global radius.
  * @nA: number of edges for the global radius.
  * @nB: number of edges for the internal radius.
- * @useMat: a flag to use the material definition or not.
+ * @renderer: (allow-none): a given #VisuElementRenderer to take
+ * the rendering properties of.
  *
  * Draw  a torus.
  *
  * Since: 3.5
  */
-void visu_gl_drawTorus(GLUquadricObj *obj _U_, int material_id, float radius,
-				float ratio, int nA, int nB, gboolean useMat)
+void visu_gl_drawTorus(GLUquadricObj *obj _U_, float radius,
+                       float ratio, int nA, int nB, const VisuElementRenderer *renderer)
 {
   int i, j;
   float tp, tc, dtA, dtB, xp1, yp1, xp2, yp2, xc1, yc1, xc2, yc2, alpha;
   float a[3], b[3], c[3], d[3], aa[3], bb[3], cc[3], dd[3];
 
-  if (useMat)
-    glCallList(material_id);
+  if (renderer)
+    visu_gl_setColor((VisuGl*)0, visu_element_renderer_getMaterial(renderer),
+                     visu_element_renderer_getColor(renderer)->rgba);
 
   glBegin(GL_QUADS);
 
