@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -47,6 +47,8 @@
 #include <glib.h>
 #include <GL/glu.h>
 
+#include <renderingMethods/elementRenderer.h>
+
 int visu_gl_objectlist_new(int size);
 void visu_gl_objectlist_init(void);
 
@@ -70,20 +72,20 @@ typedef enum
     VISU_GL_ARROW_CENTERED
   } VisuGlArrowCentering;
 
-void visu_gl_drawSmoothArrow(GLUquadricObj *obj, int material_id,
-                             VisuGlArrowCentering centering,
+void visu_gl_drawSmoothArrow(GLUquadricObj *obj, VisuGlArrowCentering centering,
                              float tailLength, float tailRadius, float tailN,
-                             gboolean tailUseMat, float hatLength,
-                             float hatRadius, float hatN, gboolean hatUseMat);
-void visu_gl_drawEdgeArrow(int material_id, VisuGlArrowCentering centering,
+                             const VisuElementRenderer *tailRenderer,
+                             float hatLength, float hatRadius, float hatN,
+                             const VisuElementRenderer *hatRenderer);
+void visu_gl_drawEdgeArrow(VisuGlArrowCentering centering,
                            float tailLength, float tailRadius,
-                           gboolean tailUseMat, float hatLength,
-                           float hatRadius, gboolean hatUseMat);
-void visu_gl_drawEllipsoid(GLUquadricObj *obj, int material_id,
+                           const VisuElementRenderer *tailRenderer, float hatLength,
+                           float hatRadius, const VisuElementRenderer *hatRenderer);
+void visu_gl_drawEllipsoid(GLUquadricObj *obj,
                            float aAxis, float bAxis,
-                           float n, gboolean useMat);
-void visu_gl_drawTorus(GLUquadricObj *obj, int material_id, float radius,
-                       float ratio, int nA, int nB, gboolean useMat);
+                           float n,const  VisuElementRenderer *renderer);
+void visu_gl_drawTorus(GLUquadricObj *obj, float radius,
+                       float ratio, int nA, int nB, const VisuElementRenderer *renderer);
 void visu_gl_drawDistance(float xyzRef[3], float xyz[3], gboolean drawLength);
 void visu_gl_drawAngle(float xyzRef[3], float xyzRef2[3],
                        float xyz[3], guint id, gboolean drawLength);
