@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -47,25 +47,9 @@
 #include <gtk/gtk.h>
 
 #include <gtk_main.h>
-#include <visu_gtk.h>
-#include <visu_rendering.h>
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
 
-VisuUiPanel* visu_ui_panel_elements_init();
-
-/**
- * VisuUiPanelElementsChangeFunc:
- * @elements: a list of all #VisuElements that are selected.
- *
- * Methods from this interface are called whenever the currently selected
- * elements are changed.
- */
-typedef void (*VisuUiPanelElementsChangeFunc)(GList *elements);
-
-void visu_ui_panel_elements_setMethod(VisuRendering *method,
-				       VisuUiPanelElementsChangeFunc change,
-				       VisuUiNewWidgetFunc create);
-GList* visu_ui_panel_elements_getSelected();
+VisuUiPanel* visu_ui_panel_elements_init(VisuUiMain *ui);
 
 /**
  * VISU_UI_PANEL_ELEMENTS:
