@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -48,11 +48,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <GL/gl.h>
-
 #include <visu_gtk.h>
 #include <visu_tools.h>
-#include <visu_object.h>
 #include <support.h>
 #include <gtk_main.h>
 #include <opengl.h>
@@ -69,16 +66,6 @@
  * <para>Nothing tunable here.</para>
  */
 
-/* Sensitive widget in this subpanel. */
-static GtkWidget *checkImmediateDrawing;
-static GtkWidget *comboOpenGLRendering;
-static GtkWidget *checkAntialiasing;
-static GtkWidget *checkTransparency;
-static GtkWidget *checkStereo;
-static GtkWidget *spinPrecision;
-static GtkWidget *spinStereoAngle;
-static GtkWidget *hboxStereo;
-
 static int disableCallbacksOpenGL;
 static GtkListStore *light_list_store;
 static GtkWidget *panelOpenGL;
@@ -88,19 +75,12 @@ static GtkListStore *renderingListStore;
 #endif
 
 #define OPENGL_FOLLOW_GLOBAL_RENDERING_MODE _("Follow global setting")
+#define DEFAULT_GL VISU_GL(visu_ui_rendering_window_getGlScene(visu_ui_main_class_getDefaultRendering()))
 
 /* Private functions. */
-GtkWidget *createInteriorOpenGL();
-void createCallBacksOpenGL();
+static GtkWidget *createInteriorOpenGL();
 
 /* Local callbacks. */
-static void immediateDrawingCheckChanged(GtkToggleButton *button, gpointer data);
-static void stereoCheckChanged(GtkToggleButton *button, gpointer data);
-static void stereoSpinChanged(GtkSpinButton *button, gpointer data);
-static void antialisingCheckChanged(GtkToggleButton *button, gpointer data);
-static void onTransparencyChanged(GtkToggleButton *button, gpointer data);
-void precisionChanged(GtkButton *button, gpointer user_data);
-void comboOpenGLRenderingChanged(GtkComboBox *combobox, gpointer data);
 void addPresetOneLightClicked(GtkButton *button, gpointer data);
 void addPresetFourLightsClicked(GtkButton *button, gpointer data);
 static void selectionChanged(GtkTreeSelection *tree, gpointer data);
@@ -126,13 +106,11 @@ VisuUiPanel* visu_ui_panel_gl_init(VisuUiMain *ui _U_)
   visu_ui_panel_setDockable(VISU_UI_PANEL(panelOpenGL), TRUE);
 
   /* Create the callbacks of all the sensitive widgets. */
-  createCallBacksOpenGL();
   g_signal_connect(G_OBJECT(panelOpenGL), "page-entered",
 		   G_CALLBACK(onOpenGLEnter), (gpointer)0);
 
   /* Private parameters. */
   disableCallbacksOpenGL = 0;
-  hboxStereo = (GtkWidget*)0;
 
   return VISU_UI_PANEL(panelOpenGL);
 }
@@ -196,9 +174,7 @@ void light_tree_show_hide(GtkCellRendererToggle *cell_renderer,
 
   light0->enabled = status;
 
-  status = visu_gl_lights_apply(visu_gl_getLights());
-  if (status)
-    VISU_REDRAW_ADD;
+  visu_gl_applyLights(DEFAULT_GL);
 }
 
 void light_update(GtkCellRendererText *cellrenderertext _U_,
@@ -207,7 +183,6 @@ void light_update(GtkCellRendererText *cellrenderertext _U_,
   GtkTreeIter iter;
   float new_value = atof(text);
   VisuGlLight *light0;
-  gboolean status;
 
   if(gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(light_list_store),
 					 &iter, path))
@@ -223,17 +198,15 @@ void light_update(GtkCellRendererText *cellrenderertext _U_,
   else
     light0->position[GPOINTER_TO_INT(user_data)-LIGHT_POSITION0] = new_value;
 			 
-  status = visu_gl_lights_apply(visu_gl_getLights());
-  if (status)
-    VISU_REDRAW_ADD;
+  visu_gl_applyLights(DEFAULT_GL);
 }
 
-void light_sync_lists(GtkListStore *list)
+static void light_sync_lists(GtkListStore *list)
 {
   g_return_if_fail(list);
 
   gtk_list_store_clear(list);
-  g_list_foreach(visu_gl_lights_getList(visu_gl_getLights()),
+  g_list_foreach(visu_gl_lights_getList(visu_gl_getLights(DEFAULT_GL)),
 		 light_store_in_list_store, (gpointer)list);  
 }
 
@@ -311,7 +284,7 @@ GtkWidget* make_renderingTreeView()
   GtkTreeIter iter;
   const char** names;
   int i;
-  GList *list;
+  GList *list, *all;
   VisuGlRenderingMode mode;
   gchar *label;
   const char *modeName;
@@ -334,22 +307,24 @@ GtkWidget* make_renderingTreeView()
   renderingListStore =
     gtk_list_store_new(RENDERING_N_PARAMETERS, G_TYPE_POINTER,
 		       G_TYPE_STRING, G_TYPE_STRING);
-  for (list = visu_gl_ext_getAll(); list; list = g_list_next(list))
-    if (visu_gl_ext_getSensitiveToRenderingMode(VISU_GL_EXT(list->data)))
-      {
-        mode = visu_gl_ext_getPreferedRenderingMode(VISU_GL_EXT(list->data));
-        if (mode == VISU_GL_RENDERING_FOLLOW)
-          modeName = OPENGL_FOLLOW_GLOBAL_RENDERING_MODE;
-        else
-          modeName = names[mode];
-        g_object_get(G_OBJECT(list->data), "label", &label, NULL);
-        gtk_list_store_append(renderingListStore, &iter);
-        gtk_list_store_set(renderingListStore, &iter,
-                           RENDERING_POINTER_TO, list->data,
-                           RENDERING_NAME, label,
-                           RENDERING_MODE, modeName, -1);
-        g_free(label);
-      }
+  all = visu_gl_ext_set_getAll
+    (VISU_GL_EXT_SET(visu_ui_rendering_window_getGlScene(visu_ui_main_class_getDefaultRendering())));
+  for (list = all; list; list = g_list_next(list))
+    {
+      mode = visu_gl_ext_getPreferedRenderingMode(VISU_GL_EXT(list->data));
+      if (mode == VISU_GL_RENDERING_FOLLOW)
+        modeName = OPENGL_FOLLOW_GLOBAL_RENDERING_MODE;
+      else
+        modeName = names[mode];
+      g_object_get(G_OBJECT(list->data), "label", &label, NULL);
+      gtk_list_store_append(renderingListStore, &iter);
+      gtk_list_store_set(renderingListStore, &iter,
+                         RENDERING_POINTER_TO, list->data,
+                         RENDERING_NAME, label,
+                         RENDERING_MODE, modeName, -1);
+      g_free(label);
+    }
+  g_list_free(all);
 
   renderingTreeView =
     gtk_tree_view_new_with_model(GTK_TREE_MODEL(renderingListStore));
@@ -357,7 +332,6 @@ GtkWidget* make_renderingTreeView()
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes(_("name of extension"), renderer,
 						    "text", RENDERING_NAME, NULL);
-  gtk_tree_view_column_set_expand(column, TRUE);
   gtk_tree_view_column_set_alignment(column, 0.);
   gtk_tree_view_append_column(GTK_TREE_VIEW(renderingTreeView), column);
 
@@ -369,6 +343,7 @@ GtkWidget* make_renderingTreeView()
 		   G_CALLBACK(renderingModeEdited), (gpointer)renderingListStore);
   column = gtk_tree_view_column_new_with_attributes(_("mode"), renderer,
 						    "text", RENDERING_MODE, NULL);
+  gtk_tree_view_column_set_expand(column, TRUE);
   gtk_tree_view_column_set_alignment(column, 0.5);
   gtk_tree_view_append_column(GTK_TREE_VIEW(renderingTreeView), column);
 
@@ -388,7 +363,7 @@ void addNewLightClicked(GtkButton *button _U_, gpointer data)
 
   g_return_if_fail(data);
 
-  if(gtk_tree_model_iter_n_children(GTK_TREE_MODEL(data), (GtkTreeIter*)0) >= GL_MAX_LIGHTS)
+  if (!visu_gl_lights_available(visu_gl_getLights(DEFAULT_GL)))
     {
       visu_ui_raiseWarning(_("OpenGL"),
 			   _("The maximm number of lights allowed by OpenGL"
@@ -397,7 +372,7 @@ void addNewLightClicked(GtkButton *button _U_, gpointer data)
     }
 
   light0 = visu_gl_light_newDefault();
-  status = visu_gl_lights_add(visu_gl_getLights(), light0);
+  status = visu_gl_lights_add(visu_gl_getLights(DEFAULT_GL), light0);
 
   if (!status)
     return;
@@ -411,15 +386,13 @@ void addNewLightClicked(GtkButton *button _U_, gpointer data)
 		     LIGHT_POSITION2, light0->position[2], 
 		     LIGHT_MULTIPLIER, light0->multiplier, -1);
 
-  status = visu_gl_lights_apply(visu_gl_getLights());
-  if (status)
-    VISU_REDRAW_ADD;
+  visu_gl_applyLights(DEFAULT_GL);
 }
 void removeSelectedLightsClicked(GtkButton *button _U_, gpointer data)
 {
   GList *tmpLst, *selectedRows;
   GtkTreeIter iter;
-  gboolean validIter, status;
+  gboolean validIter;
   VisuGlLight *light0;
   GtkTreeIter *removableIter;
 
@@ -441,7 +414,7 @@ void removeSelectedLightsClicked(GtkButton *button _U_, gpointer data)
 	  gtk_tree_model_get(GTK_TREE_MODEL(light_list_store), &iter,
 			     LIGHT_POINTER_TO, &light0,
 			     -1);
-	  visu_gl_lights_remove(visu_gl_getLights(), light0);
+	  visu_gl_lights_remove(visu_gl_getLights(DEFAULT_GL), light0);
 	  removableIter = g_malloc(sizeof(GtkTreeIter));
 	  *removableIter = iter;
 	  tmpLst->data = (gpointer)removableIter;
@@ -460,9 +433,7 @@ void removeSelectedLightsClicked(GtkButton *button _U_, gpointer data)
     }  
   g_list_free(selectedRows);
 
-  status = visu_gl_lights_apply(visu_gl_getLights());
-  if (status)
-    VISU_REDRAW_ADD;
+  visu_gl_applyLights(DEFAULT_GL);
 }
 void selectionChanged(GtkTreeSelection *tree, gpointer data)
 {
@@ -477,19 +448,38 @@ void selectionChanged(GtkTreeSelection *tree, gpointer data)
     gtk_widget_set_sensitive(GTK_WIDGET(data), TRUE);
 }
 
-
-GtkWidget *createInteriorOpenGL()
+static gboolean precToSpin(GBinding *binding _U_,
+                           const GValue *source_value,
+                           GValue *target_value,
+                           gpointer user_data _U_)
+{
+  g_value_set_double(target_value, 100. * g_value_get_float(source_value));
+  return TRUE;
+}
+static gboolean precFromSpin(GBinding *binding _U_,
+                             const GValue *source_value,
+                             GValue *target_value,
+                             gpointer user_data _U_)
+{
+  g_value_set_float(target_value, g_value_get_double(source_value) / 100.);
+  return TRUE;
+}
+static GtkWidget *createInteriorOpenGL()
 {
   GtkWidget *vbox, *hbox;
-  GtkWidget *label, *align;
+  GtkWidget *label;
   GtkWidget *scrollLight;
   GtkWidget *button;
   GtkWidget *image;
   GtkWidget *scroll, *viewport;
   GtkWidget *expanderLight, *vbox2, *expand;
   GtkWidget *light_tree_view;
+  GtkWidget *checkAntialiasing, *checkImmediateDrawing, *checkTransparency;
+  GtkWidget *checkStereo, *spinStereoAngle, *comboOpenGLRendering, *spinPrecision;
   const char** names, **ids;
   int i;
+  VisuGl *gl = DEFAULT_GL;
+  VisuGlView *view;
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   GtkWidget *scrollRendering, *expanderRendering, *renderingTreeView;
 #endif
@@ -507,24 +497,25 @@ GtkWidget *createInteriorOpenGL()
   /*************************/
   /* Rendering parameters. */
   /*************************/
+  view = visu_gl_node_scene_getGlView(visu_ui_rendering_window_getGlScene(visu_ui_main_class_getDefaultRendering()));
   expand = gtk_expander_new(_("<b>Rendering options:</b>"));
   gtk_expander_set_expanded(GTK_EXPANDER(expand), TRUE);
   label = gtk_expander_get_label_widget(GTK_EXPANDER(expand));
   gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
   gtk_widget_set_name(label, "label_head");
   gtk_box_pack_start(GTK_BOX(vbox), expand, FALSE, FALSE, 5);
-  align = gtk_alignment_new(0.5, 0.5, 1., 1.);
-  gtk_alignment_set_padding(GTK_ALIGNMENT(align), 0, 0, 5, 0);
-  gtk_container_add(GTK_CONTAINER(expand), align);
+
   vbox2 = gtk_vbox_new(FALSE, 0);
-  gtk_container_add(GTK_CONTAINER(align), vbox2);
+  gtk_widget_set_margin_start(vbox2, 5);
+  gtk_container_add(GTK_CONTAINER(expand), vbox2);
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox2), hbox, FALSE, FALSE, 2);
   label = gtk_label_new(_("Precision:"));
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   spinPrecision = gtk_spin_button_new_with_range(10, 500, 5);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPrecision),
-			    visu_gl_view_class_getPrecision() * 100.);
+  g_object_bind_property_full(view, "precision", spinPrecision, "value",
+                              G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL,
+                              precToSpin, precFromSpin, (gpointer)0, (GDestroyNotify)0);
   gtk_box_pack_start(GTK_BOX(hbox), spinPrecision, FALSE, FALSE, 2);
   label = gtk_label_new("%");
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
@@ -536,10 +527,9 @@ GtkWidget *createInteriorOpenGL()
       gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(comboOpenGLRendering), ids[i], names[i]);
   else
     g_warning("No OpenGL rendering mode available.");
-  gtk_combo_box_set_active(GTK_COMBO_BOX(comboOpenGLRendering), 0);
+  g_object_bind_property(gl, "mode", comboOpenGLRendering, "active",
+                         G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
   gtk_box_pack_end(GTK_BOX(hbox), comboOpenGLRendering, FALSE, FALSE, 2);
-  g_signal_connect(G_OBJECT(comboOpenGLRendering), "changed",
-		   G_CALLBACK(comboOpenGLRenderingChanged), (gpointer)0);
   label = gtk_label_new(_("Mode:"));
   gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   
@@ -548,30 +538,32 @@ GtkWidget *createInteriorOpenGL()
   label = gtk_label_new(_("Antialiase lines:"));
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   checkAntialiasing = gtk_check_button_new();
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkAntialiasing),
-			       (gboolean)visu_gl_getAntialias());
+  g_object_bind_property(gl, "antialias", checkAntialiasing, "active",
+                         G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
   gtk_box_pack_start(GTK_BOX(hbox), checkAntialiasing, FALSE, FALSE, 2);
 
   checkTransparency = gtk_check_button_new();
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkTransparency),
-			       visu_gl_getTrueTransparency());
+  g_object_bind_property(gl, "true-transparency", checkTransparency, "active",
+                         G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
   gtk_box_pack_end(GTK_BOX(hbox), checkTransparency, FALSE, FALSE, 2);
   label = gtk_label_new(_("Enhanced transparency:"));
   gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 2);
 
   hbox = gtk_hbox_new(FALSE, 0);
+  gtk_widget_set_sensitive(hbox, visu_gl_getStereoCapability(DEFAULT_GL));
   gtk_box_pack_start(GTK_BOX(vbox2), hbox, FALSE, FALSE, 5);
   label = gtk_label_new(_("Use stereo rendering:"));
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   checkStereo = gtk_check_button_new();
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkStereo),
-			       visu_gl_getStereo());
+  g_object_bind_property(gl, "stereo", checkStereo, "active",
+                         G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
   gtk_box_pack_start(GTK_BOX(hbox), checkStereo, FALSE, FALSE, 2);
-  hboxStereo = hbox;
   /* Degrees. */
   label = gtk_label_new(_("deg."));
   gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   spinStereoAngle = gtk_spin_button_new_with_range(0.5,25.,0.1);
+  g_object_bind_property(gl, "stereo-angle", spinStereoAngle, "value",
+                         G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
   gtk_box_pack_end(GTK_BOX(hbox), spinStereoAngle, FALSE, FALSE, 2);
   label = gtk_label_new(_("angle:"));
   gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 1);
@@ -586,9 +578,9 @@ GtkWidget *createInteriorOpenGL()
   scrollRendering = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollRendering),
 				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  gtk_widget_set_size_request(scrollRendering, -1, 125);
   gtk_container_add(GTK_CONTAINER(expanderRendering), scrollRendering);
   renderingTreeView = make_renderingTreeView();
-  gtk_widget_set_size_request(renderingTreeView, -1, 125);
   gtk_container_add(GTK_CONTAINER(scrollRendering), renderingTreeView);
 #endif
   
@@ -601,8 +593,8 @@ GtkWidget *createInteriorOpenGL()
   gtk_widget_set_name(label, "label_head");
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
   checkImmediateDrawing = gtk_check_button_new();
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkImmediateDrawing),
-			       visu_gl_getImmediate());
+  g_object_bind_property(gl, "immediate", checkImmediateDrawing, "active",
+                         G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
   gtk_box_pack_start(GTK_BOX(hbox), checkImmediateDrawing, FALSE, FALSE, 2);
   gtk_widget_show(checkImmediateDrawing);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
@@ -626,8 +618,8 @@ GtkWidget *createInteriorOpenGL()
   vbox2 = gtk_vbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(hbox), vbox2, FALSE, FALSE, 0);
   button = gtk_button_new();
-  image = gtk_image_new_from_stock(GTK_STOCK_ADD,
-				   GTK_ICON_SIZE_BUTTON);
+  image = gtk_image_new_from_icon_name("list-add",
+                                       GTK_ICON_SIZE_BUTTON);
   gtk_container_add(GTK_CONTAINER(button), image);
   g_signal_connect(G_OBJECT(button), "clicked",
 		   G_CALLBACK(addNewLightClicked),
@@ -635,8 +627,8 @@ GtkWidget *createInteriorOpenGL()
   gtk_box_pack_start(GTK_BOX(vbox2), button, FALSE, FALSE, 1);
   button = gtk_button_new();
   gtk_widget_set_sensitive(button, FALSE);
-  image = gtk_image_new_from_stock(GTK_STOCK_REMOVE,
-				   GTK_ICON_SIZE_BUTTON);
+  image = gtk_image_new_from_icon_name("list-remove",
+                                       GTK_ICON_SIZE_BUTTON);
   gtk_container_add(GTK_CONTAINER(button), image);
   g_signal_connect(G_OBJECT(button), "clicked",
 		   G_CALLBACK(removeSelectedLightsClicked),
@@ -664,92 +656,9 @@ GtkWidget *createInteriorOpenGL()
   return scroll;
 }
 
-void createCallBacksOpenGL()
-{
-  g_signal_connect(G_OBJECT(spinPrecision), "value-changed",
-		   G_CALLBACK(precisionChanged), (gpointer)0);
-  g_signal_connect(G_OBJECT(checkAntialiasing), "toggled",
-		   G_CALLBACK(antialisingCheckChanged), (gpointer)0);
-  g_signal_connect(G_OBJECT(checkTransparency), "toggled",
-		   G_CALLBACK(onTransparencyChanged), (gpointer)0);
-  g_signal_connect(G_OBJECT(checkImmediateDrawing), "toggled",
-		   G_CALLBACK(immediateDrawingCheckChanged), (gpointer)0);
-  g_signal_connect(G_OBJECT(checkStereo), "toggled",
-		   G_CALLBACK(stereoCheckChanged), (gpointer)0);
-  g_signal_connect(G_OBJECT(spinStereoAngle), "value-changed",
-		   G_CALLBACK(stereoSpinChanged), (gpointer)0);
-}
-
 /*************/
 /* Callbacks */
 /*************/
-static void immediateDrawingCheckChanged(GtkToggleButton *button, gpointer data _U_)
-{
-  if (disableCallbacksOpenGL)
-    return;
-
-  visu_gl_setImmediate(gtk_toggle_button_get_active(button));
-}
-static void stereoCheckChanged(GtkToggleButton *button, gpointer data _U_)
-{
-  if (disableCallbacksOpenGL)
-    return;
-
-  visu_gl_setStereo(gtk_toggle_button_get_active(button));
-  VISU_REDRAW_ADD;
-}
-static void stereoSpinChanged(GtkSpinButton *button, gpointer data _U_)
-{
-  if (disableCallbacksOpenGL)
-    return;
-
-  if (visu_gl_setStereoAngle((float)gtk_spin_button_get_value(button)))
-    VISU_REDRAW_ADD;
-}
-void comboOpenGLRenderingChanged(GtkComboBox *combobox, gpointer data _U_)
-{
-  int mode;
-  
-  if (disableCallbacksOpenGL)
-    return;
-
-  mode = (int)gtk_combo_box_get_active(combobox);
-
-  if (visu_gl_rendering_setGlobalMode(mode))
-    VISU_REDRAW_ADD;
-}
-static void antialisingCheckChanged(GtkToggleButton *button, gpointer data _U_)
-{
-  if (disableCallbacksOpenGL)
-    return;
-
-  if (visu_gl_setAntialias(gtk_toggle_button_get_active(button)))
-    VISU_REDRAW_ADD;
-}
-static void onTransparencyChanged(GtkToggleButton *button, gpointer data _U_)
-{
-  if (disableCallbacksOpenGL)
-    return;
-
-  if (visu_gl_setTrueTransparency(gtk_toggle_button_get_active(button)))
-    VISU_REDRAW_ADD;
-}
-void precisionChanged(GtkButton *button _U_, gpointer user_data _U_)
-{
-  float prec;
-  VisuGlView *view;
-
-  if (disableCallbacksOpenGL)
-    return;
-
-  prec = (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinPrecision));
-  if (visu_gl_view_class_setPrecision(prec / 100.))
-    {
-      view = visu_ui_panel_getView(VISU_UI_PANEL(panelOpenGL));
-      g_signal_emit_by_name(G_OBJECT(view), "DetailLevelChanged", NULL);      
-      VISU_REDRAW_ADD;
-    }
-}
 static void onOpenGLEnter(VisuUiPanel *visu_ui_panel _U_, gpointer data _U_)
 {
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
@@ -761,25 +670,7 @@ static void onOpenGLEnter(VisuUiPanel *visu_ui_panel _U_, gpointer data _U_)
   VisuGlRenderingMode mode;
 #endif
 
-  if (hboxStereo)
-    gtk_widget_set_sensitive(hboxStereo, visu_gl_getStereoCapability());
-
   disableCallbacksOpenGL = 1;
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkImmediateDrawing),
-			       visu_gl_getImmediate());
-  gtk_combo_box_set_active(GTK_COMBO_BOX(comboOpenGLRendering),
-			   visu_gl_rendering_getGlobalMode());
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinPrecision),
-			    visu_gl_view_class_getPrecision() * 100.);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkAntialiasing),
-			       (gboolean)visu_gl_getAntialias());
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkTransparency),
-			       visu_gl_getTrueTransparency());
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkStereo),
-			       visu_gl_getStereo());
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinStereoAngle),
-			    visu_gl_getStereoAngle());
-
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
   names = visu_gl_rendering_getAllModeLabels();
   valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(renderingListStore), &iter);
@@ -788,17 +679,14 @@ static void onOpenGLEnter(VisuUiPanel *visu_ui_panel _U_, gpointer data _U_)
       gtk_tree_model_get(GTK_TREE_MODEL(renderingListStore), &iter,
 			 RENDERING_POINTER_TO, &ext,
 			 RENDERING_MODE, &name, -1);
-      if (visu_gl_ext_getSensitiveToRenderingMode(ext))
-	{
-          mode = visu_gl_ext_getPreferedRenderingMode(ext);
-	  if (mode < VISU_GL_RENDERING_N_MODES && strcmp(names[mode], name))
-	    gtk_list_store_set(renderingListStore, &iter,
-			       RENDERING_MODE, names[mode], -1);
-	  else if (mode == VISU_GL_RENDERING_FOLLOW &&
-                   strcmp(OPENGL_FOLLOW_GLOBAL_RENDERING_MODE, name))
-	    gtk_list_store_set(renderingListStore, &iter, RENDERING_MODE,
-                               OPENGL_FOLLOW_GLOBAL_RENDERING_MODE, -1);
-	}
+      mode = visu_gl_ext_getPreferedRenderingMode(ext);
+      if (mode < VISU_GL_RENDERING_N_MODES && strcmp(names[mode], name))
+        gtk_list_store_set(renderingListStore, &iter,
+                           RENDERING_MODE, names[mode], -1);
+      else if (mode == VISU_GL_RENDERING_FOLLOW &&
+               strcmp(OPENGL_FOLLOW_GLOBAL_RENDERING_MODE, name))
+        gtk_list_store_set(renderingListStore, &iter, RENDERING_MODE,
+                           OPENGL_FOLLOW_GLOBAL_RENDERING_MODE, -1);
       g_free(name);
       valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(renderingListStore), &iter);
     }
@@ -812,16 +700,14 @@ void addPresetOneLightClicked(GtkButton *button _U_, gpointer data)
 
   g_return_if_fail(data);
 
-  status = visu_gl_lights_removeAll(visu_gl_getLights());
+  status = visu_gl_lights_removeAll(visu_gl_getLights(DEFAULT_GL));
 
   light = visu_gl_light_newDefault();
-  status = visu_gl_lights_add(visu_gl_getLights(), light) || status;
+  status = visu_gl_lights_add(visu_gl_getLights(DEFAULT_GL), light) || status;
 
   light_sync_lists(GTK_LIST_STORE(data)); 
 
-  status = visu_gl_lights_apply(visu_gl_getLights()) || status;
-  if (status)
-    VISU_REDRAW_ADD;
+  visu_gl_applyLights(DEFAULT_GL);
 }
 void addPresetFourLightsClicked(GtkButton *button _U_, gpointer data)
 {
@@ -830,33 +716,31 @@ void addPresetFourLightsClicked(GtkButton *button _U_, gpointer data)
 
   g_return_if_fail(data);
 
-  status = visu_gl_lights_removeAll(visu_gl_getLights());
+  status = visu_gl_lights_removeAll(visu_gl_getLights(DEFAULT_GL));
 
   light = visu_gl_light_newDefault();
   light->multiplier = 0.25;
-  status = visu_gl_lights_add(visu_gl_getLights(), light) || status;
+  status = visu_gl_lights_add(visu_gl_getLights(DEFAULT_GL), light) || status;
 
   light = visu_gl_light_newDefault();
   light->position[0] *= -1.;
   light->multiplier = 0.25;
-  status = visu_gl_lights_add(visu_gl_getLights(), light) || status;
+  status = visu_gl_lights_add(visu_gl_getLights(DEFAULT_GL), light) || status;
 
   light = visu_gl_light_newDefault();
   light->position[1] *= -1.;
   light->multiplier = 0.25;
-  status = visu_gl_lights_add(visu_gl_getLights(), light) || status;
+  status = visu_gl_lights_add(visu_gl_getLights(DEFAULT_GL), light) || status;
 
   light = visu_gl_light_newDefault();
   light->position[0] *= -1.;
   light->position[1] *= -1.;
   light->multiplier = 0.25;
-  status = visu_gl_lights_add(visu_gl_getLights(), light) || status;
+  status = visu_gl_lights_add(visu_gl_getLights(DEFAULT_GL), light) || status;
 
   light_sync_lists(GTK_LIST_STORE(data)); 
 
-  status = visu_gl_lights_apply(visu_gl_getLights()) || status;
-  if (status)
-    VISU_REDRAW_ADD;
+  visu_gl_applyLights(DEFAULT_GL);
 }
 #if GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 5
 static void renderingModeEdited(GtkCellRendererText *cellrenderertext _U_,
@@ -907,8 +791,5 @@ static void renderingModeEdited(GtkCellRendererText *cellrenderertext _U_,
       gtk_list_store_set(list, &iter,
 			 RENDERING_MODE, names[mode], -1);
     }
-
-  if (valid && visu_gl_ext_getActive(ext))
-    VISU_REDRAW_ADD;
 }
 #endif
