@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -48,18 +48,14 @@
 #include <gtk/gtk.h>
 
 #include <visu_data.h>
-#include <extraFunctions/plane.h>
+#include <extraFunctions/planeset.h>
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
 
 /**
  * VisuUiPanelPlanesColumnId:
- * @VISU_UI_PANEL_PLANES_DRAWN: a boolean, code if the plane is drawn or not.
- * @VISU_UI_PANEL_PLANES_LABEL: a string, the description of the plane (normal vector
- *                      and distance to origin).
- * @VISU_UI_PANEL_PLANES_HIDE_IS_ON: a boolean, code if the plane hide elements on one side.
- * @VISU_UI_PANEL_PLANES_HIDDEN_SIDE: a boolean, code for the side.
- * @VISU_UI_PANEL_PLANES_COLOR_PIXBUF: a pixbuf, a small colored square.
- * @VISU_UI_PANEL_PLANES_POINTER: the pointer to the #VisuPlane object.
+ * @VISU_UI_PANEL_PLANES_POINTER: the pointer to the #VisuPlane
+ * object.
+ * @VISU_UI_PANEL_PLANES_NOTIFY: a handler of the VisuPlane::notify signal.
  * @VISU_UI_PANEL_PLANES_N_COLUMNS: the number of columns.
  *
  * Thesse are the description of the columns stored in the #GtkListStore
@@ -67,24 +63,13 @@
  */
 typedef enum
   {
-    VISU_UI_PANEL_PLANES_DRAWN,
-    VISU_UI_PANEL_PLANES_LABEL,
-    VISU_UI_PANEL_PLANES_HIDE_IS_ON,
-    VISU_UI_PANEL_PLANES_HIDDEN_SIDE,
-    VISU_UI_PANEL_PLANES_COLOR_PIXBUF,
     VISU_UI_PANEL_PLANES_POINTER,
+    VISU_UI_PANEL_PLANES_NOTIFY,
     VISU_UI_PANEL_PLANES_N_COLUMNS
   } VisuUiPanelPlanesColumnId;
 
 VisuUiPanel* visu_ui_panel_planes_init();
 
-gboolean visu_ui_panel_planes_load(VisuData *dataObj, gchar *filename, GError **error);
-gboolean visu_ui_panel_planes_setUsed(gboolean value);
-gboolean visu_ui_panel_planes_setRendered(VisuPlane *plane, gboolean status);
-gboolean visu_ui_panel_planes_applyHidingScheme(VisuData *data);
 GtkListStore* visu_ui_panel_planes_getList();
-VisuPlane** visu_ui_panel_planes_getAll(gboolean maskingOnly);
-gboolean visu_ui_panel_planes_add(VisuPlane *plane,
-                                  gboolean hidingStatus, gboolean hidingSide);
 
 #endif
