@@ -2,22 +2,22 @@
 	Copyright CEA, contributeurs : Luc BILLARD, Damien
 	CALISTE, Olivier D'Astier, laboratoire L_Sim, (2001-2005)
   
-	Adresses ml :
-	BILLARD, non joignable par ml ;
+	Adresses mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 	D'ASTIER, dastier AT iie P cnam P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -49,36 +49,31 @@
 #include <gtk/gtk.h>
 #include <visu_data.h>
 #include <coreTools/toolOptions.h>
-#include <extraFunctions/plane.h>
+#include <extraFunctions/planeset.h>
 #include <extraFunctions/surfaces.h>
-#include <extraFunctions/scalarFields.h>
+#include <extraFunctions/sfielddata.h>
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
 
 VisuUiPanel* visu_ui_panel_surfaces_init();
 
-gboolean visu_ui_panel_surfaces_setUsed(gboolean used);
-gboolean visu_ui_panel_surfaces_loadFile(const char* file_name, VisuBox *boxToFit,
-                                         GHashTable *table, VisuScalarFieldMethod *meth);
-void visu_ui_panel_surfaces_addField(VisuScalarField *field, GtkTreeIter *iter);
-void visu_ui_panel_surfaces_addSurfaces(VisuSurfaces *surf, const gchar *name,
+gboolean visu_ui_panel_surfaces_loadFile(const char* file_name,
+                                         GtkTreeIter *iter,
+                                         GHashTable *table,
+                                         VisuScalarFieldMethod *meth);
+void visu_ui_panel_surfaces_addSurfaces(GList *surfs, const gchar *name,
                                         GtkTreeIter *iter);
+void visu_ui_panel_surfaces_addSurface(VisuSurface *surf,
+                                       GtkTreeIter *root, GtkTreeIter *iter);
 
 gboolean visu_ui_panel_surfaces_parseXMLFile(const gchar *filename, GError **error);
 gboolean visu_ui_panel_surfaces_exportXMLFile(const gchar *filename, GError **error);
 gboolean visu_ui_panel_surfaces_showAll(gboolean show);
 void visu_ui_panel_surfaces_editProperties(GtkTreeIter *iter);
 
-void visu_ui_panel_surfaces_add(gchar *filename, float value, gchar *name);
-const VisuSurfaces* visu_ui_panel_surfaces_compute(GtkTreeIter *iter, const float *values,
-                                         const gchar **names, guint nValues);
-const VisuSurfaces* visu_ui_panel_surfaces_computeAuto(GtkTreeIter *iter);
-
-void visu_ui_panel_surfaces_updateAtIter(GtkTreeIter *iter);
-
 /**
  * VisuUiSurfacesFieldId:
  * @VISU_UI_SURFACES_FIELD_LABEL: a string, the description of the scalar field.
- * @VISU_UI_SURFACES_FIELD_POINTER: the pointer to the #VisuScalarField object.
+ * @VISU_UI_SURFACES_FIELD_ROW: a column storing internal pointers.
  * @VISU_UI_SURFACES_FIELD_N_COLUMNS: the number of columns.
  *
  * Thesse are the description of the columns stored in the #GtkListStore
@@ -87,12 +82,12 @@ void visu_ui_panel_surfaces_updateAtIter(GtkTreeIter *iter);
 typedef enum
   {
     VISU_UI_SURFACES_FIELD_LABEL,
-    VISU_UI_SURFACES_FIELD_POINTER,
+    VISU_UI_SURFACES_FIELD_ROW,
     VISU_UI_SURFACES_FIELD_N_COLUMNS
   } VisuUiSurfacesFieldId;
 
 GtkListStore* visu_ui_panel_surfaces_getFields();
-gboolean visu_ui_panel_surfaces_hide(VisuPlane **planes);
+VisuScalarField* visu_ui_panel_surfaces_fieldsAt(GtkTreeModel *model, GtkTreeIter *iter);
 
 /**
  * VISU_UI_SURFACE_NAME_STR:
