@@ -2,22 +2,22 @@
 	Copyright CEA, contributeurs : Luc BILLARD, Damien
 	CALISTE, Olivier D'Astier, laboratoire L_Sim, (2001-2005)
   
-	Adresses ml :
-	BILLARD, non joignable par ml ;
+	Adresses mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 	D'ASTIER, dastier AT iie P cnam P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -231,7 +231,7 @@ gboolean surf_simply_parse_file(char *file_name)
       GtkWidget* choice =  
 	gtk_dialog_new_with_buttons(_("Found different dxx, ..., dzz"),
 				    GTK_WINDOW(convert_window), GTK_DIALOG_MODAL,
-				    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				    TOOL_ICON_CANCEL, GTK_RESPONSE_CANCEL,
 				    _("Keep current values"), GTK_RESPONSE_YES,
 				    _("Change values to new ones"), GTK_RESPONSE_NO, NULL);
       
@@ -286,11 +286,10 @@ void surf_open_file_chooser()
   GtkWidget* file_chooser = 
     gtk_file_chooser_dialog_new("Open .surf file", GTK_WINDOW(convert_window),
 				GTK_FILE_CHOOSER_ACTION_OPEN,
-				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+				TOOL_ICON_CANCEL, GTK_RESPONSE_CANCEL,
+                                TOOL_ICON_OPEN, GTK_RESPONSE_ACCEPT,
 				NULL);
-  gchar *directory = visu_ui_getLastOpenDirectory();
-
+  const gchar *directory = visu_ui_main_getLastOpenDirectory(visu_ui_main_class_getCurrentPanel());
 
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), directory);
@@ -342,11 +341,11 @@ void surfmerge_target_file_chooser(GtkWidget *widget _U_, gpointer data _U_)
   GtkWidget* file_chooser = 
     gtk_file_chooser_dialog_new("Save as .surf file", GTK_WINDOW(convert_window),
 				GTK_FILE_CHOOSER_ACTION_SAVE,
-				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+				TOOL_ICON_CANCEL, GTK_RESPONSE_CANCEL,
+				TOOL_ICON_SAVE, GTK_RESPONSE_ACCEPT,
 				NULL);
-  gchar *directory = visu_ui_getLastOpenDirectory();
-
+  const gchar *directory = visu_ui_main_getLastOpenDirectory(visu_ui_main_class_getCurrentPanel());
+  
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), directory);
 
@@ -816,11 +815,11 @@ GtkWidget *visu_ui_panel_surfaces_tools_fileWidget()
   GtkWidget *manage_bot_tview_vbox = gtk_vbox_new(FALSE, 0);
   GtkWidget *top_tview_hbox = gtk_hbox_new(FALSE, 0);
   GtkWidget *bot_tview_hbox = gtk_hbox_new(FALSE, 0);
-  GtkWidget *image_add = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_BUTTON);
-  GtkWidget *image_remove = gtk_image_new_from_stock ("gtk-remove", GTK_ICON_SIZE_BUTTON);
-  GtkWidget *image_go_down = gtk_image_new_from_stock ("gtk-go-down", GTK_ICON_SIZE_BUTTON);
-  GtkWidget *image_go_up = gtk_image_new_from_stock ("gtk-go-up", GTK_ICON_SIZE_BUTTON);
-  GtkWidget *image_open = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_BUTTON);
+  GtkWidget *image_add = gtk_image_new_from_icon_name("list-add", GTK_ICON_SIZE_BUTTON);
+  GtkWidget *image_remove = gtk_image_new_from_icon_name("list-remove", GTK_ICON_SIZE_BUTTON);
+  GtkWidget *image_go_down = gtk_image_new_from_icon_name("go-down", GTK_ICON_SIZE_BUTTON);
+  GtkWidget *image_go_up = gtk_image_new_from_icon_name("go-up", GTK_ICON_SIZE_BUTTON);
+  GtkWidget *image_open = gtk_image_new_from_icon_name("document-open", GTK_ICON_SIZE_BUTTON);
 
   entry_current_file = gtk_entry_new();
   entry_target_file = gtk_entry_new();
@@ -835,7 +834,7 @@ GtkWidget *visu_ui_panel_surfaces_tools_fileWidget()
   gtk_container_add (GTK_CONTAINER (move_down_surf_button), image_go_down);
   gtk_container_add (GTK_CONTAINER (move_up_surf_button), image_go_up);
   gtk_container_add (GTK_CONTAINER (open_file), image_open);
-  image_open = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_BUTTON);
+  image_open = gtk_image_new_from_icon_name("document-open", GTK_ICON_SIZE_BUTTON);
   gtk_container_add (GTK_CONTAINER (save_file), image_open);
 
   gtk_widget_set_tooltip_text(go_button, 
@@ -897,7 +896,7 @@ GtkWidget *visu_ui_panel_surfaces_tools_fileWidget()
   for(i=0; i<3; i++)
     {
       label = gtk_label_new(ddd[i]);
-      gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+      gtk_label_set_xalign(GTK_LABEL(label), 1.);
       gtk_box_pack_start(GTK_BOX(hbox_top_ddd), label, i==0 ? FALSE : TRUE, TRUE, 0);
       gtk_box_pack_start(GTK_BOX(hbox_top_ddd), surfmerge_source_ddd[i], FALSE, FALSE, 0);
     }      
@@ -905,7 +904,7 @@ GtkWidget *visu_ui_panel_surfaces_tools_fileWidget()
   for(i=3; i<6; i++)
     {
       label = gtk_label_new(ddd[i]);
-      gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+      gtk_label_set_xalign(GTK_LABEL(label), 1.);
       gtk_box_pack_start(GTK_BOX(hbox_top_ddd2), label, i==3 ? FALSE : TRUE, TRUE, 0);
       gtk_box_pack_start(GTK_BOX(hbox_top_ddd2), surfmerge_source_ddd[i], FALSE, FALSE, 0);
     }
@@ -927,7 +926,7 @@ GtkWidget *visu_ui_panel_surfaces_tools_fileWidget()
   for(i=0; i<3; i++)
     {
       label = gtk_label_new(ddd[i]);
-      gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+      gtk_label_set_xalign(GTK_LABEL(label), 1.);
       gtk_box_pack_start(GTK_BOX(hbox_bot_ddd), label, i==0 ? FALSE : TRUE, TRUE, 0);
       gtk_box_pack_start(GTK_BOX(hbox_bot_ddd), surfmerge_target_ddd[i], FALSE, FALSE, 0);
     }      
@@ -935,7 +934,7 @@ GtkWidget *visu_ui_panel_surfaces_tools_fileWidget()
   for(i=3; i<6; i++)
     {
       label = gtk_label_new(ddd[i]);
-      gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+      gtk_label_set_xalign(GTK_LABEL(label), 1.);
       gtk_box_pack_start(GTK_BOX(hbox_bot_ddd2), label, i==3 ? FALSE : TRUE, TRUE, 0);
       gtk_box_pack_start(GTK_BOX(hbox_bot_ddd2), surfmerge_target_ddd[i], FALSE, FALSE, 0);
     }      
@@ -1022,7 +1021,7 @@ void pot2surf_popup_help()
   /* Create a new dialog window for the scrolled window to be
    * packed into.  */
   window = gtk_dialog_new_with_buttons(_("pot2surf_help"), NULL, 0, 
-				       GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
+				       TOOL_ICON_OPEN, GTK_RESPONSE_ACCEPT, NULL);
   gtk_container_set_border_width (GTK_CONTAINER (window), 0);
   gtk_widget_set_size_request (window, 600, 300);
     
@@ -1035,9 +1034,13 @@ void pot2surf_popup_help()
   /* The dialog window is created with a vbox packed into it. */
   gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(window))),
 		     scrolled_window, TRUE, TRUE, 0);
-    
+
+#if GTK_MAJOR_VERSION < 3 || (GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 8)
   gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW (scrolled_window),
 					text_view);
+#else
+  gtk_container_add(GTK_CONTAINER(scrolled_window), text_view);
+#endif
     
   gtk_widget_show_all (window);
 
@@ -1142,11 +1145,12 @@ void pot2surf_select_pot_file(GtkWidget *widget _U_, gpointer data _U_)
   GtkWidget* file_chooser = 
     gtk_file_chooser_dialog_new("Select a .pot file", GTK_WINDOW(convert_window),
 				GTK_FILE_CHOOSER_ACTION_OPEN,
-				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				TOOL_ICON_CANCEL, GTK_RESPONSE_CANCEL,
 /* 				GTK_STOCK_HELP, GTK_RESPONSE_HELP, */
-				GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
-  gchar *directory = visu_ui_getLastOpenDirectory();
-
+				TOOL_ICON_OPEN, GTK_RESPONSE_ACCEPT, NULL);
+  const gchar *directory = visu_ui_main_getLastOpenDirectory(visu_ui_main_class_getCurrentPanel());
+  gchar *dir;
+  
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), directory);
 
@@ -1186,9 +1190,10 @@ void pot2surf_select_pot_file(GtkWidget *widget _U_, gpointer data _U_)
 	      gtk_entry_set_text(GTK_ENTRY(pot2surf_entry_target_surf_file), other_files->str);
 	      g_string_free(other_files, TRUE);
 
-	      directory = (char*)gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser));
-	      visu_ui_setLastOpenDirectory(directory, VISU_UI_DIR_SURFACE);
-	      g_free(directory);
+	      dir = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser));
+	      visu_ui_main_setLastOpenDirectory(visu_ui_main_class_getCurrentPanel(),
+                                                dir, VISU_UI_DIR_SURFACE);
+	      g_free(dir);
 	      gtk_list_store_clear(pot2surf_list_store);
 	      gtk_widget_destroy(file_chooser);
 	      return;
@@ -1198,9 +1203,10 @@ void pot2surf_select_pot_file(GtkWidget *widget _U_, gpointer data _U_)
 	  break;
 	case GTK_RESPONSE_CANCEL:
 	default:
-	  directory = (char*)gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser));
-	  visu_ui_setLastOpenDirectory(directory, VISU_UI_DIR_SURFACE);
-	  g_free(directory);
+	  dir = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser));
+	  visu_ui_main_setLastOpenDirectory(visu_ui_main_class_getCurrentPanel(),
+                                            dir, VISU_UI_DIR_SURFACE);
+	  g_free(dir);
 	  gtk_widget_destroy (file_chooser);
 	  return;
 	}
@@ -1265,10 +1271,11 @@ void pot2surf_select_surf_file(GtkWidget *widget _U_, gpointer data _U_)
   GtkWidget* file_chooser = 
     gtk_file_chooser_dialog_new("Select a .surf file", GTK_WINDOW(convert_window),
 				GTK_FILE_CHOOSER_ACTION_SAVE,
-				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				TOOL_ICON_CANCEL, GTK_RESPONSE_CANCEL,
 /* 				GTK_STOCK_HELP, GTK_RESPONSE_HELP, */
-				GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
-  gchar *directory = visu_ui_getLastOpenDirectory();
+				TOOL_ICON_OPEN, GTK_RESPONSE_ACCEPT, NULL);
+  const gchar *directory = visu_ui_main_getLastOpenDirectory(visu_ui_main_class_getCurrentPanel());
+  gchar *dir;
 
   if (directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), directory);
@@ -1291,19 +1298,21 @@ void pot2surf_select_surf_file(GtkWidget *widget _U_, gpointer data _U_)
 	  selected_file = 
 	    gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_chooser));
 	  gtk_entry_set_text(GTK_ENTRY(pot2surf_entry_target_surf_file), selected_file);
-      directory = (char*)gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser));
-      visu_ui_setLastOpenDirectory(directory, VISU_UI_DIR_SURFACE);
-      g_free(directory);
+          dir = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser));
+          visu_ui_main_setLastOpenDirectory(visu_ui_main_class_getCurrentPanel(),
+                                            dir, VISU_UI_DIR_SURFACE);
+          g_free(dir);
 	  gtk_widget_destroy(file_chooser);
 	  return;
 	case GTK_RESPONSE_HELP:
 	  break;
 	case GTK_RESPONSE_CANCEL:
 	default:
-      directory = (char*)gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser));
-      visu_ui_setLastOpenDirectory(directory, VISU_UI_DIR_SURFACE);
-      g_free(directory);
-	  gtk_widget_destroy (file_chooser);
+          dir = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser));
+          visu_ui_main_setLastOpenDirectory(visu_ui_main_class_getCurrentPanel(),
+                                            dir, VISU_UI_DIR_SURFACE);
+          g_free(dir);
+          gtk_widget_destroy (file_chooser);
 	  return;
 	}
     }
@@ -1318,7 +1327,7 @@ void pot2surf_update_surf_name(GtkCellRendererText *cellrenderertext _U_,
   g_return_if_fail(gtk_tree_model_get_iter_from_string
 		   (GTK_TREE_MODEL(pot2surf_list_store), &iter, path));
 
-  DBG_fprintf(stderr, "Panel VisuSurfacesTools: entered text '%s'.\n", text);
+  DBG_fprintf(stderr, "Panel VisuSurfaceTools: entered text '%s'.\n", text);
   if (!strcmp(text, VISU_UI_SURFACE_NAME_STR))
     gtk_list_store_set(pot2surf_list_store, &iter,
 		       POT2SURF_NAME, VISU_UI_SURFACE_NAME_CHOOSE, -1);
@@ -1585,7 +1594,7 @@ void pot2surf_select_instruc_file_to_save()
   GtkFileFilter *filter_instruc;
   GtkFileFilter *filter_none;
   GtkWidget* file_chooser;
-  char *directory = visu_ui_getLastOpenDirectory();
+  const char *directory = visu_ui_main_getLastOpenDirectory(visu_ui_main_class_getCurrentPanel());
   int n=0;
   const gchar *pot_file = gtk_entry_get_text(GTK_ENTRY(pot2surf_entry_source_pot_file));
   const gchar *surf_file = gtk_entry_get_text(GTK_ENTRY(pot2surf_entry_target_surf_file));
@@ -1619,8 +1628,8 @@ void pot2surf_select_instruc_file_to_save()
   filter_none = gtk_file_filter_new();
   file_chooser = gtk_file_chooser_dialog_new("Save as a .instruc file", GTK_WINDOW(convert_window),
 					     GTK_FILE_CHOOSER_ACTION_SAVE,
-					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					     GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
+					     TOOL_ICON_CANCEL, GTK_RESPONSE_CANCEL,
+					     TOOL_ICON_SAVE, GTK_RESPONSE_ACCEPT, NULL);
   if(directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), directory);
   
@@ -1642,7 +1651,8 @@ void pot2surf_select_instruc_file_to_save()
 					gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_chooser)), n))
 	   
 	  break;
-	visu_ui_setLastOpenDirectory(gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser)), VISU_UI_DIR_SURFACE);
+	visu_ui_main_setLastOpenDirectory(visu_ui_main_class_getCurrentPanel(),
+                                          gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser)), VISU_UI_DIR_SURFACE);
 	g_string_free(default_file, TRUE);
 	gtk_widget_destroy(file_chooser);
 	return;
@@ -1686,6 +1696,7 @@ gboolean pot2surf_build_surf_file(GtkWidget *button _U_, gpointer data)
   gchar **names = NULL;
   struct surf *surfaces = NULL;
   int n=0, i;
+  GtkTreeIter iter;
   const gchar *pot_file = gtk_entry_get_text(GTK_ENTRY(pot2surf_entry_source_pot_file));
   const gchar *surf_file = gtk_entry_get_text(GTK_ENTRY(pot2surf_entry_target_surf_file));
 
@@ -1728,7 +1739,7 @@ gboolean pot2surf_build_surf_file(GtkWidget *button _U_, gpointer data)
 	names[i] = (gchar*)0;
     }  
 
-  if(visu_surfaces_createFromPotentialFile(surf_file, pot_file, n, values, (const gchar **)names) != 0)
+  if(visu_surface_createFromPotentialFile(surf_file, pot_file, n, values, (const gchar **)names) != 0)
     {
       visu_ui_raiseWarning(_("Saving a file"),
 			   _("Error"), (GtkWindow*)0);
@@ -1742,7 +1753,7 @@ gboolean pot2surf_build_surf_file(GtkWidget *button _U_, gpointer data)
 
   if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data)))
     {
-      if(visu_ui_panel_surfaces_loadFile(surf_file, (VisuBox*)0,
+      if(visu_ui_panel_surfaces_loadFile(surf_file, &iter,
                                          (GHashTable*)0, (VisuScalarFieldMethod*)0) == 0)
 	{
 	  for(i=0; i<n; i++)
@@ -1919,9 +1930,9 @@ void pot2surf_select_instruc_file_to_load()
   GtkWidget* file_chooser = 
     gtk_file_chooser_dialog_new("Opens a .instruc file", GTK_WINDOW(convert_window),
 				GTK_FILE_CHOOSER_ACTION_OPEN,
-				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
-  char *directory = visu_ui_getLastOpenDirectory();
+				TOOL_ICON_CANCEL, GTK_RESPONSE_CANCEL,
+				TOOL_ICON_OPEN, GTK_RESPONSE_ACCEPT, NULL);
+  const char *directory = visu_ui_main_getLastOpenDirectory(visu_ui_main_class_getCurrentPanel());
 
   if(directory)
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser), directory);
@@ -1940,7 +1951,8 @@ void pot2surf_select_instruc_file_to_load()
       case GTK_RESPONSE_ACCEPT:
 	if(!pot2surf_load_instruc_file(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_chooser))))
 	  break;
-	visu_ui_setLastOpenDirectory(gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser)), VISU_UI_DIR_SURFACE);
+	visu_ui_main_setLastOpenDirectory(visu_ui_main_class_getCurrentPanel(),
+                                          gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER (file_chooser)), VISU_UI_DIR_SURFACE);
 	gtk_widget_destroy(file_chooser);
 	return;
       case GTK_RESPONSE_CANCEL:
@@ -1957,9 +1969,9 @@ GtkWidget* visu_ui_panel_surfaces_tools_convertWidget()
   GtkTooltips *tooltips = gtk_tooltips_new ();
 #endif
 
-  GtkToolItem *instruc_open = gtk_tool_button_new_from_stock(GTK_STOCK_OPEN);
-  GtkToolItem *instruc_save = gtk_tool_button_new_from_stock(GTK_STOCK_SAVE_AS);
-  GtkToolItem *instruc_help = gtk_tool_button_new_from_stock(GTK_STOCK_HELP);
+  GtkToolItem *instruc_open = gtk_tool_button_new(NULL, NULL);
+  GtkToolItem *instruc_save = gtk_tool_button_new(NULL, NULL);
+  GtkToolItem *instruc_help = gtk_tool_button_new(NULL, NULL);
   GtkToolItem* separator = gtk_separator_tool_item_new();
   GtkWidget *main_vbox = gtk_vbox_new(FALSE, 0);
 
@@ -1986,15 +1998,19 @@ GtkWidget* visu_ui_panel_surfaces_tools_convertWidget()
   GtkWidget *build_surf_button = gtk_button_new_with_label(_("Build"));
   GtkWidget *autoload_checkbox = gtk_check_button_new_with_label (_("Autoload in V_Sim"));
 
-  GtkWidget *image_execute = gtk_image_new_from_stock ("gtk-execute", GTK_ICON_SIZE_BUTTON);
-  GtkWidget *image_add = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_BUTTON);
-  GtkWidget *image_remove = gtk_image_new_from_stock ("gtk-remove", GTK_ICON_SIZE_BUTTON);
-  GtkWidget *image_go_up = gtk_image_new_from_stock ("gtk-go-up", GTK_ICON_SIZE_BUTTON);
-  GtkWidget *image_go_down = gtk_image_new_from_stock ("gtk-go-down", GTK_ICON_SIZE_BUTTON);
-  GtkWidget *image_open = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_BUTTON);
+  GtkWidget *image_execute = gtk_image_new_from_icon_name("system-execute", GTK_ICON_SIZE_BUTTON);
+  GtkWidget *image_add = gtk_image_new_from_icon_name("list-add", GTK_ICON_SIZE_BUTTON);
+  GtkWidget *image_remove = gtk_image_new_from_icon_name("list-remove", GTK_ICON_SIZE_BUTTON);
+  GtkWidget *image_go_up = gtk_image_new_from_icon_name("go-up", GTK_ICON_SIZE_BUTTON);
+  GtkWidget *image_go_down = gtk_image_new_from_icon_name("go-down", GTK_ICON_SIZE_BUTTON);
+  GtkWidget *image_open = gtk_image_new_from_icon_name("document-open", GTK_ICON_SIZE_BUTTON);
 
   GtkWidget *toolbar = gtk_toolbar_new();
 
+  gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(instruc_open), "document-open");
+  gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(instruc_save), "document-save-as");
+  gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(instruc_help), "help-browser");
+
   gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_BOTH_HORIZ);
   gtk_widget_set_name(toolbar, "message_toolbar");
   gtk_widget_set_name(autoload_checkbox, "message_tog");
@@ -2061,7 +2077,7 @@ GtkWidget* visu_ui_panel_surfaces_tools_convertWidget()
   gtk_container_add (GTK_CONTAINER (move_down_button), image_go_down);
   gtk_container_add (GTK_CONTAINER (move_up_button), image_go_up);
   gtk_container_add (GTK_CONTAINER (pot_open_button), image_open);
-  image_open = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_BUTTON);
+  image_open = gtk_image_new_from_icon_name("document-open", GTK_ICON_SIZE_BUTTON);
   gtk_container_add (GTK_CONTAINER (surf_open_button), image_open);
 
   gtk_toolbar_insert(GTK_TOOLBAR(toolbar), instruc_open, 0);
@@ -2144,7 +2160,6 @@ void visu_ui_panel_surfaces_tools_init()
 {
   GtkWidget *main_vbox;
   GtkWidget *convert_notebook;
-  GtkWidget *close_button_alignement;
   GtkWidget *close_button;
   GtkWidget *merge_label;
   GtkWidget *pot2surf_label;
@@ -2155,8 +2170,7 @@ void visu_ui_panel_surfaces_tools_init()
   
   main_vbox = gtk_vbox_new(FALSE, 0);
   convert_notebook = gtk_notebook_new();
-  close_button_alignement = gtk_alignment_new(1, 0.5, 0, 0);
-  close_button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
+  close_button = gtk_button_new_from_icon_name("window-close", GTK_ICON_SIZE_BUTTON);
   merge_label = gtk_label_new(_("Merge"));
   pot2surf_label = gtk_label_new(_("pot2surf"));
 
@@ -2176,8 +2190,7 @@ void visu_ui_panel_surfaces_tools_init()
 
 
   gtk_box_pack_start(GTK_BOX(main_vbox), convert_notebook, TRUE, TRUE, 0);
-  gtk_box_pack_start(GTK_BOX(main_vbox), close_button_alignement, FALSE, FALSE, 1);
-  gtk_container_add (GTK_CONTAINER (close_button_alignement), close_button);  
+  gtk_box_pack_start(GTK_BOX(main_vbox), close_button, FALSE, FALSE, 1);
 
   g_signal_connect(convert_window, "destroy",
 		   G_CALLBACK(visu_ui_panel_surfaces_tools_init_destroy), NULL);
