@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -45,74 +45,19 @@
 #define VISU_BASIC_H
 
 #include <glib.h>
-#include "visu_data.h"
 #include "visu_tools.h"
-#include "coreTools/toolFileFormat.h"
-#include "coreTools/toolOptions.h"
-#include "coreTools/toolShade.h"
 #include "coreTools/toolPhysic.h"
-#include "extraFunctions/plane.h"
-#include "extraFunctions/surfaces.h"
-#include "extraFunctions/scalarFields.h"
-#include "extraFunctions/map.h"
-#include "extensions/infos.h"
 
 G_BEGIN_DECLS
 
-/**
- * VisuBasicCLISet:
- * @colorFile: TODO
- * @planesList: TODO
- * @surfsList: TODO
- * @fieldsList: TODO
- * @mapsList: TODO
- * @shade: TODO
- * @mapPlaneId: TODO
- * @logScale: TODO
- * @nIsolines: TODO
- * @isoLinesColor: TODO
- * @bgImage: TODO
- *
- * Internal object to store values read from command line.
- */
-typedef struct _VisuBasicCLISet VisuBasicCLISet;
-
-struct _VisuBasicCLISet
-{
-  gchar *colorFile;
-
-  VisuPlane **planesList;
-
-  VisuSurfaces **surfsList;
-  GList *fieldsList;
-
-  VisuMap **mapsList;
-
-  ToolShade *shade;
-
-  gint *mapPlaneId;
-  ToolMatrixScalingFlag logScale;
-  guint nIsolines;
-  ToolColor* isoLinesColor;
-
-  gchar *bgImage;
-};
-
 void visu_basic_init(void);
+void visu_basic_initConfigFiles(GError **error);
 
 /* Common parse routines. */
-gchar* visu_basic_parseConfigFiles(VisuGlView *view);
-gboolean visu_basic_applyCommandLine(VisuData *data, VisuGlView *view,
-                                     VisuBasicCLISet *set, GError **error);
+gboolean visu_basic_parseConfigFiles(GError **error);
 gboolean visu_basic_showOptionHelp(gboolean force);
 
 /* Export routines. */
-void visu_basic_createExtensions(VisuData *data, VisuGlView *view,
-                                 VisuBasicCLISet *set, gboolean rebuild);
-VisuData* visu_basic_setDataFromCommandLine(void);
-void visu_basic_setExtInfos(VisuData *dataObj, VisuGlView *view,
-                            VisuGlExtInfosDrawMethod method,
-                            int *nodes, VisuDataNode *data);
 int visu_basic_mainExport(void);
 
 /* Some resources. */
