@@ -46,7 +46,9 @@
 #include <math.h>
 
 #include "visu_tools.h"
+#include "visu_data.h" /* To be removed! */
 #include "iface_boxed.h"
+#include "iface_nodemasker.h"
 #include "coreTools/toolMatrix.h"
 
 /**
@@ -56,19 +58,6 @@
  * <para></para>
  */
 
-/**
- * VisuBox:
- *
- * Opaque structure to stores #VisuBox object.
- */
-
-/**
- * VisuBoxClass:
- * @parent: private.
- *
- * Class structure of #VisuBox objects.
- */
-
 /* Local methods. */
 static gfloat _getBoxExtens(const VisuBox *box, gboolean withExt);
 static void _setUpGeometry(VisuBox *box, gboolean emit);
@@ -89,11 +78,14 @@ struct _VisuBoxPrivate
   /* The periodicity. */
   VisuBoxBoundaries bc;
   /* The extension of the box. */
+  gboolean extActive;
   float extension[3];
 
   /* This is the geometry of the box. Array position 1 to 6
      correspond to xx, xy, yy, zx, zy and zz. */
   double cell[6];
+  /* This is the origin in cartesian coordinates of the box origin. */
+  double origin[3];
   /* The longest length in the box (with or without extension), and
      the margin to add. */
   float extens[2], margin;
@@ -111,26 +103,49 @@ struct _VisuBoxPrivate
      matrix and that cartesian coordinates need rotation before
      storing them. */
   float fromFullToCell[3][3];
+
+  VisuBoxHiddingStatus hidding;
 };
 
 enum {
   SIZE_CHANGED_SIGNAL,
   UNIT_CHANGED_SIGNAL,
-  BOUNDARY_CHANGED_SIGNAL,
-  EXTENSION_CHANGED_SIGNAL,
   LAST_SIGNAL
 };
-static guint visu_box_signals[LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL] = { 0 };
+enum
+  {
+    PROP_0,
+    UNITS_PROP,
+    EXPAND_PROP,
+    USE_EXPAND_PROP,
+    BC_PROP,
+    HIDDING_PROP,
+    N_PROP,
+    ADJUST_PROP,
+    BOX_PROP
+  };
+static GParamSpec *properties[N_PROP];
+
 
 static void visu_box_dispose     (GObject* obj);
 static void visu_box_finalize    (GObject* obj);
+static void visu_box_get_property(GObject* obj, guint property_id,
+                                  GValue *value, GParamSpec *pspec);
+static void visu_box_set_property(GObject* obj, guint property_id,
+                                  const GValue *value, GParamSpec *pspec);
 static void visu_boxed_interface_init(VisuBoxedInterface *iface);
+static void visu_node_masker_interface_init(VisuNodeMaskerInterface *iface);
 
-G_DEFINE_TYPE_WITH_CODE(VisuBox, visu_box, G_TYPE_OBJECT,
+G_DEFINE_TYPE_WITH_CODE(VisuBox, visu_box, VISU_TYPE_OBJECT,
+                        G_ADD_PRIVATE(VisuBox)
+                        G_IMPLEMENT_INTERFACE(VISU_TYPE_NODE_MASKER,
+                                              visu_node_masker_interface_init)
                         G_IMPLEMENT_INTERFACE(VISU_TYPE_BOXED,
                                               visu_boxed_interface_init))
 
 static VisuBox* _getBox(VisuBoxed *self);
+static gboolean _maskApply(const VisuNodeMasker *self, VisuNodeArray *array);
 
 static void visu_box_class_init(VisuBoxClass *klass)
 {
@@ -148,7 +163,7 @@ static void visu_box_class_init(VisuBoxClass *klass)
    *
    * Since: 3.7
    */
-  visu_box_signals[SIZE_CHANGED_SIGNAL] =
+  signals[SIZE_CHANGED_SIGNAL] =
     g_signal_new("SizeChanged", G_TYPE_FROM_CLASS(klass),
                  G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
                  0, NULL, NULL, g_cclosure_marshal_VOID__FLOAT,
@@ -162,50 +177,85 @@ static void visu_box_class_init(VisuBoxClass *klass)
    *
    * Since: 3.7
    */
-  visu_box_signals[UNIT_CHANGED_SIGNAL] =
+  signals[UNIT_CHANGED_SIGNAL] =
     g_signal_new("UnitChanged", G_TYPE_FROM_CLASS(klass),
                  G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
 		 0, NULL, NULL, g_cclosure_marshal_VOID__FLOAT,
                  G_TYPE_NONE, 1, G_TYPE_FLOAT, NULL);
-  /**
-   * VisuBox::BoundaryChanged:
-   * @box: the object which received the signal ;
-   *
-   * Gets emitted when the boundary conditions are changed.
-   *
-   * Since: 3.7
-   */
-  visu_box_signals[BOUNDARY_CHANGED_SIGNAL] =
-    g_signal_new("BoundaryChanged", G_TYPE_FROM_CLASS(klass),
-                 G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
-		 0, NULL, NULL, g_cclosure_marshal_VOID__VOID,
-                 G_TYPE_NONE, 0, NULL);
-  /**
-   * VisuBox::ExtensionChanged:
-   * @box: the object which received the signal ;
-   *
-   * Gets emitted when the extension of the box is changed. The new
-   * size of the box is not yet computed, listen to
-   * VisuBox::SizeChanged instead.
-   *
-   * Since: 3.7
-   */
-  visu_box_signals[EXTENSION_CHANGED_SIGNAL] =
-    g_signal_new("ExtensionChanged", G_TYPE_FROM_CLASS(klass),
-                 G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
-		 0, NULL, NULL, g_cclosure_marshal_VOID__VOID,
-                 G_TYPE_NONE, 0, NULL);
 
   /* Connect the overloading methods. */
   G_OBJECT_CLASS(klass)->dispose  = visu_box_dispose;
   G_OBJECT_CLASS(klass)->finalize = visu_box_finalize;
+  G_OBJECT_CLASS(klass)->set_property = visu_box_set_property;
+  G_OBJECT_CLASS(klass)->get_property = visu_box_get_property;
 
-  g_type_class_add_private(klass, sizeof(VisuBoxPrivate));
+  /**
+   * VisuBox::units:
+   *
+   * The units of the length dimensions.
+   *
+   * Since: 3.8
+   */
+  properties[UNITS_PROP] = g_param_spec_uint("units", "Units",
+                                             "Units of dimensions",
+                                             TOOL_UNITS_UNDEFINED, TOOL_UNITS_N_VALUES - 1,
+                                             TOOL_UNITS_UNDEFINED, G_PARAM_READWRITE);
+  /**
+   * VisuBox::expansion:
+   *
+   * The expansion applied on [x,y,z] axis.
+   *
+   * Since: 3.8
+   */
+  properties[EXPAND_PROP] = g_param_spec_boxed("expansion", "Expansion on all axis",
+                                               "Expanion on all axis",
+                                               TOOL_TYPE_VECTOR, G_PARAM_READWRITE);
+  /**
+   * VisuBox::use-expansion:
+   *
+   * Wether the expansion is applied or not.
+   *
+   * Since: 3.8
+   */
+  properties[USE_EXPAND_PROP] = g_param_spec_boolean("use-expansion", "Use expansion",
+                                                     "Expanion is active or not",
+                                                     FALSE, G_PARAM_READWRITE);
+  /**
+   * VisuBox::boundary:
+   *
+   * The boundary conditions of the box.
+   *
+   * Since: 3.8
+   */
+  properties[BC_PROP] = g_param_spec_uint("boundary", "Boundary",
+                                          "Boundary conditions",
+                                          VISU_BOX_FREE, VISU_BOX_PERIODIC,
+                                          VISU_BOX_PERIODIC, G_PARAM_READWRITE);
+  /**
+   * VisuBox::hidding-scheme:
+   *
+   * The hidding scheme used by the box, if any.
+   *
+   * Since: 3.8
+   */
+  properties[HIDDING_PROP] = g_param_spec_uint("hidding-scheme", "Hidding scheme",
+                                               "hidding scheme used by the box.",
+                                               VISU_BOX_HIDE_NONE, VISU_BOX_HIDE_INSIDE,
+                                               VISU_BOX_HIDE_NONE, G_PARAM_READWRITE);
+
+  g_object_class_install_properties(G_OBJECT_CLASS(klass), N_PROP, properties);
+
+  g_object_class_override_property(G_OBJECT_CLASS(klass), ADJUST_PROP, "auto-adjust");
+  g_object_class_override_property(G_OBJECT_CLASS(klass), BOX_PROP, "box");
 }
 static void visu_boxed_interface_init(VisuBoxedInterface *iface)
 {
   iface->get_box = _getBox;
 }
+static void visu_node_masker_interface_init(VisuNodeMaskerInterface *iface)
+{
+  iface->apply = _maskApply;
+}
 
 static void visu_box_init(VisuBox *box)
 {
@@ -213,19 +263,24 @@ static void visu_box_init(VisuBox *box)
 
   DBG_fprintf(stderr, "Visu Box: initializing a new object (%p).\n",
 	      (gpointer)box);
-  box->priv = G_TYPE_INSTANCE_GET_PRIVATE(box, VISU_TYPE_BOX, VisuBoxPrivate);
+  box->priv = visu_box_get_instance_private(box);
   box->priv->dispose_has_run = FALSE;
 
+  box->priv->extActive        = FALSE;
   for (i = 0; i < 3; i++)
     box->priv->extension[i]   = 0.;
   for (i = 0; i < 6; i++)
     box->priv->cell[i]        = G_MAXFLOAT;
+  box->priv->origin[0]        = 0.;
+  box->priv->origin[1]        = 0.;
+  box->priv->origin[2]        = 0.;
   box->priv->bc               = VISU_BOX_FREE;
   box->priv->extens[0]        = G_MAXFLOAT;
   box->priv->extens[1]        = G_MAXFLOAT;
   box->priv->margin           = G_MAXFLOAT;
   box->priv->fromFullToCell[0][0] = G_MAXFLOAT;
   box->priv->units            = TOOL_UNITS_UNDEFINED;
+  box->priv->hidding          = VISU_BOX_HIDE_NONE;
 }
 
 /* This method can be called several times.
@@ -261,6 +316,69 @@ static void visu_box_finalize(GObject* obj)
   G_OBJECT_CLASS(visu_box_parent_class)->finalize(obj);
   DBG_fprintf(stderr, "Visu Box: freeing ... OK.\n");
 }
+static void visu_box_get_property(GObject* obj, guint property_id,
+                                  GValue *value, GParamSpec *pspec)
+{
+  VisuBox *self = VISU_BOX(obj);
+
+  DBG_fprintf(stderr, "Visu Box: get property '%s'.\n",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case BOX_PROP:
+      g_value_set_object(value, obj);
+      break;
+    case UNITS_PROP:
+      g_value_set_uint(value, self->priv->units);
+      break;
+    case USE_EXPAND_PROP:
+      g_value_set_boolean(value, self->priv->extActive);
+      break;
+    case EXPAND_PROP:
+      g_value_set_static_boxed(value, (gpointer)self->priv->extension);
+      break;
+    case BC_PROP:
+      g_value_set_uint(value, self->priv->bc);
+      break;
+    case HIDDING_PROP:
+      g_value_set_uint(value, self->priv->hidding);
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
+static void visu_box_set_property(GObject* obj, guint property_id,
+                                  const GValue *value, GParamSpec *pspec)
+{
+  VisuBox *self = VISU_BOX(obj);
+
+  DBG_fprintf(stderr, "Visu Box: set property '%s'.\n",
+	      g_param_spec_get_name(pspec));
+  switch (property_id)
+    {
+    case UNITS_PROP:
+      visu_box_setUnit(self, g_value_get_uint(value));
+      break;
+    case USE_EXPAND_PROP:
+      visu_box_setExtensionActive(self, g_value_get_boolean(value));
+      break;
+    case EXPAND_PROP:
+      visu_box_setExtension(self, (gfloat*)g_value_get_boxed(value));
+      break;
+    case BC_PROP:
+      visu_box_setBoundary(self, g_value_get_uint(value));
+      break;
+    case HIDDING_PROP:
+      visu_box_setHiddingStatus(self, g_value_get_uint(value));
+      break;
+    default:
+      /* We don't have any other property... */
+      G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
+      break;
+    }
+}
 
 /**
  * visu_box_new:
@@ -293,7 +411,10 @@ VisuBox* visu_box_new(double geometry[VISU_BOX_N_VECTORS],
  * @full: (array fixed-size=9): a cell definition (full matrix).
  * @bc: a boundary condition.
  *
- * A #VisuBox object store the definition of a cell.
+ * A #VisuBox object stores the definition of a cell. This may fail,
+ * if @full does not define a 3D basis set (the three vectors are not
+ * linearly independant). To check this, use visu_box_getGeometry() to
+ * test if the first vector is #G_MAXFLOAT.
  *
  * Since: 3.7
  *
@@ -308,8 +429,7 @@ VisuBox* visu_box_new_full(double full[3][3], VisuBoxBoundaries bc)
   box = VISU_BOX(g_object_new(VISU_TYPE_BOX, NULL));
 
   visu_box_setBoundary(box, bc);
-  if (!visu_box_setGeometryFull(box, full))
-    g_warning("The basis is not 3D.");
+  visu_box_setGeometryFull(box, full);
 
   return box;
 }
@@ -336,8 +456,7 @@ gboolean visu_box_setBoundary(VisuBox *box, VisuBoxBoundaries bc)
   box->priv->bc = bc;
 
   DBG_fprintf(stderr, "Visu Box: emit 'BoundaryChanged'.\n");
-  g_signal_emit(box, visu_box_signals[BOUNDARY_CHANGED_SIGNAL],
-                0, NULL);
+  g_object_notify_by_pspec(G_OBJECT(box), properties[BC_PROP]);
   DBG_fprintf(stderr, "Visu Box: emission done (BoundaryChanged).\n");
   return TRUE;
 }
@@ -371,12 +490,35 @@ void visu_box_getPeriodicity(VisuBox *box, gboolean per[3])
 {
   g_return_if_fail(VISU_IS_BOX(box));
 
-  per[0] = !(box->priv->bc == VISU_BOX_FREE ||
-             box->priv->bc == VISU_BOX_SURFACE_YZ);
-  per[1] = !(box->priv->bc == VISU_BOX_FREE ||
-             box->priv->bc == VISU_BOX_SURFACE_ZX);
-  per[2] = !(box->priv->bc == VISU_BOX_FREE ||
-             box->priv->bc == VISU_BOX_SURFACE_XY);
+  per[0] = box->priv->bc & TOOL_XYZ_MASK_X;
+  per[1] = box->priv->bc & TOOL_XYZ_MASK_Y;
+  per[2] = box->priv->bc & TOOL_XYZ_MASK_Z;
+}
+
+/**
+ * visu_box_setOrigin:
+ * @box: a #VisuBox orbject.
+ * @orig: (array fixed-size=3): the new origin
+ *
+ * Change the origin of @box.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if origin is indeed changed.
+ **/
+gboolean visu_box_setOrigin(VisuBox *box, const float orig[3])
+{
+  g_return_val_if_fail(VISU_IS_BOX(box), FALSE);
+
+  if (orig[0] == box->priv->origin[0] &&
+      orig[1] == box->priv->origin[1] &&
+      orig[2] == box->priv->origin[2])
+    return FALSE;
+
+  box->priv->origin[0] = orig[0];
+  box->priv->origin[1] = orig[1];
+  box->priv->origin[2] = orig[2];
+  return TRUE;
 }
 
 /**
@@ -456,12 +598,13 @@ static void _setUpGeometry(VisuBox *box, gboolean emit)
   _setUpMatrixFromCell(box);
   box->priv->extens[0] = _getBoxExtens(box, FALSE);
   box->priv->extens[1] = _getBoxExtens(box, TRUE);
-  DBG_fprintf(stderr, "Visu Box: set box geometry done.\n");
+  DBG_fprintf(stderr, "Visu Box: set box geometry done (%g %g).\n",
+              box->priv->extens[0], box->priv->extens[1]);
 
   if (box->priv->cell[0] != G_MAXFLOAT && box->priv->margin != G_MAXFLOAT && emit)
     {
       DBG_fprintf(stderr, "Visu Box: emit SizeChanged.\n");
-      g_signal_emit(box, visu_box_signals[SIZE_CHANGED_SIGNAL],
+      g_signal_emit(box, signals[SIZE_CHANGED_SIGNAL],
                     0, box->priv->extens[1] + box->priv->margin, NULL);
       DBG_fprintf(stderr, "Visu Box: emission done (SizeChanged).\n");
     }
@@ -519,17 +662,17 @@ static gfloat _getBoxExtens(const VisuBox *box, gboolean withExt)
   float geometry[VISU_BOX_N_VECTORS];
 
   /* calculate bare = 1/2 radius of centered sample */
-  geometry[VISU_BOX_DXX] = (withExt)?box->priv->cell[VISU_BOX_DXX] *
+  geometry[VISU_BOX_DXX] = (withExt && box->priv->extActive)?box->priv->cell[VISU_BOX_DXX] *
     (1. + 2. * box->priv->extension[0]):box->priv->cell[VISU_BOX_DXX];
-  geometry[VISU_BOX_DYX] = (withExt)?box->priv->cell[VISU_BOX_DYX] *
+  geometry[VISU_BOX_DYX] = (withExt && box->priv->extActive)?box->priv->cell[VISU_BOX_DYX] *
     (1. + 2. * box->priv->extension[1]):box->priv->cell[VISU_BOX_DYX];
-  geometry[VISU_BOX_DZX] = (withExt)?box->priv->cell[VISU_BOX_DZX] *
+  geometry[VISU_BOX_DZX] = (withExt && box->priv->extActive)?box->priv->cell[VISU_BOX_DZX] *
     (1. + 2. * box->priv->extension[2]):box->priv->cell[VISU_BOX_DZX];
-  geometry[VISU_BOX_DYY] = (withExt)?box->priv->cell[VISU_BOX_DYY] *
+  geometry[VISU_BOX_DYY] = (withExt && box->priv->extActive)?box->priv->cell[VISU_BOX_DYY] *
     (1. + 2. * box->priv->extension[1]):box->priv->cell[VISU_BOX_DYY];
-  geometry[VISU_BOX_DZY] = (withExt)?box->priv->cell[VISU_BOX_DZY] *
+  geometry[VISU_BOX_DZY] = (withExt && box->priv->extActive)?box->priv->cell[VISU_BOX_DZY] *
     (1. + 2. * box->priv->extension[2]):box->priv->cell[VISU_BOX_DZY];
-  geometry[VISU_BOX_DZZ] = (withExt)?box->priv->cell[VISU_BOX_DZZ] *
+  geometry[VISU_BOX_DZZ] = (withExt && box->priv->extActive)?box->priv->cell[VISU_BOX_DZZ] *
     (1. + 2. * box->priv->extension[2]):box->priv->cell[VISU_BOX_DZZ];
 
   dz = geometry[VISU_BOX_DZZ];
@@ -572,12 +715,13 @@ gboolean visu_box_setMargin(VisuBox *box, gfloat margin, gboolean emit)
   if (margin < 0.f || margin == box->priv->margin)
     return FALSE;
 
+  DBG_fprintf(stderr, "Visu Box: set margin to %g (was %g).\n", margin, box->priv->margin);
   box->priv->margin = margin;
 
   if (box->priv->cell[0] != G_MAXFLOAT && box->priv->margin != G_MAXFLOAT && emit)
     {
       DBG_fprintf(stderr, "Visu Box: emit SizeChanged.\n");
-      g_signal_emit(box, visu_box_signals[SIZE_CHANGED_SIGNAL],
+      g_signal_emit(box, signals[SIZE_CHANGED_SIGNAL],
                     0, box->priv->extens[1] + box->priv->margin, NULL);
       DBG_fprintf(stderr, "Visu Box: emission done (SizeChanged).\n");
     }
@@ -599,12 +743,12 @@ void visu_box_getCentre(VisuBox *box, float centre[3])
 {
   g_return_if_fail(VISU_IS_BOX(box));
 
-  centre[0] = 0.5f * (box->priv->cell[VISU_BOX_DXX] +
-                      box->priv->cell[VISU_BOX_DYX] +
-                      box->priv->cell[VISU_BOX_DZX]);
-  centre[1] = 0.5f * (box->priv->cell[VISU_BOX_DYY] +
-                      box->priv->cell[VISU_BOX_DZY]);
-  centre[2] = 0.5f * (box->priv->cell[VISU_BOX_DZZ]);
+  centre[0] = box->priv->origin[0] + 0.5f * (box->priv->cell[VISU_BOX_DXX] +
+                                             box->priv->cell[VISU_BOX_DYX] +
+                                             box->priv->cell[VISU_BOX_DZX]);
+  centre[1] = box->priv->origin[1] + 0.5f * (box->priv->cell[VISU_BOX_DYY] +
+                                             box->priv->cell[VISU_BOX_DZY]);
+  centre[2] = box->priv->origin[2] + 0.5f * (box->priv->cell[VISU_BOX_DZZ]);
 }
 
 /**
@@ -644,7 +788,7 @@ void visu_box_convertFullToCell(VisuBox *box, float cell[3], float full[3])
  *
  * Since: 3.7
  */
-void visu_box_convertXYZtoBoxCoordinates(VisuBox *box, float boxCoord[3], float xyz[3])
+void visu_box_convertXYZtoBoxCoordinates(const VisuBox *box, float boxCoord[3], float xyz[3])
 {
   int i, j;
 
@@ -654,7 +798,7 @@ void visu_box_convertXYZtoBoxCoordinates(VisuBox *box, float boxCoord[3], float
     {
       boxCoord[i] = 0.;
       for (j = 0; j < 3; j++)
-	boxCoord[i] += (float)box->priv->fromXYZtoBox[i][j] * xyz[j];
+	boxCoord[i] += (float)box->priv->fromXYZtoBox[i][j] * (xyz[j] - box->priv->origin[j]);
     }
 }
 /**
@@ -691,7 +835,7 @@ void visu_box_convertXYZToReduced(VisuBox *box, GArray *xyz,
  *
  * Since: 3.7
  */
-void visu_box_convertBoxCoordinatestoXYZ(VisuBox *box, float xyz[3], float boxCoord[3])
+void visu_box_convertBoxCoordinatestoXYZ(VisuBox *box, float xyz[3], const float boxCoord[3])
 {
   int i, j;
 
@@ -699,7 +843,7 @@ void visu_box_convertBoxCoordinatestoXYZ(VisuBox *box, float xyz[3], float boxCo
 
   for (i = 0; i < 3; i++)
     {
-      xyz[i] = 0.;
+      xyz[i] = box->priv->origin[i];
       for (j = 0; j < 3; j++)
 	xyz[i] += (float)box->priv->fromBoxtoXYZ[i][j] * boxCoord[j];
     }
@@ -789,8 +933,6 @@ void visu_box_getCellMatrix(VisuBox *box, double matrix[3][3])
  *
  * This method is a binding method for visu_box_getCellMatrix().
  *
- * Rename to: visu_box_getCellMatrix
- *
  * Since: 3.7
  */
 void visu_box_getCellMatrixv(VisuBox *box, double *m11, double *m12, double *m13,
@@ -835,7 +977,7 @@ gboolean visu_box_constrainInside(VisuBox *box, float translat[3], float xyz[3],
   gboolean moved;
   int k;
 
-  if (withExt)
+  if (withExt && box->priv->extActive)
     {
       bounds[0] = ceil(box->priv->extension[0]);
       bounds[1] = ceil(box->priv->extension[1]);
@@ -901,12 +1043,13 @@ gboolean visu_box_constrainInside(VisuBox *box, float translat[3], float xyz[3],
 void visu_box_getVertices(VisuBox *box, float v[8][3],
                           gboolean withExtension)
 {
+  int i;
   float transX[3], transY[3], transZ[3], ext[3];
   double *boxGeometry;
 
   g_return_if_fail(VISU_IS_BOX(box));
 
-  if (withExtension)
+  if (withExtension && box->priv->extActive)
     {
       ext[0] = box->priv->extension[0];
       ext[1] = box->priv->extension[1];
@@ -976,15 +1119,73 @@ void visu_box_getVertices(VisuBox *box, float v[8][3],
   v[7][0] = boxGeometry[3] + boxGeometry[1] - transX[0] + transY[0] + transZ[0];
   v[7][1] = boxGeometry[4] + boxGeometry[2] - transX[1] + transY[1] + transZ[1];
   v[7][2] = boxGeometry[5] + 0.f            - transX[2] + transY[2] + transZ[2];
+
+  for (i = 0; i < 8; i++)
+    {
+      v[i][0] += box->priv->origin[0];
+      v[i][1] += box->priv->origin[1];
+      v[i][2] += box->priv->origin[2];
+    }
   DBG_fprintf(stderr, " | done.\n");
 }
 
+/**
+ * visu_box_getExtensionActive:
+ * @box: a #VisuBox object.
+ *
+ * Retrieve if extensions are applied or not.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if extensions are applied.
+ **/
+gboolean visu_box_getExtensionActive(VisuBox *box)
+{
+  g_return_val_if_fail(VISU_IS_BOX(box), FALSE);
+  return box->priv->extActive;
+}
+/**
+ * visu_box_setExtensionActive:
+ * @box: a #VisuBox object.
+ * @status: a boolean.
+ *
+ * Change if extension values are used not not.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if status has changed.
+ **/
+gboolean visu_box_setExtensionActive(VisuBox *box, gboolean status)
+{
+  float oldExtens;
+
+  g_return_val_if_fail(VISU_IS_BOX(box), FALSE);
+
+  if (box->priv->extActive == status)
+    return FALSE;
+
+  box->priv->extActive = status;
+  g_object_notify_by_pspec(G_OBJECT(box), properties[USE_EXPAND_PROP]);
+
+  oldExtens = box->priv->extens[1];
+  box->priv->extens[1] = _getBoxExtens(box, TRUE);
+  if (box->priv->cell[0] != G_MAXFLOAT && box->priv->margin != G_MAXFLOAT &&
+      box->priv->extens[1] != oldExtens)
+    {
+      DBG_fprintf(stderr, "Visu Box: emit SizeChanged.\n");
+      g_signal_emit(box, signals[SIZE_CHANGED_SIGNAL],
+                    0, box->priv->extens[1] + box->priv->margin, NULL);
+      DBG_fprintf(stderr, "Visu Box: emission done (SizeChanged).\n");
+    }
+
+  return TRUE;
+}
 /**
  * visu_box_getExtension:
  * @boxObj: a #VisuBox object ;
  * @extension: (out) (array fixed-size=3): an allocated array to store the values.
  *
- * Using visu_data_replicate(), it is possible to duplicate the primitive box
+ * Using visu_box_setExtension(), it is possible to duplicate the primitive box
  * in each directions. Use this method to know the current extension. Returned
  * values are positive floating point values. An extension of 0. means that
  * only the primitive box exists, while a value of one means a duplication of
@@ -1005,11 +1206,7 @@ void visu_box_getExtension(const VisuBox *boxObj, float extension[3])
  * @boxObj: a #VisuBox object ;
  * @extension: (in) (array fixed-size=3): an allocated array to store the values.
  *
- * Using visu_data_replicate(), it is possible to duplicate the primitive box
- * in each directions. Use this method to know the current extension. Returned
- * values are positive floating point values. An extension of 0. means that
- * only the primitive box exists, while a value of one means a duplication of
- * one box in each direction of the coordinate.
+ * Change the duplication of the box in the three directions.
  *
  * Since: 3.7
  *
@@ -1017,27 +1214,30 @@ void visu_box_getExtension(const VisuBox *boxObj, float extension[3])
  */
 gboolean visu_box_setExtension(VisuBox *boxObj, float extension[3])
 {
+  float oldExtens;
+
   g_return_val_if_fail(VISU_IS_BOX(boxObj), FALSE);
 
   if (extension[0] == boxObj->priv->extension[0] &&
       extension[1] == boxObj->priv->extension[1] &&
       extension[2] == boxObj->priv->extension[2])
     return FALSE;
-
+  
   boxObj->priv->extension[0] = extension[0];
   boxObj->priv->extension[1] = extension[1];
   boxObj->priv->extension[2] = extension[2];
 
   DBG_fprintf(stderr, "Visu Box: emit ExtensionChanged.\n");
-  g_signal_emit(boxObj, visu_box_signals[EXTENSION_CHANGED_SIGNAL], 0, NULL);
+  g_object_notify_by_pspec(G_OBJECT(boxObj), properties[EXPAND_PROP]);
   DBG_fprintf(stderr, "Visu Box: emission done (ExtensionChanged).\n");
 
+  oldExtens = boxObj->priv->extens[1];
   boxObj->priv->extens[1] = _getBoxExtens(boxObj, TRUE);
-
-  if (boxObj->priv->cell[0] != G_MAXFLOAT && boxObj->priv->margin != G_MAXFLOAT)
+  if (boxObj->priv->cell[0] != G_MAXFLOAT && boxObj->priv->margin != G_MAXFLOAT &&
+      boxObj->priv->extens[1] != oldExtens)
     {
       DBG_fprintf(stderr, "Visu Box: emit SizeChanged.\n");
-      g_signal_emit(boxObj, visu_box_signals[SIZE_CHANGED_SIGNAL],
+      g_signal_emit(boxObj, signals[SIZE_CHANGED_SIGNAL],
                     0, boxObj->priv->extens[1] + boxObj->priv->margin, NULL);
       DBG_fprintf(stderr, "Visu Box: emission done (SizeChanged).\n");
     }
@@ -1056,7 +1256,7 @@ gboolean visu_box_setExtension(VisuBox *boxObj, float extension[3])
  *
  * Since: 3.7
  *
- * Returns: #G_MAXFLOAT on failure, otherwise a length for the biggest
+ * Returns: %G_MAXFLOAT on failure, otherwise a length for the biggest
  * diagonal distance of the box, with or without extension.
  **/
 float visu_box_getGlobalSize(VisuBox *box, gboolean withExt)
@@ -1112,12 +1312,12 @@ gboolean visu_box_setUnit(VisuBox *box, ToolUnits unit)
 
   unit_ = box->priv->units;
   box->priv->units = unit;
+  g_object_notify_by_pspec(G_OBJECT(box), properties[UNITS_PROP]);
 
   if (unit_ == TOOL_UNITS_UNDEFINED || unit == TOOL_UNITS_UNDEFINED)
     {
       DBG_fprintf(stderr, "Visu Box: emit UnitChanged.\n");
-      g_signal_emit(box, visu_box_signals[UNIT_CHANGED_SIGNAL],
-                    0, 1.f, NULL);
+      g_signal_emit(box, signals[UNIT_CHANGED_SIGNAL], 0, 1.f);
       DBG_fprintf(stderr, "Visu Box: emission done (UnitChanged).\n");
       return TRUE;
     }
@@ -1136,21 +1336,89 @@ gboolean visu_box_setUnit(VisuBox *box, ToolUnits unit)
   _setUpGeometry(box, FALSE);
 
   DBG_fprintf(stderr, "Visu Box: emit UnitChanged.\n");
-  g_signal_emit(box, visu_box_signals[UNIT_CHANGED_SIGNAL],
-		0, fact, NULL);
+  g_signal_emit(box, signals[UNIT_CHANGED_SIGNAL], 0, fact);
   DBG_fprintf(stderr, "Visu Box: emission done (UnitChanged).\n");
 
   if (box->priv->cell[0] != G_MAXFLOAT && box->priv->margin != G_MAXFLOAT)
     {
       DBG_fprintf(stderr, "Visu Box: emit SizeChanged.\n");
-      g_signal_emit(box, visu_box_signals[SIZE_CHANGED_SIGNAL],
-                    0, box->priv->extens[1] + box->priv->margin, NULL);
+      box->priv->margin *= fact;
+      g_signal_emit(box, signals[SIZE_CHANGED_SIGNAL],
+                    0, box->priv->extens[1] + box->priv->margin);
       DBG_fprintf(stderr, "Visu Box: emission done (SizeChanged).\n");
     }
 
   return TRUE;
 }
 
+/**
+ * visu_box_getInside:
+ * @box: a #VisuBox object.
+ * @vect: (array fixed-size=3) (inout): some cartesian coordinates.
+ * @ratio: a ratio in [0;1].
+ *
+ * Update @vect, taking into consideration the particular periodicity
+ * of @box, for @vect expressed in reduced coordinates to be within
+ * [-ratio;ratio].
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if vect is actually changed.
+ **/
+gboolean visu_box_getInside(VisuBox *box, float vect[3], float ratio)
+{
+  int i, j;
+  float red[3];
+  VisuBoxBoundaries bc;
+  gboolean mod;
+
+  g_return_val_if_fail(VISU_IS_BOX(box), FALSE);
+
+  mod = FALSE;
+
+  bc = box->priv->bc;
+  if (bc == VISU_BOX_FREE)
+    return mod;
+
+  /* DBG_fprintf(stderr, "Visu Box: transform %gx%gx%g into", red[0], red[1], red[2]); */
+  red[0] = 0.;
+  for (j = 0; j < 3; j++)
+    red[0] += (float)box->priv->fromXYZtoBox[0][j] * vect[j];
+  if (bc & TOOL_XYZ_MASK_X)
+    {
+      mod = (red[0] < -ratio || red[0] >= ratio);
+      while (red[0] >= ratio) red[0] -= 1.f;
+      while (red[0] < -ratio) red[0] += 1.f;
+    }
+
+  red[1] = 0.;
+  for (j = 0; j < 3; j++)
+    red[1] += (float)box->priv->fromXYZtoBox[1][j] * vect[j];
+  if (bc & TOOL_XYZ_MASK_Y)
+    {
+      mod = mod || (red[1] < -ratio || red[1] >= ratio);
+      while (red[1] >= ratio) red[1] -= 1.f;
+      while (red[1] < -ratio) red[1] += 1.f;
+    }
+
+  red[2] = 0.;
+  for (j = 0; j < 3; j++)
+    red[2] += (float)box->priv->fromXYZtoBox[2][j] * vect[j];
+  if (bc & TOOL_XYZ_MASK_Z)
+    {
+      mod = mod || (red[2] < -ratio || red[2] >= ratio);
+      while (red[2] >= ratio) red[2] -= 1.f;
+      while (red[2] < -ratio) red[2] += 1.f;
+    }
+  /* DBG_fprintf(stderr, " %gx%gx%g.\n", red[0], red[1], red[2]); */
+  for (i = 0; i < 3; i++)
+    {
+      vect[i] = 0.f;
+      for (j = 0; j < 3; j++)
+	vect[i] += (float)box->priv->fromBoxtoXYZ[i][j] * red[j];
+    }
+  return mod;
+}
 /**
  * visu_box_getPeriodicVector: (skip)
  * @box: a #VisuBox object.
@@ -1160,42 +1428,15 @@ gboolean visu_box_setUnit(VisuBox *box, ToolUnits unit)
  * account the periodicity.
  *
  * Since: 3.7
+ *
+ * Returns: %TRUE if @vect has been modified.
  **/
-void visu_box_getPeriodicVector(VisuBox *box, float vect[3])
+gboolean visu_box_getPeriodicVector(VisuBox *box, float vect[3])
 {
-  float red[3];
-  VisuBoxBoundaries bc;
-
-  g_return_if_fail(VISU_IS_BOX(box));
-
-  bc = box->priv->bc;
-  if (bc == VISU_BOX_FREE)
-    return;
-
-  visu_box_convertXYZtoBoxCoordinates(box, red, vect);
-  /* DBG_fprintf(stderr, "Visu Box: transform %gx%gx%g into", red[0], red[1], red[2]); */
-  if (bc != VISU_BOX_SURFACE_YZ)
-    {
-      while (red[0] >= 0.5f) red[0] -= 1.f;
-      while (red[0] < -0.5f) red[0] += 1.f;
-    }
-
-  if (bc != VISU_BOX_SURFACE_ZX)
-    {
-      while (red[1] >= 0.5f) red[1] -= 1.f;
-      while (red[1] < -0.5f) red[1] += 1.f;
-    }
-
-  if (bc != VISU_BOX_SURFACE_XY)
-    {
-      while (red[2] >= 0.5f) red[2] -= 1.f;
-      while (red[2] < -0.5f) red[2] += 1.f;
-    }
-  /* DBG_fprintf(stderr, " %gx%gx%g.\n", red[0], red[1], red[2]); */
-  visu_box_convertBoxCoordinatestoXYZ(box, vect, red);
+  return visu_box_getInside(box, vect, 0.5f);
 }
 /**
- * visu_box_getPeriodicVectorv:
+ * visu_box_getPeriodicVectorv: (rename-to visu_box_getPeriodicVector)
  * @box: a #VisuBox object.
  * @x: (out): the new x part.
  * @y: (out): the new y part.
@@ -1204,8 +1445,6 @@ void visu_box_getPeriodicVector(VisuBox *box, float vect[3])
  *
  * Equivalent of visu_box_getPeriodicVector() used for bindings.
  *
- * Rename to: visu_box_getPeriodicVector
- *
  * Since: 3.7
  **/
 void visu_box_getPeriodicVectorv(VisuBox *box, float *x, float *y, float *z,
@@ -1213,7 +1452,7 @@ void visu_box_getPeriodicVectorv(VisuBox *box, float *x, float *y, float *z,
 {
   g_return_if_fail(x && y && z);
 
-  visu_box_getPeriodicVector(box, vect);
+  visu_box_getInside(box, vect, 0.5f);
   *x = vect[0];
   *y = vect[1];
   *z = vect[2];
@@ -1238,7 +1477,114 @@ void visu_box_getPeriodicArray(VisuBox *box, float *array, guint nEle)
     visu_box_getPeriodicVector(box, array + i * 3);
   DBG_fprintf(stderr, " | done.\n");
 }
+
+/**
+ * visu_box_getHiddingStatus:
+ * @box: a #VisuBox object.
+ *
+ * Retrieves the masking status of @box.
+ *
+ * Since: 3.8
+ *
+ * Returns: the current masking status.
+ **/
+VisuBoxHiddingStatus visu_box_getHiddingStatus(const VisuBox *box)
+{
+  g_return_val_if_fail(VISU_IS_BOX(box), VISU_BOX_HIDE_NONE);
+
+  return box->priv->hidding;
+}
+/**
+ * visu_box_setHiddingStatus:
+ * @box: a #VisuBox object.
+ * @status: a status.
+ *
+ * Changes the masking status of @box for @status.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if the status is actually changed.
+ **/
+gboolean visu_box_setHiddingStatus(VisuBox *box, VisuBoxHiddingStatus status)
+{
+  g_return_val_if_fail(VISU_IS_BOX(box), FALSE);
+
+  if (box->priv->hidding == status)
+    return FALSE;
+
+  box->priv->hidding = status;
+  g_object_notify_by_pspec(G_OBJECT(box), properties[HIDDING_PROP]);
+
+  visu_node_masker_emitDirty(VISU_NODE_MASKER(box));
+  return TRUE;
+}
+
+/**
+ * visu_box_getVolume:
+ * @box: a #VisuBox object.
+ *
+ * Compute the volume of the box.
+ *
+ * Since: 3.8
+ *
+ * Returns: the box volume.
+ **/
+float visu_box_getVolume(const VisuBox *box)
+{
+  g_return_val_if_fail(VISU_IS_BOX(box), 0.f);
+
+  return box->priv->cell[VISU_BOX_DXX] * box->priv->cell[VISU_BOX_DYY]
+    * box->priv->cell[VISU_BOX_DZZ];
+}
+
 static VisuBox* _getBox(VisuBoxed *self)
 {
   return VISU_BOX(self);
 }
+static gboolean _maskApply(const VisuNodeMasker *self, VisuNodeArray *array)
+{
+  gboolean reDraw, outside;
+  float point[3], red[3];
+  VisuNodeArrayIter iter;
+  VisuBox *box;
+
+  g_return_val_if_fail(VISU_IS_BOX(self), FALSE);
+
+  box = VISU_BOX(self);
+
+  DBG_fprintf(stderr, "Visu Box: applying masking properties.\n");
+  if (!visu_box_getHiddingStatus(box))
+    return FALSE;
+
+  reDraw = FALSE;
+  /* We change the rendered attribute of all nodes, very expensive... */
+  visu_node_array_iter_new(array, &iter);
+  for (visu_node_array_iterStart(array, &iter); iter.element;
+       visu_node_array_iterNextElement(array, &iter, FALSE))
+    if (visu_element_getMaskable(iter.element) &&
+        visu_element_getRendered(iter.element))
+      {
+        DBG_fprintf(stderr, " | element '%s'\n", iter.element->name);
+        for (visu_node_array_iterRestartNode(array, &iter); iter.node;
+             visu_node_array_iterNextNode(array, &iter))
+          {
+            /* If node is already hiden, well, we go to the next. */
+            if (!iter.node->rendered)
+              continue;
+
+            visu_data_getNodePosition(VISU_DATA(array), iter.node, point);
+            visu_box_convertXYZtoBoxCoordinates(box, red, point);
+            outside = (red[0] < -box->priv->extension[0] ||
+                       red[1] < -box->priv->extension[1] ||
+                       red[2] < -box->priv->extension[2] ||
+                       red[0] >= 1.f + box->priv->extension[0] ||
+                       red[1] >= 1.f + box->priv->extension[1] ||
+                       red[2] >= 1.f + box->priv->extension[2]);
+            if ((box->priv->hidding == VISU_BOX_HIDE_OUTSIDE && outside) ||
+                (box->priv->hidding == VISU_BOX_HIDE_INSIDE && !outside))
+              reDraw = visu_node_setVisibility(iter.node, FALSE) || reDraw;
+            DBG_fprintf(stderr, " | node '%d' -> %d\n", iter.node->number, iter.node->rendered);
+          }
+      }
+  return reDraw;
+}
