@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -50,8 +50,11 @@
 #include "visu_tools.h"
 #include "visu_elements.h"
 #include "visu_nodes.h"
+#include "extraFunctions/nodeProp.h"
+#include "extraFunctions/stringProp.h"
 #include "visu_box.h"
 #include "iface_boxed.h"
+#include "iface_pointset.h"
 #include "coreTools/toolPhysic.h"
 #include "coreTools/toolFileFormat.h"
 
@@ -101,6 +104,12 @@ G_BEGIN_DECLS
 
 typedef struct _VisuDataPrivate VisuDataPrivate;
 typedef struct _VisuData VisuData;
+
+/**
+ * VisuData:
+ *
+ * Opaque structure for #VisuData objects.
+ */
 struct _VisuData
 {
   VisuNodeArray parent;
@@ -120,31 +129,6 @@ struct _VisuDataClass
   VisuNodeArrayClass parent;
 };
 
-/**
- * VisuDataColorFunc:
- * @visuData: a pointer to the calling object ;
- * @ele: a #VisuElement ;
- * @node: a #VisuNode ;
- * @rgba: (in) (array fixed-size=4): an 4 allocated float area to store the return values.
- *
- * This prototype is used to specify an optional method
- * to associate a color with external values to each node.
- *
- * Returns: TRUE if the node should take colour read in @rgba.
- */
-typedef gboolean (*VisuDataColorFunc)(VisuData *visuData, float rgba[4], VisuElement *ele, VisuNode* node);
-/**
- * VisuDataScalingFunc:
- * @visuData: a pointer to the calling object ;
- * @node: a #VisuNode ;
- *
- * Interface for routine that need to rescale @node before drawing
- * them.
- *
- * Returns: the scaling factor.
- */
-typedef float (*VisuDataScalingFunc)(VisuData *visuData, VisuNode* node);
-
 /**
  * visu_data_get_type:
  *
@@ -155,78 +139,41 @@ typedef float (*VisuDataScalingFunc)(VisuData *visuData, VisuNode* node);
 GType visu_data_get_type(void);
 
 VisuData* visu_data_new(void);
-VisuData* visu_data_new_withFiles(const gchar **files);
 void visu_data_freePopulation(VisuData *data);
 
-/* Methods to deal with file representation of VisuData objects. */
-void visu_data_addFile(VisuData *data, const gchar* file,
-                       int kind, ToolFileFormat *format);
-void visu_data_removeAllFiles(VisuData *data);
-const gchar* visu_data_getFile(VisuData *data, int kind,
-                               ToolFileFormat **format);
-gchar* visu_data_getFilesAsLabel(const VisuData *data);
-
-void visu_data_setFileCommentary(VisuData *data, gchar* commentary, gint iSet);
-gchar* visu_data_getFileCommentary(VisuData *data, gint iSet);
-
-void visu_data_setNSubset(VisuData *data, int nSet);
-int visu_data_getNSubset(VisuData *data);
-void visu_data_setISubset(VisuData *data, int iSet);
-int visu_data_getISubset(VisuData *data);
-
-void visu_data_setChangeElementFlag(VisuData *data, gboolean changeElement);
-gboolean visu_data_getChangeElementFlag(VisuData *data);
+void visu_data_setDescription(VisuData *data, const gchar* commentary);
+const gchar* visu_data_getDescription(const VisuData *data);
 
 gfloat visu_data_getAllNodeExtens(VisuData *dataObj, VisuBox *box);
 
 VisuNode* visu_data_addNodeFromElement(VisuData *data, VisuElement *ele,
-                                       float xyz[3], gboolean reduced,
-                                       gboolean emitSignal);
+                                       float xyz[3], gboolean reduced);
 VisuNode* visu_data_addNodeFromElementName(VisuData *data, const gchar *name,
-                                           float xyz[3], gboolean reduced,
-                                           gboolean emitSignal);
+                                           float xyz[3], gboolean reduced);
 VisuNode* visu_data_addNodeFromIndex(VisuData *data, guint position,
-                                     float xyz[3], gboolean reduced, gboolean emitSignal);
-
-void visu_data_setColorFunc(VisuData *data, VisuDataColorFunc func);
-gboolean visu_data_hasUserColorFunc(VisuData *data);
-gboolean visu_data_getUserColor(VisuData *data, VisuElement *ele,
-				VisuNode *node, float rgba[4]);
-
-float* visu_data_getXYZtranslation(VisuData* data);
-gboolean visu_data_setXYZtranslation(VisuData* data, float xyz[3]);
-gboolean visu_data_forceXYZtranslation(VisuData* data, float xyz[3]);
-gboolean visu_data_getTranslationStatus(VisuData *data);
+                                     float xyz[3], gboolean reduced);
 
 VisuBox* visu_data_setTightBox(VisuData *data);
 
 gboolean visu_data_getNodeBoxFromNumber(VisuData *data, guint nodeId, int nodeBox[3]);
 gboolean visu_data_getNodeBoxFromCoord(VisuData *data, float xcart[3], int nodeBox[3]);
 
-gboolean visu_data_constrainedElementInTheBox(VisuData *data, VisuElement *element);
-gboolean visu_data_constrainedInTheBox(VisuData *data);
-gboolean visu_data_constrainedFree(VisuData *data);
+void visu_data_getNodeCoordinates(VisuData *data, VisuNode *node, gboolean user, float *x, float *y, float *z);
+void visu_data_getNodePosition(const VisuData *data, const VisuNode *node, float coord[3]);
+void visu_data_getNodeUserPosition(const VisuData *data, const VisuNode *node, float coord[3]);
 
-gboolean visu_data_replicate(VisuData *data, float extension[3]);
-gboolean visu_data_restore(VisuData *data);
-
-void visu_data_getNodeCoordinates(VisuData *data, VisuNode *node, float *x, float *y, float *z);
-void visu_data_getNodePosition(VisuData *data, VisuNode *node, float coord[3]);
-void visu_data_getNodeUserPosition(VisuData *data, VisuNode *node, float coord[3]);
-
-
-VisuNodeInfo* visu_data_getDistanceList(VisuData *data, guint nodeId, float *minVal);
 gboolean visu_data_setNewBasisFromNodes(VisuData *data, guint nO, guint nA, guint nB, guint nC);
 gboolean visu_data_setNewBasis(VisuData *data, float matA[3][3], float O[3]);
-gboolean visu_data_reorder(VisuData *data, VisuData *dataRef);
+gboolean visu_data_reorder(VisuData *data, const VisuData *dataRef);
 
-void visu_data_setNodeScalingFunc(VisuData *data, VisuDataScalingFunc scaling);
-float visu_data_getNodeScalingFactor(VisuData *data, VisuNode *node);
+gboolean visu_data_addNodeProperties(VisuData *data, VisuNodeValues *values);
+gboolean visu_data_removeNodeProperties(VisuData *data, const gchar *label);
+GList* visu_data_getAllNodeProperties(VisuData *data);
+VisuNodeValues* visu_data_getNodeProperties(VisuData *data, const gchar *label);
+VisuNodeValuesString* visu_data_getNodeLabels(VisuData *data);
+const gchar* visu_data_getNodeLabelAt(const VisuData *data, const VisuNode *node);
 
-guint visu_data_addTimeout(VisuData *data, guint time, GSourceFunc func, gpointer user_data);
-gboolean visu_data_removeTimeout(VisuData *data, guint timeoutId);
-
-GList* visu_data_class_getAllObjects(void);
+gboolean visu_data_applyTransformationsFromCLI(VisuData *data, GError **error);
 
 G_END_DECLS
 
