@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -53,29 +53,6 @@
 
 G_BEGIN_DECLS
 
-/**
- * VisuDumpWriteFunc:
- * @format: a #ToolFileFormat object, corresponding to the write method ;
- * @fileName: a string that defined the file to write to ;
- * @width: an integer ;
- * @height: an integer.
- * @dataObj: the #VisuData to be exported ;
- * @image: the data to be written ;
- * @error: (allow-none): a location to store some error (not NULL) ;
- * @functionWait: (allow-none) (scope call): a method to call
- * periodically during the dump ;
- * @data: (closure): some pointer on object to be passed to the wait function.
- *
- * This is a prototype of a method implemented by a dumping extension that is called
- * when the current rendering must be dumped to a file.
- *
- * Returns: TRUE if everything went right.
- */
-typedef gboolean (*VisuDumpWriteFunc) (ToolFileFormat *format, const char* fileName,
-				       int width, int height, VisuData *dataObj,
-				       guchar* image, GError **error,
-				       ToolVoidDataFunc functionWait, gpointer data);
-
 /**
  * VISU_TYPE_DUMP:
  *
@@ -118,18 +95,22 @@ typedef gboolean (*VisuDumpWriteFunc) (ToolFileFormat *format, const char* fileN
  */
 #define VISU_DUMP_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS(obj, VISU_TYPE_DUMP, VisuDumpClass))
 
-/**
- * VisuDump:
- *
- * An opaque structure.
- */
 typedef struct _VisuDump VisuDump;
+struct _VisuDump
+{
+  ToolFileFormat parent;
+};
 /**
  * VisuDumpClass:
+ * @parent: the parent class.
  *
  * An opaque structure.
  */
 typedef struct _VisuDumpClass VisuDumpClass;
+struct _VisuDumpClass
+{
+  ToolFileFormatClass parent;
+};
 
 /**
  * visu_dump_get_type
@@ -141,11 +122,11 @@ typedef struct _VisuDumpClass VisuDumpClass;
 GType visu_dump_get_type(void);
 
 /**
- * VISU_ERROR_DUMP: (skip)
+ * VISU_DUMP_ERROR: (skip)
  *
  * Internal function for error handling.
  */
-#define VISU_ERROR_DUMP visu_dump_getQuark()
+#define VISU_DUMP_ERROR visu_dump_getQuark()
 GQuark visu_dump_getQuark();
 /**
  * VisuDumpErrorFlag:
@@ -175,22 +156,9 @@ typedef enum
  */
 typedef const VisuDump* (*VisuDumpInitFunc) ();
 
-VisuDump* visu_dump_new(const gchar* descr, const gchar** patterns,
-                        VisuDumpWriteFunc method, gboolean bitmap);
-void visu_dump_setHasAlpha(VisuDump *dump, gboolean hasAlpha);
-void visu_dump_setGl(VisuDump *dump, gboolean needGl);
-gboolean visu_dump_getBitmapStatus(VisuDump *dump);
-gboolean visu_dump_getGlStatus(VisuDump *dump);
-gboolean visu_dump_getAlphaStatus(VisuDump *dump);
-
-gboolean visu_dump_write(VisuDump *dump, const char* fileName,
-                         int width, int height, VisuData *dataObj,
-                         GArray* image, ToolVoidDataFunc functionWait,
-                         gpointer data, GError **error);
-
-
-GList* visu_dump_getAllModules();
+GList* visu_dump_pool_getAllModules();
 gint visu_dump_getNModules();
+void visu_dump_pool_finalize(void);
 
 /**
  * visu_dump_abort:
