@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -43,7 +43,6 @@
 */
 #include "visu_extension.h"
 #include "visu_configFile.h"
-#include "coreTools/toolConfigFile.h"
 #include "openGLFunctions/objectList.h"
 
 #include <stdlib.h>
@@ -90,13 +89,10 @@
 
 #define FLAG_PARAMETER_MODE "extension_render"
 #define DESC_PARAMETER_MODE "Rules the way OpenGl draws extensions (see opengl_render); name (string) value (string)"
-static gboolean readExtensionRendering(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
-				       VisuData *dataObj, VisuGlView *view,
-                                       GError **error);
-static void exportParametersRendering(GString *data, VisuData *dataObj, VisuGlView *view);
-
-/* Method used to compare the priority of two extensions. */
-static gint compareExtensionPriority(gconstpointer a, gconstpointer b);
+#define FLAG_RESOURCE_MODE "glExtension_render"
+#define DESC_RESOURCE_MODE "Rules the way OpenGl draws extensions (see gl_render); name (string) value (string)"
+static guint _rMode;
+static void exportRendering(GString *data, VisuData *dataObj);
 
 static void callList(GList *lst, VisuGlRenderingMode *renderingMode,
 		     VisuGlRenderingMode globalRenderingMode);
@@ -110,19 +106,12 @@ enum
     DESCRIPTION_PROP,
     PRIORITY_PROP,
     SAVE_STATE_PROP,
-    NGLOBJ_PROP
+    DIRTY_PROP,
+    NGLOBJ_PROP,
+    RMODE_PROP,
+    N_PROP
   };
-
-struct _VisuGlExtClassPrivate
-{
-  /* This flag is TRUE when some priorities are new or have changed, and 
-     the list should be reordered. */
-  gboolean reorderingNeeded;
-
-  /* A GList to store all the available OpenGL extensions
-     in the system. */
-  GList *allExtensions;
-};
+static GParamSpec *properties[N_PROP];
 
 struct _VisuGlExtPrivate
 {
@@ -138,6 +127,8 @@ struct _VisuGlExtPrivate
      the extension is refered by this int. */
   guint nGlObj;
   int objectListId;
+  /* Global translation to apply to the list before displaying. */
+  float trans[3];
 
   /* A priority for the extension. */
   guint priority;
@@ -147,17 +138,20 @@ struct _VisuGlExtPrivate
   gboolean saveState;
 
   /* Fine tune of rendering mode (VISU_GL_RENDERING_WIREFRAME, smooth...).
-     The flag isSensitiveToRenderingMode define is the
-     extension cares about rendering mode. This flag is FALSE
-     by default. When FALSE, the global value for rendering
+     When FOLLOW, the global value for rendering
      mode is used. Otherwise the value is stored in
      preferedRenderingMode. */
-  gboolean isSensitiveToRenderingMode;
   VisuGlRenderingMode preferedRenderingMode;
 
   /* A boolean to know if this extension is actually used
      or not. */
   gboolean used;
+  
+  /* Set to FALSE to skip draw calls. */
+  gboolean dirty;
+
+  /* The context with gl options the extension is drawing to. */
+  VisuGl *gl;
 };
 
 static VisuGlExtClass *my_class = NULL;
@@ -169,11 +163,14 @@ static void visu_gl_ext_get_property(GObject* obj, guint property_id,
 static void visu_gl_ext_set_property(GObject* obj, guint property_id,
                                      const GValue *value, GParamSpec *pspec);
 
-G_DEFINE_TYPE(VisuGlExt, visu_gl_ext, G_TYPE_OBJECT)
+static void onEntryMode(VisuGlExt *ext, VisuConfigFileEntry *entry, VisuConfigFile *obj);
+
+G_DEFINE_TYPE_WITH_CODE(VisuGlExt, visu_gl_ext, VISU_TYPE_OBJECT,
+                        G_ADD_PRIVATE(VisuGlExt))
 
 static void visu_gl_ext_class_init(VisuGlExtClass *klass)
 {
-  VisuConfigFileEntry *confEntry;
+  VisuConfigFileEntry *confEntry, *oldEntry;
 
   DBG_fprintf(stderr, "Visu Extension: creating the class of the object.\n");
   /* DBG_fprintf(stderr, "                - adding new signals ;\n"); */
@@ -183,8 +180,6 @@ static void visu_gl_ext_class_init(VisuGlExtClass *klass)
   G_OBJECT_CLASS(klass)->finalize = visu_gl_ext_finalize;
   G_OBJECT_CLASS(klass)->set_property = visu_gl_ext_set_property;
   G_OBJECT_CLASS(klass)->get_property = visu_gl_ext_get_property;
-  /* Default methods. */
-  klass->rebuild = NULL;
 
   /**
    * VisuGlExt::name:
@@ -205,10 +200,11 @@ static void visu_gl_ext_class_init(VisuGlExtClass *klass)
    *
    * Since: 3.7
    */
-  g_object_class_install_property
-    (G_OBJECT_CLASS(klass), ACTIVE_PROP,
-     g_param_spec_boolean("active", "Active", "extension is used or not", FALSE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+  properties[ACTIVE_PROP] = g_param_spec_boolean("active", "Active",
+                                                 "extension is used or not", FALSE,
+                                                 G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+  g_object_class_install_property(G_OBJECT_CLASS(klass), ACTIVE_PROP,
+                                  properties[ACTIVE_PROP]);
   /**
    * VisuGlExt::label:
    *
@@ -245,7 +241,8 @@ static void visu_gl_ext_class_init(VisuGlExtClass *klass)
                        VISU_GL_EXT_PRIORITY_BACKGROUND,
                        VISU_GL_EXT_PRIORITY_LAST,
                        VISU_GL_EXT_PRIORITY_NORMAL,
-                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+                       G_PARAM_CONSTRUCT | G_PARAM_READWRITE |
+                       G_PARAM_STATIC_STRINGS));
   /**
    * VisuGlExt::saveState:
    *
@@ -257,7 +254,8 @@ static void visu_gl_ext_class_init(VisuGlExtClass *klass)
   g_object_class_install_property
     (G_OBJECT_CLASS(klass), SAVE_STATE_PROP,
      g_param_spec_boolean("saveState", "Save state", "save OpenGL state", FALSE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+                          G_PARAM_CONSTRUCT | G_PARAM_READWRITE |
+                          G_PARAM_STATIC_STRINGS));
   /**
    * VisuGlExt::nGlObj:
    *
@@ -270,43 +268,71 @@ static void visu_gl_ext_class_init(VisuGlExtClass *klass)
      g_param_spec_uint("nGlObj", "N GL objects", "number of GL lists dealt with",
                        1, 2048, 1,
                        G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+  /**
+   * VisuGlExt::dirty:
+   *
+   * Rendering properties have changed and the object should be drawn again.
+   *
+   * Since: 3.8
+   */
+  properties[DIRTY_PROP] = g_param_spec_boolean("dirty", "Dirty", "object rendering is out of date",
+                                                FALSE, G_PARAM_READWRITE);
+  g_object_class_install_property(G_OBJECT_CLASS(klass), DIRTY_PROP, properties[DIRTY_PROP]);
+  /**
+   * VisuGlExt::rendering-mode:
+   *
+   * The specific rendering mode of the extension or follow global setting.
+   *
+   * Since: 3.8
+   */
+  properties[RMODE_PROP] = g_param_spec_uint("rendering-mode", "Rendering mode",
+                                             "specific rendering mode for the extension",
+                                             VISU_GL_RENDERING_WIREFRAME,
+                                             VISU_GL_RENDERING_FOLLOW,
+                                             VISU_GL_RENDERING_FOLLOW,
+                                             G_PARAM_READWRITE);
+  g_object_class_install_property(G_OBJECT_CLASS(klass), RMODE_PROP, properties[RMODE_PROP]);
   
-  klass->priv = g_malloc(sizeof(VisuGlExtClassPrivate));
-  klass->priv->reorderingNeeded = FALSE;
-  klass->priv->allExtensions = (GList*)0;
+  oldEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
+                                       FLAG_PARAMETER_MODE, DESC_PARAMETER_MODE, 1, NULL);
+  visu_config_file_entry_setVersion(oldEntry, 3.4f);
+  confEntry = visu_config_file_addEnumEntry(VISU_CONFIG_FILE_RESOURCE,
+                                            FLAG_RESOURCE_MODE,
+                                            DESC_RESOURCE_MODE,
+                                            &_rMode, visu_gl_rendering_getModeFromName, TRUE);
+  visu_config_file_entry_setVersion(confEntry, 3.8f);
+  visu_config_file_entry_setReplace(confEntry, oldEntry);
+  visu_config_file_addExportFunction(VISU_CONFIG_FILE_RESOURCE, exportRendering);
 
-  confEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
-                                       FLAG_PARAMETER_MODE,
-                                       DESC_PARAMETER_MODE,
-                                       1, readExtensionRendering);
-  visu_config_file_entry_setVersion(confEntry, 3.4f);
-  visu_config_file_addExportFunction(VISU_CONFIG_FILE_PARAMETER,
-                                     exportParametersRendering);
-
-  g_type_class_add_private(klass, sizeof(VisuGlExtPrivate));
+  klass->allExtensions = (GList*)0;
 
   my_class = klass;
 }
 
 static void visu_gl_ext_init(VisuGlExt *ext)
 {
-  VisuGlExtClass *klass;
-
   DBG_fprintf(stderr, "Visu Extension: initializing a new object (%p).\n",
 	      (gpointer)ext);
-  ext->priv = G_TYPE_INSTANCE_GET_PRIVATE(ext, VISU_TYPE_GL_EXT, VisuGlExtPrivate);
+  ext->priv = visu_gl_ext_get_instance_private(ext);
   ext->priv->dispose_has_run = FALSE;
 
   /* Set-up all not parameters attributes. */
   ext->priv->used = TRUE;
+  ext->priv->dirty = TRUE;
+  ext->priv->priority = VISU_GL_EXT_PRIORITY_NORMAL;
   ext->priv->objectListId = 0;
-  ext->priv->isSensitiveToRenderingMode = FALSE;
   ext->priv->preferedRenderingMode = VISU_GL_RENDERING_FOLLOW;
 
-  /* We add it to the known extension list. */
-  klass = VISU_GL_EXT_GET_CLASS(ext);
-  klass->priv->allExtensions = g_list_append(klass->priv->allExtensions, (gpointer)ext);
-  klass->priv->reorderingNeeded = TRUE;
+  ext->priv->trans[0] = 0.f;
+  ext->priv->trans[1] = 0.f;
+  ext->priv->trans[2] = 0.f;
+
+  ext->priv->gl = (VisuGl*)0;
+
+  g_signal_connect_object(VISU_CONFIG_FILE_RESOURCE, "parsed::" FLAG_RESOURCE_MODE,
+                          G_CALLBACK(onEntryMode), (gpointer)ext, G_CONNECT_SWAPPED);
+
+  my_class->allExtensions = g_list_append(my_class->allExtensions, (gpointer)ext);
 }
 
 /* This method can be called several times.
@@ -329,7 +355,6 @@ static void visu_gl_ext_dispose(GObject* obj)
 /* This method is called once only. */
 static void visu_gl_ext_finalize(GObject* obj)
 {
-  VisuGlExtClass *klass;
   VisuGlExtPrivate *ext;
 
   g_return_if_fail(obj);
@@ -345,8 +370,7 @@ static void visu_gl_ext_finalize(GObject* obj)
     g_free(ext->description);
   glDeleteLists(ext->objectListId, ext->nGlObj);
 
-  klass = VISU_GL_EXT_GET_CLASS(obj);
-  klass->priv->allExtensions = g_list_remove_all(klass->priv->allExtensions, (gpointer)obj);
+  my_class->allExtensions = g_list_remove_all(my_class->allExtensions, (gpointer)obj);
 
   /* Chain up to the parent class */
   DBG_fprintf(stderr, "Visu Extension: chain to parent.\n");
@@ -367,7 +391,10 @@ static void visu_gl_ext_get_property(GObject* obj, guint property_id,
       DBG_fprintf(stderr, "%s.\n", self->name);
       break;
     case LABEL_PROP:
-      g_value_set_string(value, self->nameI18n);
+      if (self->nameI18n && self->nameI18n[0])
+        g_value_set_string(value, self->nameI18n);
+      else
+        g_value_set_string(value, self->name);
       DBG_fprintf(stderr, "%s.\n", self->nameI18n);
       break;
     case DESCRIPTION_PROP:
@@ -390,6 +417,14 @@ static void visu_gl_ext_get_property(GObject* obj, guint property_id,
       g_value_set_uint(value, self->nGlObj);
       DBG_fprintf(stderr, "%d.\n", self->nGlObj);
       break;
+    case DIRTY_PROP:
+      g_value_set_boolean(value, self->dirty);
+      DBG_fprintf(stderr, "%d.\n", self->dirty);
+      break;
+    case RMODE_PROP:
+      g_value_set_uint(value, self->preferedRenderingMode);
+      DBG_fprintf(stderr, "%d.\n", self->preferedRenderingMode);
+      break;
     default:
       /* We don't have any other property... */
       G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
@@ -418,8 +453,9 @@ static void visu_gl_ext_set_property(GObject* obj, guint property_id,
       DBG_fprintf(stderr, "%s.\n", self->description);
       break;
     case ACTIVE_PROP:
-      self->used = g_value_get_boolean(value);
+      visu_gl_ext_setActive(VISU_GL_EXT(obj), g_value_get_boolean(value));
       DBG_fprintf(stderr, "%d.\n", self->used);
+      /* visu_gl_ext_draw(VISU_GL_EXT(obj)); */
       break;
     case SAVE_STATE_PROP:
       self->saveState = g_value_get_boolean(value);
@@ -427,7 +463,6 @@ static void visu_gl_ext_set_property(GObject* obj, guint property_id,
       break;
     case PRIORITY_PROP:
       self->priority = g_value_get_uint(value);
-      my_class->priv->reorderingNeeded = TRUE;
       DBG_fprintf(stderr, "%d.\n", self->priority);
       break;
     case NGLOBJ_PROP:
@@ -435,6 +470,14 @@ static void visu_gl_ext_set_property(GObject* obj, guint property_id,
       DBG_fprintf(stderr, "%d.\n", self->nGlObj);
       self->objectListId = visu_gl_objectlist_new(self->nGlObj);
       break;
+    case DIRTY_PROP:
+      DBG_fprintf(stderr, "%d.\n", self->nGlObj);
+      visu_gl_ext_setDirty(VISU_GL_EXT(obj), g_value_get_boolean(value));
+      break;
+    case RMODE_PROP:
+      DBG_fprintf(stderr, "%d.\n", g_value_get_uint(value));
+      visu_gl_ext_setPreferedRenderingMode(VISU_GL_EXT(obj), g_value_get_uint(value));
+      break;
     default:
       /* We don't have any other property... */
       G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, property_id, pspec);
@@ -442,6 +485,34 @@ static void visu_gl_ext_set_property(GObject* obj, guint property_id,
     }
 }
 
+/**
+ * visu_gl_ext_setDirty:
+ * @ext: a #VisuGlExt object.
+ * @status: a boolean.
+ *
+ * Set an internal flag to mark that @ext should be redrawn before
+ * next OpenGL frame view.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE is status is actually changed.
+ **/
+gboolean visu_gl_ext_setDirty(VisuGlExt *ext, gboolean status)
+{
+  g_return_val_if_fail(VISU_IS_GL_EXT(ext), FALSE);
+
+  /* It's an exception here, it's VisuGlExtSet that will ignore
+     redundant call to dirty status. */
+  if (ext->priv->dirty == status)
+    return FALSE;
+
+  DBG_fprintf(stderr, "Visu Extension: '%s' becomes dirty (%d).\n", ext->priv->name, status);
+  ext->priv->dirty = status;
+  if (status)
+    g_object_notify_by_pspec(G_OBJECT(ext), properties[DIRTY_PROP]);
+  return TRUE;
+}
+
 /**
  * visu_gl_ext_getActive:
  * @extension: the extension.
@@ -453,6 +524,8 @@ static void visu_gl_ext_set_property(GObject* obj, guint property_id,
  */
 gboolean visu_gl_ext_getActive(VisuGlExt* extension)
 {
+  g_return_val_if_fail(VISU_IS_GL_EXT(extension), FALSE);
+
   if (extension)
     return extension->priv->used;
   else
@@ -467,99 +540,50 @@ gboolean visu_gl_ext_getActive(VisuGlExt* extension)
  */
 gboolean visu_gl_ext_setActive(VisuGlExt* extension, gboolean value)
 {
-  g_return_val_if_fail(VISU_IS_GL_EXT_TYPE(extension), FALSE);
+  g_return_val_if_fail(VISU_IS_GL_EXT(extension), FALSE);
 
   if (extension->priv->used == value)
     return FALSE;
 
-  g_object_set(G_OBJECT(extension), "active", value, NULL);
+  DBG_fprintf(stderr, "Visu Extension: '%s' becomes active (%d).\n",
+              extension->priv->name, value);
+  extension->priv->used = value;
+  g_object_notify_by_pspec(G_OBJECT(extension), properties[ACTIVE_PROP]);
+
   return TRUE;
 }
 /**
- * visu_gl_ext_setPriority:
- * @extension: a #VisuGlExt object ;
- * @priority: an integer value.
- *
- * Extentions are drawn in an order that depends on their priority.
- * The lower is the number, the sooner the extension is drawn. Flags,
- * such as #VISU_GL_EXT_PRIORITY_NORMAL or #VISU_GL_EXT_PRIORITY_LOW,
- * can be used or user defined values are also possible.
- */
-void visu_gl_ext_setPriority(VisuGlExt* extension, guint priority)
-{
-  g_return_if_fail(VISU_IS_GL_EXT_TYPE(extension));
-
-  g_object_set(G_OBJECT(extension), "priority", priority, NULL);
-}
-
-/**
- * visu_gl_ext_setSaveState:
- * @extension: a #VisuGlExt object ;
- * @saveState: an boolean value.
- *
- * If the extension needs to change some OpenGL state (to disable the fog for example,
- * or the cullface), a flag should be set to enable V_Sim to restore the right values after
- * the extensio have been called. Because the OpenGL list of an extension is just GL_COMPILE
- * the extension can't just save and restore state itself because when the list is called,
- * the state can have been changed.
- */
-void visu_gl_ext_setSaveState(VisuGlExt *extension, gboolean saveState)
-{
-  g_return_if_fail(VISU_IS_GL_EXT_TYPE(extension));
-
-  g_object_set(G_OBJECT(extension), "saveState", saveState, NULL);
-}
-
-/**
- * visu_gl_ext_setSensitiveToRenderingMode:
- * @extension: a #VisuGlExt object ;
- * @status: an boolean value.
- *
- * If @status is TRUE, when the extension is rendered, OpenGL context is
- * switched to the rendering mode preferd for the extension. Use
- * visu_gl_ext_setPreferedRenderingMode() to choose one.
- */
-void visu_gl_ext_setSensitiveToRenderingMode(VisuGlExt* extension,
-                                                gboolean status)
-{
-  g_return_if_fail(extension);
-  extension->priv->isSensitiveToRenderingMode = status;
-}
-/**
- * visu_gl_ext_getSensitiveToRenderingMode:
+ * visu_gl_ext_getPriority:
  * @extension: a #VisuGlExt object.
  *
- * Each #VisuGlExt method can follow or not the global setting for
- * the rendering mode, see #VisuGlRenderingMode. See also
- * visu_gl_ext_setSensitiveToRenderingMode().
+ * Inquire the priority of @extension.
  *
- * Since: 3.7
+ * Since: 3.8
  *
- * Returns: TRUE if @extension can change its rendering mode according
- * to global settings.
- */
-gboolean visu_gl_ext_getSensitiveToRenderingMode(VisuGlExt* extension)
+ * Returns: the #VisuGlExt priority.
+ **/
+guint visu_gl_ext_getPriority(VisuGlExt *extension)
 {
-  g_return_val_if_fail(VISU_IS_GL_EXT_TYPE(extension), FALSE);
-  return extension->priv->isSensitiveToRenderingMode;
+  g_return_val_if_fail(VISU_IS_GL_EXT(extension), VISU_GL_EXT_PRIORITY_BACKGROUND);
+
+  return extension->priv->priority;
 }
+
 /**
  * visu_gl_ext_setPreferedRenderingMode:
  * @extension: a #VisuGlExt object ;
  * @value: see #VisuGlRenderingMode to choose one.
  *
  * This method is used to specify the rendering mode that the extension should use
- * to be drawn (if the sensitive flag has been set, see
- * visu_gl_ext_setSensitiveToRenderingMode()). If the @value is set
- * to VISU_GL_RENDERING_FOLLOW, the extension follows the global setting
- * for rendering mode.
+ * to be drawn. If the @value is set to #VISU_GL_RENDERING_FOLLOW, the
+ * extension follows the global setting for rendering mode.
  *
- * Returns: TRUE if the "OpenGLAskForReDraw" should be emitted.
+ * Returns: TRUE if value is actually changed.
  */
 gboolean visu_gl_ext_setPreferedRenderingMode(VisuGlExt* extension,
-                                                 VisuGlRenderingMode value)
+                                              VisuGlRenderingMode value)
 {
-  g_return_val_if_fail(VISU_IS_GL_EXT_TYPE(extension), FALSE);
+  g_return_val_if_fail(VISU_IS_GL_EXT(extension), FALSE);
   g_return_val_if_fail(value < VISU_GL_RENDERING_N_MODES ||
 		       value == VISU_GL_RENDERING_FOLLOW, FALSE);
 
@@ -567,6 +591,7 @@ gboolean visu_gl_ext_setPreferedRenderingMode(VisuGlExt* extension,
     return FALSE;
 
   extension->priv->preferedRenderingMode = value;
+  g_object_notify_by_pspec(G_OBJECT(extension), properties[RMODE_PROP]);
 
   return TRUE;
 }
@@ -584,7 +609,7 @@ gboolean visu_gl_ext_setPreferedRenderingMode(VisuGlExt* extension,
  **/
 VisuGlRenderingMode visu_gl_ext_getPreferedRenderingMode(VisuGlExt* extension)
 {
-  g_return_val_if_fail(VISU_IS_GL_EXT_TYPE(extension), VISU_GL_RENDERING_FOLLOW);
+  g_return_val_if_fail(VISU_IS_GL_EXT(extension), VISU_GL_RENDERING_FOLLOW);
   return extension->priv->preferedRenderingMode;
 }
 /**
@@ -600,58 +625,40 @@ VisuGlRenderingMode visu_gl_ext_getPreferedRenderingMode(VisuGlExt* extension)
  **/
 guint visu_gl_ext_getGlList(VisuGlExt *extension)
 {
-  g_return_val_if_fail(VISU_IS_GL_EXT_TYPE(extension), 0);
+  g_return_val_if_fail(VISU_IS_GL_EXT(extension), 0);
   return extension->priv->objectListId;
 }
+/**
+ * visu_gl_ext_setTranslation:
+ * @extension: a #VisuGlExt method.
+ * @trans: (array fixed-size=3): a translation vector in real space.
+ *
+ * Change the translation the extension is drawn at.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if the translations are indeed changed.
+ **/
+gboolean visu_gl_ext_setTranslation(VisuGlExt *extension, const gfloat trans[3])
+{
+  g_return_val_if_fail(VISU_IS_GL_EXT(extension), FALSE);
+
+  if (extension->priv->trans[0] == trans[0] &&
+      extension->priv->trans[1] == trans[1] &&
+      extension->priv->trans[2] == trans[2])
+    return FALSE;
+
+  extension->priv->trans[0] = trans[0];
+  extension->priv->trans[1] = trans[1];
+  extension->priv->trans[2] = trans[2];
+
+  return TRUE;
+}
 
 /********************/
 /* Class functions. */
 /********************/
 
-/**
- * visu_gl_ext_getFromName:
- * @name: a string identifying a #VisuGlExt object.
- *
- * #VisuGlExt objects are identified by an id.
- *
- * Since: 3.7
- *
- * Returns: (transfer none): a #VisuGlExt object matching @name.
- **/
-VisuGlExt* visu_gl_ext_getFromName(const gchar* name)
-{
-  GList *pnt;
-  VisuGlExt *ext;
-
-  DBG_fprintf(stderr, "Visu Extension: get '%s' from list.\n", name);
-
-  if (!my_class)
-    g_type_class_ref(VISU_TYPE_GL_EXT);
-
-  for (pnt = my_class->priv->allExtensions; pnt; pnt = g_list_next(pnt))
-    {
-      ext = (VisuGlExt*)pnt->data;
-      if (!strcmp(ext->priv->name, name))
-	return ext;
-    }
-  return (VisuGlExt*)0;
-}
-
-static void mayReorder()
-{
-  if (!my_class)
-    g_type_class_ref(VISU_TYPE_GL_EXT);
-
-  if (my_class->priv->reorderingNeeded)
-    {
-      DBG_fprintf(stderr, "Visu Extension: sorting known extension"
-                  " depending on their priority.\n");
-      my_class->priv->allExtensions = g_list_sort(my_class->priv->allExtensions,
-                                                  compareExtensionPriority);
-      my_class->priv->reorderingNeeded = FALSE;
-    }
-}
-
 /**
  * visu_gl_ext_call:
  * @extension: a #VisuGlExt object.
@@ -669,52 +676,42 @@ void visu_gl_ext_call(VisuGlExt *ext, gboolean lastOnly)
   VisuGlRenderingMode renderingMode, globalRenderingMode;
   GList lst;
 
-  g_return_if_fail(VISU_IS_GL_EXT_TYPE(ext));
+  g_return_if_fail(VISU_IS_GL_EXT(ext));
   /* DBG_fprintf(stderr, "Visu Extension: call '%s' list.\n", ext->priv->name); */
   /* DBG_fprintf(stderr, "|  has %d ref counts.\n", G_OBJECT(ext)->ref_count); */
 
-  globalRenderingMode = visu_gl_rendering_getGlobalMode();
-  renderingMode = globalRenderingMode;
-  if (ext->priv->used &&
-      ((lastOnly && ext->priv->priority == VISU_GL_EXT_PRIORITY_LAST) ||
-       (!lastOnly && ext->priv->priority < VISU_GL_EXT_PRIORITY_LAST)) &&
-      ext->priv->objectListId > 1000)
+  if (!ext->priv->used || ext->priv->objectListId < 1000)
+    return;
+
+  if ((lastOnly && ext->priv->priority == VISU_GL_EXT_PRIORITY_LAST) ||
+      (!lastOnly && ext->priv->priority < VISU_GL_EXT_PRIORITY_LAST))
     {
+      /* Rebuild it if necessary. */
+      if (VISU_GL_EXT_GET_CLASS(ext)->draw && ext->priv->dirty)
+        VISU_GL_EXT_GET_CLASS(ext)->draw(ext);
+      globalRenderingMode = visu_gl_getMode(ext->priv->gl);
+      renderingMode = globalRenderingMode;
       lst.data = (gpointer)ext;
       lst.next = lst.prev = (GList*)0;
+      glTranslatef(ext->priv->trans[0], ext->priv->trans[1], ext->priv->trans[2]);
       callList(&lst, &renderingMode, globalRenderingMode);
+      glTranslatef(-ext->priv->trans[0], -ext->priv->trans[1], -ext->priv->trans[2]);
       if (renderingMode != globalRenderingMode)
 	/* Return the rendering mode to normal. */
 	visu_gl_rendering_applyMode(globalRenderingMode);
     }
 }
-/**
- * visu_gl_ext_rebuildAll:
- *
- * For each registered extension that has a valid rebuild method,
- * it calls it.
- */
-void visu_gl_ext_rebuildAll()
-{
-  GList *pnt;
-
-  mayReorder();
-
-  DBG_fprintf(stderr, "Visu Extension: Rebuilding all lists...\n");
-  for (pnt = my_class->priv->allExtensions; pnt; pnt = g_list_next(pnt))
-    visu_gl_ext_rebuild(VISU_GL_EXT(pnt->data));
-}
 /**
  * visu_gl_ext_rebuild:
  * @self: a #VisuGlExt object.
  *
  * This routine does not sort the extension on their priority and
- * should be used only to draw some selected extensions. To draw all
- * of them, use visu_gl_ext_rebuildAll() instead.
+ * should be used only to draw some selected extensions. This method
+ * is called automatically for all extensions in a #VisuGlExtSet when required.
  */
 void visu_gl_ext_rebuild(VisuGlExt *self)
 {
-  g_return_if_fail(VISU_IS_GL_EXT_TYPE(self));
+  g_return_if_fail(VISU_IS_GL_EXT(self));
 
   DBG_fprintf(stderr, "Visu Extension: rebuilding '%s' list.\n", self->priv->name);
 
@@ -722,21 +719,113 @@ void visu_gl_ext_rebuild(VisuGlExt *self)
     VISU_GL_EXT_GET_CLASS(self)->rebuild(self);
 }
 /**
- * visu_gl_ext_getAll:
+ * visu_gl_ext_setGlView:
+ * @ext: a #VisuGlExt object.
+ * @view: a #VisuGlView object.
  *
- * This method is used to get the list of all registered VisuGlExt.
- * This list is own by V_Sim and should not be freed.
+ * Attach a @view to the @self extension.
  *
- * Returns: (element-type VisuGlExt*) (transfer none): the list of
- * all #VisuGlExt.
+ * Since: 3.8
+ *
+ * Returns: TRUE if the @view is changed.
  */
-GList* visu_gl_ext_getAll(void)
+gboolean visu_gl_ext_setGlView(VisuGlExt *ext, VisuGlView *view)
 {
-  mayReorder();
+  g_return_val_if_fail(VISU_IS_GL_EXT(ext), FALSE);
 
-  return my_class->priv->allExtensions;
+  DBG_fprintf(stderr, "Visu Extension: set view %p to '%s' (%d).\n",
+              (gpointer)view, ext->priv->name, ext->priv->used);
+
+  return (VISU_GL_EXT_GET_CLASS(ext)->setGlView &&
+          VISU_GL_EXT_GET_CLASS(ext)->setGlView(ext, view));
 }
 
+/**
+ * visu_gl_ext_getGlContext:
+ * @extension: a #VisuGlExt object.
+ *
+ * The #VisuGl object this extension draws to.
+ *
+ * Since: 3.8
+ *
+ * Returns: (transfer none) (allow-none): the #VisuGl object this
+ * extension draws to.
+ **/
+VisuGl* visu_gl_ext_getGlContext(VisuGlExt* extension)
+{
+  g_return_val_if_fail(VISU_IS_GL_EXT(extension), (VisuGl*)0);
+  return extension->priv->gl;
+}
+/**
+ * visu_gl_ext_setGlContext:
+ * @extension: a #VisuGlExt object.
+ * @gl: (transfer none): a #VisuGl object.
+ *
+ * Associate @gl to @extension.
+ *
+ * Since: 3.8
+ *
+ * Returns: TRUE if the value is actually changed.
+ **/
+gboolean visu_gl_ext_setGlContext(VisuGlExt* extension, VisuGl *gl)
+{
+  g_return_val_if_fail(VISU_IS_GL_EXT(extension), FALSE);
+  if (extension->priv->gl == gl)
+    return FALSE;
+  extension->priv->gl = gl;
+  return TRUE;
+}
+
+/**
+ * visu_gl_ext_getName:
+ * @extension: a #VisuGlExt object.
+ *
+ * Retrieve the name of the extension.
+ *
+ * Since: 3.8
+ *
+ * Returns: the name of the extension.
+ **/
+const gchar* visu_gl_ext_getName(const VisuGlExt *extension)
+{
+  g_return_val_if_fail(VISU_IS_GL_EXT(extension), (const gchar*)0);
+  
+  return extension->priv->name;
+}
+
+/**
+ * visu_gl_ext_startDrawing:
+ * @extension: a #VisuGlExt object.
+ *
+ * Method to be called in the draw function to start compiling the
+ * list. Wghen drawing primitives are all done, call
+ * visu_gl_ext_completeDrawing().
+ *
+ * Since: 3.8
+ **/
+void visu_gl_ext_startDrawing(VisuGlExt *extension)
+{
+  g_return_if_fail(VISU_IS_GL_EXT(extension));
+  
+  glNewList(extension->priv->objectListId, GL_COMPILE);
+}
+/**
+ * visu_gl_ext_completeDrawing:
+ * @extension: a #VisuGlExt object.
+ *
+ * A method to be called after calling visu_gl_ext_startDrawing(),
+ * when the drawing primitives have all been called. It also reset the
+ * dirty flag for this extension.
+ *
+ * Since: 3.8
+ **/
+void visu_gl_ext_completeDrawing(VisuGlExt *extension)
+{
+  g_return_if_fail(VISU_IS_GL_EXT(extension));
+  
+  visu_gl_ext_setDirty(extension, FALSE);
+  glEndList();
+}
 
 /****************/
 /* Private area */
@@ -757,8 +846,7 @@ static void callList(GList *lst, VisuGlRenderingMode *renderingMode,
     {
       ext = (VisuGlExt*)lst->data;
       /* The extension needs its own rendering mode. */
-      if (ext->priv->isSensitiveToRenderingMode &&
-	  ext->priv->preferedRenderingMode < VISU_GL_RENDERING_N_MODES)
+      if (ext->priv->preferedRenderingMode < VISU_GL_RENDERING_N_MODES)
 	{
 	  if (ext->priv->preferedRenderingMode != *renderingMode)
 	    {
@@ -781,7 +869,7 @@ static void callList(GList *lst, VisuGlRenderingMode *renderingMode,
 	  glPushAttrib(GL_ENABLE_BIT);
 	}
 
-      if (ext->priv->isSensitiveToRenderingMode &&
+      if (ext->priv->preferedRenderingMode < VISU_GL_RENDERING_N_MODES &&
           *renderingMode == VISU_GL_RENDERING_SMOOTH_AND_EDGE)
         {
           glPushAttrib(GL_ENABLE_BIT);
@@ -790,15 +878,15 @@ static void callList(GList *lst, VisuGlRenderingMode *renderingMode,
         }
 
       /* Call the compiled list. */
-      DBG_fprintf(stderr, "Visu Extension: call list %d (%s)",
-                  ext->priv->objectListId, ext->priv->name);
+      DBG_fprintf(stderr, "Visu Extension: call list %d (%s %d)",
+                  ext->priv->objectListId, ext->priv->name, ext->priv->used);
       glCallList(ext->priv->objectListId);
       DBG_fprintf(stderr, " at %g micro-s",
                   g_timer_elapsed(timer, &fractionTimer)*1e6);
       DBG_fprintf(stderr, ".\n");
 
       /* Add a wireframe draw if renderingMode is VISU_GL_RENDERING_SMOOTH_AND_EDGE. */
-      if (ext->priv->isSensitiveToRenderingMode &&
+      if (ext->priv->preferedRenderingMode < VISU_GL_RENDERING_N_MODES &&
           *renderingMode == VISU_GL_RENDERING_SMOOTH_AND_EDGE)
         {
           glDisable(GL_POLYGON_OFFSET_FILL);
@@ -824,52 +912,14 @@ static void callList(GList *lst, VisuGlRenderingMode *renderingMode,
 #endif
 }
 
-static gint compareExtensionPriority(gconstpointer a, gconstpointer b)
+static void onEntryMode(VisuGlExt *ext, VisuConfigFileEntry *entry, VisuConfigFile *obj _U_)
 {
-  if (((VisuGlExt*)a)->priv->priority < ((VisuGlExt*)b)->priv->priority)
-    return (gint)-1;
-  else if (((VisuGlExt*)a)->priv->priority > ((VisuGlExt*)b)->priv->priority)
-    return (gint)+1;
-  else
-    return (gint)0;
+  if (strcmp(ext->priv->name, visu_config_file_entry_getLabel(entry)))
+    return;
+
+  visu_gl_ext_setPreferedRenderingMode(ext, _rMode);
 }
-
-static gboolean readExtensionRendering(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
-				       VisuData *dataObj _U_, VisuGlView *view _U_,
-                                       GError **error)
-{
-  gchar **val;
-  VisuGlExt *ext;
-  VisuGlRenderingMode id;
-  
-  g_return_val_if_fail(nbLines == 1, FALSE);
-
-  if (!tool_config_file_readString(lines[0], position, &val, 2, FALSE, error))
-    return FALSE;
-  ext = visu_gl_ext_getFromName(val[0]);
-  if (!ext)
-    {
-      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_VALUE,
-			   _("Parse error at line %d: the extension"
-			     " '%s' is unknown.\n"), position, val[0]);
-      g_strfreev(val);
-      return FALSE;
-    }
-  if (!visu_gl_rendering_getModeFromName(val[1], &id))
-    {
-      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_VALUE,
-			   _("Parse error at line %d: the rendering mode"
-			     " '%s' is unknown.\n"), position, val[1]);
-      g_strfreev(val);
-      return FALSE;
-    }
-  g_strfreev(val);
-  visu_gl_ext_setPreferedRenderingMode(ext, id);
-
-  return TRUE;
-}
-static void exportParametersRendering(GString *data,
-                                      VisuData *dataObj _U_, VisuGlView *view _U_)
+static void exportRendering(GString *data, VisuData *dataObj _U_)
 {
   GList *tmp;
   VisuGlExt *ext;
@@ -878,16 +928,15 @@ static void exportParametersRendering(GString *data,
   if (!my_class)
     g_type_class_ref(VISU_TYPE_GL_EXT);
 
-  g_string_append_printf(data, "# %s\n", DESC_PARAMETER_MODE);
+  visu_config_file_exportComment(data, DESC_RESOURCE_MODE);
 
   names = visu_gl_rendering_getAllModes();
-  for (tmp = my_class->priv->allExtensions; tmp; tmp = g_list_next(tmp))
+  for (tmp = my_class->allExtensions; tmp; tmp = g_list_next(tmp))
     {
       ext = (VisuGlExt*)tmp->data;
-      if (ext->priv->isSensitiveToRenderingMode &&
-	  ext->priv->preferedRenderingMode < VISU_GL_RENDERING_N_MODES)
-	g_string_append_printf(data, "%s: %s %s\n", FLAG_PARAMETER_MODE,
-			       ext->priv->name, names[ext->priv->preferedRenderingMode]);
+      if (ext->priv->preferedRenderingMode < VISU_GL_RENDERING_N_MODES)
+        visu_config_file_exportEntry(data, FLAG_RESOURCE_MODE, ext->priv->name,
+                                     "%s", names[ext->priv->preferedRenderingMode]);
     }
-  g_string_append_printf(data, "\n");
+  visu_config_file_exportComment(data, "");
 }
