@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -50,9 +50,8 @@
 #include "visu_plugins.h"
 #include "visu_gtk.h"
 #include "gtk_main.h"
-#include "visu_data.h"
+#include "visu_dataloadable.h"
 #include "extensions/scale.h"
-#include "renderingMethods/renderingSpin.h"
 #include "gtk_renderingWindowWidget.h"
 
 #include <unistd.h>
@@ -62,9 +61,6 @@
 #include <locale.h>
 #include <glib.h>
 
-#ifdef WITH_GOBJECT_INTROSPECTION
-#include <girepository.h>
-#endif
 #ifdef HAVE_GTKGLEXT
 #include <gdk/gdkgl.h>
 #endif
@@ -75,26 +71,28 @@ int main (int argc, char *argv[])
 {
   int res;
   char *arg;
-  VisuData *newData;
+  VisuDataLoadable *newData;
   gchar *dirname, *normDir;
-#ifdef WITH_GOBJECT_INTROSPECTION
   GError *error;
-#endif
   gboolean GUIerror;
   VisuUiRenderingWindow *window;
 
 #if DEBUG == 1 && VISU_MEM_CHECK == 1
   g_mem_set_vtable(glib_mem_profiler_table);
 #endif
+#if GLIB_MAJOR_VERSION < 2 || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION < 36)
   g_type_init();
+#endif
 
   DBG_fprintf(stderr, "--- Get the default path ---\n");
   visu_basic_setExePath(argv[0]);
 
 #ifdef G_THREADS_ENABLED
   DBG_fprintf(stderr, "--- Initialise threads ---\n");
+#if GLIB_MAJOR_VERSION < 2 || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION < 32)
   g_thread_init(NULL);
 #endif
+#endif
 
 #ifdef ENABLE_NLS
   setlocale (LC_ALL, "");
@@ -125,7 +123,13 @@ int main (int argc, char *argv[])
 #endif
 
       DBG_fprintf(stderr,"--- Initialising plugins ---\n");
-      visu_plugins_init();
+      error = (GError*)0;
+      visu_plugins_init(&error);
+      if (error)
+        {
+          g_message("Plugin error: %s", error->message);
+          g_error_free(error);
+        }
 
       DBG_fprintf(stderr, "Visu Main: test for help message.\n");
       if (visu_basic_showOptionHelp(FALSE))
@@ -137,33 +141,6 @@ int main (int argc, char *argv[])
 
       return res;
     }
-
-  /* Introspection case, must be called after g_object initialisation. */
-  if (commandLineGet_introspect())
-    {
-#ifdef WITH_GOBJECT_INTROSPECTION
-      /* Additional classes. */
-      g_type_class_ref(VISU_TYPE_RENDERING);
-      g_type_class_ref(VISU_TYPE_DATA);
-      g_type_class_ref(VISU_TYPE_GL_EXT_SCALE);
-      g_type_class_ref(VISU_TYPE_GL_EXT_MARKS);
-      g_type_class_ref(VISU_UI_TYPE_RENDERING_WINDOW);
-      g_type_class_ref(VISU_UI_TYPE_MAIN);
-
-      DBG_fprintf(stderr, "Visu Main: call introspection for file '%s'.\n",
-		  commandLineGet_introspect());
-      error = (GError*)0;
-      g_irepository_dump(commandLineGet_introspect(), &error);
-      if (error)
-	{
-	  g_error("%s", error->message);
-	  g_error_free(error);
-	}
-      return 0;
-#else
-      g_warning("Introspection required but not compiled.");
-#endif
-    }
   g_return_val_if_fail(GUIerror, 1);
 
   gtk_window_set_default_icon_name("v_sim");
@@ -178,7 +155,6 @@ int main (int argc, char *argv[])
   /* 38713o still allocated by GLIB and GTK. */
 
   visu_basic_init();
-  visu_gl_initGraphics();
 
   /* the default is V_Sim with gtk interface. */
   if (!strcmp(commandLineGet_windowMode(), "renderOnly"))
@@ -191,13 +167,13 @@ int main (int argc, char *argv[])
   if (visu_basic_showOptionHelp(FALSE))
     exit(0);
 
-  newData = visu_basic_setDataFromCommandLine();
+  newData = visu_data_loadable_new_fromCLI();
   if (newData)
     {
-      dirname = g_path_get_dirname(visu_data_getFile(newData, FILE_KIND_POSITION,
-						    (ToolFileFormat**)0));
+      dirname = g_path_get_dirname(visu_data_loadable_getFilename(newData, 0));
       normDir = tool_path_normalize(dirname);
-      visu_ui_setLastOpenDirectory((char*)normDir, VISU_UI_DIR_FILE);
+      visu_ui_main_setLastOpenDirectory(visu_ui_main_class_getCurrentPanel(),
+                                        (char*)normDir, VISU_UI_DIR_FILE);
       g_free(dirname);
       g_free(normDir);
 
@@ -208,30 +184,31 @@ int main (int argc, char *argv[])
 	g_idle_add(visu_ui_runCommandLine, (gpointer)0);
       else
 	{
-	  g_idle_add(visu_ui_main_initPanels, (gpointer)0);
+	  g_idle_add(visu_ui_main_initPanels, visu_ui_main_class_getCurrentPanel());
 	  g_idle_add(visu_ui_main_runCommandLine, (gpointer)visu_ui_getPanel());
 	}
     }
   else
     {
-      visu_ui_rendering_window_setData(window, (VisuData*)0);
+      visu_gl_node_scene_setData(visu_ui_rendering_window_getGlScene(window), (VisuData*)0);
 
       /* Run the command line. */
       if (strcmp(commandLineGet_windowMode(), "renderOnly"))
-	g_idle_add(visu_ui_main_initPanels, (gpointer)0);
+	g_idle_add(visu_ui_main_initPanels, visu_ui_main_class_getCurrentPanel());
     }
 
   DBG_fprintf(stderr, "Visu Main: starting main GTK loop.\n");
   gtk_main();
   DBG_fprintf(stderr, "Visu Main: quit main GTK loop.\n");
 
-  visu_plugins_free();
   visu_basic_freeAll();
   commandLineFree_all();
 
 #if DEBUG == 1
+#if GLIB_MAJOR_VERSION < 2 || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION < 46)
   g_mem_profile();
 #endif
-
+#endif
+  
   return 0;
 }
