@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -104,9 +104,6 @@ struct _VisuPlugin
 /* Local variables. */
 GList *presentPlugins = NULL;
 
-/* Local methods. */
-static gboolean visuPluginLoad_byPath(const gchar* path);
-
 /**
  * visu_plugins_getListLoaded:
  *
@@ -118,12 +115,12 @@ static gboolean visuPluginLoad_byPath(const gchar* path);
 GList* visu_plugins_getListLoaded()
 {
   if (!presentPlugins)
-    visu_plugins_init();
+    visu_plugins_init(NULL);
 
   return presentPlugins;
 }
 
-static gboolean visuPluginLoad_byPath(const gchar* path)
+static gboolean visuPluginLoad_byPath(const gchar* path, GError **error)
 {
   gchar *func, *name, *ptChar, *libname;
   VisuPlugin *plugin;
@@ -149,8 +146,9 @@ static gboolean visuPluginLoad_byPath(const gchar* path)
       g_free(func);
       if (!res)
 	{
-	  g_warning("The plugin '%s' doesn't have any %sInit() method.",
-		    name, name);
+          g_set_error(error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
+                      "The plugin '%s' doesn't have any %sInit() method.",
+                      name, name);
 	  g_free(plugin);
 	  g_free(name);
 	  return FALSE;
@@ -160,8 +158,9 @@ static gboolean visuPluginLoad_byPath(const gchar* path)
       g_free(func);
       if (!res)
 	{
-	  g_warning("The plugin '%s' doesn't have any %sGet_description() method.",
-		    name, name);
+          g_set_error(error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
+                      "The plugin '%s' doesn't have any %sGet_description() method.",
+                      name, name);
 	  g_free(plugin);
 	  g_free(name);
 	  return FALSE;
@@ -171,8 +170,9 @@ static gboolean visuPluginLoad_byPath(const gchar* path)
       g_free(func);
       if (!res)
 	{
-	  g_warning("The plugin '%s' doesn't have any %sGet_authors() method.",
-		    name, name);
+          g_set_error(error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
+                      "The plugin '%s' doesn't have any %sGet_authors() method.",
+                      name, name);
 	  g_free(plugin);
 	  g_free(name);
 	  return FALSE;
@@ -198,8 +198,9 @@ static gboolean visuPluginLoad_byPath(const gchar* path)
     }
   else
     {
-      g_warning("The plugin '%s' is not a loadable module, error:\n%s.",
-		path, g_module_error());
+      g_set_error(error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
+                  "The plugin '%s' is not a loadable module, error:\n%s.",
+                  path, g_module_error());
       g_free(plugin);
       return FALSE;
     }
@@ -275,15 +276,16 @@ static gchar** visuPluginsGet_installedPlugins()
 
 /**
  * visu_plugins_init:
+ * @error: an error location.
  *
  * Initialise this part of code. Should not be called (called once
  * by V_Sim on startup only). It try to load
  * all plugins found in the installation directory and in the user directory.
  */
-void visu_plugins_init()
+void visu_plugins_init(GError **error)
 {
   gchar **plugins;
-  gboolean res;
+  GError *perr;
   int i;
 
   if (g_module_supported() && !presentPlugins)
@@ -293,9 +295,13 @@ void visu_plugins_init()
 	{
 	  DBG_fprintf(stderr, "Visu Plugins : try to load the plugin '%s'.\n",
 		      plugins[i]);
-	  res = visuPluginLoad_byPath(plugins[i]);
-	  if (res)
+          perr = (GError*)0;
+	  if (visuPluginLoad_byPath(plugins[i], &perr))
 	    ((VisuPlugin*)presentPlugins->data)->init();
+          if ((!error || !*error) && perr)
+            g_propagate_error(error, perr);
+          else
+            g_clear_error(&perr);
 	}
       g_strfreev(plugins);
     }
