@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -42,7 +42,6 @@
 	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
 */
 #include "visu_tools.h"
-#include "visu_object.h"
 
 #include <string.h>
 #include <stdio.h>
@@ -73,6 +72,10 @@ gchar* tool_getValidPath(GList **pathList, const char **filenames, int accessMod
   int fileOk;
   guint i;
 
+  g_return_val_if_fail(pathList && filenames, (gchar*)0);
+  
+  DBG_fprintf(stderr, "Visu Tools : test access (%d) from list of %d elements.\n",
+              accessMode, g_list_length(*pathList));
   validPath = (char*)0;
   /* look for a directory to save or read a file. */
   fileOk = 0;
@@ -98,7 +101,8 @@ gchar* tool_getValidPath(GList **pathList, const char **filenames, int accessMod
           DBG_fprintf(stderr, " failed.\n");
           g_free(validPath);
         }
-      *pathList = g_list_next(*pathList);
+      if (!fileOk)
+        *pathList = g_list_next(*pathList);
     }
   if (fileOk)
     {
@@ -183,13 +187,11 @@ gchar* tool_path_normalize(const gchar* path)
       /* Token[i] is a valid chain, then we prepend it to the list. */
       lst = g_list_prepend(lst, tokens[i]);
     }
-    /* Write the lst to the string. */
-    tmplst = lst;
-  while(tmplst)
+  /* Write the lst to the string. */
+  for (tmplst = lst; tmplst; tmplst = g_list_next(tmplst))
     {
       g_string_prepend(normPath, (gchar*)tmplst->data);
       g_string_prepend(normPath, FILE_SYSTEM_SEP);
-      tmplst = g_list_next(tmplst);
     }
   g_list_free(lst);
 #if SYSTEM_WIN32 == 1
