@@ -2,21 +2,21 @@
 	Copyright CEA, contributeurs : Luc BILLARD et Damien
 	CALISTE, laboratoire L_Sim, (2001-2005)
   
-	Adresse ml :
-	BILLARD, non joignable par ml ;
+	Adresse mèl :
+	BILLARD, non joignable par mèl ;
 	CALISTE, damien P caliste AT cea P fr.
 
-	Ce logiciel est un programme informatique servant  visualiser des
+	Ce logiciel est un programme informatique servant à visualiser des
 	structures atomiques dans un rendu pseudo-3D. 
 
-	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
+	Ce logiciel est régi par la licence CeCILL soumise au droit français et
 	respectant les principes de diffusion des logiciels libres. Vous pouvez
 	utiliser, modifier et/ou redistribuer ce programme sous les conditions
-	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
+	de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 	sur le site "http://www.cecill.info".
 
-	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
-	pris connaissance de la licence CeCILL, et que vous en avez accept les
+	Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
+	pris connaissance de la licence CeCILL, et que vous en avez accepté les
 	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
 */
 
@@ -52,6 +52,8 @@
 #include <glib.h>
 #include <glib-object.h>
 
+#include "coreTools/toolDbg.h"
+
 G_BEGIN_DECLS
 
 #ifndef DEBUG
@@ -59,6 +61,21 @@ G_BEGIN_DECLS
 #endif
 #define DBG_fprintf if(DEBUG) (void)fprintf
 
+#if DEBUG == 1
+#define VisuObject ToolDbgObj
+#define VisuObjectClass ToolDbgObjClass
+#define VISU_TYPE_OBJECT TOOL_TYPE_DBG_OBJ
+#else
+#define VisuObject GObject
+#define VisuObjectClass GObjectClass
+#define VISU_TYPE_OBJECT G_TYPE_OBJECT
+#endif
+
+#define VISU_DECLARE_CONST(ModuleObjName, module_obj_name, MODULE, OBJ_NAME) \
+  static inline const ModuleObjName * MODULE##_##OBJ_NAME##_CONST (gconstpointer ptr) {    \
+    return G_TYPE_CHECK_INSTANCE_CAST (ptr, module_obj_name##_get_type (), ModuleObjName); } \
+
+
 #ifdef ENABLE_NLS
 #  include <libintl.h>
 #  undef _
